(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     22224,        732]*)
(*NotebookOutlinePosition[     29628,        953]*)
(*  CellTagsIndexPosition[     29264,        935]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[{
  StyleBox["QDENSITY",
    FontSlant->"Italic"],
  "\nBasics of Cluster Model "
}], "Title",
  CellTags->"c:1"],

Cell["Cluster State computations, basics", "Subtitle"],

Cell[TextData[{
  "Last Version:18-Aug-2005\n",
  Cell[BoxData[
      FormBox[GridBox[{
            {\(\(References\)\(:\)\), \(\([1]\)\ R . \ 
                  Raussendorf\ and\ H . \ J . \ Briegel, \ 
              Phys . \ Rev . \ Lett . \ 86\ \((2001)\)\ 5188\n
              \([2]\)\ R . \ Raussendorf, \ 
              D . \ Brownie\ and\ H . J . \ Briegel, \ \n
              Phys . \ Rev . \ A\ 68, \ 022312\ \((2003)\)\n
              \([2]\)\ Michael\ I . \ Nielsen, \ quant - ph/0504097\n
              \([3]\)\ QDENSITY\ manual, \ Sect . \ 11\)}
            },
          ColumnAlignments->{Right, Left}], TraditionalForm]], 
    "DefinitionBox",
    GridBoxOptions->{RowSpacings->0.4,
    RowLines->False},
    CellTags->"S5.1.1"]
}], "Abstract"],

Cell[CellGroupData[{

Cell["Cluster State basics:", "Section",
  FontFamily->"Times",
  CellTags->"c:2"],

Cell[TextData[StyleBox["Uses the Qdensity package:",
  FontFamily->"Helvetica"]], "Text",
  FontFamily->"Courier New"],

Cell[BoxData[
    \(Needs["\<QDENSITY`Qdensity`\>"]\)], "Input",
  CellTags->"b:14.0"],

Cell["?QDENSITY`Qdensity`*", "Input"],

Cell[TextData[{
  StyleBox["Access the QDENSpalette it by clicking here: ",
    FontFamily->"Helvetica"],
  ButtonBox["QDENSpalette.nb",
    ButtonData:>{"QDENSpalette.nb", None},
    ButtonStyle->"Hyperlink"]
}], "Text",
  FontFamily->"Courier New",
  CellTags->"b:14.0"],

Cell[CellGroupData[{

Cell["Discard Theorem", "Subsection",
  CellFrame->True,
  FontFamily->"Times",
  CellTags->{"b:5.0.0", "c:3"}],

Cell[TextData[StyleBox["We set the number of Qubits to 2",
  FontWeight->"Plain",
  Background->None,
  FontVariations->{"CompatibilityType"->0}]], "Text",
  FontFamily->"Helvetica"],

Cell[BoxData[
    \(\(nqx = 2;\)\)], "Input"],

Cell[TextData[StyleBox["Decide whether the computation will be carried out \
numerically (icalc=0) or \nalgebraically (icalc=1)",
  FontWeight->"Plain",
  Background->None,
  FontVariations->{"CompatibilityType"->0}]], "Text",
  FontFamily->"Helvetica"],

Cell[BoxData[
    \(Icalc = 0\)], "Input"],

Cell[BoxData[{
    \(\(figure1 = 
        Import["\<drawings/discard1.png\>", "\<PNG\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(figure2 = 
        Import["\<drawings/discard2.png\>", "\<PNG\>"];\)\), "\
\[IndentingNewLine]", 
    \(Show[figure1]\), "\[IndentingNewLine]", 
    \(\(Show[figure2];\)\)}], "Input"],

Cell[TextData[StyleBox["We'll show that the two circuits in the figures are \
equivalent:\nThe unknown qubit one, will be generated at Random:", \
"DisplayText",
  FontWeight->"Plain",
  Background->None,
  FontVariations->{"CompatibilityType"->0}]], "Text",
  FontFamily->"Helvetica",
  CellTags->"b:5.0.0"],

Cell[BoxData[
    \(\[Rho] = RandomQubit1\)], "Input",
  CellTags->"b:5.0.0"],

Cell[BoxData[{
    \(\(If\ [
        Icalc == 1, \[Rho]1 = \ \((A*Ket[0] + 
                B*Ket[1])\)\[CircleTimes]Adj[\((A*Ket[0] + 
                  B*Ket[1])\)], \[Rho]1 = \[Rho]];\)\), \
"\[IndentingNewLine]", 
    \(\[Rho]1\)}], "Input",
  CellTags->"b:5.0.0"],

Cell[TextData[StyleBox["The second one is in the |+\[RightAngleBracket] \
state, its density matrix is thus:", "DisplayText",
  FontWeight->"Plain",
  Background->None,
  FontVariations->{"CompatibilityType"->0}]], "Text",
  FontFamily->"Helvetica",
  CellTags->"b:5.0.0"],

Cell[BoxData[
    \(\[Rho]2 = KetX[0]\[CircleTimes]BraX[0]\)], "Input",
  CellTags->"b:5.0.0"],

Cell[TextData[StyleBox["The initial state is therefore:", "DisplayText",
  FontWeight->"Plain",
  Background->None,
  FontVariations->{"CompatibilityType"->0}]], "Text",
  FontFamily->"Helvetica",
  CellTags->"b:5.0.0"],

Cell[BoxData[
    \(\[Rho]12 = \[Rho]1\ \[CircleTimes]\ \[Rho]2\)], "Input",
  CellTags->"b:5.0.0"],

Cell[TextData[StyleBox["We perform the control phase operation between the \
two qubits,", "DisplayText",
  FontWeight->"Plain",
  Background->None,
  FontVariations->{"CompatibilityType"->0}]], "Text",
  FontFamily->"Helvetica",
  CellTags->"b:5.0.0"],

Cell[BoxData[
    \(\[Rho]CP = 
      Chop[\ CPHASE[2, 1, 2] . \[Rho]12 . Adj[CPHASE[2, 1, 2]]]\)], "Input",
  CellTags->"b:5.0.0"],

Cell[TextData[StyleBox["Now we measure the second Qubit, in the Z basis:", \
"DisplayText",
  FontWeight->"Plain",
  Background->None,
  FontVariations->{"CompatibilityType"->0}]], "Text",
  FontFamily->"Helvetica",
  CellTags->"b:5.0.0"],

Cell[BoxData[{
    \(\(P\_a_ := \[DoubleStruckCapitalI]\[CircleTimes]\ \[ScriptCapitalP]\_a;\
\)\), "\[IndentingNewLine]", 
    \(\[Rho]M[a_]\  := Chop[PTr[{2}, \ 2*P\_a . \[Rho]CP . P\_a]]\)}], "Input",\

  CellTags->"b:5.0.0"],

Cell[TextData[StyleBox["The two possible remaining density matrices for Qubit \
one are,", "DisplayText",
  FontWeight->"Plain",
  Background->None,
  FontVariations->{"CompatibilityType"->0}]], "Text",
  FontFamily->"Helvetica",
  CellTags->"b:5.0.0"],

Cell[BoxData[{
    \(\[Rho]M[0]\), "\[IndentingNewLine]", 
    \(\[Rho]M[1]\)}], "Input",
  CellTags->"b:5.0.0"],

Cell[TextData[{
  StyleBox["The ", "DisplayText",
    FontWeight->"Plain",
    Background->None,
    FontVariations->{"CompatibilityType"->0}],
  StyleBox["second Circuit", "DisplayText",
    FontWeight->"Bold",
    Background->None,
    FontVariations->{"CompatibilityType"->0}],
  StyleBox[" is simply:", "DisplayText",
    FontWeight->"Plain",
    Background->None,
    FontVariations->{"CompatibilityType"->0}]
}], "Text",
  FontFamily->"Helvetica",
  CellTags->"b:5.0.0"],

Cell[BoxData[{
    \(\(\[Rho]M2C[a_] := \ 
        MatrixPower[\[Sigma]\_3, a] . \[Rho]1 . 
          Adj[MatrixPower[\[Sigma]\_3, a]];\)\), "\[IndentingNewLine]", 
    \(Chop[\[Rho]M2C[0]]\), "\[IndentingNewLine]", 
    \(Chop[\[Rho]M2C[1]]\)}], "Input",
  CellTags->"b:5.0.0"]
}, Closed]],

Cell[CellGroupData[{

Cell["Identity Gate with 3 qubits", "Subsection",
  CellFrame->True,
  FontFamily->"Times",
  CellTags->{"b:5.0.0", "c:4"}],

Cell[TextData[StyleBox["We set the number of Qubits to 3",
  FontWeight->"Plain",
  Background->None,
  FontVariations->{"CompatibilityType"->0}]], "Text",
  FontFamily->"Helvetica"],

Cell[BoxData[
    \(\(nqx = 3;\)\)], "Input"],

Cell[TextData[StyleBox["Decide whether the computation will be carried out \
numerically (icalc=0) or \nalgebraically (icalc=1)",
  FontWeight->"Plain",
  Background->None,
  FontVariations->{"CompatibilityType"->0}]], "Text",
  FontFamily->"Helvetica"],

Cell[BoxData[
    \(Icalc = 0\)], "Input"],

Cell[BoxData[{
    \(\(figure1 = 
        Import["\<drawings/ClusterI3q.png\>", "\<PNG\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(Show[figure1];\)\)}], "Input"],

Cell[TextData[{
  StyleBox["We'll show that the circuit in the figure is equivalent to doing \
nothing on qubit 1.\nThe", "DisplayText",
    FontWeight->"Plain",
    Background->None,
    FontVariations->{"CompatibilityType"->0}],
  StyleBox[" unknown qubit one", "DisplayText",
    FontWeight->"Bold",
    Background->None,
    FontVariations->{"CompatibilityType"->0}],
  StyleBox[", will be generated at Random:", "DisplayText",
    FontWeight->"Plain",
    Background->None,
    FontVariations->{"CompatibilityType"->0}]
}], "Text",
  FontFamily->"Helvetica",
  CellTags->"b:5.0.0"],

Cell[BoxData[
    \(\[Rho] = RandomQubit1\)], "Input",
  CellTags->"b:5.0.0"],

Cell[BoxData[{
    \(\(If\ [
        Icalc == 1, \[Rho]1 = \ \((A*Ket[0] + 
                B*Ket[1])\)\[CircleTimes]Adj[\((A*Ket[0] + 
                  B*Ket[1])\)], \[Rho]1 = \[Rho]];\)\), \
"\[IndentingNewLine]", 
    \(\[Rho]1\)}], "Input",
  CellTags->"b:5.0.0"],

Cell[TextData[{
  StyleBox["The ", "DisplayText",
    FontWeight->"Plain",
    Background->None,
    FontVariations->{"CompatibilityType"->0}],
  StyleBox["second and third ones are in the |+\[RightAngleBracket] state", 
    "DisplayText",
    FontWeight->"Bold",
    Background->None,
    FontVariations->{"CompatibilityType"->0}],
  StyleBox[", its density matrix are thus:", "DisplayText",
    FontWeight->"Plain",
    Background->None,
    FontVariations->{"CompatibilityType"->0}]
}], "Text",
  FontFamily->"Helvetica",
  CellTags->"b:5.0.0"],

Cell[BoxData[{
    \(\[Rho]2 = KetX[0]\[CircleTimes]BraX[0]\), "\[IndentingNewLine]", 
    \(\[Rho]3 = KetX[0]\[CircleTimes]BraX[0]\)}], "Input",
  CellTags->"b:5.0.0"],

Cell[TextData[{
  StyleBox["The ", "DisplayText",
    FontWeight->"Plain",
    Background->None,
    FontVariations->{"CompatibilityType"->0}],
  StyleBox["initial state", "DisplayText",
    FontWeight->"Bold",
    Background->None,
    FontVariations->{"CompatibilityType"->0}],
  StyleBox[" i", "DisplayText",
    Background->None,
    FontVariations->{"CompatibilityType"->0}],
  StyleBox["s therefo", "DisplayText",
    Background->None,
    FontVariations->{"CompatibilityType"->0}],
  StyleBox["re:", "DisplayText",
    FontWeight->"Plain",
    Background->None,
    FontVariations->{"CompatibilityType"->0}]
}], "Text",
  FontFamily->"Helvetica",
  CellTags->"b:5.0.0"],

Cell[BoxData[
    \(\[Rho]123 = \((\[Rho]1\ \[CircleTimes]\ \[Rho]2)\)\[CircleTimes]\[Rho]3\
\)], "Input",
  CellTags->"b:5.0.0"],

Cell[TextData[StyleBox["We perform the control phase operation between the \
three qubits,", "DisplayText",
  FontWeight->"Plain",
  Background->None,
  FontVariations->{"CompatibilityType"->0}]], "Text",
  FontFamily->"Helvetica",
  CellTags->"b:5.0.0"],

Cell[BoxData[{
    \(\(CPOp = 
        CPHASE[3, 1, 2] . CPHASE[3, 2, 3];\)\), "\[IndentingNewLine]", 
    \(\[Rho]CP = Chop[\ CPOp . \[Rho]123 . Adj[CPOp]]\)}], "Input",
  CellTags->"b:5.0.0"],

Cell[TextData[{
  StyleBox["Now we ", "DisplayText",
    FontWeight->"Plain",
    Background->None,
    FontVariations->{"CompatibilityType"->0}],
  StyleBox["measure the first and second Qubits, in the X basis:", 
    "DisplayText",
    FontWeight->"Bold",
    Background->None,
    FontVariations->{"CompatibilityType"->0}]
}], "Text",
  FontFamily->"Helvetica",
  CellTags->"b:5.0.0"],

Cell[BoxData[{
    \(\(P\_\(a_, b_\) := \((PX[a]\[CircleTimes]PX[
                b])\)\[CircleTimes]\[DoubleStruckCapitalI];\)\), "\
\[IndentingNewLine]", 
    \(\[Rho]M[a_, b_]\  := 
      Chop[PTr[{1, 2}, \ 
          2^2*P\_\(a, b\) . \[Rho]CP . P\_\(a, b\)]]\)}], "Input",
  CellTags->"b:5.0.0"],

Cell[TextData[StyleBox["The gate is realized up to a prefactor depending on \
the measurements which is of the form:", "DisplayText",
  FontWeight->"Plain",
  Background->None,
  FontVariations->{"CompatibilityType"->0}]], "Text",
  FontFamily->"Helvetica",
  CellTags->"b:5.0.0"],

Cell[BoxData[
    \(Prefactor[a_, b_] := 
      MatrixPower[s[1], b] . MatrixPower[s[3], a]\)], "Input",
  CellTags->"b:5.0.0"],

Cell[TextData[{
  StyleBox["The action of the ",
    FontWeight->"Plain",
    Background->None,
    FontVariations->{"CompatibilityType"->0}],
  StyleBox["prefactor",
    FontWeight->"Bold",
    Background->None,
    FontVariations->{"CompatibilityType"->0}],
  StyleBox[" can removed performing:",
    FontWeight->"Plain",
    Background->None,
    FontVariations->{"CompatibilityType"->0}]
}], "Text",
  FontFamily->"Helvetica",
  CellTags->"b:5.0.0"],

Cell[BoxData[
    \(\[Rho]Final[a_, b_] := 
      Prefactor[a, b] . \[Rho]M[a, b] . Adj[Prefactor[a, b]]\)], "Input"],

Cell[TextData[StyleBox["We can then plot the four possible outcomes, which \
should all give the matrix, \nirrespective of the measured values at this \
point:",
  FontWeight->"Plain",
  Background->None,
  FontVariations->{"CompatibilityType"->0}]], "Text",
  FontFamily->"Helvetica",
  CellTags->"b:5.0.0"],

Cell[BoxData[{
    \(Chop[\[Rho]Final[0, 0]]\), "\[IndentingNewLine]", 
    \(Chop[\[Rho]Final[1, 0]]\), "\[IndentingNewLine]", 
    \(Chop[\[Rho]Final[0, 1]]\), "\[IndentingNewLine]", 
    \(Chop[\[Rho]Final[1, 1]]\)}], "Input"],

Cell[TextData[{
  StyleBox["The Identity", "DisplayText",
    FontWeight->"Plain",
    Background->None,
    FontVariations->{"CompatibilityType"->0}],
  StyleBox[" Circuit", "DisplayText",
    FontWeight->"Bold",
    Background->None,
    FontVariations->{"CompatibilityType"->0}],
  StyleBox[" is simply:", "DisplayText",
    FontWeight->"Plain",
    Background->None,
    FontVariations->{"CompatibilityType"->0}]
}], "Text",
  FontFamily->"Helvetica",
  CellTags->"b:5.0.0"],

Cell[BoxData[
    \(\[Rho]1\)], "Input",
  CellTags->"b:5.0.0"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["An example of CNOT gate in the cluster model approach", "Section",
  FontFamily->"Times",
  CellTags->"c:5"],

Cell[BoxData[
    \(Needs["\<QDENSITY`Qdensity`\>"]\)], "Input",
  CellTags->"b:14.0"],

Cell["?QDENSITY`Qdensity`*", "Input"],

Cell[CellGroupData[{

Cell["Step 1: Build the cluster state", "Subsection",
  CellFrame->True,
  FontFamily->"Times",
  CellTags->{"b:4.0.0", "c:6"}],

Cell[TextData[StyleBox["The diagrammatic representation of the gate, as in \
Ref.[1], is :", "DisplayText",
  FontWeight->"Plain",
  Background->None,
  FontVariations->{"CompatibilityType"->0}]], "Text",
  FontFamily->"Helvetica",
  CellTags->"b:4.0.0"],

Cell[BoxData[{
    \(\(figure = 
        Import["\<drawings/CNOTc4qubits.png\>", "\<PNG\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(Show[figure];\)\)}], "Input",
  CellTags->"b:4.0.0"],

Cell[TextData[StyleBox["Icalc controls whether the qubits are handeld \
algebraically (1) or numerically (0):", "DisplayText",
  FontWeight->"Plain",
  Background->None,
  FontVariations->{"CompatibilityType"->0}]], "Text",
  FontFamily->"Helvetica",
  CellTags->"b:4.0.0"],

Cell[BoxData[
    \(\(Icalc = 0;\)\)], "Input",
  CellTags->"b:4.0.0"],

Cell[TextData[StyleBox["Set total number of qubits to 4:",
  FontWeight->"Plain",
  Background->None,
  FontVariations->{"CompatibilityType"->0}]], "Text",
  FontFamily->"Helvetica",
  CellTags->"b:4.0.0"],

Cell[BoxData[
    \(\(nq = 4;\)\)], "Input",
  CellTags->"b:4.0.0"],

Cell[TextData[StyleBox["The figure tells us that qubits 2 and 3 are in |+\
\[RightAngleBracket] state while qubits 1 (target) and 4 (control) are in \na \
general 1 qubit state:",
  FontWeight->"Plain",
  Background->None,
  FontVariations->{"CompatibilityType"->0}]], "Text",
  FontFamily->"Helvetica",
  CellTags->"b:4.0.0"],

Cell[BoxData[{
    \(\(ket1 = RandomKet1;\)\), "\[IndentingNewLine]", 
    \(\(ket4 = RandomKet1;\)\), "\[IndentingNewLine]", 
    \(\(If\ [Icalc \[Equal] 1, ket1 = Ket1[\[Theta]\_1, \[Phi]\_1]; 
        ket4 = Ket1[\[Theta]\_4, \[Phi]\_4]];\)\), "\[IndentingNewLine]", 
    \(ket1\), "\[IndentingNewLine]", 
    \(ket4\)}], "Input",
  CellTags->"b:4.0.0"],

Cell[TextData[StyleBox["The structure of the Cluster is essentially described \
in ClusterLinks, which \ncontains the pairs of CPHASE interacting qubits:",
  FontWeight->"Plain",
  Background->None,
  FontVariations->{"CompatibilityType"->0}]], "Text",
  FontFamily->"Helvetica",
  CellTags->"b:4.0.0"],

Cell[BoxData[{
    \(NCS = nq\), "\[IndentingNewLine]", 
    \(\(ClusterLinks = {{1, 2}, {2, 3}, {2, 4}};\)\), "\[IndentingNewLine]", 
    \(Nlinks = Length[ClusterLinks]\)}], "Input",
  CellTags->"b:4.0.0"],

Cell[TextData[StyleBox["The 4 qubit initial state before building in the \
correlations is:",
  FontWeight->"Plain",
  Background->None,
  FontVariations->{"CompatibilityType"->0}]], "Text",
  FontFamily->"Helvetica",
  CellTags->"b:4.0.0"],

Cell[BoxData[{
    \(InitialState = \((\((ket1\[CircleTimes]KetX[0])\)\[CircleTimes]KetX[
              0])\)\[CircleTimes]ket4\), "\[IndentingNewLine]", 
    \(\(\[Rho]initial = 
        InitialState\[CircleTimes]Adj[
            InitialState];\)\), "\[IndentingNewLine]", 
    \(Chop[Tr[InitialState\[CircleTimes]Adj[InitialState]]]\)}], "Input",
  CellTags->"b:4.0.0"],

Cell[TextData[StyleBox["We define recursively the operation of the CPHASE \
gates:", "DisplayText",
  FontWeight->"Plain",
  Background->None,
  FontVariations->{"CompatibilityType"->0}]], "Text",
  FontFamily->"Helvetica",
  CellTags->"b:4.0.0"],

Cell[BoxData[{
    \(\(CPhaseG[0] = InitialState;\)\), "\[IndentingNewLine]", 
    \(\(CPhaseG[i_] := \(ChpaseG[i] = 
          CPHASEV[ClusterLinks[\([i, 1]\)], ClusterLinks[\([i, 2]\)], 
            CPhaseG[i - 1]]\);\)\)}], "Input",
  CellTags->"b:4.0.0"],

Cell[TextData[StyleBox["We compute the cluster vector and build its pure \
state density matrix:", "DisplayText",
  FontWeight->"Plain",
  Background->None,
  FontVariations->{"CompatibilityType"->0}]], "Text",
  FontFamily->"Helvetica",
  CellTags->"b:4.0.0"],

Cell[BoxData[{
    \(ClusterVector = CPhaseG[Nlinks]\), "\[IndentingNewLine]", 
    \(\(ClusterDensity = 
        ClusterVector\[CircleTimes]Adj[
            ClusterVector];\)\), "\[IndentingNewLine]", 
    \(Chop[Tr[ClusterDensity]]\), "\[IndentingNewLine]", 
    \(Chop[Eigenvalues[ClusterDensity]]\)}], "Input",
  CellTags->"b:4.0.0"]
}, Closed]],

Cell[CellGroupData[{

Cell["Step 2: Measure qubits 1 and 2 in the X basis", "Subsection",
  CellFrame->True,
  FontFamily->"Times",
  CellTags->{"b:4.0.1", "c:7"}],

Cell[TextData[StyleBox["Preparation of measurements on the X bases for qubits \
1 and 2, first build the proyectors\nand then operate and Trace Off the \
measured qubits:",
  FontWeight->"Plain",
  Background->None,
  FontVariations->{"CompatibilityType"->0}]], "Text",
  FontFamily->"Helvetica",
  CellTags->"b:4.0.1"],

Cell[BoxData[{
    \(P\_\(a_, b_\) := \((\((\((PX[a]\[CircleTimes]\ 
                  PX[b])\)\[CircleTimes]\[DoubleStruckCapitalI])\)\
\[CircleTimes]\[DoubleStruckCapitalI])\)\), "\[IndentingNewLine]", 
    \(\[Rho]M[a_, b_]\  := 
      Chop[PTr[{1, 2}, \ 
          2^2*P\_\(a, b\) . ClusterDensity . Adj[P\_\(a, b\)]]]\)}], "Input",
  CellTags->"b:4.0.1"],

Cell[TextData[StyleBox["The result of the measurement is generated at \
random:", "DisplayText",
  FontWeight->"Plain",
  Background->None,
  FontVariations->{"CompatibilityType"->0}]], "Text",
  FontFamily->"Helvetica",
  CellTags->"b:4.0.1"],

Cell[BoxData[{
    \(M1 = Random[Integer, {0, 1}]\), "\[IndentingNewLine]", 
    \(M2 = Random[Integer, {0, 1}]\)}], "Input",
  CellTags->"b:4.0.1"]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Step 3: Undo prefactor cluster operations and compare to usual CNOT \
gate\
\>", "Subsection",
  CellFrame->True,
  FontFamily->"Times",
  CellTags->{"b:4.0.2", "c:8"}],

Cell[TextData[StyleBox["According to their PRL paper the outcome in qubits 3 \
and 4 will be \nthe target of the CNOT[1,4] and the control untouched up to \
this \noperations. We undo them to compare. The prefactor operations are:", \
"DisplayText",
  FontWeight->"Plain",
  Background->None,
  FontVariations->{"CompatibilityType"->0}]], "Text",
  FontFamily->"Helvetica",
  CellTags->"b:4.0.2"],

Cell[BoxData[
    \(PrefactorOp = \((MatrixPower[s[3], M1] . 
            MatrixPower[s[1], M2])\)\[CircleTimes]MatrixPower[s[3], 
          M1]\)], "Input",
  CellTags->"b:4.0.2"],

Cell[BoxData[
    \(A34 = Chop[PrefactorOp . \[Rho]M[M1, M2] . Adj[PrefactorOp]]\)], "Input",\

  CellTags->"b:4.0.2"],

Cell[TextData[StyleBox["The reduced density matrix for both qubits are:", \
"DisplayText",
  FontWeight->"Plain",
  Background->None,
  FontVariations->{"CompatibilityType"->0}]], "Text",
  FontFamily->"Helvetica",
  CellTags->"b:4.0.2"],

Cell[BoxData[{
    \(Chop[PTr[{2}, A34]]\), "\[IndentingNewLine]", 
    \(Chop[PTr[{1}, A34]]\)}], "Input",
  CellTags->"b:4.0.2"],

Cell[TextData[{
  StyleBox["And we ", "DisplayText",
    FontWeight->"Plain",
    Background->None,
    FontVariations->{"CompatibilityType"->0}],
  StyleBox["compare with a standard realization of the CNOT", "DisplayText",
    FontWeight->"Bold",
    Background->None,
    FontVariations->{"CompatibilityType"->0}],
  StyleBox[" gate between 1 and 4.", "DisplayText",
    FontWeight->"Plain",
    Background->None,
    FontVariations->{"CompatibilityType"->0}]
}], "Text",
  FontFamily->"Helvetica",
  CellTags->"b:4.0.2"],

Cell[BoxData[{
    \(\(Ket14 = ket1\[CircleTimes]ket4;\)\), "\[IndentingNewLine]", 
    \(\(\[Rho]14 = 
        Ket14\[CircleTimes]Adj[Ket14];\)\), "\[IndentingNewLine]", 
    \(\(CN14 = 
        Chop[CNOT[2, 2, 1] . \[Rho]14 . 
            Adj[CNOT[2, 2, 1]]];\)\), "\[IndentingNewLine]", 
    \(Chop[PTr[{2}, CN14]]\), "\[IndentingNewLine]", 
    \(Chop[PTr[{1}, CN14]]\)}], "Input",
  CellTags->"b:4.0.2"],

Cell[BoxData[
    \(Quit\)], "Input"]
}, Closed]]
}, Closed]]
},
FrontEndVersion->"5.2 for X",
ScreenRectangle->{{0, 1280}, {0, 800}},
ScreenStyleEnvironment->"Working",
ShowPageBreaks->False,
WindowToolbars->{},
WindowSize->{861, 746},
WindowMargins->{{133, Automatic}, {Automatic, 0}},
PrintingStartingPageNumber->77,
PrintingPageRange->{Automatic, Automatic},
PrintingOptions->{"PaperSize"->{612, 792},
"PaperOrientation"->"Portrait",
"PostScriptOutputFile":>FrontEnd`FileName[{$RootDirectory, "export", "home", \
"brunojd"}, "c.ps", CharacterEncoding -> "iso8859-1"],
"Magnification"->1},
ShowSelection->True,
TaggingRules:>{"PaginationCache" -> {{2005, 8, 9, 3, 36, \
23.409337`8.121964096655068}, {77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, \
77, 77, 77, 78, 78, 78, 78, 78, 78, 78, 78, 78, 78, 78, 78, 78, 78, 78, 78, \
79, 79, 79, 79, 79, 79, 79, 79, 79, 79, 79, 79, 79, 79, 79, 79, 79, 80, 80, \
80, 80, 80, 80, 80, 80, 80, 80, 80, 80, 80, 80, 80, 80, 81, 81, 81, 81, 81, \
81, 81, 81, 81, 81, 81, 81, 81, 81, 82, 82, 82, 82, 82, 82, 82, 82, 82, 82, \
82, 82, 82}, Automatic}},
CellLabelAutoDelete->True,
Magnification->1,
StyleDefinitions -> "Classroom.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "c:1"->{
    Cell[1754, 51, 127, 5, 122, "Title",
      CellTags->"c:1"]},
  "c:2"->{
    Cell[2725, 82, 82, 2, 62, "Section",
      CellTags->"c:2"]},
  "b:14.0"->{
    Cell[2931, 90, 86, 2, 47, "Input",
      CellTags->"b:14.0"],
    Cell[3060, 96, 272, 8, 28, "Text",
      CellTags->"b:14.0"],
    Cell[14387, 483, 86, 2, 47, "Input",
      CellTags->"b:14.0"]},
  "b:5.0.0"->{
    Cell[3357, 108, 111, 3, 69, "Subsection",
      CellTags->{"b:5.0.0", "c:3"}],
    Cell[4320, 142, 308, 7, 58, "Text",
      CellTags->"b:5.0.0"],
    Cell[4631, 151, 77, 2, 47, "Input",
      CellTags->"b:5.0.0"],
    Cell[4711, 155, 268, 7, 63, "Input",
      CellTags->"b:5.0.0"],
    Cell[4982, 164, 272, 6, 28, "Text",
      CellTags->"b:5.0.0"],
    Cell[5257, 172, 94, 2, 47, "Input",
      CellTags->"b:5.0.0"],
    Cell[5354, 176, 219, 5, 28, "Text",
      CellTags->"b:5.0.0"],
    Cell[5576, 183, 99, 2, 47, "Input",
      CellTags->"b:5.0.0"],
    Cell[5678, 187, 252, 6, 28, "Text",
      CellTags->"b:5.0.0"],
    Cell[5933, 195, 131, 3, 47, "Input",
      CellTags->"b:5.0.0"],
    Cell[6067, 200, 238, 6, 28, "Text",
      CellTags->"b:5.0.0"],
    Cell[6308, 208, 228, 5, 63, "Input",
      CellTags->"b:5.0.0"],
    Cell[6539, 215, 252, 6, 28, "Text",
      CellTags->"b:5.0.0"],
    Cell[6794, 223, 112, 3, 63, "Input",
      CellTags->"b:5.0.0"],
    Cell[6909, 228, 476, 15, 28, "Text",
      CellTags->"b:5.0.0"],
    Cell[7388, 245, 278, 6, 79, "Input",
      CellTags->"b:5.0.0"],
    Cell[7703, 256, 123, 3, 53, "Subsection",
      CellTags->{"b:5.0.0", "c:4"}],
    Cell[8527, 286, 586, 16, 58, "Text",
      CellTags->"b:5.0.0"],
    Cell[9116, 304, 77, 2, 47, "Input",
      CellTags->"b:5.0.0"],
    Cell[9196, 308, 268, 7, 63, "Input",
      CellTags->"b:5.0.0"],
    Cell[9467, 317, 547, 16, 28, "Text",
      CellTags->"b:5.0.0"],
    Cell[10017, 335, 168, 3, 63, "Input",
      CellTags->"b:5.0.0"],
    Cell[10188, 340, 676, 21, 28, "Text",
      CellTags->"b:5.0.0"],
    Cell[10867, 363, 129, 3, 47, "Input",
      CellTags->"b:5.0.0"],
    Cell[10999, 368, 254, 6, 28, "Text",
      CellTags->"b:5.0.0"],
    Cell[11256, 376, 193, 4, 63, "Input",
      CellTags->"b:5.0.0"],
    Cell[11452, 382, 387, 12, 28, "Text",
      CellTags->"b:5.0.0"],
    Cell[11842, 396, 300, 7, 63, "Input",
      CellTags->"b:5.0.0"],
    Cell[12145, 405, 280, 6, 28, "Text",
      CellTags->"b:5.0.0"],
    Cell[12428, 413, 127, 3, 47, "Input",
      CellTags->"b:5.0.0"],
    Cell[12558, 418, 453, 15, 28, "Text",
      CellTags->"b:5.0.0"],
    Cell[13134, 439, 308, 7, 58, "Text",
      CellTags->"b:5.0.0"],
    Cell[13677, 454, 478, 15, 28, "Text",
      CellTags->"b:5.0.0"],
    Cell[14158, 471, 63, 2, 47, "Input",
      CellTags->"b:5.0.0"]},
  "c:3"->{
    Cell[3357, 108, 111, 3, 69, "Subsection",
      CellTags->{"b:5.0.0", "c:3"}]},
  "c:4"->{
    Cell[7703, 256, 123, 3, 53, "Subsection",
      CellTags->{"b:5.0.0", "c:4"}]},
  "c:5"->{
    Cell[14270, 479, 114, 2, 42, "Section",
      CellTags->"c:5"]},
  "b:4.0.0"->{
    Cell[14538, 491, 127, 3, 69, "Subsection",
      CellTags->{"b:4.0.0", "c:6"}],
    Cell[14668, 496, 254, 6, 28, "Text",
      CellTags->"b:4.0.0"],
    Cell[14925, 504, 184, 5, 63, "Input",
      CellTags->"b:4.0.0"],
    Cell[15112, 511, 273, 6, 28, "Text",
      CellTags->"b:4.0.0"],
    Cell[15388, 519, 70, 2, 47, "Input",
      CellTags->"b:4.0.0"],
    Cell[15461, 523, 205, 5, 28, "Text",
      CellTags->"b:4.0.0"],
    Cell[15669, 530, 67, 2, 47, "Input",
      CellTags->"b:4.0.0"],
    Cell[15739, 534, 326, 7, 58, "Text",
      CellTags->"b:4.0.0"],
    Cell[16068, 543, 356, 7, 111, "Input",
      CellTags->"b:4.0.0"],
    Cell[16427, 552, 302, 6, 58, "Text",
      CellTags->"b:4.0.0"],
    Cell[16732, 560, 207, 4, 79, "Input",
      CellTags->"b:4.0.0"],
    Cell[16942, 566, 240, 6, 28, "Text",
      CellTags->"b:4.0.0"],
    Cell[17185, 574, 371, 7, 79, "Input",
      CellTags->"b:4.0.0"],
    Cell[17559, 583, 246, 6, 28, "Text",
      CellTags->"b:4.0.0"],
    Cell[17808, 591, 258, 5, 63, "Input",
      CellTags->"b:4.0.0"],
    Cell[18069, 598, 260, 6, 28, "Text",
      CellTags->"b:4.0.0"],
    Cell[18332, 606, 337, 7, 95, "Input",
      CellTags->"b:4.0.0"]},
  "c:6"->{
    Cell[14538, 491, 127, 3, 69, "Subsection",
      CellTags->{"b:4.0.0", "c:6"}]},
  "b:4.0.1"->{
    Cell[18706, 618, 141, 3, 53, "Subsection",
      CellTags->{"b:4.0.1", "c:7"}],
    Cell[18850, 623, 319, 7, 58, "Text",
      CellTags->"b:4.0.1"],
    Cell[19172, 632, 359, 7, 63, "Input",
      CellTags->"b:4.0.1"],
    Cell[19534, 641, 243, 6, 28, "Text",
      CellTags->"b:4.0.1"],
    Cell[19780, 649, 148, 3, 63, "Input",
      CellTags->"b:4.0.1"]},
  "c:7"->{
    Cell[18706, 618, 141, 3, 53, "Subsection",
      CellTags->{"b:4.0.1", "c:7"}]},
  "b:4.0.2"->{
    Cell[19965, 657, 178, 6, 53, "Subsection",
      CellTags->{"b:4.0.2", "c:8"}],
    Cell[20146, 665, 396, 8, 88, "Text",
      CellTags->"b:4.0.2"],
    Cell[20545, 675, 180, 4, 47, "Input",
      CellTags->"b:4.0.2"],
    Cell[20728, 681, 118, 3, 47, "Input",
      CellTags->"b:4.0.2"],
    Cell[20849, 686, 237, 6, 28, "Text",
      CellTags->"b:4.0.2"],
    Cell[21089, 694, 130, 3, 63, "Input",
      CellTags->"b:4.0.2"],
    Cell[21222, 699, 523, 15, 28, "Text",
      CellTags->"b:4.0.2"],
    Cell[21748, 716, 408, 9, 111, "Input",
      CellTags->"b:4.0.2"]},
  "c:8"->{
    Cell[19965, 657, 178, 6, 53, "Subsection",
      CellTags->{"b:4.0.2", "c:8"}]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"c:1", 23756, 768},
  {"c:2", 23833, 771},
  {"b:14.0", 23913, 774},
  {"b:5.0.0", 24129, 781},
  {"c:3", 26514, 850},
  {"c:4", 26609, 853},
  {"c:5", 26704, 856},
  {"b:4.0.0", 26788, 859},
  {"c:6", 27995, 894},
  {"b:4.0.1", 28095, 897},
  {"c:7", 28469, 908},
  {"b:4.0.2", 28569, 911},
  {"c:8", 29154, 928}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 127, 5, 122, "Title",
  CellTags->"c:1"],
Cell[1884, 58, 54, 0, 41, "Subtitle"],
Cell[1941, 60, 759, 18, 161, "Abstract"],

Cell[CellGroupData[{
Cell[2725, 82, 82, 2, 62, "Section",
  CellTags->"c:2"],
Cell[2810, 86, 118, 2, 28, "Text"],
Cell[2931, 90, 86, 2, 47, "Input",
  CellTags->"b:14.0"],
Cell[3020, 94, 37, 0, 47, "Input"],
Cell[3060, 96, 272, 8, 28, "Text",
  CellTags->"b:14.0"],

Cell[CellGroupData[{
Cell[3357, 108, 111, 3, 69, "Subsection",
  CellTags->{"b:5.0.0", "c:3"}],
Cell[3471, 113, 182, 4, 28, "Text"],
Cell[3656, 119, 45, 1, 47, "Input"],
Cell[3704, 122, 253, 5, 58, "Text"],
Cell[3960, 129, 42, 1, 47, "Input"],
Cell[4005, 132, 312, 8, 95, "Input"],
Cell[4320, 142, 308, 7, 58, "Text",
  CellTags->"b:5.0.0"],
Cell[4631, 151, 77, 2, 47, "Input",
  CellTags->"b:5.0.0"],
Cell[4711, 155, 268, 7, 63, "Input",
  CellTags->"b:5.0.0"],
Cell[4982, 164, 272, 6, 28, "Text",
  CellTags->"b:5.0.0"],
Cell[5257, 172, 94, 2, 47, "Input",
  CellTags->"b:5.0.0"],
Cell[5354, 176, 219, 5, 28, "Text",
  CellTags->"b:5.0.0"],
Cell[5576, 183, 99, 2, 47, "Input",
  CellTags->"b:5.0.0"],
Cell[5678, 187, 252, 6, 28, "Text",
  CellTags->"b:5.0.0"],
Cell[5933, 195, 131, 3, 47, "Input",
  CellTags->"b:5.0.0"],
Cell[6067, 200, 238, 6, 28, "Text",
  CellTags->"b:5.0.0"],
Cell[6308, 208, 228, 5, 63, "Input",
  CellTags->"b:5.0.0"],
Cell[6539, 215, 252, 6, 28, "Text",
  CellTags->"b:5.0.0"],
Cell[6794, 223, 112, 3, 63, "Input",
  CellTags->"b:5.0.0"],
Cell[6909, 228, 476, 15, 28, "Text",
  CellTags->"b:5.0.0"],
Cell[7388, 245, 278, 6, 79, "Input",
  CellTags->"b:5.0.0"]
}, Closed]],

Cell[CellGroupData[{
Cell[7703, 256, 123, 3, 53, "Subsection",
  CellTags->{"b:5.0.0", "c:4"}],
Cell[7829, 261, 182, 4, 28, "Text"],
Cell[8014, 267, 45, 1, 47, "Input"],
Cell[8062, 270, 253, 5, 58, "Text"],
Cell[8318, 277, 42, 1, 47, "Input"],
Cell[8363, 280, 161, 4, 63, "Input"],
Cell[8527, 286, 586, 16, 58, "Text",
  CellTags->"b:5.0.0"],
Cell[9116, 304, 77, 2, 47, "Input",
  CellTags->"b:5.0.0"],
Cell[9196, 308, 268, 7, 63, "Input",
  CellTags->"b:5.0.0"],
Cell[9467, 317, 547, 16, 28, "Text",
  CellTags->"b:5.0.0"],
Cell[10017, 335, 168, 3, 63, "Input",
  CellTags->"b:5.0.0"],
Cell[10188, 340, 676, 21, 28, "Text",
  CellTags->"b:5.0.0"],
Cell[10867, 363, 129, 3, 47, "Input",
  CellTags->"b:5.0.0"],
Cell[10999, 368, 254, 6, 28, "Text",
  CellTags->"b:5.0.0"],
Cell[11256, 376, 193, 4, 63, "Input",
  CellTags->"b:5.0.0"],
Cell[11452, 382, 387, 12, 28, "Text",
  CellTags->"b:5.0.0"],
Cell[11842, 396, 300, 7, 63, "Input",
  CellTags->"b:5.0.0"],
Cell[12145, 405, 280, 6, 28, "Text",
  CellTags->"b:5.0.0"],
Cell[12428, 413, 127, 3, 47, "Input",
  CellTags->"b:5.0.0"],
Cell[12558, 418, 453, 15, 28, "Text",
  CellTags->"b:5.0.0"],
Cell[13014, 435, 117, 2, 47, "Input"],
Cell[13134, 439, 308, 7, 58, "Text",
  CellTags->"b:5.0.0"],
Cell[13445, 448, 229, 4, 95, "Input"],
Cell[13677, 454, 478, 15, 28, "Text",
  CellTags->"b:5.0.0"],
Cell[14158, 471, 63, 2, 47, "Input",
  CellTags->"b:5.0.0"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[14270, 479, 114, 2, 42, "Section",
  CellTags->"c:5"],
Cell[14387, 483, 86, 2, 47, "Input",
  CellTags->"b:14.0"],
Cell[14476, 487, 37, 0, 47, "Input"],

Cell[CellGroupData[{
Cell[14538, 491, 127, 3, 69, "Subsection",
  CellTags->{"b:4.0.0", "c:6"}],
Cell[14668, 496, 254, 6, 28, "Text",
  CellTags->"b:4.0.0"],
Cell[14925, 504, 184, 5, 63, "Input",
  CellTags->"b:4.0.0"],
Cell[15112, 511, 273, 6, 28, "Text",
  CellTags->"b:4.0.0"],
Cell[15388, 519, 70, 2, 47, "Input",
  CellTags->"b:4.0.0"],
Cell[15461, 523, 205, 5, 28, "Text",
  CellTags->"b:4.0.0"],
Cell[15669, 530, 67, 2, 47, "Input",
  CellTags->"b:4.0.0"],
Cell[15739, 534, 326, 7, 58, "Text",
  CellTags->"b:4.0.0"],
Cell[16068, 543, 356, 7, 111, "Input",
  CellTags->"b:4.0.0"],
Cell[16427, 552, 302, 6, 58, "Text",
  CellTags->"b:4.0.0"],
Cell[16732, 560, 207, 4, 79, "Input",
  CellTags->"b:4.0.0"],
Cell[16942, 566, 240, 6, 28, "Text",
  CellTags->"b:4.0.0"],
Cell[17185, 574, 371, 7, 79, "Input",
  CellTags->"b:4.0.0"],
Cell[17559, 583, 246, 6, 28, "Text",
  CellTags->"b:4.0.0"],
Cell[17808, 591, 258, 5, 63, "Input",
  CellTags->"b:4.0.0"],
Cell[18069, 598, 260, 6, 28, "Text",
  CellTags->"b:4.0.0"],
Cell[18332, 606, 337, 7, 95, "Input",
  CellTags->"b:4.0.0"]
}, Closed]],

Cell[CellGroupData[{
Cell[18706, 618, 141, 3, 53, "Subsection",
  CellTags->{"b:4.0.1", "c:7"}],
Cell[18850, 623, 319, 7, 58, "Text",
  CellTags->"b:4.0.1"],
Cell[19172, 632, 359, 7, 63, "Input",
  CellTags->"b:4.0.1"],
Cell[19534, 641, 243, 6, 28, "Text",
  CellTags->"b:4.0.1"],
Cell[19780, 649, 148, 3, 63, "Input",
  CellTags->"b:4.0.1"]
}, Closed]],

Cell[CellGroupData[{
Cell[19965, 657, 178, 6, 53, "Subsection",
  CellTags->{"b:4.0.2", "c:8"}],
Cell[20146, 665, 396, 8, 88, "Text",
  CellTags->"b:4.0.2"],
Cell[20545, 675, 180, 4, 47, "Input",
  CellTags->"b:4.0.2"],
Cell[20728, 681, 118, 3, 47, "Input",
  CellTags->"b:4.0.2"],
Cell[20849, 686, 237, 6, 28, "Text",
  CellTags->"b:4.0.2"],
Cell[21089, 694, 130, 3, 63, "Input",
  CellTags->"b:4.0.2"],
Cell[21222, 699, 523, 15, 28, "Text",
  CellTags->"b:4.0.2"],
Cell[21748, 716, 408, 9, 111, "Input",
  CellTags->"b:4.0.2"],
Cell[22159, 727, 37, 1, 47, "Input"]
}, Closed]]
}, Closed]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

