(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     18404,        686]*)
(*NotebookOutlinePosition[     28971,        999]*)
(*  CellTagsIndexPosition[     28399,        973]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[{
  StyleBox["QDENSITY",
    FontSlant->"Italic"],
  "\nGrover searching algorithms"
}], "Title",
  CellTags->"c:1"],

Cell["Searching for one or two items on a database", "Subtitle"],

Cell[TextData[{
  "Last Version: 18-Aug-2005\n",
  Cell[BoxData[
      FormBox[GridBox[{
            {\(\(References\)\(:\)\), \(\([1]\)\ Lov . \ K . \ Grover, \ 
              Phys . \ Rev . \ Lett . \ 79\ \((1997)\)\ 325\n
              \([2]\)\ QDENSITY\ manual, \ Sect . \ 8\)}
            },
          ColumnAlignments->{Right, Left}], TraditionalForm]], 
    "DefinitionBox",
    GridBoxOptions->{RowSpacings->0.4,
    RowLines->False},
    CellTags->"S5.1.1"]
}], "Abstract"],

Cell[TextData[ButtonBox["Click here to get the palette: QDENSpalette.nb",
  ButtonData:>{"QDENSpalette.nb", None},
  ButtonStyle->"Hyperlink"]], "Text"],

Cell[CellGroupData[{

Cell["Grover Searching Algorithm-Single Marked Item.", "Section",
  FontFamily->"Times",
  CellTags->"c:2"],

Cell["\<\
Grover's search algorithm making use of density matrices in subspace |x\
\[RightAngleBracket]. 
The space |y\[RightAngleBracket] is part of the search, but keeps the same \
state during 
the process and can therefore be suppressed.\
\>", "Text",
  FontFamily->"Helvetica",
  CellTags->"b:8.0.1"],

Cell[BoxData[
    \(Needs["\<QDENSITY`Qdensity`\>"]\)], "Input",
  CellTags->"b:14.0"],

Cell[BoxData[
    \(\(?QDENSITY`Qdensity`*\)\)], "Input",
  CellTags->"b:8.0.0"],

Cell[BoxData[{
    \(\(figure = 
        Import["\<drawings/Grover.png\>", "\<PNG\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(Show[figure];\)\)}], "Input"],

Cell[CellGroupData[{

Cell["Step 1: Setting the conditions", "Subsection",
  CellFrame->True,
  FontFamily->"Times",
  CellTags->{"b:8.0.1", "c:3"}],

Cell[TextData[{
  "Set the number of x  \n- ",
  Cell[BoxData[
      \(TraditionalForm\`nqx\)]],
  " is the number of qubits of the unknown state"
}], "Text",
  FontFamily->"Helvetica",
  CellTags->"b:8.0.1"],

Cell[BoxData[{
    \(\(nqx = 6;\)\), "\[IndentingNewLine]", 
    \(If[nqx\  > 10, 
      Print["\<Check your nqx, it may take too long to compute\>"], ]\), "\
\[IndentingNewLine]", 
    \(qtab := Table[qx\_i, {i, 1, nqx}]\), "\[IndentingNewLine]", 
    \(qtab\)}], "Input",
  CellTags->"b:8.0.1"],

Cell[BoxData[
    \(\(nq = nqx;\)\)], "Input",
  CellTags->"b:8.0.1"],

Cell["Total number of bits;  we suppress the y bit", "Text",
  FontFamily->"Helvetica",
  CellTags->"b:8.0.1"],

Cell[BoxData[
    \(nbits = 2^nq\)], "Input",
  CellTags->"b:8.0.1"],

Cell["In the figure we depict the full searching circuit.", "Text",
  FontFamily->"Helvetica",
  CellTags->"b:8.0.1"],

Cell["Initialize all n qubits ( x and y qubits)  to Zero State", "Text",
  FontFamily->"Helvetica",
  CellTags->"b:8.0.1"],

Cell[TextData[{
  StyleBox["NOTE: The state  |0\[RightAngleBracket] is the array \
(1,0,0,0,...,0) in the nq bit space",
    FontSize->12],
  "\n",
  StyleBox["Here  \[Rho]0  is the density matrix in the \
|x\[RightAngleBracket]  space",
    FontSize->12],
  " "
}], "SmallText",
  FontFamily->"Helvetica",
  CellTags->"b:8.0.1"],

Cell["\<\
\[Rho]0 = N[Table[KroneckerDelta[i, 1] * KroneckerDelta[i, j],{i, 1, \
nbits},{j, 1, nbits}]];\
\>", "Input",
  CellTags->"b:8.0.1"],

Cell[TextData[{
  "Prepare State By Hadamarding all x qubits and since |y\[RightAngleBracket] \
 remains as ",
  Cell[BoxData[
      \(1\/\@2\)]],
  "( |0\[RightAngleBracket] - |1\[RightAngleBracket] ), the |y\
\[RightAngleBracket] space can be suppressed"
}], "Text",
  FontFamily->"Helvetica",
  CellTags->"b:8.0.1"],

Cell["\<\
Prepare the x qubits in equi-weighted state by Hadamarding all of them using \
HALL\
\>", "Text",
  FontFamily->"Helvetica",
  CellTags->"b:8.0.1"],

Cell[BoxData[
    \(\(\(Generate\)\(\ \)\(the\)\(\ \ \)\(density\)\(\ \
\)\(matrix\)\(\ \ \)\(\[Rho]1\)\(\ \)\)\)], "Text",
  FontFamily->"Helvetica",
  CellTags->"b:8.0.1"],

Cell[BoxData[
    \(\(\[Rho]1 = N[HALL[nqx] . \[Rho]0 . Adj[N[HALL[nqx]]]];\)\)], "Input",
  CellTags->"b:8.0.1"]
}, Closed]],

Cell[CellGroupData[{

Cell["Step 2: Building the Grover operator", "Subsection",
  CellFrame->True,
  FontFamily->"Times",
  CellTags->{"b:8.0.2", "c:4"}],

Cell["\<\
Prepare the Grover operator G as the \"inversion about the mean\" times the \
Oracle
The Oracle defines an arbitrary single marked state as indicated by the \
function f.
When acting in just the |x\[RightAngleBracket] space, the Grover Oracle G \
changes the sign of the marked state.\
\>", "Text",
  FontFamily->"Helvetica",
  CellTags->"b:8.0.2"],

Cell[BoxData[
    \(nx = 2^nqx\)], "Input",
  CellTags->"b:8.0.2"],

Cell[BoxData[
    \(Generate\ the\ \ marked\ state\ randomly\ and\ incluse\ in\ the\ Oracle\
\)], "Text",
  FontFamily->"Helvetica",
  CellTags->"b:8.0.1"],

Cell[BoxData[{
    \(\(f = 
        ReplacePart[ZeroT[nx], 1, 
          xpick = Random[Integer, {1, nx}]];\)\), "\[IndentingNewLine]", 
    \(\(markit = \((\(-1\))\)^f;\)\)}], "Input",
  CellTags->"b:8.0.2"],

Cell[BoxData[
    \(\(OracleG = 
        Table[markit[\([i]\)]*KroneckerDelta[i, j], {i, 1, nx}, {j, 1, 
            nx}];\)\)], "Input",
  CellTags->"b:8.0.2"],

Cell[TextData[{
  "phaseinvert is the (2 |0\[RightAngleBracket]\[LeftAngleBracket]0| - I)  \
phase inversion matrix  in the ",
  Cell[BoxData[
      \(TraditionalForm\`n\_x\)]],
  " space "
}], "Text",
  FontFamily->"Helvetica",
  CellTags->"b:8.0.2"],

Cell[BoxData[
    \(\(phaseinvert = 
        N[Table[KroneckerDelta[i, j]*\((\(-1\))\)*\((\(-1\))\)^
                KroneckerDelta[1, j], {i, 1, 2^nqx}, {j, 1, 
              2^nqx}]];\)\)], "Input",
  CellTags->"b:8.0.2"],

Cell["\<\
Put the above together to form Inversion about the mean: Invmean \
\>", "Text",
  FontFamily->"Helvetica",
  CellTags->"b:8.0.2"],

Cell["Invmean = N[HALL[nq]].(phaseinvert .N[ HALL[nq]]);", "Input",
  CellTags->"b:8.0.2"],

Cell["Then the Grover operator reads:", "Text",
  FontFamily->"Helvetica",
  CellTags->"b:8.0.2"],

Cell["G = N[Invmean . OracleG];", "Input",
  CellTags->"b:8.0.2"],

Cell["\<\
Apply G  nG Times  to obtain the final density matrix \[Rho]F [ nG ]  \
\>", "Text",
  FontFamily->"Helvetica",
  CellTags->"b:8.0.2"],

Cell["\<\
\[Rho]F[0] = N[\[Rho]1];
\[Rho]F[nG_] := \[Rho]F[nG] = G . (\[Rho]F[nG-1] . (Adj[G]))\
\>", "Input",
  CellTags->"b:8.0.2"]
}, Closed]],

Cell[CellGroupData[{

Cell["Step 3: Apply the Grover operator a certain number of times", \
"Subsection",
  CellFrame->True,
  FontFamily->"Times",
  CellTags->{"b:8.0.3", "c:5"}],

Cell["\<\
The Grover operator, G, must be applied a number of times which 
is estimated here:\
\>", "Text",
  FontFamily->"Helvetica",
  CellTags->"b:8.0.3"],

Cell[BoxData[
    \(ntry = IntegerPart[Sqrt[Length[f]]] - 1\)], "Input",
  CellTags->"b:8.0.3"],

Cell["Get final density matrix after ntry iterations.", "Text",
  FontFamily->"Helvetica",
  CellTags->"b:8.0.3"],

Cell[BoxData[
    \(\(Z = \[Rho]F[ntry];\)\)], "Input",
  CellTags->"b:8.0.3"],

Cell["\<\
Take Trace for Projective Measurements using Tr  [ | n \[RightAngleBracket]\
\[LeftAngleBracket] n |  \[Rho]  ] = \[LeftAngleBracket] n | \[Rho]  | n \
\[RightAngleBracket] directly.\
\>", "Text",
  FontFamily->"Helvetica",
  CellTags->"b:8.0.3"],

Cell[BoxData[
    \(\(\(\ \)\(Clear[
      R]; \(\(R\)\(:=\)\(N[
        Table[\ Z[\([i, i]\)]\ , {i, 1, nx}]]\)\(\ \)\)\)\)\)], "Input",
  CellTags->"b:8.0.3"]
}, Closed]],

Cell[CellGroupData[{

Cell["Step 4: Analyze results ", "Subsection",
  CellFrame->True,
  FontFamily->"Times",
  CellTags->{"b:8.0.4", "c:6"}],

Cell["Look at results", "Text",
  FontFamily->"Helvetica",
  CellTags->"b:8.0.4"],

Cell[BoxData[
    \(\(probsearch = 
        Flatten[Table[\ \ {R[\([\ i]\)]}, {i, 1, nx}]];\)\)], "Input",
  CellTags->"b:8.0.4"],

Cell["\<\
We can plot the possible outcomes of the search with their probabilities:\
\>", "Text",
  FontFamily->"Helvetica",
  CellTags->"b:8.0.4"],

Cell[BoxData[
    \(\(Plot1 = 
        ListPlot[probsearch, AxesLabel \[Rule] {Item\ number, Probability}, 
          PlotStyle \[Rule] PointSize[0.025], 
          PlotRange \[Rule] {0, 1. }];\)\)], "Input",
  CellTags->{"ListPlot", "b:8.0.4"}],

Cell["Isolate the maximum probability:", "Text",
  FontFamily->"Helvetica",
  CellTags->"b:8.0.4"],

Cell[BoxData[
    \(N[Max[probsearch]]\)], "Input",
  CellTags->"b:8.0.4"],

Cell["\<\
And get the position corresponding to the maximum probability:\
\>", "Text",
  FontFamily->"Helvetica",
  CellTags->"b:8.0.4"],

Cell[BoxData[
    \(grover\  = Flatten[Position[probsearch, Max[probsearch]]]\)], "Input",
  CellTags->{"Ordering", "b:8.0.4"}],

Cell["Compare to the \"unknown\" marked state as stored in f ", "Text",
  FontFamily->"Helvetica",
  CellTags->"b:8.0.4"],

Cell[BoxData[
    \(Do[{If[f[\([s]\)] == 1, Print["\<marked item is number=\>", s, "\<    
          Grover search found=\>", grover], "\<\>"]}, {s, 1, 
        Length[f]}]\)], "Input",
  CellTags->"b:8.0.4"],

Cell["Quit", "Input",
  CellTags->"b:8.0.4"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Grover Searching Algorithm-Two Marked Items.", "Section",
  FontFamily->"Times",
  CellTags->"c:7"],

Cell["\<\
Grover's search algorithm making use of density matrices in subspace |x\
\[RightAngleBracket]. 
The space |y\[RightAngleBracket] is part of the search, but keeps the same \
state during 
the process and can therefore be suppressed.\
\>", "Text",
  FontFamily->"Helvetica",
  CellTags->"b:8.0.1"],

Cell[BoxData[
    \(Needs["\<QDENSITY`Qdensity`\>"]\)], "Input",
  CellTags->"b:14.0"],

Cell[BoxData[
    \(\(?QDENSITY`Qdensity`*\)\)], "Input",
  CellTags->"b:8.1.0"],

Cell[CellGroupData[{

Cell["Step 1: Setting the conditions", "Subsection",
  CellFrame->True,
  FontFamily->"Times",
  CellTags->{"b:8.1.1", "c:8"}],

Cell["\<\
Set the number of x  
- nqx is the number of qubits of the unknown state\
\>", "Text",
  FontFamily->"Helvetica",
  CellTags->"b:8.1.1"],

Cell[BoxData[{
    \(\(nqx = 6;\)\), "\[IndentingNewLine]", 
    \(If[nqx\  > 10, 
      Print["\<Check your nqx, it may take too long to compute\>"], ]\), "\
\[IndentingNewLine]", 
    \(qtab := Table[qx\_i, {i, 1, nqx}]\), "\[IndentingNewLine]", 
    \(qtab\)}], "Input",
  CellTags->"b:8.1.1"],

Cell[BoxData[
    \(\(nq = nqx;\)\)], "Input",
  CellTags->"b:8.1.1"],

Cell["Total number of bits;  we suppress the y bit", "Text",
  FontFamily->"Helvetica",
  CellTags->"b:8.1.1"],

Cell[BoxData[
    \(n = 2^nq\)], "Input",
  CellTags->"b:8.1.1"],

Cell["In the figure we depict the full searching circuit.", "Text",
  FontFamily->"Helvetica",
  CellTags->"b:8.1.1"],

Cell["Initialize all n qubits ( x and y qubits)  to Zero State", "Text",
  FontFamily->"Helvetica",
  CellTags->"b:8.1.1"],

Cell[TextData[{
  StyleBox["NOTE: the | 0  \[RightAngleBracket] state is the array \
(1,0,0,0,...,0) in the nq bit space",
    FontSize->12],
  "\n",
  StyleBox["Here  \[Rho]0  is the density matrix in the |x \
\[RightAngleBracket]  space",
    FontSize->12],
  " "
}], "SmallText",
  FontFamily->"Helvetica",
  CellTags->"b:8.1.1"],

Cell[BoxData[
    \(\(\[Rho]0 = 
        N[Table[KroneckerDelta[i, 1]*KroneckerDelta[i, j], {i, 1, n}, {j, 1, 
              n}]];\)\)], "Input",
  CellTags->"b:8.1.1"],

Cell[TextData[{
  "Prepare State By Hadamarding all x qubits and  since \
|y\[RightAngleBracket]  remains as ",
  Cell[BoxData[
      \(1\/\@2\)]],
  "( |0\[RightAngleBracket] - |1\[RightAngleBracket] ), the |y\
\[RightAngleBracket] space can be suppressed"
}], "Text",
  FontFamily->"Helvetica",
  CellTags->"b:8.1.1"],

Cell["\<\
Prepare the x qubits in equi-weighted state by Hadamarding all of them using \
HALL\
\>", "Text",
  FontFamily->"Helvetica",
  CellTags->"b:8.1.1"],

Cell[BoxData[
    \(\(\(Generate\)\(\ \)\(the\)\(\ \ \)\(density\)\(\ \
\)\(matrix\)\(\ \ \)\(\[Rho]1\)\(\ \)\)\)], "Text",
  FontFamily->"Helvetica",
  CellTags->"b:8.1.1"],

Cell[BoxData[
    \(\(\[Rho]1 = 
        N[HALL[nqx]] . \[Rho]0 . \((Adj[N[HALL[nqx]]])\);\)\)], "Input",
  CellTags->"b:8.1.1"]
}, Closed]],

Cell[CellGroupData[{

Cell["Step 2: Prepare the Grover operator", "Subsection",
  CellFrame->True,
  FontFamily->"Times",
  CellTags->{"b:8.1.1", "c:9"}],

Cell["\<\
Prepare the Grover operator G as the \"inversion about the mean\" times the \
Oracle.
The Oracle defines an arbitrary set of two marked states as indicated by the \
function f.
When acting in just the | x \[RightAngleBracket] space, the Grover OracleG \
changes the sign of the marked states.\
\>", "Text",
  FontFamily->"Helvetica",
  CellTags->"b:8.1.1"],

Cell[BoxData[
    \(nx = 2^nqx\)], "Input",
  CellTags->"b:8.1.1"],

Cell[BoxData[{
    \(f = 
      ReplacePart[ZeroT[nx], 
        1, {{xpick1 = Random[Integer, {1, nx}]}, {xpick2 = 
              Random[Integer, {1, nx}]}}]\), "\[IndentingNewLine]", 
    \(markit = \(\(\((\(-1\))\)^f\)\(\ \)\)\)}], "Input",
  CellTags->"b:8.1.1"],

Cell[BoxData[{
    \(\(OracleG = 
        Table[markit[\([i]\)]*KroneckerDelta[i, j], {i, 1, nx}, {j, 1, 
            nx}];\)\), "\[IndentingNewLine]", 
    \(\ \)}], "Input",
  CellTags->"b:8.1.1"],

Cell["\<\
phaseinvert is the (2 | 0 \[RightAngleBracket] \[LeftAngleBracket]  0 | - I ) \
 phase inversion matrix in the nqx space \
\>", "Text",
  FontFamily->"Helvetica",
  CellTags->"b:8.1.1"],

Cell["\<\
phaseinvert = \
N[Table[KroneckerDelta[i,j]*(-1)*(-1)^KroneckerDelta[1,j],{i,1,2^nqx},{j, 1, \
nx}]];\
\>", "Input",
  CellTags->"b:8.1.1"],

Cell["\<\
Put the above together to form Inversion about the mean: Invmean \
\>", "Text",
  FontFamily->"Helvetica",
  CellTags->"b:8.1.1"],

Cell["Invmean = N[HALL[nq]] . (phaseinvert .N[ HALL[nq]]);", "Input",
  CellTags->"b:8.1.1"],

Cell["The Grover operator is thus:", "Text",
  FontFamily->"Helvetica",
  CellTags->"b:8.0.2"],

Cell["G = N[Invmean . OracleG];", "Input",
  CellTags->"b:8.1.1"]
}, Closed]],

Cell[CellGroupData[{

Cell["Step 3: Apply the Grover Operator ntry times", "Subsection",
  CellFrame->True,
  FontFamily->"Times",
  CellTags->{"b:8.1.1", "c:10"}],

Cell["\<\
Apply G   nG Times to obtain the final density matrix \[Rho]F [ nG ]. The \
definition is 
done recursively:  \
\>", "Text",
  FontFamily->"Helvetica",
  CellTags->"b:8.1.1"],

Cell["\<\
\[Rho]F[0] = N[\[Rho]1];
\[Rho]F[nG_] := \[Rho]F[nG] = G . (\[Rho]F[nG-1] . (Adj[G]))\
\>", "Input",
  CellTags->"b:8.1.1"],

Cell["\<\
The number of times we apply the Grover operator is defined here:\
\>", "Text",
  FontFamily->"Helvetica",
  CellTags->"b:8.1.1"],

Cell[BoxData[
    \(ntry = IntegerPart[Sqrt[Length[f]]] - 4\)], "Input",
  CellTags->"b:8.1.1"],

Cell["Get final density matrix after ntry iterations.", "Text",
  FontFamily->"Helvetica",
  CellTags->"b:8.1.1"],

Cell[BoxData[
    \(\(Z = \[Rho]F[ntry];\)\)], "Input",
  CellTags->"b:8.1.1"]
}, Closed]],

Cell[CellGroupData[{

Cell["Step 4: Analyze results", "Subsection",
  CellFrame->True,
  FontFamily->"Times",
  CellTags->{"b:8.1.1", "c:11"}],

Cell["\<\
Take Trace for Projective Measurements using Tr  [ | n \[RightAngleBracket]\
\[LeftAngleBracket] n |  \[Rho] ] = \[LeftAngleBracket] n | \[Rho] | n \
\[RightAngleBracket] directly.\
\>", "Text",
  FontFamily->"Helvetica",
  CellTags->"b:8.1.1"],

Cell[BoxData[
    \(\(\(\ \)\(Clear[
      R]; \(\(R\)\(:=\)\(N[
        Table[\ Z[\([i, i]\)]\ , {i, 1, nx}]]\)\(\ \)\)\)\)\)], "Input",
  CellTags->"b:8.1.1"],

Cell["Look at results", "Text",
  FontFamily->"Helvetica",
  CellTags->"b:8.1.1"],

Cell[BoxData[
    \(\(probsearch = 
        Flatten[Table[\ \ {R[\([\ i]\)]}, {i, 1, nx}]];\)\)], "Input",
  CellTags->"b:8.1.1"],

Cell["Plot the possible results with their probabilities:", "Text",
  FontFamily->"Helvetica",
  CellTags->"b:8.1.1"],

Cell[BoxData[
    \(\(ListPlot[probsearch, PlotStyle \[Rule] PointSize[0.025], 
        PlotRange \[Rule] {0, 1. }];\)\)], "Input",
  CellTags->{"ListPlot", "b:8.1.1"}],

Cell["Find the highest probabilities from the table", "Text",
  FontFamily->"Helvetica",
  CellTags->"b:8.1.1"],

Cell[BoxData[
    \(val = Max[probsearch]\)], "Input",
  CellTags->"b:8.1.1"],

Cell[BoxData[
    \(grover\  = 
      Flatten[Position[
          probsearch, _?\((\((val -  .01)\) < # < \((val +  .01)\) &)\)]]\)], \
"Input",
  CellTags->{"Ordering", "b:8.1.1"}],

Cell["Compare to the \"unknown\"  marked state as stored in f ", "Text",
  FontFamily->"Helvetica",
  CellTags->"b:8.1.1"],

Cell[BoxData[
    \(Do[{If[f[\([s]\)] == 1, Print["\<marked item is number=\>", s, "\<    
          Grover search found=\>", grover], "\<\>"]}, {s, 1, 
        Length[f]}]\)], "Input",
  CellTags->"b:8.1.1"],

Cell["Quit", "Input",
  CellTags->"b:8.1.1"]
}, Closed]]
}, Closed]]
},
FrontEndVersion->"5.2 for X",
ScreenRectangle->{{0, 1280}, {0, 800}},
ShowPageBreaks->False,
WindowToolbars->{},
WindowSize->{886, 746},
WindowMargins->{{Automatic, 5}, {Automatic, 0}},
PrintingStartingPageNumber->39,
PrintingPageRange->{Automatic, Automatic},
PrintingOptions->{"PaperSize"->{612, 792},
"PaperOrientation"->"Portrait",
"PostScriptOutputFile":>FrontEnd`FileName[{"home", "bruno", "PITT", "QC"}, \
"Test1.1.nb.ps", CharacterEncoding -> "iso8859-1"],
"Magnification"->1},
ShowSelection->True,
TaggingRules:>{"PaginationCache" -> {{2005, 8, 9, 3, 36, \
20.212814`8.058201763306208}, {39, 39, 39, 39, 39, 39, 39, 39, 39, 39, 39, \
39, 40, 40, 40, 40, 40, 40, 40, 40, 40, 40, 40, 40, 40, 40, 40, 40, 40, 41, \
41, 41, 41, 41, 41, 41, 41, 41, 41, 41, 41, 41, 41, 41, 41, 41, 41, 42, 42, \
42, 42, 42, 42, 42, 42, 42, 42, 42, 42, 42, 42, 42, 43, 43, 43, 43, 43, 43, \
43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 44, 44, 44, 44, 44, 44, 44, 44, 44, \
44, 44, 44, 44, 44, 44, 44, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, \
45}, Automatic}},
CellLabelAutoDelete->True,
Magnification->1,
StyleDefinitions -> "Classroom.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "c:1"->{
    Cell[1754, 51, 130, 5, 122, "Title",
      CellTags->"c:1"]},
  "c:2"->{
    Cell[2616, 81, 107, 2, 62, "Section",
      CellTags->"c:2"]},
  "b:8.0.1"->{
    Cell[2726, 85, 305, 8, 88, "Text",
      CellTags->"b:8.0.1"],
    Cell[3386, 111, 126, 3, 69, "Subsection",
      CellTags->{"b:8.0.1", "c:3"}],
    Cell[3515, 116, 208, 7, 58, "Text",
      CellTags->"b:8.0.1"],
    Cell[3726, 125, 296, 7, 96, "Input",
      CellTags->"b:8.0.1"],
    Cell[4025, 134, 69, 2, 47, "Input",
      CellTags->"b:8.0.1"],
    Cell[4097, 138, 110, 2, 28, "Text",
      CellTags->"b:8.0.1"],
    Cell[4210, 142, 68, 2, 47, "Input",
      CellTags->"b:8.0.1"],
    Cell[4281, 146, 117, 2, 28, "Text",
      CellTags->"b:8.0.1"],
    Cell[4401, 150, 122, 2, 28, "Text",
      CellTags->"b:8.0.1"],
    Cell[4526, 154, 329, 11, 52, "SmallText",
      CellTags->"b:8.0.1"],
    Cell[4858, 167, 142, 4, 47, "Input",
      CellTags->"b:8.0.1"],
    Cell[5003, 173, 318, 9, 38, "Text",
      CellTags->"b:8.0.1"],
    Cell[5324, 184, 157, 5, 28, "Text",
      CellTags->"b:8.0.1"],
    Cell[5484, 191, 173, 4, 26, "Text",
      CellTags->"b:8.0.1"],
    Cell[5660, 197, 113, 2, 47, "Input",
      CellTags->"b:8.0.1"],
    Cell[6375, 224, 155, 4, 26, "Text",
      CellTags->"b:8.0.1"],
    Cell[10898, 399, 305, 8, 88, "Text",
      CellTags->"b:8.0.1"]},
  "b:14.0"->{
    Cell[3034, 95, 86, 2, 47, "Input",
      CellTags->"b:14.0"],
    Cell[11206, 409, 86, 2, 47, "Input",
      CellTags->"b:14.0"]},
  "b:8.0.0"->{
    Cell[3123, 99, 80, 2, 47, "Input",
      CellTags->"b:8.0.0"]},
  "c:3"->{
    Cell[3386, 111, 126, 3, 69, "Subsection",
      CellTags->{"b:8.0.1", "c:3"}]},
  "b:8.0.2"->{
    Cell[5810, 204, 132, 3, 53, "Subsection",
      CellTags->{"b:8.0.2", "c:4"}],
    Cell[5945, 209, 358, 9, 88, "Text",
      CellTags->"b:8.0.2"],
    Cell[6306, 220, 66, 2, 47, "Input",
      CellTags->"b:8.0.2"],
    Cell[6533, 230, 208, 5, 63, "Input",
      CellTags->"b:8.0.2"],
    Cell[6744, 237, 160, 4, 47, "Input",
      CellTags->"b:8.0.2"],
    Cell[6907, 243, 251, 8, 28, "Text",
      CellTags->"b:8.0.2"],
    Cell[7161, 253, 223, 5, 47, "Input",
      CellTags->"b:8.0.2"],
    Cell[7387, 260, 139, 4, 28, "Text",
      CellTags->"b:8.0.2"],
    Cell[7529, 266, 90, 1, 47, "Input",
      CellTags->"b:8.0.2"],
    Cell[7622, 269, 97, 2, 28, "Text",
      CellTags->"b:8.0.2"],
    Cell[7722, 273, 65, 1, 47, "Input",
      CellTags->"b:8.0.2"],
    Cell[7790, 276, 144, 4, 28, "Text",
      CellTags->"b:8.0.2"],
    Cell[7937, 282, 133, 4, 62, "Input",
      CellTags->"b:8.0.2"],
    Cell[15431, 569, 94, 2, 28, "Text",
      CellTags->"b:8.0.2"]},
  "c:4"->{
    Cell[5810, 204, 132, 3, 53, "Subsection",
      CellTags->{"b:8.0.2", "c:4"}]},
  "b:8.0.3"->{
    Cell[8107, 291, 157, 4, 53, "Subsection",
      CellTags->{"b:8.0.3", "c:5"}],
    Cell[8267, 297, 157, 5, 58, "Text",
      CellTags->"b:8.0.3"],
    Cell[8427, 304, 95, 2, 47, "Input",
      CellTags->"b:8.0.3"],
    Cell[8525, 308, 113, 2, 28, "Text",
      CellTags->"b:8.0.3"],
    Cell[8641, 312, 78, 2, 47, "Input",
      CellTags->"b:8.0.3"],
    Cell[8722, 316, 256, 6, 28, "Text",
      CellTags->"b:8.0.3"],
    Cell[8981, 324, 160, 4, 47, "Input",
      CellTags->"b:8.0.3"]},
  "c:5"->{
    Cell[8107, 291, 157, 4, 53, "Subsection",
      CellTags->{"b:8.0.3", "c:5"}]},
  "b:8.0.4"->{
    Cell[9178, 333, 120, 3, 53, "Subsection",
      CellTags->{"b:8.0.4", "c:6"}],
    Cell[9301, 338, 81, 2, 28, "Text",
      CellTags->"b:8.0.4"],
    Cell[9385, 342, 129, 3, 47, "Input",
      CellTags->"b:8.0.4"],
    Cell[9517, 347, 147, 4, 28, "Text",
      CellTags->"b:8.0.4"],
    Cell[9667, 353, 245, 5, 63, "Input",
      CellTags->{"ListPlot", "b:8.0.4"}],
    Cell[9915, 360, 98, 2, 28, "Text",
      CellTags->"b:8.0.4"],
    Cell[10016, 364, 74, 2, 47, "Input",
      CellTags->"b:8.0.4"],
    Cell[10093, 368, 136, 4, 28, "Text",
      CellTags->"b:8.0.4"],
    Cell[10232, 374, 127, 2, 47, "Input",
      CellTags->{"Ordering", "b:8.0.4"}],
    Cell[10362, 378, 121, 2, 28, "Text",
      CellTags->"b:8.0.4"],
    Cell[10486, 382, 208, 4, 63, "Input",
      CellTags->"b:8.0.4"],
    Cell[10697, 388, 44, 1, 47, "Input",
      CellTags->"b:8.0.4"]},
  "c:6"->{
    Cell[9178, 333, 120, 3, 53, "Subsection",
      CellTags->{"b:8.0.4", "c:6"}]},
  "ListPlot"->{
    Cell[9667, 353, 245, 5, 63, "Input",
      CellTags->{"ListPlot", "b:8.0.4"}],
    Cell[17447, 651, 168, 3, 47, "Input",
      CellTags->{"ListPlot", "b:8.1.1"}]},
  "Ordering"->{
    Cell[10232, 374, 127, 2, 47, "Input",
      CellTags->{"Ordering", "b:8.0.4"}],
    Cell[17812, 664, 181, 5, 47, "Input",
      CellTags->{"Ordering", "b:8.1.1"}]},
  "c:7"->{
    Cell[10790, 395, 105, 2, 42, "Section",
      CellTags->"c:7"]},
  "b:8.1.0"->{
    Cell[11295, 413, 80, 2, 47, "Input",
      CellTags->"b:8.1.0"]},
  "b:8.1.1"->{
    Cell[11400, 419, 126, 3, 69, "Subsection",
      CellTags->{"b:8.1.1", "c:8"}],
    Cell[11529, 424, 146, 5, 58, "Text",
      CellTags->"b:8.1.1"],
    Cell[11678, 431, 296, 7, 96, "Input",
      CellTags->"b:8.1.1"],
    Cell[11977, 440, 69, 2, 47, "Input",
      CellTags->"b:8.1.1"],
    Cell[12049, 444, 110, 2, 28, "Text",
      CellTags->"b:8.1.1"],
    Cell[12162, 448, 64, 2, 47, "Input",
      CellTags->"b:8.1.1"],
    Cell[12229, 452, 117, 2, 28, "Text",
      CellTags->"b:8.1.1"],
    Cell[12349, 456, 122, 2, 28, "Text",
      CellTags->"b:8.1.1"],
    Cell[12474, 460, 332, 11, 52, "SmallText",
      CellTags->"b:8.1.1"],
    Cell[12809, 473, 168, 4, 47, "Input",
      CellTags->"b:8.1.1"],
    Cell[12980, 479, 319, 9, 38, "Text",
      CellTags->"b:8.1.1"],
    Cell[13302, 490, 157, 5, 28, "Text",
      CellTags->"b:8.1.1"],
    Cell[13462, 497, 173, 4, 26, "Text",
      CellTags->"b:8.1.1"],
    Cell[13638, 503, 128, 3, 47, "Input",
      CellTags->"b:8.1.1"],
    Cell[13803, 511, 131, 3, 53, "Subsection",
      CellTags->{"b:8.1.1", "c:9"}],
    Cell[13937, 516, 366, 9, 88, "Text",
      CellTags->"b:8.1.1"],
    Cell[14306, 527, 66, 2, 47, "Input",
      CellTags->"b:8.1.1"],
    Cell[14375, 531, 265, 6, 63, "Input",
      CellTags->"b:8.1.1"],
    Cell[14643, 539, 198, 5, 63, "Input",
      CellTags->"b:8.1.1"],
    Cell[14844, 546, 195, 5, 28, "Text",
      CellTags->"b:8.1.1"],
    Cell[15042, 553, 149, 5, 47, "Input",
      CellTags->"b:8.1.1"],
    Cell[15194, 560, 139, 4, 28, "Text",
      CellTags->"b:8.1.1"],
    Cell[15336, 566, 92, 1, 47, "Input",
      CellTags->"b:8.1.1"],
    Cell[15528, 573, 65, 1, 47, "Input",
      CellTags->"b:8.1.1"],
    Cell[15630, 579, 141, 3, 53, "Subsection",
      CellTags->{"b:8.1.1", "c:10"}],
    Cell[15774, 584, 184, 6, 58, "Text",
      CellTags->"b:8.1.1"],
    Cell[15961, 592, 133, 4, 62, "Input",
      CellTags->"b:8.1.1"],
    Cell[16097, 598, 139, 4, 28, "Text",
      CellTags->"b:8.1.1"],
    Cell[16239, 604, 95, 2, 47, "Input",
      CellTags->"b:8.1.1"],
    Cell[16337, 608, 113, 2, 28, "Text",
      CellTags->"b:8.1.1"],
    Cell[16453, 612, 78, 2, 47, "Input",
      CellTags->"b:8.1.1"],
    Cell[16568, 619, 120, 3, 53, "Subsection",
      CellTags->{"b:8.1.1", "c:11"}],
    Cell[16691, 624, 254, 6, 28, "Text",
      CellTags->"b:8.1.1"],
    Cell[16948, 632, 160, 4, 47, "Input",
      CellTags->"b:8.1.1"],
    Cell[17111, 638, 81, 2, 28, "Text",
      CellTags->"b:8.1.1"],
    Cell[17195, 642, 129, 3, 47, "Input",
      CellTags->"b:8.1.1"],
    Cell[17327, 647, 117, 2, 28, "Text",
      CellTags->"b:8.1.1"],
    Cell[17447, 651, 168, 3, 47, "Input",
      CellTags->{"ListPlot", "b:8.1.1"}],
    Cell[17618, 656, 111, 2, 28, "Text",
      CellTags->"b:8.1.1"],
    Cell[17732, 660, 77, 2, 47, "Input",
      CellTags->"b:8.1.1"],
    Cell[17812, 664, 181, 5, 47, "Input",
      CellTags->{"Ordering", "b:8.1.1"}],
    Cell[17996, 671, 122, 2, 28, "Text",
      CellTags->"b:8.1.1"],
    Cell[18121, 675, 208, 4, 63, "Input",
      CellTags->"b:8.1.1"],
    Cell[18332, 681, 44, 1, 47, "Input",
      CellTags->"b:8.1.1"]},
  "c:8"->{
    Cell[11400, 419, 126, 3, 69, "Subsection",
      CellTags->{"b:8.1.1", "c:8"}]},
  "c:9"->{
    Cell[13803, 511, 131, 3, 53, "Subsection",
      CellTags->{"b:8.1.1", "c:9"}]},
  "c:10"->{
    Cell[15630, 579, 141, 3, 53, "Subsection",
      CellTags->{"b:8.1.1", "c:10"}]},
  "c:11"->{
    Cell[16568, 619, 120, 3, 53, "Subsection",
      CellTags->{"b:8.1.1", "c:11"}]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"c:1", 19964, 722},
  {"c:2", 20041, 725},
  {"b:8.0.1", 20123, 728},
  {"b:14.0", 21318, 763},
  {"b:8.0.0", 21468, 768},
  {"c:3", 21547, 771},
  {"b:8.0.2", 21646, 774},
  {"c:4", 22628, 803},
  {"b:8.0.3", 22727, 806},
  {"c:5", 23231, 821},
  {"b:8.0.4", 23330, 824},
  {"c:6", 24209, 849},
  {"ListPlot", 24309, 852},
  {"Ordering", 24493, 857},
  {"c:7", 24673, 862},
  {"b:8.1.0", 24757, 865},
  {"b:8.1.1", 24842, 868},
  {"c:8", 27997, 957},
  {"c:9", 28093, 960},
  {"c:10", 28190, 963},
  {"c:11", 28288, 966}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 130, 5, 122, "Title",
  CellTags->"c:1"],
Cell[1887, 58, 64, 0, 41, "Subtitle"],
Cell[1954, 60, 482, 13, 63, "Abstract"],
Cell[2439, 75, 152, 2, 28, "Text"],

Cell[CellGroupData[{
Cell[2616, 81, 107, 2, 62, "Section",
  CellTags->"c:2"],
Cell[2726, 85, 305, 8, 88, "Text",
  CellTags->"b:8.0.1"],
Cell[3034, 95, 86, 2, 47, "Input",
  CellTags->"b:14.0"],
Cell[3123, 99, 80, 2, 47, "Input",
  CellTags->"b:8.0.0"],
Cell[3206, 103, 155, 4, 63, "Input"],

Cell[CellGroupData[{
Cell[3386, 111, 126, 3, 69, "Subsection",
  CellTags->{"b:8.0.1", "c:3"}],
Cell[3515, 116, 208, 7, 58, "Text",
  CellTags->"b:8.0.1"],
Cell[3726, 125, 296, 7, 96, "Input",
  CellTags->"b:8.0.1"],
Cell[4025, 134, 69, 2, 47, "Input",
  CellTags->"b:8.0.1"],
Cell[4097, 138, 110, 2, 28, "Text",
  CellTags->"b:8.0.1"],
Cell[4210, 142, 68, 2, 47, "Input",
  CellTags->"b:8.0.1"],
Cell[4281, 146, 117, 2, 28, "Text",
  CellTags->"b:8.0.1"],
Cell[4401, 150, 122, 2, 28, "Text",
  CellTags->"b:8.0.1"],
Cell[4526, 154, 329, 11, 52, "SmallText",
  CellTags->"b:8.0.1"],
Cell[4858, 167, 142, 4, 47, "Input",
  CellTags->"b:8.0.1"],
Cell[5003, 173, 318, 9, 38, "Text",
  CellTags->"b:8.0.1"],
Cell[5324, 184, 157, 5, 28, "Text",
  CellTags->"b:8.0.1"],
Cell[5484, 191, 173, 4, 26, "Text",
  CellTags->"b:8.0.1"],
Cell[5660, 197, 113, 2, 47, "Input",
  CellTags->"b:8.0.1"]
}, Closed]],

Cell[CellGroupData[{
Cell[5810, 204, 132, 3, 53, "Subsection",
  CellTags->{"b:8.0.2", "c:4"}],
Cell[5945, 209, 358, 9, 88, "Text",
  CellTags->"b:8.0.2"],
Cell[6306, 220, 66, 2, 47, "Input",
  CellTags->"b:8.0.2"],
Cell[6375, 224, 155, 4, 26, "Text",
  CellTags->"b:8.0.1"],
Cell[6533, 230, 208, 5, 63, "Input",
  CellTags->"b:8.0.2"],
Cell[6744, 237, 160, 4, 47, "Input",
  CellTags->"b:8.0.2"],
Cell[6907, 243, 251, 8, 28, "Text",
  CellTags->"b:8.0.2"],
Cell[7161, 253, 223, 5, 47, "Input",
  CellTags->"b:8.0.2"],
Cell[7387, 260, 139, 4, 28, "Text",
  CellTags->"b:8.0.2"],
Cell[7529, 266, 90, 1, 47, "Input",
  CellTags->"b:8.0.2"],
Cell[7622, 269, 97, 2, 28, "Text",
  CellTags->"b:8.0.2"],
Cell[7722, 273, 65, 1, 47, "Input",
  CellTags->"b:8.0.2"],
Cell[7790, 276, 144, 4, 28, "Text",
  CellTags->"b:8.0.2"],
Cell[7937, 282, 133, 4, 62, "Input",
  CellTags->"b:8.0.2"]
}, Closed]],

Cell[CellGroupData[{
Cell[8107, 291, 157, 4, 53, "Subsection",
  CellTags->{"b:8.0.3", "c:5"}],
Cell[8267, 297, 157, 5, 58, "Text",
  CellTags->"b:8.0.3"],
Cell[8427, 304, 95, 2, 47, "Input",
  CellTags->"b:8.0.3"],
Cell[8525, 308, 113, 2, 28, "Text",
  CellTags->"b:8.0.3"],
Cell[8641, 312, 78, 2, 47, "Input",
  CellTags->"b:8.0.3"],
Cell[8722, 316, 256, 6, 28, "Text",
  CellTags->"b:8.0.3"],
Cell[8981, 324, 160, 4, 47, "Input",
  CellTags->"b:8.0.3"]
}, Closed]],

Cell[CellGroupData[{
Cell[9178, 333, 120, 3, 53, "Subsection",
  CellTags->{"b:8.0.4", "c:6"}],
Cell[9301, 338, 81, 2, 28, "Text",
  CellTags->"b:8.0.4"],
Cell[9385, 342, 129, 3, 47, "Input",
  CellTags->"b:8.0.4"],
Cell[9517, 347, 147, 4, 28, "Text",
  CellTags->"b:8.0.4"],
Cell[9667, 353, 245, 5, 63, "Input",
  CellTags->{"ListPlot", "b:8.0.4"}],
Cell[9915, 360, 98, 2, 28, "Text",
  CellTags->"b:8.0.4"],
Cell[10016, 364, 74, 2, 47, "Input",
  CellTags->"b:8.0.4"],
Cell[10093, 368, 136, 4, 28, "Text",
  CellTags->"b:8.0.4"],
Cell[10232, 374, 127, 2, 47, "Input",
  CellTags->{"Ordering", "b:8.0.4"}],
Cell[10362, 378, 121, 2, 28, "Text",
  CellTags->"b:8.0.4"],
Cell[10486, 382, 208, 4, 63, "Input",
  CellTags->"b:8.0.4"],
Cell[10697, 388, 44, 1, 47, "Input",
  CellTags->"b:8.0.4"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[10790, 395, 105, 2, 42, "Section",
  CellTags->"c:7"],
Cell[10898, 399, 305, 8, 88, "Text",
  CellTags->"b:8.0.1"],
Cell[11206, 409, 86, 2, 47, "Input",
  CellTags->"b:14.0"],
Cell[11295, 413, 80, 2, 47, "Input",
  CellTags->"b:8.1.0"],

Cell[CellGroupData[{
Cell[11400, 419, 126, 3, 69, "Subsection",
  CellTags->{"b:8.1.1", "c:8"}],
Cell[11529, 424, 146, 5, 58, "Text",
  CellTags->"b:8.1.1"],
Cell[11678, 431, 296, 7, 96, "Input",
  CellTags->"b:8.1.1"],
Cell[11977, 440, 69, 2, 47, "Input",
  CellTags->"b:8.1.1"],
Cell[12049, 444, 110, 2, 28, "Text",
  CellTags->"b:8.1.1"],
Cell[12162, 448, 64, 2, 47, "Input",
  CellTags->"b:8.1.1"],
Cell[12229, 452, 117, 2, 28, "Text",
  CellTags->"b:8.1.1"],
Cell[12349, 456, 122, 2, 28, "Text",
  CellTags->"b:8.1.1"],
Cell[12474, 460, 332, 11, 52, "SmallText",
  CellTags->"b:8.1.1"],
Cell[12809, 473, 168, 4, 47, "Input",
  CellTags->"b:8.1.1"],
Cell[12980, 479, 319, 9, 38, "Text",
  CellTags->"b:8.1.1"],
Cell[13302, 490, 157, 5, 28, "Text",
  CellTags->"b:8.1.1"],
Cell[13462, 497, 173, 4, 26, "Text",
  CellTags->"b:8.1.1"],
Cell[13638, 503, 128, 3, 47, "Input",
  CellTags->"b:8.1.1"]
}, Closed]],

Cell[CellGroupData[{
Cell[13803, 511, 131, 3, 53, "Subsection",
  CellTags->{"b:8.1.1", "c:9"}],
Cell[13937, 516, 366, 9, 88, "Text",
  CellTags->"b:8.1.1"],
Cell[14306, 527, 66, 2, 47, "Input",
  CellTags->"b:8.1.1"],
Cell[14375, 531, 265, 6, 63, "Input",
  CellTags->"b:8.1.1"],
Cell[14643, 539, 198, 5, 63, "Input",
  CellTags->"b:8.1.1"],
Cell[14844, 546, 195, 5, 28, "Text",
  CellTags->"b:8.1.1"],
Cell[15042, 553, 149, 5, 47, "Input",
  CellTags->"b:8.1.1"],
Cell[15194, 560, 139, 4, 28, "Text",
  CellTags->"b:8.1.1"],
Cell[15336, 566, 92, 1, 47, "Input",
  CellTags->"b:8.1.1"],
Cell[15431, 569, 94, 2, 28, "Text",
  CellTags->"b:8.0.2"],
Cell[15528, 573, 65, 1, 47, "Input",
  CellTags->"b:8.1.1"]
}, Closed]],

Cell[CellGroupData[{
Cell[15630, 579, 141, 3, 53, "Subsection",
  CellTags->{"b:8.1.1", "c:10"}],
Cell[15774, 584, 184, 6, 58, "Text",
  CellTags->"b:8.1.1"],
Cell[15961, 592, 133, 4, 62, "Input",
  CellTags->"b:8.1.1"],
Cell[16097, 598, 139, 4, 28, "Text",
  CellTags->"b:8.1.1"],
Cell[16239, 604, 95, 2, 47, "Input",
  CellTags->"b:8.1.1"],
Cell[16337, 608, 113, 2, 28, "Text",
  CellTags->"b:8.1.1"],
Cell[16453, 612, 78, 2, 47, "Input",
  CellTags->"b:8.1.1"]
}, Closed]],

Cell[CellGroupData[{
Cell[16568, 619, 120, 3, 53, "Subsection",
  CellTags->{"b:8.1.1", "c:11"}],
Cell[16691, 624, 254, 6, 28, "Text",
  CellTags->"b:8.1.1"],
Cell[16948, 632, 160, 4, 47, "Input",
  CellTags->"b:8.1.1"],
Cell[17111, 638, 81, 2, 28, "Text",
  CellTags->"b:8.1.1"],
Cell[17195, 642, 129, 3, 47, "Input",
  CellTags->"b:8.1.1"],
Cell[17327, 647, 117, 2, 28, "Text",
  CellTags->"b:8.1.1"],
Cell[17447, 651, 168, 3, 47, "Input",
  CellTags->{"ListPlot", "b:8.1.1"}],
Cell[17618, 656, 111, 2, 28, "Text",
  CellTags->"b:8.1.1"],
Cell[17732, 660, 77, 2, 47, "Input",
  CellTags->"b:8.1.1"],
Cell[17812, 664, 181, 5, 47, "Input",
  CellTags->{"Ordering", "b:8.1.1"}],
Cell[17996, 671, 122, 2, 28, "Text",
  CellTags->"b:8.1.1"],
Cell[18121, 675, 208, 4, 63, "Input",
  CellTags->"b:8.1.1"],
Cell[18332, 681, 44, 1, 47, "Input",
  CellTags->"b:8.1.1"]
}, Closed]]
}, Closed]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

