(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     23311,        691]*)
(*NotebookOutlinePosition[     30511,        900]*)
(*  CellTagsIndexPosition[     30199,        884]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[{
  StyleBox["QDENSITY",
    FontSlant->"Italic"],
  "\nQuantum Fourier Transform"
}], "Title",
  CellTags->"c:1"],

Cell["Implementation of the QFT", "Subtitle"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[GridBox[{
            {\(\(References\)\(:\)\), \(\([1]\)\ Quantum\ Computation\ and\ \
Quantum\ Information, \ Nielsen\ and\ Chuang\)}
            },
          ColumnAlignments->{Right, Left}], TraditionalForm]], 
    "DefinitionBox",
    GridBoxOptions->{RowSpacings->0.4,
    RowLines->False},
    CellTags->"S5.1.1"],
  "\nLast Version: 18-Aug-2005"
}], "Abstract"],

Cell[TextData[ButtonBox["Click here to get the palette: QDENSpalette.nb",
  ButtonData:>{"QDENSpalette.nb", None},
  ButtonStyle->"Hyperlink"]], "Text"],

Cell[CellGroupData[{

Cell["Quantum Fourier Transform", "Section",
  FontFamily->"Times",
  CellTags->"c:2"],

Cell["\<\
The Quantum Fourier Transform is equivalent to the Discrete Fourier Transform \

We present here two ways of writing down algorithms that perform the QFT; the \
first one deals with state vectors, while the second one uses the density \
matrix approach. \
\>", "Text",
  FontFamily->"Helvetica"],

Cell[BoxData[
    \(Needs["\<QDENSITY`Qdensity`\>"]\)], "Input",
  FontFamily->"Courier New"],

Cell[BoxData[
    \(\(?QDENSITY`Qdensity`*\)\)], "Input",
  FontFamily->"Courier New"],

Cell[BoxData[{
    \(\(figure = 
        Import["\<drawings/QFT.png\>", "\<PNG\>"];\)\), \
"\[IndentingNewLine]", 
    \(\(Show[figure, ImageSize \[Rule] 900];\)\)}], "Input"],

Cell[CellGroupData[{

Cell["a) Quantum Fourier Transform using vectors", "Subsection",
  CellFrame->True,
  FontFamily->"Times",
  CellTags->{"b:11.0.0", "c:3"}],

Cell["\<\
The quantum Fourier transform of a vector written in its binary \
representation has a very nice expression (we follow the notation of Ref [1]) \
:\
\>", "Text",
  FontFamily->"Helvetica",
  CellTags->"b:11.0.0"],

Cell[BoxData[
    FormBox[GridBox[{
          {Cell[BoxData[
                \(TraditionalForm\`\(\(QuantumFourierTransformV[j\_1, 
                    j\_2,  .. , 
                    j\_n]\)\(=\)\(\ \)\)\)]], \
\(\(\(\(\(\(\(\(\(\(\(\(\((\(|\)\(0\)\)\(\[RightAngleBracket]\)\) + 
                                        e\^\(\[ImaginaryI]2\[Pi]0 . j\_n\) | 
                                        1\)\(\[RightAngleBracket]\)\)\(\ \
\)\()\)\)\[CircleTimes]\(\((\ \(|\)\(0\)\)\(\[RightAngleBracket]\)\) + 
                                e\^\(\[ImaginaryI]2\[Pi]0 . j\_\(n - 1\) j\_n\
\) | 1\)\(\[RightAngleBracket]\)\)\(\ \)\()\)\) ... \)\[CircleTimes]\(\((\ \
\(|\)\(0\)\)\(\[RightAngleBracket]\)\) + 
                    e\^\(\(\[ImaginaryI]2\[Pi]0 . j\_1 .. \) j\_n\) | 
                  1\)\(\[RightAngleBracket]\)\)\()\)\)\n\n
            \(0.  j\_m .. \) 
                j\_l := \(j\_m/2 + j\_\(m + 1\)/2^2\  + \  ... \) + 
                j\_\(n/2\^\(m - l + 1\)\)\)}
          },
        ColumnAlignments->{Right, Left}], TraditionalForm]], "DefinitionBox",
  Editable->False,
  GridBoxOptions->{RowSpacings->0.4},
  CellTags->{"S5.1.1", "b:11.0.0"}],

Cell[TextData[{
  "\nThe binary representation of the base vectors is:",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox[\(\(|\)\(j\_1\)\),
            "TraditionalForm"], ",", \(j\_2\)}], TraditionalForm]]],
  ", ..., ",
  Cell[BoxData[
      \(TraditionalForm\`j\_N\)]],
  "\[RightAngleBracket].  A general vector maybe decomposed as:"
}], "Text",
  FontFamily->"Helvetica",
  CellTags->"b:11.0.0"],

Cell[TextData[{
  " |\[Psi]\[RightAngleBracket] = ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[Sum]\)\(\ \)\)\)]],
  "[ ",
  Cell[BoxData[
      \(TraditionalForm\`a\_k\)]],
  "  * IntegerDigits[k,2,N] , {k,1,2^N}]\nThe function IntegerDigits[k,2,N] \
returns the number k in base 2 with N figures, which is the binary \
representation of the vector k."
}], "Text",
  FontFamily->"Helvetica",
  CellTags->"b:11.0.0"],

Cell[TextData[{
  "Let's ",
  StyleBox["start ",
    FontWeight->"Bold"],
  "by defining the operation ",
  Cell[BoxData[
      \(TraditionalForm\`0.  j\_m\)]],
  " ... ",
  Cell[BoxData[
      \(TraditionalForm\`j\_l\)]],
  ", which enters in the exponents of the Fourier Transform, we call it, \
Zeroff:\nThe symbol  ",
  Cell[BoxData[
      \(TraditionalForm\`0.  j\_m\)]],
  " ... ",
  Cell[BoxData[
      \(TraditionalForm\`j\_l\)]],
  " denotes the series:     ",
  Cell[BoxData[
      \(TraditionalForm\`j\_m\)]],
  " /  2  + ",
  Cell[BoxData[
      \(TraditionalForm\`j\_\(m + 1\)\)]],
  "/ 4 +  ...... ",
  Cell[BoxData[
      \(TraditionalForm\`j\_l\)]],
  " / ",
  Cell[BoxData[
      \(TraditionalForm\`2\^\(m + 1\)\)]],
  "= Zeroff.\nThe notation used is that vac is the vector in binary notation \
that we are going to Fourier Transform and the array R  stores the indices m \
to j ."
}], "Text",
  FontFamily->"Helvetica",
  CellTags->"b:11.0.0"],

Cell[BoxData[
    \(Zeroff[vac_, R_] := 
      Sum[vac[\([R[\([i]\)]]\)]/2^i, {i, 1, Length[R]}]\)], "Input",
  CellTags->"b:11.0.0"],

Cell["\<\
Then the Quantum Fourier Transform can be readily written  using tensor \
products of Kets:  (and its inverse);  this corresponds to Eq. 5.4 in \
Ref.[1].\
\>", "Text",
  FontFamily->"Helvetica",
  CellTags->"b:11.0.0"],

Cell[BoxData[
    \(\(\(QuantumFourierTransformV[
          vac_] := \[IndentingNewLine]Module[{\[CapitalOmega], L}, 
          L = Length[
              vac]; \[CapitalOmega] = \((Ket[0] + 
                Exp[2*\[Pi]*\ \[ImaginaryI]*Zeroff[vac, Range[L, L]]]*
                  Ket[1])\); \[IndentingNewLine]For[i = 2, 
            i \[LessEqual] L, \(i++\), 
            phass = 2*\[Pi]*\ \[ImaginaryI]*
                Zeroff[vac, 
                  Range[L - i + 1, 
                    L]]; \[CapitalOmega] = \
\[CapitalOmega]\[CircleTimes]\((Ket[0] + 
                    Exp[phass]*
                      Ket[1])\)]; \[IndentingNewLine]\[CapitalOmega] = \
\[CapitalOmega]/2^\((L/2)\); \[CapitalOmega]];\)\(\ \ \)\)\)], "Input",
  CellTags->"b:11.0.0"],

Cell[BoxData[
    \(\(\(IQuantumFourierTransformV[
          vac_] := \[IndentingNewLine]Module[{\[CapitalOmega], L}, 
          L = Length[
              vac]; \[CapitalOmega] = \((Ket[0] + 
                Exp[\(-2\)*\[Pi]*\ \[ImaginaryI]*Zeroff[vac, Range[L, L]]]*
                  Ket[1])\); \[IndentingNewLine]For[i = 2, 
            i \[LessEqual] L, \(i++\), 
            phass = \(-2\)*\[Pi]*\ \[ImaginaryI]*
                Zeroff[vac, 
                  Range[L - i + 1, 
                    L]]; \[CapitalOmega] = \
\[CapitalOmega]\[CircleTimes]\((Ket[0] + 
                    Exp[phass]*Ket[1])\)]; \[CapitalOmega]/
            2^\((L/2)\)];\)\(\ \ \)\)\)], "Input",
  CellTags->"b:11.0.0"],

Cell[TextData[{
  "For example, let us compute the QFT of state vector  | 0,1,1 \
\[RightAngleBracket]  ( In the full computational base, this vector would \
correspond to  the matrix (00010000) that is since binary 011 is decimal 3,\n\
the matrix representing the state has a 1 in location four.\n NOTE that \
|0,0,1\[RightAngleBracket]+|1,0,0\[RightAngleBracket] \[NotEqual] |1,0,1\
\[RightAngleBracket] !!  ) \n Now consider the QFT of the state state vector  \
| 0,1,1 \[RightAngleBracket]  which is of length ",
  Cell[BoxData[
      \(TraditionalForm\`2\^3\)]]
}], "Text",
  FontFamily->"Helvetica",
  CellTags->"b:11.0.0"],

Cell[BoxData[
    \(QFT011 = QuantumFourierTransformV[{0, 1, 1}]\)], "Input",
  CellTags->"b:11.0.0"],

Cell[TextData[{
  "As can be seen the output is a list of ",
  Cell[BoxData[
      \(TraditionalForm\`2\^N\)]],
  " numbers, where N is the dimension of our vector in the binary \
representation."
}], "Text",
  FontFamily->"Helvetica",
  CellTags->"b:11.0.0"],

Cell["We can check whether it is normalized:", "Text",
  FontFamily->"Helvetica",
  CellTags->"b:11.0.0"],

Cell[BoxData[
    \(Norm[QFT011]\)], "Input",
  CellTags->"b:11.0.0"],

Cell[CellGroupData[{

Cell[TextData[{
  "A ",
  StyleBox["more general random vector (with N=4)",
    FontWeight->"Bold"],
  " could be:"
}], "Subsubsection",
  FontFamily->"Helvetica",
  CellTags->{"b:11.0.0", "c:4"}],

Cell[BoxData[{
    \(\(RanVector = 
        Table[Random[Real, {0, 2}], {i, 1, 
            2^4}];\)\), "\[IndentingNewLine]", 
    \(RanVector = RanVector/Norm[RanVector]\), "\[IndentingNewLine]", 
    \(\(ListPlot[RanVector, PlotJoined \[Rule] True];\)\)}], "Input",
  CellTags->"b:11.0.0"],

Cell["\<\
we apply the quantum fourier transform: (NOTE we compute the QFT of the base \
vectors)\
\>", "Text",
  FontFamily->"Helvetica",
  CellTags->"b:11.0.0"],

Cell[BoxData[
    \(QFTVec = 
      Sum[RanVector[\([i + 1]\)] 
          QuantumFourierTransformV[IntegerDigits[i, 2, 4]], {i, 0, 
          2^4 - 1}]\)], "Input",
  CellTags->"b:11.0.0"],

Cell["\<\
An we can then use the inverse and compare with the original vector:\
\>", "Text",
  FontFamily->"Helvetica",
  CellTags->"b:11.0.0"],

Cell[BoxData[{
    \(IQFTVec = 
      Chop[Sum[\(QFTVec[\([i + 1]\)]\)[\([1]\)]*
            IQuantumFourierTransformV[IntegerDigits[i, 2, 4]], {i, 0, 
            2^4 - 1}]]\), "\[IndentingNewLine]", 
    \(\(IQFTVec = Flatten[IQFTVec];\)\), "\[IndentingNewLine]", 
    \(Chop[RanVector - IQFTVec]\)}], "Input",
  CellTags->"b:11.0.0"],

Cell["\<\
The  inverse of the QFT and  the original vector prove to be the same, which \
is a check on the procedures.\
\>", "Text",
  FontFamily->"Helvetica",
  CellTags->"b:11.0.0"]
}, Open  ]],

Cell[CellGroupData[{

Cell["QFT of the Sin[x]/x function", "Subsubsection",
  FontFamily->"Helvetica",
  CellTags->{"b:11.0.0", "c:5"}],

Cell["\<\
In this example, we construct our vector out of a known function, Sin[x/a]/x. \
We make use of 6 qubits. \
\>", "Text",
  FontFamily->"Helvetica",
  CellTags->"b:11.0.0"],

Cell[BoxData[{
    \(\(SinVector = 
        Table[Sin[i/2^6*4*Pi]/i, {i, 1, 
            2^6}];\)\ \ \), "\[IndentingNewLine]", 
    \(\(SinVector = SinVector/Norm[SinVector];\)\), "\[IndentingNewLine]", 
    \(\(ListPlot[SinVector, PlotJoined \[Rule] True, 
        AxesLabel \[Rule] {Number, "\<Sin[Number]\>"}];\)\)}], "Input",
  CellTags->"b:11.0.0"],

Cell["\<\
we apply the quantum Fourier transform: (NOTE we compute the QFT of the base \
vectors)\
\>", "Text",
  FontFamily->"Helvetica",
  CellTags->"b:11.0.0"],

Cell[BoxData[{
    \(\(QFTSin = 
        N[Sum[SinVector[\([i + 1]\)]*
              QuantumFourierTransformV[IntegerDigits[i, 2, 6]], {i, 0, 
              2^6 - 1}]];\)\), "\[IndentingNewLine]", 
    \(\(Chop[QFTSin];\)\), "\[IndentingNewLine]", 
    \(\(QFTSinplotRe = Chop[Re[N[QFTSin]]];\)\), "\[IndentingNewLine]", 
    \(\(QFTSinplotIM = Chop[Im[QFTSin]];\)\), "\[IndentingNewLine]", 
    \(\(ListPlot[Flatten[QFTSinplotRe], PlotJoined \[Rule] True, 
        AxesLabel \[Rule] {Number, "\<Real part of QFT\>"}, 
        PlotRange \[Rule] {\(-0.05\),  .1}];\)\), "\[IndentingNewLine]", 
    \(\(ListPlot[Flatten[QFTSinplotIM], PlotJoined \[Rule] True, 
        AxesLabel \[Rule] {Number, "\<Imaginary part QFT\>"}, 
        PlotRange \[Rule] {\(-0.2\),  .2}];\)\)}], "Input",
  CellTags->"b:11.0.0"],

Cell["And we invert it to recover the original function:", "Text",
  FontFamily->"Helvetica",
  CellTags->"b:11.0.0"],

Cell[BoxData[{
    \(\(IQFTSin = 
        Chop[Sum[\(QFTSin[\([i + 1]\)]\)[\([1]\)]*
              IQuantumFourierTransformV[IntegerDigits[i, 2, 6]], {i, 0, 
              2^6 - 1}]];\)\), "\[IndentingNewLine]", 
    \(\(IQFTSin = Chop[Flatten[N[IQFTSin]]];\)\), "\[IndentingNewLine]", 
    \(\(ListPlot[Flatten[IQFTSin], PlotJoined \[Rule] True];\)\)}], "Input",
  CellTags->"b:11.0.0"],

Cell["\<\
The Quantum Fourier Transform is in fact the same as the Discrete Fourier \
Transform (DFT):; therefore, 
we can check our results by performing the DFT that is already provided in \
Mathematica.  For instance,  this last 
step of inverting is invoked by the command  InverseFourier[ ].
[NOTE: Although mathematically the same thing, it is essential to emphasize \
that the physical implementation of the QFT making good use of quantum \
interference is what makes it appealing.]\
\>", "Text",
  FontFamily->"Helvetica",
  CellTags->"b:11.0.0"],

Cell[BoxData[{
    \(\(itras = Chop[InverseFourier[QFTSin]];\)\), "\[IndentingNewLine]", 
    \(\(ListPlot[Flatten[itras]];\)\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["QFT of a constant function", "Subsubsection",
  FontFamily->"Helvetica",
  CellTags->{"b:11.0.0", "c:6"}],

Cell[BoxData[{
    \(\(CteVector = Table[1, {i, 1, 2^6}];\)\ \), "\[IndentingNewLine]", 
    \(\(CteVector = CteVector/Norm[CteVector];\)\), "\[IndentingNewLine]", 
    \(\(ListPlot[CteVector, PlotJoined \[Rule] True, 
        AxesLabel \[Rule] {Number, "\<Cte\>"}];\)\)}], "Input",
  CellTags->"b:11.0.0"],

Cell["\<\
we apply the quantum Fourier transform: (NOTE we compute the QFT of the base \
vectors)\
\>", "Text",
  FontFamily->"Helvetica",
  CellTags->"b:11.0.0"],

Cell[BoxData[{
    \(\(QFTCte = 
        N[Sum[CteVector[\([i + 1]\)]*
              QuantumFourierTransformV[IntegerDigits[i, 2, 6]], {i, 0, 
              2^6 - 1}]];\)\), "\[IndentingNewLine]", 
    \(\(Chop[QFTCte];\)\), "\[IndentingNewLine]", 
    \(\(QFTCteplotRe = Chop[Re[N[QFTCte]]];\)\), "\[IndentingNewLine]", 
    \(\(QFTCteplotIM = Chop[Im[QFTCte]];\)\), "\[IndentingNewLine]", 
    \(\(ListPlot[Flatten[QFTCteplotRe], PlotJoined \[Rule] True, 
        AxesLabel \[Rule] {Number, "\<Real part of QFT\>"}, 
        PlotRange \[Rule] {\(-0.05\),  .1}];\)\), "\[IndentingNewLine]", 
    \(\(ListPlot[Flatten[QFTCteplotIM], PlotJoined \[Rule] True, 
        AxesLabel \[Rule] {Number, "\<Imaginary part QFT\>"}, 
        PlotRange \[Rule] {\(-0.2\),  .2}];\)\)}], "Input",
  CellTags->"b:11.0.0"],

Cell["And we invert it to recover the original function:", "Text",
  FontFamily->"Helvetica",
  CellTags->"b:11.0.0"],

Cell[BoxData[{
    \(\(IQFTCte = 
        Chop[Sum[\(QFTCte[\([i + 1]\)]\)[\([1]\)]*
              IQuantumFourierTransformV[IntegerDigits[i, 2, 6]], {i, 0, 
              2^6 - 1}]];\)\), "\[IndentingNewLine]", 
    \(\(IQFTCte = Chop[Flatten[N[IQFTCte]]];\)\), "\[IndentingNewLine]", 
    \(\(ListPlot[Flatten[IQFTCte], PlotJoined \[Rule] True, 
        PlotRange \[Rule] {0, 1}];\)\)}], "Input",
  CellTags->"b:11.0.0"]
}, Open  ]],

Cell[CellGroupData[{

Cell["QFT of the Mod[x,5] function", "Subsubsection",
  FontFamily->"Helvetica",
  CellTags->{"b:11.0.0", "c:7"}],

Cell[BoxData[{
    \(\(ModVector = 
        Table[Mod[i, 5], {i, 1, 2^6}];\)\ \), "\[IndentingNewLine]", 
    \(\(ModVector = ModVector/Norm[ModVector];\)\), "\[IndentingNewLine]", 
    \(\(ListPlot[ModVector, PlotJoined \[Rule] True, 
        AxesLabel \[Rule] {Number, "\<Mod[Number,5]\>"}];\)\)}], "Input",
  CellTags->"b:11.0.0"],

Cell["\<\
we apply the quantum Fourier transform: (NOTE we compute the QFT of the base \
vectors)\
\>", "Text",
  FontFamily->"Helvetica",
  CellTags->"b:11.0.0"],

Cell[BoxData[{
    \(\(QFTMod = 
        N[Sum[ModVector[\([i + 1]\)]*
              QuantumFourierTransformV[IntegerDigits[i, 2, 6]], {i, 0, 
              2^6 - 1}]];\)\), "\[IndentingNewLine]", 
    \(\(Chop[QFTMod];\)\), "\[IndentingNewLine]", 
    \(\(QFTModplotRe = Chop[Re[N[QFTMod]]];\)\), "\[IndentingNewLine]", 
    \(\(QFTModplotIM = Chop[Im[QFTMod]];\)\), "\[IndentingNewLine]", 
    \(\(ListPlot[Flatten[QFTModplotRe], PlotJoined \[Rule] True, 
        AxesLabel \[Rule] {Number, "\<Real part of QFT\>"}, 
        PlotRange \[Rule] {\(-0.05\),  .1}];\)\), "\[IndentingNewLine]", 
    \(\(ListPlot[Flatten[QFTModplotIM], PlotJoined \[Rule] True, 
        AxesLabel \[Rule] {Number, "\<Imaginary part QFT\>"}, 
        PlotRange \[Rule] {\(-0.2\),  .2}];\)\)}], "Input",
  CellTags->"b:11.0.0"],

Cell["And we invert it to recover the original function:", "Text",
  FontFamily->"Helvetica",
  CellTags->"b:11.0.0"],

Cell[BoxData[{
    \(\(IQFTMod = 
        Chop[Sum[\(QFTMod[\([i + 1]\)]\)[\([1]\)]*
              IQuantumFourierTransformV[IntegerDigits[i, 2, 6]], {i, 0, 
              2^6 - 1}]];\)\), "\[IndentingNewLine]", 
    \(\(IQFTMod = Chop[Flatten[N[IQFTMod]]];\)\), "\[IndentingNewLine]", 
    \(\(ListPlot[Flatten[IQFTMod], PlotJoined \[Rule] True];\)\)}], "Input",
  CellTags->"b:11.0.0"],

Cell["\<\
This kind of periodicity plays an important role in Shor's algorithm.\
\>", "Text",
  FontFamily->"Helvetica",
  CellTags->"b:11.0.0"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["b) Quantum Fourier Transform using  density matrices", "Subsection",
  CellFrame->True,
  FontFamily->"Times",
  CellTags->{"b:11.0.1", "c:8"}],

Cell["\<\
To compute the Quantum Fourier Transform in a density matrix framework, we \
define it in a multiqubit system by following the above figure where it is \
built by combining Controlled phase gates and Hadamard gates. First we define \
the gates we need, and provide compiled versions to speed the computation.\
\>", "Text",
  FontFamily->"Helvetica",
  CellTags->"b:11.0.1"],

Cell[TextData[{
  "The controlled phase gate used ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(R\_k\)\(\ \)\(=\)\)\)]],
  Cell[BoxData[
      FormBox[
        RowBox[{"(", GridBox[{
              {"1", "0"},
              {"0", \(e\^\(2  \[Pi]\ \[ImaginaryI]/2\^k\)\)}
              }], ")"}], TraditionalForm]]],
  ", can be written in the following way as a two qubit operator:"
}], "Text",
  FontFamily->"Helvetica",
  CellTags->"b:11.0.1"],

Cell[BoxData[
    \(\(ControlP[L_, q1_, q2_, k_] := 
        Module[{\[Phi]}, \[Phi] = Exp[2*\ \[Pi]\ *\ \[ImaginaryI]\ /2\^k]; 
          1/4*\((\((3 + \[Phi])\)*TwoOp[L, q1, q2, 0, 0] + \((1 - \[Phi])\)*
                  TwoOp[L, q1, q2, 3, 0] + \((1 - \[Phi])\)*
                  TwoOp[L, q1, q2, 0, 3] + \((\[Phi] - 1)\)*
                  TwoOp[L, q1, q2, 3, 3])\)];\)\)], "Input",
  CellTags->"b:11.0.1"],

Cell[" Forms Operator to Invert L qubits... the last step of QFT ", "Text",
  FontFamily->"Helvetica",
  CellTags->"b:11.0.1"],

Cell[BoxData[
    \(InvertQubits[L_] := \(InvertQubits[L] = 
        Table[If[
            Reverse[IntegerDigits[i, 2, L]] \[Equal] \ 
              IntegerDigits[j, 2, L], 1, 0], {i, 0, 2^L - 1}, {j, 0, 
            2^L - 1}]\)\)], "Input",
  CellTags->"b:11.0.1"],

Cell[TextData[StyleBox["Generate Compiled versions of the Functions to speed \
the computation: ",
  FontWeight->"Bold"]], "Text",
  FontFamily->"Helvetica",
  CellTags->"b:11.0.1"],

Cell[BoxData[
    \(\(CompControlP = \ 
        Compile[{{L, _Integer}, {q1, _Integer}, {q2, _Integer}, {k, \
_Integer}}, 
          Block[{Lv = L, qv1 = q1, qv2 = q2, kv = k\ \ }, \ 
            ControlP[Lv, qv1, qv2, 
              kv]], {{\ \ \ ControlP[Lv, qv1, qv2, kv], _Complex, 
              2}}]\ ;\)\)], "Input",
  CellTags->"b:11.0.1"],

Cell[BoxData[
    \(\(CompHad = \ 
        Compile[{{L, _Integer}, {i, _Integer}}, 
          Block[{Lv = L, iv = i}, \ 
            had[Lv, iv]], {{\ \ \ had[Lv, iv], _Real, 2}}]\ \ ;\)\)], "Input",\

  CellTags->"b:11.0.1"],

Cell[BoxData[
    \(\(CompInvertQubits = \ 
        Compile[{{L, _Integer}}, 
          Block[{Lv = L\ }, 
            InvertQubits[Lv]], {{\ \ InvertQubits[Lv], _Real, 
              2}}]\ \ ;\)\)], "Input",
  CellTags->"b:11.0.1"],

Cell["Then the Quantum Fourier Transform operator reads:", "Text",
  FontFamily->"Helvetica",
  CellTags->"b:11.0.1"],

Cell[BoxData[
    \(\(\(QuantumFourierTransform = 
        Compile[{{L, _Integer}, {\[CapitalOmega]s, _Complex, 
              2}}, \[IndentingNewLine]Module[{\[CapitalOmega]}, \
\[CapitalOmega] = \[CapitalOmega]s; \[IndentingNewLine]For[i = 1, 
              i \[LessEqual] L, \(i++\), \[CapitalOmega] = 
                N[CompHad[L, i] . \[CapitalOmega]]; 
              For[\ j = i + 1, 
                j \[LessEqual] L, \(j++\), \[CapitalOmega] = 
                  N[CompControlP[L, j, i, 
                        j - i + 
                          1] . \[CapitalOmega]]]]; \[IndentingNewLine]\
\[CapitalOmega] = 
              CompInvertQubits[
                  L] . \[CapitalOmega]; \[CapitalOmega]], \ \
\[IndentingNewLine]{{\ CompHad[L, i], _Real, 2}, {\ 
              CompControlP[L, j, i, j - i + 1], _Complex, 2}, {\ 
              CompInvertQubits[L], _Real, 2}}\ ];\)\(\ \ \)\)\)], "Input",
  CellTags->"b:11.0.1"],

Cell["\<\
We can check both definitions, the density matrix one and the vector one. \
Making use of our previous RanVector, we can construct the pure state density \
matrix:\
\>", "Text",
  FontFamily->"Helvetica",
  CellTags->"b:11.0.1"],

Cell[BoxData[
    \(\(DensRanVec = {RanVector}\[CircleTimes]Adj[{RanVector}];\)\)], "Input",\

  CellTags->"b:11.0.1"],

Cell["And apply the quantum fourier transform just defined:", "Text",
  FontFamily->"Helvetica",
  CellTags->"b:11.0.1"],

Cell[BoxData[{
    \(\(QFTDens = 
        QuantumFourierTransform[4, 
          IdentityMatrix[4^2]];\)\), "\[IndentingNewLine]", 
    \(\(QFTDensVec = 
        QFTDens . DensRanVec . Adj[QFTDens];\)\), "\[IndentingNewLine]", 
    \(Length[QFTDens]\)}], "Input",
  CellTags->"b:11.0.1"],

Cell["\<\
Which we can compare to the pure state density matrix constructed with the \
fourier transform of RanVector:\
\>", "Text",
  FontFamily->"Helvetica",
  CellTags->"b:11.0.1"],

Cell[BoxData[
    \(DensQFTVec = QFTVec\[CircleTimes]Adj[QFTVec]\)], "Input",
  CellTags->"b:11.0.1"],

Cell[BoxData[
    \(Chop[DensQFTVec - QFTDensVec]\)], "Input",
  CellTags->"b:11.0.1"],

Cell[BoxData[
    \(Quit\)], "Input",
  CellTags->"b:11.0.1"]
}, Open  ]]
}, Closed]]
},
FrontEndVersion->"5.2 for X",
ScreenRectangle->{{0, 1280}, {0, 800}},
ShowPageBreaks->False,
WindowToolbars->{},
WindowSize->{1267, 746},
WindowMargins->{{0, Automatic}, {Automatic, 1}},
PrintingStartingPageNumber->46,
PrintingPageRange->{Automatic, Automatic},
PrintingOptions->{"PaperSize"->{612, 792},
"PaperOrientation"->"Portrait",
"PostScriptOutputFile":>FrontEnd`FileName[{$RootDirectory, "export", "home", \
"brunojd"}, "t.ps", CharacterEncoding -> "iso8859-1"],
"Magnification"->1},
ShowSelection->True,
TaggingRules:>{"PaginationCache" -> {{2005, 8, 9, 3, 36, \
21.330055`8.081566958720561}, {46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, \
46, 46, 47, 47, 47, 47, 47, 47, 47, 47, 47, 47, 47, 48, 48, 48, 48, 48, 48, \
48, 48, 48, 48, 48, 48, 48, 49, 49, 49, 49, 49, 49, 49, 49, 49, 50, 50, 50, \
50, 50, 50, 50, 50, 50, 50, 50, 50, 51, 51, 51, 51, 51, 51, 51, 51, 51, 51, \
51, 51, 51, 51, 52}, Automatic}},
CellLabelAutoDelete->True,
Magnification->1,
StyleDefinitions -> "Classroom.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "c:1"->{
    Cell[1754, 51, 128, 5, 122, "Title",
      CellTags->"c:1"]},
  "c:2"->{
    Cell[2528, 80, 86, 2, 62, "Section",
      CellTags->"c:2"]},
  "b:11.0.0"->{
    Cell[3310, 109, 139, 3, 69, "Subsection",
      CellTags->{"b:11.0.0", "c:3"}],
    Cell[3452, 114, 222, 6, 28, "Text",
      CellTags->"b:11.0.0"],
    Cell[3677, 122, 1162, 22, 88, "DefinitionBox",
      CellTags->{"S5.1.1", "b:11.0.0"}],
    Cell[4842, 146, 418, 13, 58, "Text",
      CellTags->"b:11.0.0"],
    Cell[5263, 161, 421, 12, 58, "Text",
      CellTags->"b:11.0.0"],
    Cell[5687, 175, 962, 34, 88, "Text",
      CellTags->"b:11.0.0"],
    Cell[6652, 211, 133, 3, 47, "Input",
      CellTags->"b:11.0.0"],
    Cell[6788, 216, 229, 6, 28, "Text",
      CellTags->"b:11.0.0"],
    Cell[7020, 224, 759, 16, 95, "Input",
      CellTags->"b:11.0.0"],
    Cell[7782, 242, 704, 15, 79, "Input",
      CellTags->"b:11.0.0"],
    Cell[8489, 259, 629, 12, 118, "Text",
      CellTags->"b:11.0.0"],
    Cell[9121, 273, 101, 2, 47, "Input",
      CellTags->"b:11.0.0"],
    Cell[9225, 277, 259, 8, 28, "Text",
      CellTags->"b:11.0.0"],
    Cell[9487, 287, 105, 2, 28, "Text",
      CellTags->"b:11.0.0"],
    Cell[9595, 291, 69, 2, 47, "Input",
      CellTags->"b:11.0.0"],
    Cell[9689, 297, 196, 7, 46, "Subsubsection",
      CellTags->{"b:11.0.0", "c:4"}],
    Cell[9888, 306, 292, 6, 79, "Input",
      CellTags->"b:11.0.0"],
    Cell[10183, 314, 162, 5, 28, "Text",
      CellTags->"b:11.0.0"],
    Cell[10348, 321, 188, 5, 47, "Input",
      CellTags->"b:11.0.0"],
    Cell[10539, 328, 143, 4, 28, "Text",
      CellTags->"b:11.0.0"],
    Cell[10685, 334, 336, 7, 79, "Input",
      CellTags->"b:11.0.0"],
    Cell[11024, 343, 183, 5, 28, "Text",
      CellTags->"b:11.0.0"],
    Cell[11244, 353, 113, 2, 46, "Subsubsection",
      CellTags->{"b:11.0.0", "c:5"}],
    Cell[11360, 357, 180, 5, 28, "Text",
      CellTags->"b:11.0.0"],
    Cell[11543, 364, 354, 7, 79, "Input",
      CellTags->"b:11.0.0"],
    Cell[11900, 373, 162, 5, 28, "Text",
      CellTags->"b:11.0.0"],
    Cell[12065, 380, 805, 14, 127, "Input",
      CellTags->"b:11.0.0"],
    Cell[12873, 396, 117, 2, 28, "Text",
      CellTags->"b:11.0.0"],
    Cell[12993, 400, 387, 7, 79, "Input",
      CellTags->"b:11.0.0"],
    Cell[13383, 409, 554, 11, 118, "Text",
      CellTags->"b:11.0.0"],
    Cell[14116, 429, 111, 2, 46, "Subsubsection",
      CellTags->{"b:11.0.0", "c:6"}],
    Cell[14230, 433, 306, 5, 79, "Input",
      CellTags->"b:11.0.0"],
    Cell[14539, 440, 162, 5, 28, "Text",
      CellTags->"b:11.0.0"],
    Cell[14704, 447, 805, 14, 127, "Input",
      CellTags->"b:11.0.0"],
    Cell[15512, 463, 117, 2, 28, "Text",
      CellTags->"b:11.0.0"],
    Cell[15632, 467, 422, 8, 79, "Input",
      CellTags->"b:11.0.0"],
    Cell[16091, 480, 113, 2, 46, "Subsubsection",
      CellTags->{"b:11.0.0", "c:7"}],
    Cell[16207, 484, 333, 6, 79, "Input",
      CellTags->"b:11.0.0"],
    Cell[16543, 492, 162, 5, 28, "Text",
      CellTags->"b:11.0.0"],
    Cell[16708, 499, 805, 14, 127, "Input",
      CellTags->"b:11.0.0"],
    Cell[17516, 515, 117, 2, 28, "Text",
      CellTags->"b:11.0.0"],
    Cell[17636, 519, 387, 7, 79, "Input",
      CellTags->"b:11.0.0"],
    Cell[18026, 528, 144, 4, 28, "Text",
      CellTags->"b:11.0.0"]},
  "c:3"->{
    Cell[3310, 109, 139, 3, 69, "Subsection",
      CellTags->{"b:11.0.0", "c:3"}]},
  "S5.1.1"->{
    Cell[3677, 122, 1162, 22, 88, "DefinitionBox",
      CellTags->{"S5.1.1", "b:11.0.0"}]},
  "c:4"->{
    Cell[9689, 297, 196, 7, 46, "Subsubsection",
      CellTags->{"b:11.0.0", "c:4"}]},
  "c:5"->{
    Cell[11244, 353, 113, 2, 46, "Subsubsection",
      CellTags->{"b:11.0.0", "c:5"}]},
  "c:6"->{
    Cell[14116, 429, 111, 2, 46, "Subsubsection",
      CellTags->{"b:11.0.0", "c:6"}]},
  "c:7"->{
    Cell[16091, 480, 113, 2, 46, "Subsubsection",
      CellTags->{"b:11.0.0", "c:7"}]},
  "b:11.0.1"->{
    Cell[18219, 538, 149, 3, 69, "Subsection",
      CellTags->{"b:11.0.1", "c:8"}],
    Cell[18371, 543, 383, 7, 46, "Text",
      CellTags->"b:11.0.1"],
    Cell[18757, 552, 446, 13, 51, "Text",
      CellTags->"b:11.0.1"],
    Cell[19206, 567, 412, 7, 67, "Input",
      CellTags->"b:11.0.1"],
    Cell[19621, 576, 126, 2, 28, "Text",
      CellTags->"b:11.0.1"],
    Cell[19750, 580, 265, 6, 47, "Input",
      CellTags->"b:11.0.1"],
    Cell[20018, 588, 181, 4, 28, "Text",
      CellTags->"b:11.0.1"],
    Cell[20202, 594, 347, 8, 63, "Input",
      CellTags->"b:11.0.1"],
    Cell[20552, 604, 225, 6, 47, "Input",
      CellTags->"b:11.0.1"],
    Cell[20780, 612, 232, 6, 47, "Input",
      CellTags->"b:11.0.1"],
    Cell[21015, 620, 117, 2, 28, "Text",
      CellTags->"b:11.0.1"],
    Cell[21135, 624, 931, 18, 111, "Input",
      CellTags->"b:11.0.1"],
    Cell[22069, 644, 238, 6, 28, "Text",
      CellTags->"b:11.0.1"],
    Cell[22310, 652, 118, 3, 47, "Input",
      CellTags->"b:11.0.1"],
    Cell[22431, 657, 120, 2, 28, "Text",
      CellTags->"b:11.0.1"],
    Cell[22554, 661, 286, 7, 79, "Input",
      CellTags->"b:11.0.1"],
    Cell[22843, 670, 183, 5, 28, "Text",
      CellTags->"b:11.0.1"],
    Cell[23029, 677, 101, 2, 47, "Input",
      CellTags->"b:11.0.1"],
    Cell[23133, 681, 86, 2, 47, "Input",
      CellTags->"b:11.0.1"],
    Cell[23222, 685, 61, 2, 47, "Input",
      CellTags->"b:11.0.1"]},
  "c:8"->{
    Cell[18219, 538, 149, 3, 69, "Subsection",
      CellTags->{"b:11.0.1", "c:8"}]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"c:1", 24737, 725},
  {"c:2", 24814, 728},
  {"b:11.0.0", 24896, 731},
  {"c:3", 28042, 818},
  {"S5.1.1", 28141, 821},
  {"c:4", 28245, 824},
  {"c:5", 28344, 827},
  {"c:6", 28444, 830},
  {"c:7", 28544, 833},
  {"b:11.0.1", 28649, 836},
  {"c:8", 30088, 877}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 128, 5, 122, "Title",
  CellTags->"c:1"],
Cell[1885, 58, 45, 0, 41, "Subtitle"],
Cell[1933, 60, 415, 12, 42, "Abstract"],
Cell[2351, 74, 152, 2, 28, "Text"],

Cell[CellGroupData[{
Cell[2528, 80, 86, 2, 62, "Section",
  CellTags->"c:2"],
Cell[2617, 84, 305, 7, 58, "Text"],
Cell[2925, 93, 93, 2, 47, "Input"],
Cell[3021, 97, 86, 2, 47, "Input"],
Cell[3110, 101, 175, 4, 63, "Input"],

Cell[CellGroupData[{
Cell[3310, 109, 139, 3, 69, "Subsection",
  CellTags->{"b:11.0.0", "c:3"}],
Cell[3452, 114, 222, 6, 28, "Text",
  CellTags->"b:11.0.0"],
Cell[3677, 122, 1162, 22, 88, "DefinitionBox",
  CellTags->{"S5.1.1", "b:11.0.0"}],
Cell[4842, 146, 418, 13, 58, "Text",
  CellTags->"b:11.0.0"],
Cell[5263, 161, 421, 12, 58, "Text",
  CellTags->"b:11.0.0"],
Cell[5687, 175, 962, 34, 88, "Text",
  CellTags->"b:11.0.0"],
Cell[6652, 211, 133, 3, 47, "Input",
  CellTags->"b:11.0.0"],
Cell[6788, 216, 229, 6, 28, "Text",
  CellTags->"b:11.0.0"],
Cell[7020, 224, 759, 16, 95, "Input",
  CellTags->"b:11.0.0"],
Cell[7782, 242, 704, 15, 79, "Input",
  CellTags->"b:11.0.0"],
Cell[8489, 259, 629, 12, 118, "Text",
  CellTags->"b:11.0.0"],
Cell[9121, 273, 101, 2, 47, "Input",
  CellTags->"b:11.0.0"],
Cell[9225, 277, 259, 8, 28, "Text",
  CellTags->"b:11.0.0"],
Cell[9487, 287, 105, 2, 28, "Text",
  CellTags->"b:11.0.0"],
Cell[9595, 291, 69, 2, 47, "Input",
  CellTags->"b:11.0.0"],

Cell[CellGroupData[{
Cell[9689, 297, 196, 7, 46, "Subsubsection",
  CellTags->{"b:11.0.0", "c:4"}],
Cell[9888, 306, 292, 6, 79, "Input",
  CellTags->"b:11.0.0"],
Cell[10183, 314, 162, 5, 28, "Text",
  CellTags->"b:11.0.0"],
Cell[10348, 321, 188, 5, 47, "Input",
  CellTags->"b:11.0.0"],
Cell[10539, 328, 143, 4, 28, "Text",
  CellTags->"b:11.0.0"],
Cell[10685, 334, 336, 7, 79, "Input",
  CellTags->"b:11.0.0"],
Cell[11024, 343, 183, 5, 28, "Text",
  CellTags->"b:11.0.0"]
}, Open  ]],

Cell[CellGroupData[{
Cell[11244, 353, 113, 2, 46, "Subsubsection",
  CellTags->{"b:11.0.0", "c:5"}],
Cell[11360, 357, 180, 5, 28, "Text",
  CellTags->"b:11.0.0"],
Cell[11543, 364, 354, 7, 79, "Input",
  CellTags->"b:11.0.0"],
Cell[11900, 373, 162, 5, 28, "Text",
  CellTags->"b:11.0.0"],
Cell[12065, 380, 805, 14, 127, "Input",
  CellTags->"b:11.0.0"],
Cell[12873, 396, 117, 2, 28, "Text",
  CellTags->"b:11.0.0"],
Cell[12993, 400, 387, 7, 79, "Input",
  CellTags->"b:11.0.0"],
Cell[13383, 409, 554, 11, 118, "Text",
  CellTags->"b:11.0.0"],
Cell[13940, 422, 139, 2, 63, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[14116, 429, 111, 2, 46, "Subsubsection",
  CellTags->{"b:11.0.0", "c:6"}],
Cell[14230, 433, 306, 5, 79, "Input",
  CellTags->"b:11.0.0"],
Cell[14539, 440, 162, 5, 28, "Text",
  CellTags->"b:11.0.0"],
Cell[14704, 447, 805, 14, 127, "Input",
  CellTags->"b:11.0.0"],
Cell[15512, 463, 117, 2, 28, "Text",
  CellTags->"b:11.0.0"],
Cell[15632, 467, 422, 8, 79, "Input",
  CellTags->"b:11.0.0"]
}, Open  ]],

Cell[CellGroupData[{
Cell[16091, 480, 113, 2, 46, "Subsubsection",
  CellTags->{"b:11.0.0", "c:7"}],
Cell[16207, 484, 333, 6, 79, "Input",
  CellTags->"b:11.0.0"],
Cell[16543, 492, 162, 5, 28, "Text",
  CellTags->"b:11.0.0"],
Cell[16708, 499, 805, 14, 127, "Input",
  CellTags->"b:11.0.0"],
Cell[17516, 515, 117, 2, 28, "Text",
  CellTags->"b:11.0.0"],
Cell[17636, 519, 387, 7, 79, "Input",
  CellTags->"b:11.0.0"],
Cell[18026, 528, 144, 4, 28, "Text",
  CellTags->"b:11.0.0"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[18219, 538, 149, 3, 69, "Subsection",
  CellTags->{"b:11.0.1", "c:8"}],
Cell[18371, 543, 383, 7, 46, "Text",
  CellTags->"b:11.0.1"],
Cell[18757, 552, 446, 13, 51, "Text",
  CellTags->"b:11.0.1"],
Cell[19206, 567, 412, 7, 67, "Input",
  CellTags->"b:11.0.1"],
Cell[19621, 576, 126, 2, 28, "Text",
  CellTags->"b:11.0.1"],
Cell[19750, 580, 265, 6, 47, "Input",
  CellTags->"b:11.0.1"],
Cell[20018, 588, 181, 4, 28, "Text",
  CellTags->"b:11.0.1"],
Cell[20202, 594, 347, 8, 63, "Input",
  CellTags->"b:11.0.1"],
Cell[20552, 604, 225, 6, 47, "Input",
  CellTags->"b:11.0.1"],
Cell[20780, 612, 232, 6, 47, "Input",
  CellTags->"b:11.0.1"],
Cell[21015, 620, 117, 2, 28, "Text",
  CellTags->"b:11.0.1"],
Cell[21135, 624, 931, 18, 111, "Input",
  CellTags->"b:11.0.1"],
Cell[22069, 644, 238, 6, 28, "Text",
  CellTags->"b:11.0.1"],
Cell[22310, 652, 118, 3, 47, "Input",
  CellTags->"b:11.0.1"],
Cell[22431, 657, 120, 2, 28, "Text",
  CellTags->"b:11.0.1"],
Cell[22554, 661, 286, 7, 79, "Input",
  CellTags->"b:11.0.1"],
Cell[22843, 670, 183, 5, 28, "Text",
  CellTags->"b:11.0.1"],
Cell[23029, 677, 101, 2, 47, "Input",
  CellTags->"b:11.0.1"],
Cell[23133, 681, 86, 2, 47, "Input",
  CellTags->"b:11.0.1"],
Cell[23222, 685, 61, 2, 47, "Input",
  CellTags->"b:11.0.1"]
}, Open  ]]
}, Closed]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

