(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     90781,       3062]*)
(*NotebookOutlinePosition[    170427,       5590]*)
(*  CellTagsIndexPosition[    168476,       5515]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[{
  StyleBox["QDENSITY",
    FontSlant->"Italic"],
  "\nTeleportation"
}], "Title",
  CellTags->"c:1"],

Cell["Several Examples of Teleportation circuits", "Subtitle"],

Cell[TextData[{
  "Last Version:18-Aug-2005\n",
  Cell[BoxData[
      FormBox[GridBox[{
            {\(\(References\)\(:\)\), \(\([1]\)\ C . H . Bennett, \ 
              et\ al . \ Phys . Rev . Lett . 70, 1895 - 1899\ \((1993)\)\n
              \([2]\)\ QDENSITY\ manual, \ Sect . \ 7\)}
            },
          ColumnAlignments->{Right, Left}], TraditionalForm]], 
    "DefinitionBox",
    GridBoxOptions->{RowSpacings->0.4,
    RowLines->False},
    CellTags->"S5.1.1"]
}], "Abstract"],

Cell[TextData[ButtonBox["Click here to get the palette: QDENSpalette.nb",
  ButtonData:>{"QDENSpalette.nb", None},
  ButtonStyle->"Hyperlink"]], "Text"],

Cell[CellGroupData[{

Cell["Teleportation Algorithm: One Qubit", "Section",
  FontFamily->"Times",
  CellTags->"c:2"],

Cell[TextData[StyleBox["Teleportation with Density Matrices July 2003 uses \
Qdensity package",
  FontFamily->"Helvetica"]], "Text",
  FontFamily->"Courier New"],

Cell[BoxData[
    \(Needs["\<QDENSITY`Qdensity`\>"]\)], "Input",
  FontFamily->"Courier New"],

Cell[BoxData[
    \(\(?QDENSITY`Qdensity`*\)\)], "Input",
  FontFamily->"Courier New"],

Cell[TextData[StyleBox["In the following figure we present the key \
ingredients in the teleportation process:", "DisplayText",
  FontWeight->"Plain",
  Background->None,
  FontVariations->{"CompatibilityType"->0}]], "Text",
  FontFamily->"Helvetica"],

Cell[BoxData[{
    \(\(figure = 
        Import["\<drawings/1tele.png\>", "\<PNG\>"];\)\), \
"\[IndentingNewLine]", 
    \(\(Show[figure];\)\)}], "Input"],

Cell[TextData[{
  StyleBox["NOTE: The ", "DisplayText",
    FontWeight->"Plain",
    Background->None,
    FontVariations->{"CompatibilityType"->0}],
  ButtonBox["Hadamard and CNOT gates",
    ButtonData:>{"Tutorial.nb", "Quantum Gates"},
    ButtonStyle->"Hyperlink"],
  StyleBox[" acting on qubits 2 and 3 are used to build the a \nprecise EPR \
state  ", "DisplayText",
    FontWeight->"Plain",
    Background->None,
    FontVariations->{"CompatibilityType"->0}],
  Cell[BoxData[
      \(TraditionalForm\`\(\(\(\(\(1/\@2 \((\(|\)\(00\)\[RightAngleBracket]\)\
\)\(\ \)\(+\)\)\  | 11\)\(\[RightAngleBracket]\)\)\(\ \)\()\)\)\)]],
  StyleBox[", in the following the 4 different EPR states are considered", 
    "DisplayText",
    FontWeight->"Plain",
    Background->None,
    FontVariations->{"CompatibilityType"->0}]
}], "Text",
  FontFamily->"Helvetica"],

Cell[CellGroupData[{

Cell["Step 1: Alice prepares the state to be teleported", "Subsection",
  CellFrame->True,
  FontFamily->"Times",
  CellTags->{"b:0.0.0", "c:3"}],

Cell[TextData[StyleBox["Alice needs to specify qubit which will be teleported \
during the process. \nIn this example we construct it by choosing a random \
polarization vector:\nNote that if the magnitude of the polarization vector \
is less than 1, the state is not pure ", "DisplayText",
  FontWeight->"Plain",
  Background->None,
  FontVariations->{"CompatibilityType"->0}]], "Text",
  Evaluatable->False,
  FontFamily->"Helvetica",
  CellTags->"b:0.0.0"],

Cell["\<\
\[Theta]=Random[Real,{0,\[Pi]}]
\[CurlyPhi]=Random[Real,{0,2\[Pi]}]
P=Random[Real,{0,1}]\
\>", "Input",
  CellTags->"b:0.0.0"],

Cell["Therefore its cartesian components are:", "Text",
  FontFamily->"Helvetica",
  CellTags->"b:0.0.0"],

Cell["\<\
Px = P Sin[\[Theta]] Cos[\[CurlyPhi]]
Py = P Sin[\[Theta]] Sin[\[CurlyPhi]]
Pz = P Cos[\[Theta]]\
\>", "Input",
  CellTags->"b:0.0.0"],

Cell["\<\
This example permits both an algebraic computation or a numerical one. 
This is controlled by the value of Icalc: 1 [Algebraic] / Else [Numerical]\
\>", "Text",
  FontFamily->"Helvetica",
  CellTags->"b:0.0.0"],

Cell[BoxData[
    \(\(Icalc = 1;\)\)], "Input",
  CellTags->"b:0.0.0"],

Cell[BoxData[{
    \(\(If[Icalc == 1, Clear[Px, Py, Pz], \ ];\)\ \), "\[IndentingNewLine]", 
    \({Px, \ Py, \ Pz}\)}], "Input",
  FontFamily->"Courier New",
  CellTags->"b:0.0.0"],

Cell["\<\
Once the polarization vector has been chosen, in this case at random, we can 
write down its density matrix\
\>", "Text",
  FontFamily->"Helvetica",
  CellTags->"b:0.0.0"],

Cell[BoxData[
    RowBox[{
      RowBox[{\(\[Rho]\_\[Psi]\), " ", "=", " ", 
        RowBox[{
          RowBox[{"(", 
            StyleBox[\(1/2\),
              FontSize->12], 
            StyleBox[")",
              FontSize->12]}], 
          
          StyleBox[\((\ \[DoubleStruckCapitalI]\  + \ {Px, Py, 
                    Pz} . \ {\[Sigma]\_1, \ \[Sigma]\_2\ , \[Sigma]\_3})\),
            FontSize->12]}]}], 
      StyleBox[";",
        FontSize->12], 
      StyleBox[\(Chop[\[Rho]\_\[Psi]\ ]\),
        FontSize->12], " "}]], "Input",
  FontFamily->"Courier New",
  CellTags->"b:0.0.0"],

Cell["\<\
If everything went ok, the density matrix should be Hermitian:\
\>", "Text",
  FontFamily->"Helvetica",
  CellTags->"b:0.0.0"],

Cell[BoxData[
    \(\(\(\ \)\(If[Icalc \[Equal] 0, 
      If[Chop[Adj[\[Rho]\_\[Psi]]\  - \[Rho]\_\[Psi]] \[Equal] 
          ZeroMatrix[Length[\[Rho]\_\[Psi]]], Print["\<Hermitian\>"], 
        Print["\<Not Hermitian\>"]], "\<\>"]\)\)\)], "Input",
  FontFamily->"Courier New",
  CellTags->"b:0.0.0"],

Cell["Its Eigenvalues, Trace and Purity can be readily computed:", "Text",
  FontFamily->"Helvetica",
  CellTags->"b:0.0.0"],

Cell[BoxData[{\(evPsi := 
        Eigenvalues[\[Rho]\_\[Psi]];\), "\[IndentingNewLine]", 
    StyleBox[\(Chop[evPsi]\),
      FontSize->12], "\[IndentingNewLine]", 
    RowBox[{"Simplify", "[", 
      RowBox[{"Chop", "[", \(Tr[\[Rho]\_\[Psi]\ ]\), 
        StyleBox["]",
          FontSize->12]}], 
      StyleBox["]",
        FontSize->12]}], "\[IndentingNewLine]", 
    RowBox[{"Simplify", "[", 
      RowBox[{"Chop", "[", 
        RowBox[{"Purity", "[", 
          StyleBox[\(\[Rho]\_\[Psi]\),
            FontSize->12], 
          StyleBox["]",
            FontSize->12]}], 
        StyleBox["]",
          FontSize->12]}], 
      StyleBox["]",
        FontSize->12]}]}], "Input",
  FontFamily->"Courier New",
  CellTags->"b:0.0.0"],

Cell["Eigenvalues should be positive", "Text",
  FontFamily->"Helvetica",
  CellTags->"b:0.0.0"],

Cell[BoxData[
    \(Do[If[Chop[evPsi[\([i]\)]] \[GreaterEqual] 0, 
        Print["\<Positive eigenvalue\>"], Print["\<Negative\>"]], {i, 1, 
        2}]\)], "Input",
  FontFamily->"Courier New",
  CellTags->{"Do", "b:0.0.0"}]
}, Closed]],

Cell[CellGroupData[{

Cell["Step 2: Bob prepares the Bell state", "Subsection",
  CellFrame->True,
  FontFamily->"Times",
  CellTags->{"b:0.0.1", "c:4"}],

Cell["\<\
Bob needs to share a Bell state, 2 qubits, with Alice. He prepares it in the \
following way. 
First, he constructs the four density matrices needed:\
\>", "Text",
  FontFamily->"Helvetica",
  CellTags->"b:0.0.1"],

Cell[BoxData[{
    RowBox[{
      StyleBox[\(\[Rho]\_00\),
        FontSize->12], 
      StyleBox["=",
        FontSize->
          12], \(\[ScriptCapitalP]\_0\ \ \[CircleTimes]\ \ \
\[ScriptCapitalP]\_0\)}], "\[IndentingNewLine]", 
    RowBox[{
      StyleBox[\(\[Rho]\_01\),
        FontSize->12], 
      StyleBox["=",
        FontSize->
          12], \(\[ScriptCapitalP]\_0\ \ \[CircleTimes]\ \ \
\[ScriptCapitalP]\_1\)}], "\[IndentingNewLine]", 
    RowBox[{
      StyleBox[\(\[Rho]\_10\),
        FontSize->12], 
      StyleBox["=",
        FontSize->
          12], \(\[ScriptCapitalP]\_1\ \ \[CircleTimes]\ \ \
\[ScriptCapitalP]\_0\)}], "\[IndentingNewLine]", 
    RowBox[{
      StyleBox[\(\[Rho]\_11\),
        FontSize->12], 
      StyleBox["=",
        FontSize->
          12], \(\[ScriptCapitalP]\_1\ \ \[CircleTimes]\ \ \
\[ScriptCapitalP]\_1\)}]}], "Input",
  CellTags->"b:0.0.1"],

Cell["\<\
The Bell state operator of qubits i and j can be decomposed into the action \
of a Hadamard 
on qubit i and a CNOT gate on qubits i and j.\
\>", "Text",
  FontFamily->"Helvetica",
  CellTags->"b:0.0.1"],

Cell[BoxData[
    \(\(\(\ \)\(Bellop[qi_, qj_] := \(\(CNOT[2, qi, qj] . 
        had[2, qi]\)\(\ \)\)\)\)\)], "Input",
  FontFamily->"Courier New",
  CellTags->"b:0.0.1"],

Cell["\<\
NOTE: an alternative way using LEFT operator \
BellOp[qi_,qj_]:=CNOT[2,qi,qj].had[2,qi].(\[Sigma]\[CircleTimes]\
\[DoubleStruckCapitalI])\
\>", "Text",
  FontFamily->"Helvetica",
  CellTags->"b:0.0.1"],

Cell[BoxData[
    \(Bellop[1, 2]\)], "Input",
  FontFamily->"Courier New",
  CellTags->"b:0.0.1"],

Cell["\<\
The density matrix for any of the four Bell states produced by Bob from \
qubits 2 & 3. 
Afterwards, Bob sends one of these qubits to Alice who has qubit 1 in state \
\[Psi]\
\>", "Text",
  FontFamily->"Helvetica",
  CellTags->"b:0.0.1"],

Cell[BoxData[
    StyleBox[\(\(\ \)\(\(\[Rho]\_B00\ \  := \ 
          Bellop[1, 2] . \[Rho]\_00 . Adj[Bellop[1, 2]];\)\[IndentingNewLine]
      \ \(\[Rho]\_B01\ \  := \ 
          Bellop[1, 2] . \[Rho]\_01 . Adj[Bellop[1, 2]];\)\[IndentingNewLine]
      \ \(\[Rho]\_B10\ \  := \ 
          Bellop[1, 2] . \[Rho]\_10 . Adj[Bellop[1, 2]];\)\[IndentingNewLine]
      \ \(\[Rho]\_B11\ \  := \ 
          Bellop[1, 2] . \[Rho]\_11 . Adj[Bellop[1, 2]];\)\)\),
      FontSize->12]], "Input",
  FontFamily->"Courier New",
  FontSize->12,
  CellTags->"b:0.0.1"],

Cell["Checks on Bell states", "Text",
  FontFamily->"Helvetica",
  CellTags->"b:0.0.1"],

Cell[BoxData[{
    StyleBox[\(\[Rho]\_B00\),
      FontSize->12], "\[IndentingNewLine]", 
    StyleBox[\(\[Rho]\_B01\),
      FontSize->12], "\[IndentingNewLine]", 
    StyleBox[\(\[Rho]\_B10\),
      FontSize->12], "\[IndentingNewLine]", 
    StyleBox[\(\[Rho]\_B11\),
      FontSize->12]}], "Input",
  CellTags->"b:0.0.1"],

Cell["\<\
Bob needs to know the type of Bell state shared with Alice, either by \
preparing it himself or 
by being informed of its type by a message from Alice or from a third party \
distributor of Bell states  
In our example we pick one of the 4 Bell States at random\
\>", "Text",
  FontFamily->"Helvetica",
  CellTags->"b:0.0.1"],

Cell[BoxData[
    \(\(Ipick = Random[Integer, {1, 4}];\)\)], "Input",
  CellTags->"b:0.0.1"],

Cell[BoxData[
    \(\[Rho]\_\(\(B\)\(\ \)\) = 
      Which[Ipick == 1, \[Rho]\_B00, Ipick == 2, \[Rho]\_B01, 
        Ipick == 3, \[Rho]\_B10, Ipick == 4, \[Rho]\_B11]\)], "Input",
  CellTags->"b:0.0.1"],

Cell["\<\
He computes the vector and tensor polarizations of the Bell state in the \
following way:\
\>", "Text",
  FontFamily->"Helvetica",
  CellTags->"b:0.0.1"],

Cell[BoxData[{
    RowBox[{
      RowBox[{\(T[i_, j_]\), ":=", 
        RowBox[{"Tr", "[", 
          RowBox[{\((\[Sigma]\_i\[CircleTimes]\[Sigma]\_j)\), ".", 
            StyleBox[\(\[Rho]\_B\),
              FontSize->12]}], 
          StyleBox[" ",
            FontSize->12], 
          StyleBox["]",
            FontSize->12]}]}], 
      StyleBox[";",
        FontSize->12]}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        StyleBox["PA",
          FontSize->12], 
        StyleBox["=",
          FontSize->12], 
        RowBox[{
          StyleBox["{",
            FontSize->12], 
          RowBox[{
            StyleBox[\(T[1, 0]\),
              FontSize->12], 
            StyleBox[",",
              FontSize->12], \(T[2, 0]\), ",", \(T[3, 0]\)}], "}"}]}], 
      ";"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        StyleBox["PB",
          FontSize->12], 
        StyleBox["=",
          FontSize->12], 
        RowBox[{
          StyleBox["{",
            FontSize->12], 
          RowBox[{
            StyleBox[\(T[0, 1]\),
              FontSize->12], 
            StyleBox[",",
              FontSize->12], \(T[0, 2]\), ",", \(T[0, 3]\)}], "}"}]}], 
      ";"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        StyleBox[
          RowBox[{"T", 
            StyleBox["AB",
              FontSize->12]}]], 
        StyleBox["=",
          FontSize->12], 
        RowBox[{
          StyleBox["{",
            FontSize->12], 
          RowBox[{
            StyleBox["Table",
              FontSize->12], 
            StyleBox["[",
              FontSize->12], 
            RowBox[{
              StyleBox[\(T[i, j]\),
                FontSize->12], 
              StyleBox[",",
                FontSize->12], \({i, 1, 3}\), ",", \({j, 1, 3}\)}], "]"}], 
          "}"}]}], ";"}]}], "Input",
  FontFamily->"Courier New",
  CellTags->"b:0.0.1"],

Cell["Vector polarizations are zero for Bell states", "Text",
  FontFamily->"Helvetica",
  CellTags->"b:0.0.1"],

Cell[BoxData[{
    \(PA\), "\[IndentingNewLine]", 
    \(PB\)}], "Input",
  CellTags->"b:0.0.1"],

Cell["Tensor polarizations for Bell state", "Text",
  FontFamily->"Helvetica",
  CellTags->"b:0.0.1"],

Cell[BoxData[
    \(Flatten[TAB, 1]\)], "Input",
  CellTags->"b:0.0.1"]
}, Closed]],

Cell[CellGroupData[{

Cell["Step 3: The three Qubits", "Subsection",
  CellFrame->True,
  FontFamily->"Times",
  CellTags->{"b:0.0.2", "c:5"}],

Cell["\<\
The tensor product of both the qubit prepared by Alice and the Bell state \
prepared 
by Bob can be computed. The complete density matrix is then:\
\>", "Text",
  FontFamily->"Helvetica",
  CellTags->"b:0.0.1"],

Cell[BoxData[
    RowBox[{
      StyleBox[\(\[Rho]\_C\),
        FontSize->12], 
      StyleBox["=",
        FontSize->12], 
      StyleBox[" ",
        FontSize->12], 
      RowBox[{\(\[Rho]\_\[Psi]\), " ", "\[CircleTimes]", " ", 
        StyleBox[\(\[Rho]\_B\),
          FontSize->12]}]}]], "Input",
  FontFamily->"Courier New",
  CellTags->"b:0.0.2"],

Cell["We check its length and Trace:", "Text",
  FontFamily->"Helvetica",
  CellTags->"b:0.0.2"],

Cell[BoxData[
    RowBox[{"Length", "[", 
      StyleBox[\(\[Rho]\_C\),
        FontSize->12], 
      StyleBox["]",
        FontSize->12]}]], "Input",
  FontFamily->"Courier New",
  CellTags->"b:0.0.2"],

Cell[BoxData[
    RowBox[{"Simplify", "[", 
      RowBox[{"Chop", "[", 
        RowBox[{"Tr", "[", 
          StyleBox[\(\[Rho]\_C\),
            FontSize->12], 
          StyleBox["]",
            FontSize->12]}], 
        StyleBox["]",
          FontSize->12]}], 
      StyleBox["]",
        FontSize->12]}]], "Input",
  FontFamily->"Courier New",
  CellTags->"b:0.0.2"],

Cell[TextData[{
  "The Trace of ",
  Cell[BoxData[
      StyleBox[\(\[Rho]\_C\),
        FontSize->12]],
    FontFamily->"Helvetica"],
  "squared is a meassure of the purity of the state of the whole system:"
}], "Text",
  FontFamily->"Helvetica",
  CellTags->"b:0.0.2"],

Cell[BoxData[
    RowBox[{"Simplify", "[", 
      RowBox[{"Chop", "[", 
        RowBox[{"Tr", "[", 
          RowBox[{\(\[Rho]\_C\), 
            StyleBox[".",
              FontSize->12], \(\[Rho]\_C\)}], 
          StyleBox["]",
            FontSize->12]}], 
        StyleBox["]",
          FontSize->12]}], 
      StyleBox["]",
        FontSize->12]}]], "Input",
  FontFamily->"Courier New",
  CellTags->"b:0.0.2"],

Cell["\<\
Finally we check its eigenvalues are positive as they should be:\
\>", "Text",
  FontFamily->"Helvetica",
  CellTags->"b:0.0.2"],

Cell[BoxData[{
    RowBox[{
      RowBox[{"evC", ":=", 
        RowBox[{"Eigenvalues", "[", 
          StyleBox[\(\[Rho]\_C\),
            FontSize->12], 
          StyleBox["]",
            FontSize->12]}]}], 
      StyleBox[";",
        FontSize->12]}], "\[IndentingNewLine]", \(Do[
      If[Chop[evC[\([i]\)]] \[GreaterEqual] 0, 
        Print["\<Positive eigenvalue\>"], Print["\<Negative\>"]], {i, 1, 
        Length[evC]}]\)}], "Input",
  FontFamily->"Courier New",
  CellTags->{"Do", "b:0.0.2"}]
}, Closed]],

Cell[CellGroupData[{

Cell["Step 4: Bob sends qubit 2 to Alice", "Subsection",
  CellFrame->True,
  FontFamily->"Times",
  CellTags->{"b:0.0.3", "c:6"}],

Cell["\<\
Alice, now receives one qubit from Bob and performs the following operations. \
Let us remind that the labelling is 
now: 
\tQubit 1: Original unknown qubit Alice wants to teleport
\tQubit 2: Qubit that Bob is sending her from the EPR pair
\tQubit 3: Bob's qubit that was in a Bell state with Qubit 2
\
\>", "Text",
  TextJustification->0,
  FontFamily->"Helvetica",
  CellTags->"b:0.0.3"],

Cell["\<\
Now Alice performs a series of operations with her original qubit and the one \
received from Bob.
CNOT on Alice's Qubits 1,2; 
Followed by Hadamard on qubit 1, 
whereby Alice entangles her original qubit with one of the shared ones\
\>", "Text",
  FontFamily->"Helvetica",
  CellTags->"b:0.0.3"],

Cell[BoxData[
    \(Three\ qubit\ density\ \ is\ now\ denoted\ by\ \[Rho]\_T\)], "Text",
  FontFamily->"Helvetica",
  CellTags->"b:0.0.3"],

Cell[BoxData[
    RowBox[{
      RowBox[{\(\[Rho]\_T\), "=", 
        RowBox[{\(had[3, 1]\), ".", \(CNOT[3, 1, 2]\), ".", 
          StyleBox[\(\[Rho]\_C\),
            FontSize->12], ".", \(CNOT[3, 1, 2]\), ".", \(had[3, 1]\)}]}], 
      ";"}]], "Input",
  FontFamily->"Courier New",
  CellTags->"b:0.0.3"],

Cell[BoxData[
    \(Some\ Checks\ on\ \[Rho]\_T, \ Trace, \ purity, \ 
    eigenvalues\ and\ \(\(length\)\(.\)\)\)], "Text",
  FontFamily->"Helvetica",
  CellTags->"b:0.0.3"],

Cell[BoxData[{
    \(Simplify[Chop[Tr[\[Rho]\_T]]]\), "\n", 
    \(Simplify[Chop[Tr[\[Rho]\_T . \[Rho]\_T]]]\)}], "Input",
  FontFamily->"Courier New",
  CellTags->"b:0.0.3"],

Cell[BoxData[
    \(evF := Eigenvalues[\[Rho]\_T]; 
    Do[If[Chop[evF[\([i]\)]] \[GreaterEqual] 0, 
        Print["\<Positive eigenvalue\>"], Print["\<Negative\>"]], {i, 1, 
        Length[evF]}]\)], "Input",
  FontFamily->"Courier New",
  CellTags->"b:0.0.3"],

Cell[BoxData[
    \(Length[\[Rho]\_T]\)], "Input",
  FontFamily->"Courier New",
  CellTags->"b:0.0.3"],

Cell[TextData[{
  "Four Projection Operators for Qubits 1 and 2 are used for ",
  ButtonBox["projective measurements",
    ButtonData:>{"Tutorial.nb", None},
    ButtonStyle->"Hyperlink"],
  " on Qubits 1 & 2 by Alice"
}], "Text",
  FontFamily->"Helvetica",
  CellTags->"b:0.0.3"],

Cell[BoxData[
    \(P\_\(a_, b_\)\ \  := \ \ \((\[ScriptCapitalP]\_a\ \ \[CircleTimes]\ \ \
\[ScriptCapitalP]\_b)\)\[CircleTimes]\ \[DoubleStruckCapitalI]\)], "Input",
  CellTags->"b:0.0.3"],

Cell[BoxData[
    \(\(\(\ \)\(\(P\_\(0, 0\);\)\n
    \ \(P\_\(0, 1\)\ ;\)\ \[IndentingNewLine]
    \ \(P\_\(1, 0\)\ ;\)\n
    \ \(P\_\(1, 1\);\)\)\)\)], "Input",
  FontFamily->"Courier New",
  CellTags->"b:0.0.3"]
}, Closed]],

Cell[CellGroupData[{

Cell["Step 5: Alice measures the state of her Qubits", "Subsection",
  CellFrame->True,
  FontFamily->"Times",
  CellTags->{"b:0.0.4", "c:7"}],

Cell[TextData[{
  "After receiving the qubit form Bob and performing the abovementioned \
operations, \nshe measures the state of her two qubits obtaining values: ",
  Cell[BoxData[
      \(TraditionalForm\`a\_a\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`a\_b\)]],
  ". Bob's  Density Matrix, \nafter Alice measures is computed:"
}], "Text",
  FontFamily->"Helvetica",
  CellTags->"b:0.0.4"],

Cell[BoxData[{
    \(\(a\_A = Random[Integer, {0, 1}];\)\), "\[IndentingNewLine]", 
    \(\(a\_B = Random[Integer, {0, 1}];\)\)}], "Input",
  CellTags->"b:0.0.4"],

Cell[BoxData[
    \(\(\(\[Rho]\_Bob[a_, b_]\)\(:=\)\(\ \)\(PTr[{1, 2}, 
        4*P\_\(a, b\) . \[Rho]\_T . P\_\(a, b\)]\)\(\ \)\)\)], "Input",
  CellTags->"b:0.0.4"],

Cell["\<\
Qubit 3 has no polarization, but if Alice makes a measurement, its state is \
delineated \
\>", "Text",
  FontFamily->"Helvetica",
  CellTags->"b:0.0.4"],

Cell[BoxData[
    \(\(\(Chop[\ PTr[{1, 2}, \ \[Rho]\_T]]\)\(\ \)\)\)], "Input",
  CellTags->"b:0.0.4"],

Cell[BoxData[
    \(Simplify[\[Rho]\_Bob[0, 0] + \[Rho]\_Bob[0, 1] + \[Rho]\_Bob[1, 
            0] + \[Rho]\_Bob[1, 1]]/4\)], "Input",
  CellTags->"b:0.0.4"],

Cell[BoxData[
    \(Ipick\)], "Input",
  CellTags->"b:0.0.4"],

Cell[BoxData[{
    \(\[Rho]\_Bob[0, 0]\), "\[IndentingNewLine]", 
    \(\[Rho]\_Bob[0, 1]\), "\[IndentingNewLine]", 
    \(\[Rho]\_Bob[1, 0]\), "\[IndentingNewLine]", 
    \(\[Rho]\_Bob[1, 1]\)}], "Input",
  CellTags->"b:0.0.4"],

Cell[TextData[{
  "Alice Clasically Transmits the result of her measurement to Bob (",
  Cell[BoxData[
      \(a\_A\)]],
  ", ",
  Cell[BoxData[
      \(a\_B\)]],
  ") as one of the \nfour cases |00\[RightAngleBracket],|01\
\[RightAngleBracket],|10\[RightAngleBracket] or |11\[RightAngleBracket]. \n\
Bob, chooses his corresponding density matrix once he has received the data \
from Alice."
}], "Text",
  FontFamily->"Helvetica",
  CellTags->"b:0.0.5"],

Cell[BoxData[
    \(\[Rho]\_B = \[Rho]\_Bob[a\_A, a\_B]\)], "Input",
  CellTags->"b:0.0.5"],

Cell["\<\
Also need to know the type of Bell state shared marked by Ipick\
\>", "Text",
  FontFamily->"Helvetica",
  CellTags->"b:0.0.5"],

Cell["Ipick", "Input",
  CellTags->"b:0.0.5"],

Cell["\<\
Then he will need to perform rotations which will be made of:\
\>", "Text",
  FontFamily->"Helvetica",
  CellTags->"b:0.0.5"],

Cell[BoxData[
    \(S\_\(\(i_\)\(\ \)\(,\)\(j_\)\(\ \)\)\ \  := \ \ \[Sigma]\_i\  . \ \ \
\[Sigma]\_j\)], "Input",
  CellTags->"b:0.0.5"],

Cell["\<\
Here we detail the four possibilities explicitly:
\
\>", "Text",
  FontFamily->"Helvetica",
  CellTags->"b:0.0.5"],

Cell[TextData[{
  StyleBox["If Qubits 1 & 2 are in |00> State:Bob",
    FontWeight->"Bold"],
  "\n        Ipick=1 (Does Nothing)\n        Ipick=2 (rotates about x-axis  )\
\n        Ipick=3 (rotates about the z-axis)\n        Ipick=4 (rotates about \
x-axis and then the z-axis )\n                and would have the following \
polarization for his qubit 3\n      \n",
  StyleBox["If Qubits 1 & 2 are in |01> State:Bob",
    FontWeight->"Bold"],
  "\n        Ipick=1 (rotates about x-axis )\n        Ipick=2 (Does Nothing)\n\
        Ipick=3 (rotates about x-axis and then the z-axis)\n        Ipick=4 \
(rotates about the z-axis)\n                 and would have the following \
polarization for his qubit 3   \n\n",
  StyleBox["If Qubits 1 & 2 are in |10> State:Bob",
    FontWeight->"Bold"],
  "\n        Ipick=1 (rotates about the z-axis)\n        Ipick=2 (rotates \
about x-axis and then the z-axis)\n        Ipick=3 (Does Nothing)\n        \
Ipick=4 (rotates about x-axis)\n                 and would have the following \
polarization for his qubit 3           \n\n",
  StyleBox["If Qubits 1 & 2 are in |11> State:Bob",
    FontWeight->"Bold"],
  "\n        Ipick=1 (rotates about x-axis and then the z-axis)\n        \
Ipick=2 (rotates about the z-axis)\n        Ipick=3 (rotates about x-axis )\n \
       Ipick=4 (Does Nothing)\n                and would have the following \
polarization for his qubit 3"
}], "Text",
  FontFamily->"Helvetica",
  CellTags->"b:0.0.5"],

Cell[BoxData[{
    RowBox[{"Rot", "=", 
      RowBox[{"Which", "[", " ", 
        RowBox[{\({a\_A, a\_B} \[Equal] {0, 0}\), ",", " ", 
          RowBox[{"Which", "[", " ", 
            RowBox[{\(Ipick \[Equal] 1\), ",", \(S\_\(0\ , 0\)\), ",", 
              StyleBox[\(Ipick \[Equal] 2\),
                FontSize->12], 
              StyleBox[",",
                FontSize->12], 
              StyleBox[\(S\_\(1, \ 0\)\),
                FontSize->12], 
              StyleBox[",",
                FontSize->12], 
              StyleBox[\(Ipick \[Equal] 3\),
                FontSize->12], 
              StyleBox[",",
                FontSize->12], 
              StyleBox[\(S\_\(\(\ \)\(3, 0\)\)\),
                FontSize->12], 
              StyleBox[",",
                FontSize->12], 
              StyleBox[\(Ipick \[Equal] 4\),
                FontSize->12], 
              StyleBox[",",
                FontSize->12], 
              StyleBox[\(S\_\(3, 1\)\),
                FontSize->12]}], 
            StyleBox["]",
              FontSize->12]}], 
          StyleBox[",",
            FontSize->12], 
          StyleBox["\[IndentingNewLine]",
            FontSize->12], 
          StyleBox["                      ",
            FontSize->12], 
          RowBox[{
            RowBox[{
              StyleBox["{",
                FontSize->12], \(a\_A, a\_B\), "}"}], 
            "\[Equal]", \({0, 1}\)}], ",", " ", 
          RowBox[{"Which", "[", " ", 
            RowBox[{\(Ipick \[Equal] 1\), ",", \(S\_\(1\ , 0\)\), ",", 
              StyleBox[\(Ipick \[Equal] 2\),
                FontSize->12], 
              StyleBox[",",
                FontSize->12], 
              StyleBox[\(S\_\(0, \ 0\)\),
                FontSize->12], 
              StyleBox[",",
                FontSize->12], 
              StyleBox[\(Ipick \[Equal] 3\),
                FontSize->12], 
              StyleBox[",",
                FontSize->12], 
              StyleBox[\(S\_\(\(\ \)\(3, 1\)\)\),
                FontSize->12], 
              StyleBox[",",
                FontSize->12], 
              StyleBox[\(Ipick \[Equal] 4\),
                FontSize->12], 
              StyleBox[",",
                FontSize->12], 
              StyleBox[\(S\_\(3, 0\)\),
                FontSize->12]}], 
            StyleBox["]",
              FontSize->12]}], 
          StyleBox[",",
            FontSize->12], 
          StyleBox["\[IndentingNewLine]",
            FontSize->12], 
          StyleBox["                      ",
            FontSize->12], 
          StyleBox[\({a\_A, a\_B} == {1, 0}\),
            FontSize->12], ",", " ", 
          RowBox[{"Which", "[", " ", 
            RowBox[{\(Ipick \[Equal] 1\), ",", \(S\_\(0\ , 3\)\), ",", 
              StyleBox[\(Ipick \[Equal] 2\),
                FontSize->12], 
              StyleBox[",",
                FontSize->12], 
              StyleBox[\(S\_\(3, \ 1\)\),
                FontSize->12], 
              StyleBox[",",
                FontSize->12], 
              StyleBox[\(Ipick \[Equal] 3\),
                FontSize->12], 
              StyleBox[",",
                FontSize->12], 
              StyleBox[\(S\_\(\(\ \)\(0, 0\)\)\),
                FontSize->12], 
              StyleBox[",",
                FontSize->12], 
              StyleBox[\(Ipick \[Equal] 4\),
                FontSize->12], 
              StyleBox[",",
                FontSize->12], 
              StyleBox[\(S\_\(1, 0\)\),
                FontSize->12]}], 
            StyleBox["]",
              FontSize->12]}], 
          StyleBox[",",
            FontSize->12], 
          StyleBox["\[IndentingNewLine]",
            FontSize->12], 
          StyleBox["                      ",
            FontSize->12], 
          RowBox[{
            RowBox[{
              StyleBox["{",
                FontSize->12], \(a\_A, a\_B\), "}"}], 
            "\[Equal]", \({1, 1}\)}], ",", 
          RowBox[{"Which", "[", " ", 
            RowBox[{\(Ipick \[Equal] 1\), ",", \(S\_\(1\ , 3\)\), ",", 
              StyleBox[\(Ipick \[Equal] 2\),
                FontSize->12], 
              StyleBox[",",
                FontSize->12], 
              StyleBox[\(S\_\(3, \ 0\)\),
                FontSize->12], 
              StyleBox[",",
                FontSize->12], 
              StyleBox[\(Ipick \[Equal] 3\),
                FontSize->12], 
              StyleBox[",",
                FontSize->12], 
              StyleBox[\(S\_\(\(\ \)\(1, 0\)\)\),
                FontSize->12], 
              StyleBox[",",
                FontSize->12], 
              StyleBox[\(Ipick \[Equal] 4\),
                FontSize->12], 
              StyleBox[",",
                FontSize->12], 
              StyleBox[\(S\_\(0, 0\)\),
                FontSize->12]}], 
            StyleBox["]",
              FontSize->12]}]}], 
        StyleBox["]",
          FontSize->12]}]}], "\[IndentingNewLine]", \(Adj[
      Rot]\), "\n", \(X = 
        Simplify[Rot . \[Rho]\_B . Adj[Rot]];\), "\n", \(Simplify[
      X]\), "\n", \(Chop[\[Rho]\_B];\)}], "Input",
  CellTags->"b:0.0.5"],

Cell["\<\
... finally, Bob, extracts the polarization for his 3 qubit
and gets....\
\>", "DisplayText",
  FontFamily->"Helvetica",
  CellTags->"b:0.0.5"],

Cell[BoxData[
    \(PFINAL = 
      Chop[{Simplify[\ Tr[X . \[Sigma]\_1]], Simplify[Tr[X . \[Sigma]\_2]], 
          Simplify[Tr[X . \[Sigma]\_3]]}]\)], "Input",
  CellTags->"b:0.0.5"],

Cell["\<\
... which you can now compare to the original
state in the hands of Alice:\
\>", "DisplayText",
  FontFamily->"Helvetica",
  CellTags->"b:0.0.5"],

Cell[BoxData[
    \({Px, Py, Pz}\)], "Input",
  CellTags->"b:0.0.5"],

Cell["Quit", "Input",
  CellTags->"b:0.0.5"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Two qubit teleportation algorithm using 6 qubits", "Section",
  FontFamily->"Times",
  CellTags->"c:8"],

Cell[TextData[StyleBox["Uses the Qdensity package:",
  FontFamily->"Helvetica"]], "Text",
  FontFamily->"Courier New"],

Cell[BoxData[
    \(Needs["\<QDENSITY`Qdensity`\>"]\)], "Input",
  FontFamily->"Courier New"],

Cell[BoxData[
    \(\(?QDENSITY`Qdensity`*\)\)], "Input",
  FontFamily->"Courier New"],

Cell[TextData[StyleBox["We set the number of Qubits to 6", "DisplayText",
  FontWeight->"Plain",
  Background->None,
  FontVariations->{"CompatibilityType"->0}]], "Text",
  FontFamily->"Helvetica"],

Cell[BoxData[
    \(\(nqx = 6;\)\)], "Input"],

Cell[BoxData[{
    \(\(figure = 
        Import["\<drawings/2teleport.png\>", "\<PNG\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(Show[figure];\)\)}], "Input"],

Cell[CellGroupData[{

Cell["\<\
Step 1: Alice  prepares the two qubit state to be teleported and a four qubit \
entangled state is provided\
\>", "Subsection",
  CellFrame->True,
  FontFamily->"Times",
  CellTags->{"b:1.0.0", "c:9"}],

Cell[TextData[StyleBox["We prepare a random two qubit state. First a random \
one qubit state is prepared.", "DisplayText",
  FontWeight->"Plain",
  Background->None,
  FontVariations->{"CompatibilityType"->0}]], "Text",
  FontFamily->"Helvetica",
  CellTags->"b:1.0.0"],

Cell[BoxData[
    \(a = RandomQubit1\)], "Input",
  CellTags->"b:1.0.0"],

Cell[BoxData[{
    \(\(\[Rho]\_AB = RandomQubit2;\)\), "\[IndentingNewLine]", 
    \(\(PA = 
        Chop[{Tr[\[Rho]\_AB\ \  . \((\[Sigma]\_1\ \[CircleTimes]\ \
\[Sigma]\_0)\)], 
            Tr[\[Rho]\_AB\ \  . \((\[Sigma]\_2\ \[CircleTimes]\ \
\[Sigma]\_0)\)]\ , 
            Tr[\[Rho]\_AB\ \  . \((\[Sigma]\_3\ \[CircleTimes]\ \
\[Sigma]\_0)\)]\ }];\)\), "\[IndentingNewLine]", 
    \(\(PB = 
        Chop[{Tr[\[Rho]\_AB\  . \((\[Sigma]\_0\ \[CircleTimes]\ \
\[Sigma]\_1)\)], 
            Tr[\[Rho]\_AB\  . \((\[Sigma]\_0\ \[CircleTimes]\ \[Sigma]\_2)\)]\
\ , \ Tr[\[Rho]\_AB\  . \((\[Sigma]\_0\ \[CircleTimes]\ \
\[Sigma]\_3)\)]}];\)\), "\[IndentingNewLine]", 
    \(T[i_, j_] := \(T[i, j] = \ 
        Chop[Tr[\[Rho]\_AB\  . \((\[Sigma]\_i\ \[CircleTimes]\ \
\[Sigma]\_j)\)]\ ]\)\ \ \), "\[IndentingNewLine]", 
    \(PA\), "\[IndentingNewLine]", 
    \(PB\)}], "Input",
  FontFamily->"Courier New",
  CellTags->"b:1.0.0"],

Cell[TextData[StyleBox["The density matrix to be teleported and its \
eigenvalues are:", "DisplayText",
  FontWeight->"Plain",
  Background->None,
  FontVariations->{"CompatibilityType"->0}]], "Text",
  FontFamily->"Helvetica",
  CellTags->"b:1.0.0"],

Cell[BoxData[{
    \(\[Rho]\_AB\), "\[IndentingNewLine]", 
    \(Chop[Eigenvalues[\[Rho]\_AB]]\)}], "Input",
  CellTags->"b:1.0.0"],

Cell[TextData[{
  "We also need the ",
  StyleBox["entangled state made of qubits 3, 4, 5, and 6",
    FontWeight->"Bold"],
  " which is constructed as:"
}], "Text",
  FontFamily->"Helvetica",
  CellTags->"b:1.0.0"],

Cell[BoxData[{
    \(\(\[Rho]\_1 = \((\((\((\[ScriptCapitalP]\_0\[CircleTimes]\
\[ScriptCapitalP]\_0)\)\[CircleTimes]\[ScriptCapitalP]\_0)\)\[CircleTimes]\
\[ScriptCapitalP]\_0)\);\)\), "\[IndentingNewLine]", 
    \(\(OpE = 
        CNOT[4, 2, 4] . had[4, 2] . CNOT[4, 1, 3] . 
          had[4, 1];\)\), "\[IndentingNewLine]", 
    \(\[Rho]\_3456 = \ OpE . \[Rho]\_1 . Adj[OpE]\), "\[IndentingNewLine]", 
    \(Tr[\[Rho]\_3456]\)}], "Input",
  CellTags->"b:1.0.0"],

Cell["Then the FULL density matrix for the \"initial\" system is:", "Text",
  FontFamily->"Helvetica",
  CellTags->"b:1.0.0"],

Cell[BoxData[{
    \(\(\[Rho]\_0 = \[Rho]\_AB\[CircleTimes]\[Rho]\_3456;\)\), "\
\[IndentingNewLine]", 
    \(Tr[\[Rho]\_0]\)}], "Input",
  CellTags->"b:1.0.0"],

Cell["is the full density matrix hermitian?", "Text",
  FontFamily->"Helvetica",
  CellTags->"b:1.0.0"],

Cell[BoxData[
    \(\(\(\ \)\(If[
      Chop[Adj[\[Rho]\_0]\  - \[Rho]\_0] \[Equal] 
        ZeroMatrix[Length[\[Rho]\_0]], Print["\<Hermitian\>"], 
      Print["\<Not Hermitian\>"]]\)\)\)], "Input",
  FontFamily->"Courier New",
  CellTags->"b:0.0.0"]
}, Closed]],

Cell[CellGroupData[{

Cell["Step 2: Alice operates on her four qubits", "Subsection",
  CellFrame->True,
  FontFamily->"Times",
  CellTags->{"b:1.0.1", "c:10"}],

Cell["\<\
Alice operations can be constructed easily in the 6 qubit space: 
[This is one of the important features of working in the Density matrix \
approach:
the mapping between the circuit in the Figure and the operations is \
straightforward] \
\>", "Text",
  FontFamily->"Helvetica",
  CellTags->"b:1.0.1"],

Cell[BoxData[
    \(\(\(\ \)\(Bop[qi_, qj_, qk_, ql_, qm_, qn_] := 
      had[6, qi] . had[6, qj] . CNOT[6, qi, qk] . 
        CNOT[6, qj, ql]\)\)\)], "Input",
  FontFamily->"Courier New",
  CellTags->"b:1.0.1"]
}, Closed]],

Cell[CellGroupData[{

Cell["Step 3: The final state density matrix is obtained", "Subsection",
  CellFrame->True,
  FontFamily->"Times",
  CellTags->{"b:1.0.2", "c:11"}],

Cell["\<\
The application of Alice operations to the initial density matrix is readily \
evaluated:\
\>", "Text",
  FontFamily->"Helvetica",
  CellTags->"b:1.0.2"],

Cell[BoxData[
    RowBox[{
      StyleBox[" ",
        FontSize->12], 
      RowBox[{
        StyleBox[\(\[Rho]\_E\ \  := \ 
              Bop[1, 2, 3, 4, 5, 6] . \[Rho]\_0 . 
                Adj[Bop[1, 2, 3, 4, 5, 6]];\),
          FontSize->12], 
        StyleBox["\[IndentingNewLine]",
          FontSize->12], 
        RowBox[{
          StyleBox["Chop",
            FontSize->12], 
          StyleBox["[",
            FontSize->12], \(Tr[\[Rho]\_E]\), "]"}]}]}]], "Input",
  FontFamily->"Courier New",
  FontSize->12,
  CellTags->"b:1.0.2"],

Cell["\<\
We can check that the density matrix is indeed so by computing its trace and \
the trace 
of it squared (Purity):\
\>", "Text",
  FontFamily->"Helvetica",
  CellTags->"b:1.0.2"],

Cell[BoxData[{
    \(Simplify[Chop[Tr[\[Rho]\_E]]]\), "\n", 
    \(Simplify[Chop[Purity[\[Rho]\_E]]]\)}], "Input",
  CellTags->"b:1.0.2"]
}, Closed]],

Cell[CellGroupData[{

Cell["Step 4: Alice measures her four qubits, 1,2,3,4", "Subsection",
  CellFrame->True,
  FontFamily->"Times",
  CellTags->{"b:1.0.3", "c:12"}],

Cell["\<\
Measurements are performed by means of projection operators. The projection \
operator on qubits 1,2,3,4 is written:\
\>", "Text",
  FontFamily->"Helvetica",
  CellTags->"b:1.0.3"],

Cell[BoxData[
    RowBox[{\(P\_\(a_, b_, c_, d_\)\), ":=", 
      RowBox[{"(", 
        StyleBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{"(", 
                      RowBox[{
                        RowBox[{"(", 
                          RowBox[{
                            SubscriptBox["\[ScriptCapitalP]", 
                              StyleBox["a",
                                ScriptLevel->0]], "\[CircleTimes]", 
                            SubscriptBox["\[ScriptCapitalP]", 
                              StyleBox["b",
                                ScriptLevel->0]]}], ")"}], "\[CircleTimes]", 
                        SubscriptBox["\[ScriptCapitalP]", 
                          StyleBox["c",
                            ScriptLevel->0]]}], ")"}], "\[CircleTimes]", 
                    SubscriptBox["\[ScriptCapitalP]", 
                      StyleBox["d",
                        ScriptLevel->0]]}], ")"}], "\[CircleTimes]", 
                "\[DoubleStruckCapitalI]"}], ")"}], "\[CircleTimes]", 
            "\[DoubleStruckCapitalI]"}],
          ScriptLevel->0], 
        StyleBox[")",
          ScriptLevel->0]}]}]], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  Cell[BoxData[
      FormBox[Cell[TextData[Cell[BoxData[
            FormBox[Cell[""], TraditionalForm]]]]], TraditionalForm]]],
  "Step 5: Bob state is computed "
}], "Subsection",
  CellFrame->True,
  FontFamily->"Times",
  CellTags->{"b:1.0.4", "c:13"}],

Cell["\<\
Bob's two qubit state, made of qubits 5 and 6, is obtained by taking the \
partial trace of the full final state after 
Alice's measurement (here is written in general depending on the four values \
of alice measurement)\
\>", "Text",
  FontFamily->"Helvetica",
  CellTags->"b:1.0.4"],

Cell[BoxData[
    \(\(Bob[a_, b_, c_, d_] := 
        Chop[\ PTr[{1, 2, 3, 4}\ \ , 
            2^4*P\_\(a, b, c, d\) . \[Rho]\_E . 
                P\_\(a, b, c, d\)\ ]];\)\)], "Input",
  CellTags->"b:1.0.4"],

Cell["\<\
Alice measurement is produced at random, the result of her measurement is \
P1,P2,P3,P4\
\>", "Text",
  FontFamily->"Helvetica",
  CellTags->"b:1.0.4"],

Cell[BoxData[{
    \(\(P1 = Random[Integer, {0, 1}];\)\), "\[IndentingNewLine]", 
    \(\(P2 = Random[Integer, {0, 1}];\)\), "\[IndentingNewLine]", 
    \(\(P3 = Random[Integer, {0, 1}];\)\), "\[IndentingNewLine]", 
    \(\(P4 = Random[Integer, {0, 1}];\)\), "\[IndentingNewLine]", 
    \({P1, P2, P3, P4}\)}], "Input",
  CellTags->"b:1.0.4"],

Cell[TextData[{
  "Bob state, once Alice has ",
  StyleBox["clasically communicated",
    FontWeight->"Bold"],
  " P1,P2,P3,P4 reads:"
}], "Text",
  FontFamily->"Helvetica",
  CellTags->"b:1.0.4"],

Cell[BoxData[
    \(\[Rho]\_Bob = Bob[P1, P2, P3, P4]\)], "Input",
  CellTags->"b:1.0.4"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  Cell[BoxData[
      FormBox[Cell[TextData[Cell[BoxData[
            FormBox[Cell[""], TraditionalForm]]]]], TraditionalForm]]],
  "Step 6: Bob performs an arranged transformation on its state to recover \
the initial state"
}], "Subsection",
  CellFrame->True,
  FontFamily->"Times",
  CellTags->{"b:1.0.5", "c:14"}],

Cell["\<\
The coding of the operations is quite compact altough it could be improved \
slightly\
\>", "Text",
  FontFamily->"Helvetica",
  CellTags->"b:1.0.5"],

Cell[BoxData[{
    \(\(I1 = P1*2 + P3;\)\), "\[IndentingNewLine]", 
    \(\(I2 = P2*2 + P4;\)\), "\[IndentingNewLine]", 
    \(\(If\ [P1*2 + P3 \[Equal] 2, \ I1 = 3];\)\), "\[IndentingNewLine]", 
    \(\(If\ [P1*2 + P3 \[Equal] 3, \ I1 = 2];\)\), "\[IndentingNewLine]", 
    \(\(If\ [P2*2 + P4 \[Equal] 2, \ I2 = 3];\)\), "\[IndentingNewLine]", 
    \(\(If\ [P2*2 + P4 \[Equal] 3, \ I2 = 2];\)\), "\[IndentingNewLine]", 
    \(TrasF = \[Sigma]\_I1\ \[CircleTimes]\ \[Sigma]\_I2\)}], "Input",
  CellTags->"b:1.0.5"],

Cell["\<\
The 2 qubit state in bobs hands after the transformation reads:\
\>", "Text",
  FontFamily->"Helvetica",
  CellTags->"b:1.0.5"],

Cell[BoxData[{
    \(BobT = \ 
      Chop[TrasF . \[Rho]\_Bob . Adj[TrasF]]\), "\[IndentingNewLine]", 
    \(Chop[Eigenvalues[BobT]]\)}], "Input",
  CellTags->"b:1.0.5"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  Cell[BoxData[
      FormBox[Cell[TextData[Cell[BoxData[
            FormBox[Cell[""], TraditionalForm]]]]], TraditionalForm]]],
  "Step 7: Moment of truth, we compare both intial Alice state and final Bob \
state"
}], "Subsection",
  CellFrame->True,
  FontFamily->"Times",
  CellTags->{"b:1.0.6", "c:15"}],

Cell["\<\
The 2qubit state density matrix that bob has is characterized by :\
\>", "Text",
  FontFamily->"Helvetica",
  CellTags->"b:1.0.6"],

Cell[BoxData[{
    RowBox[{
      RowBox[{\(T[i_, j_]\), ":=", 
        RowBox[{
        "Tr", "[", \(\((\[Sigma]\_i\[CircleTimes]\[Sigma]\_j)\) . BobT\), 
          StyleBox[" ",
            FontSize->12], 
          StyleBox["]",
            FontSize->12]}]}], 
      StyleBox[";",
        FontSize->12]}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        StyleBox["PA",
          FontSize->12], 
        StyleBox["=",
          FontSize->12], 
        RowBox[{
          StyleBox["{",
            FontSize->12], 
          RowBox[{
            StyleBox[\(T[1, 0]\),
              FontSize->12], 
            StyleBox[",",
              FontSize->12], \(T[2, 0]\), ",", \(T[3, 0]\)}], "}"}]}], 
      ";"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        StyleBox["PB",
          FontSize->12], 
        StyleBox["=",
          FontSize->12], 
        RowBox[{
          StyleBox["{",
            FontSize->12], 
          RowBox[{
            StyleBox[\(T[0, 1]\),
              FontSize->12], 
            StyleBox[",",
              FontSize->12], \(T[0, 2]\), ",", \(T[0, 3]\)}], "}"}]}], 
      ";"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        StyleBox[
          RowBox[{"T", 
            StyleBox["AB",
              FontSize->12]}]], 
        StyleBox["=",
          FontSize->12], 
        RowBox[{
          StyleBox["{",
            FontSize->12], 
          RowBox[{
            StyleBox["Table",
              FontSize->12], 
            StyleBox["[",
              FontSize->12], 
            RowBox[{
              StyleBox[\(T[i, j]\),
                FontSize->12], 
              StyleBox[",",
                FontSize->12], \({i, 1, 3}\), ",", \({j, 1, 3}\)}], "]"}], 
          "}"}]}], ";"}], "\[IndentingNewLine]", \(Chop[
      PA]\), "\[IndentingNewLine]", \(Chop[
      PB]\), "\[IndentingNewLine]", \(Chop[TAB]\)}], "Input",
  CellTags->"b:1.0.6"],

Cell["\<\
...which we can compare to the original two qubit density matrix:\
\>", "Text",
  FontFamily->"Helvetica",
  CellTags->"b:1.0.6"],

Cell[BoxData[{
    RowBox[{
      RowBox[{\(TT[i_, j_]\), ":=", 
        RowBox[{
        "Tr", "[", \(\((\[Sigma]\_i\[CircleTimes]\[Sigma]\_j)\) . \
\[Rho]\_AB\), 
          StyleBox[" ",
            FontSize->12], 
          StyleBox["]",
            FontSize->12]}]}], 
      StyleBox[";",
        FontSize->12]}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        StyleBox[
          RowBox[{"T", 
            StyleBox["PA",
              FontSize->12]}]], 
        StyleBox["=",
          FontSize->12], 
        RowBox[{
          StyleBox["{",
            FontSize->12], 
          RowBox[{
            StyleBox[\(TT[1, 0]\),
              FontSize->12], 
            StyleBox[",",
              FontSize->12], \(TT[2, 0]\), ",", \(TT[3, 0]\)}], "}"}]}], 
      ";"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        StyleBox[
          RowBox[{"T", 
            StyleBox["PB",
              FontSize->12]}]], 
        StyleBox["=",
          FontSize->12], 
        RowBox[{
          StyleBox["{",
            FontSize->12], 
          RowBox[{
            StyleBox[\(TT[0, 1]\),
              FontSize->12], 
            StyleBox[",",
              FontSize->12], \(TT[0, 2]\), ",", \(TT[0, 3]\)}], "}"}]}], 
      ";"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        StyleBox[
          RowBox[{"TT", 
            StyleBox["AB",
              FontSize->12]}]], 
        StyleBox["=",
          FontSize->12], 
        RowBox[{
          StyleBox["{",
            FontSize->12], 
          RowBox[{
            StyleBox["Table",
              FontSize->12], 
            StyleBox["[",
              FontSize->12], 
            RowBox[{
              StyleBox[\(TT[i, j]\),
                FontSize->12], 
              StyleBox[",",
                FontSize->12], \({i, 1, 3}\), ",", \({j, 1, 3}\)}], "]"}], 
          "}"}]}], ";"}], "\[IndentingNewLine]", \(Chop[
      TPA]\), "\[IndentingNewLine]", \(Chop[
      TPB]\), "\[IndentingNewLine]", \(Chop[TTAB]\)}], "Input",
  CellTags->"b:1.0.6"],

Cell[BoxData[
    RowBox[{"Chop", "[", \(\[Rho]\_AB - BobT\), 
      StyleBox[" ",
        FontSize->12], 
      StyleBox["]",
        FontSize->12]}]], "Input",
  CellTags->"b:1.0.6"]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Step 8: For completeness all one qubit partial traces are shown\
\>", "Subsection",
  CellFrame->True,
  FontFamily->"Times",
  CellTags->{"b:1.0.7", "c:16"}],

Cell[BoxData[{
    StyleBox[\(\[Rho]\_\(1  F\) = Chop[PTr[{2, 3, 4, 5, 6}, \[Rho]\_E]]\),
      FontSize->12], "\[IndentingNewLine]", 
    StyleBox[\(\[Rho]\_\(2  F\) = Chop[PTr[{1, 3, 4, 5, 6}, \[Rho]\_E]]\),
      FontSize->12], "\[IndentingNewLine]", 
    StyleBox[\(\[Rho]\_\(3  F\) = Chop[PTr[{1, 2, 4, 5, 6}, \[Rho]\_E]]\),
      FontSize->12], "\[IndentingNewLine]", 
    StyleBox[\(\[Rho]\_\(4  F\) = Chop[PTr[{1, 2, 3, 5, 6}, \[Rho]\_E]]\),
      FontSize->12], "\[IndentingNewLine]", 
    StyleBox[\(\[Rho]\_\(5  F\) = Chop[PTr[{1, 2, 3, 4, 6}, \[Rho]\_E]]\),
      FontSize->12], "\[IndentingNewLine]", 
    StyleBox[\(\[Rho]\_\(6  F\) = Chop[PTr[{1, 2, 3, 4, 5}, \[Rho]\_E]]\),
      FontSize->12]}], "Input",
  CellTags->"b:1.0.7"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Three qubit teleportation algorithm using 9 qubits", "Section",
  FontFamily->"Times",
  CellTags->"c:17"],

Cell[TextData[StyleBox["Uses the Qdensity package:",
  FontFamily->"Helvetica"]], "Text",
  FontFamily->"Courier New"],

Cell[BoxData[
    \(Needs["\<QDENSITY`Qdensity`\>"]\)], "Input",
  FontFamily->"Courier New"],

Cell[BoxData[
    \(\(?QDENSITY`Qdensity`*\)\)], "Input",
  FontFamily->"Courier New"],

Cell[TextData[StyleBox["We set the number of Qubits to 9", "DisplayText",
  FontWeight->"Plain",
  Background->None,
  FontVariations->{"CompatibilityType"->0}]], "Text",
  FontFamily->"Helvetica"],

Cell[BoxData[
    \(\(nqx = 3*3;\)\)], "Input"],

Cell[BoxData[{
    \(\(figure = 
        Import["\<drawings/3teleport.png\>", "\<PNG\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(Show[figure];\)\)}], "Input"],

Cell[CellGroupData[{

Cell["\<\
Step 1: Alice  prepares the three qubit state to be teleported\
\>", "Subsection",
  CellFrame->True,
  FontFamily->"Times",
  CellTags->{"b:2.0.0", "c:18"}],

Cell["\<\
Alice builds the density matrix to be teleported. Qubits 1, 2 and 3. Here the \
teleported
state is constructed at random in the following way:\
\>", "Text",
  FontFamily->"Helvetica",
  CellTags->"b:2.0.0"],

Cell[BoxData[
    RowBox[{"RandomQubit3", " ", "=", 
      RowBox[{"Module", "[", 
        RowBox[{\({i, j, k, U}\), ",", 
          
          RowBox[{\(A1 = RandomQubit1\), ";", \(A2 = \ RandomQubit1\), 
            ";", \(A3 = \ RandomQubit1\), ";", 
            StyleBox["\[IndentingNewLine]",
              FontSize->12], \(Do[
              J\_\(i, j, k\) = Random[Real, {\(-100\), 100}], {i, 1, 3}, {j, 
                1, 3}, {k, 1, 3}]\), 
            ";", \(U = 
              MatrixExp[
                Sum[\ \[ImaginaryI]\ *
                    J\_\(i, j, k\)\ \((\((\ \[Sigma]\_\(\(i\)\(\ \)\)\
\[CircleTimes]\ \[Sigma]\_j)\)\[CircleTimes]\ \[Sigma]\_k)\), {i, 1, 3}, {j, 
                    1, 3}, {k, 1, 3}]]\), 
            ";", \(\[Rho]\_123\  = 
              Chop[Adj[\ 
                    U] . \((\((A1\[CircleTimes]A2)\)\[CircleTimes]A3)\) . 
                  U\ ]\), " ", ";", "\[IndentingNewLine]", 
            " ", \(\[Rho]\_123\)}]}], "]"}]}]], "Input",
  CellTags->"b:2.0.0"],

Cell["Its trace and purity can be readily obtained:", "Text",
  FontFamily->"Helvetica",
  CellTags->"b:2.0.0"],

Cell[BoxData[{
    \(Tr[\[Rho]\_123]\), "\[IndentingNewLine]", 
    \(Chop[Purity[\[Rho]\_123]]\)}], "Input",
  CellTags->"b:2.0.0"],

Cell["And its eigenvalues:", "Text",
  FontFamily->"Helvetica",
  CellTags->"b:2.0.0"],

Cell[BoxData[
    \(Chop[Eigenvalues[\[Rho]\_123]]\)], "Input",
  CellTags->"b:2.0.0"],

Cell[TextData[{
  "We also need to construct the entangled state of qubits 4,5,6,7,8 and 9.\n\
",
  StyleBox["[NOTE: The parentheses are essential in the tensor product]",
    FontWeight->"Bold"]
}], "Text",
  FontFamily->"Helvetica",
  CellTags->"b:2.0.0"],

Cell[BoxData[{
    \(\(\[Rho]\_1 = \((\((\((\((\((\[ScriptCapitalP]\_0\[CircleTimes]\
\[ScriptCapitalP]\_0)\)\[CircleTimes]\[ScriptCapitalP]\_0)\)\[CircleTimes]\
\[ScriptCapitalP]\_0)\)\[CircleTimes]\[ScriptCapitalP]\_0)\)\[CircleTimes]\
\[ScriptCapitalP]\_0)\);\)\), "\[IndentingNewLine]", 
    \(\(OpE = 
        CNOT[6, 3, 6] . had[6, 3] . CNOT[6, 2, 5] . had[6, 2] . 
          CNOT[6, 1, 4] . had[6, 1];\)\), "\[IndentingNewLine]", 
    \(\(\[Rho]\_3456 = \ 
        N[OpE . \[Rho]\_1 . Adj[OpE]];\)\), "\[IndentingNewLine]", 
    \(Tr[\[Rho]\_3456]\), "\[IndentingNewLine]", 
    \(Tr[\[Rho]\_3456 . \[Rho]\_3456]\)}], "Input",
  CellTags->"b:2.0.0"],

Cell["Then the density matrix for the \"initial\" system is:", "Text",
  FontFamily->"Helvetica",
  CellTags->"b:2.0.0"],

Cell[BoxData[{
    \(\(\[Rho]\_0 = 
        N[\[Rho]\_123\[CircleTimes]\[Rho]\_3456];\)\), "\[IndentingNewLine]", \

    \(N[Tr[\[Rho]\_0]]\), "\[IndentingNewLine]", 
    \(Chop[Purity[\[Rho]\_0 . \[Rho]\_0]]\)}], "Input",
  CellTags->"b:2.0.0"],

Cell["is the full density matrix hermitian?", "Text",
  FontFamily->"Helvetica",
  CellTags->"b:1.0.0"],

Cell[BoxData[
    \(\(\(\ \)\(If[
      Chop[Adj[\[Rho]\_0]\  - \[Rho]\_0] \[Equal] 
        ZeroMatrix[Length[\[Rho]\_0]], Print["\<Hermitian\>"], 
      Print["\<Not Hermitian\>"]]\)\)\)], "Input",
  FontFamily->"Courier New",
  CellTags->"b:0.0.0"]
}, Closed]],

Cell[CellGroupData[{

Cell["Step 2: Alice operates on its four qubits", "Subsection",
  CellFrame->True,
  FontFamily->"Times",
  CellTags->{"b:2.0.1", "c:19"}],

Cell["\<\
Alice operations can be constructed easily in the 6 qubit space: \
\>", "Text",
  FontFamily->"Helvetica",
  CellTags->"b:2.0.1"],

Cell[BoxData[
    \(\(\(\ \)\(Bop[qi_, qj_, qk_, ql_, qm_, qn_, qo_, qp_, qq_] := 
        had[9, qi] . had[9, qj] . had[9, qk] . CNOT[9, qi, ql] . 
          CNOT[9, qj, qm] . CNOT[9, qk, qn];\)\)\)], "Input",
  FontFamily->"Courier New",
  CellTags->"b:2.0.1"],

Cell["(we precompile the operator)", "Text",
  FontFamily->"Helvetica",
  CellTags->"b:2.0.1"],

Cell[BoxData[
    \(\(CompBop = 
        Compile[{{qi, _Integer, 0}, {qj, _Integer, 0}, {qk, _Integer, 
              0}, {ql, _Integer, 0}, {qm, _Integer, 0}, {qn, _Integer, 
              0}, {qo, _Integer, 0}, {qp, _Integer, 0}, {qq, _Integer, 0}}, \ 
          Bop[qi, qj, qk, ql, qm, qn, qo, qp, 
            qq]\ , {{\ \ \ Bop[qi, qj, qk, ql, qm, qn, qo, qp, qq], _Complex, 
              2}}]\ \ ;\)\)], "Input",
  FontFamily->"Courier New",
  CellTags->"b:2.0.1"],

Cell[BoxData[
    \(Length[\[Rho]\_0]\)], "Input",
  CellTags->"b:2.0.1"]
}, Closed]],

Cell[CellGroupData[{

Cell["Step 3: The final state density matrix is obtained", "Subsection",
  CellFrame->True,
  FontFamily->"Times",
  CellTags->{"b:2.0.2", "c:20"}],

Cell["\<\
The application of Alice operations to the initial density matrix is readily \
evaluated:\
\>", "Text",
  FontFamily->"Helvetica",
  CellTags->"b:2.0.2"],

Cell[BoxData[
    StyleBox[\(\(\ \)\(\[Rho]\_E\ \  := \ 
          N[CompBop[1, 2, 3, 4, 5, 6, 7, 8, 9] . \[Rho]\_0 . 
              Adj[CompBop[1, 2, 3, 4, 5, 6, 7, 8, 9]]];\)\),
      FontSize->12]], "Input",
  FontFamily->"Courier New",
  FontSize->12,
  CellTags->"b:2.0.2"],

Cell["\<\
We can check that the density matrix is indeed so by computing its 
trace and the trace of it squared:\
\>", "Text",
  FontFamily->"Helvetica",
  CellTags->"b:2.0.2"],

Cell[BoxData[
    \(\(\( (*N[Chop[Tr[\[Rho]\_E]]]*) \)\(\n\)\( (*N[
        Chop[Tr[\[Rho]\_E . \[Rho]\_E]]]*) \)\)\)], "Input",
  CellTags->"b:2.0.2"]
}, Closed]],

Cell[CellGroupData[{

Cell["Step 4: Alice measures her four qubits, 1,2,3,4,5,6", "Subsection",
  CellFrame->True,
  FontFamily->"Times",
  CellTags->{"b:2.0.3", "c:21"}],

Cell["\<\
Alice measurement is produced here at random, the result of her measurement \
is 
P1,P2,P3,P4,P5,P6\
\>", "Text",
  FontFamily->"Helvetica",
  CellTags->"b:2.0.3"],

Cell[BoxData[{
    \(\(P1 = Random[Integer, {0, 1}];\)\), "\[IndentingNewLine]", 
    \(\(P2 = Random[Integer, {0, 1}];\)\), "\[IndentingNewLine]", 
    \(\(P3 = Random[Integer, {0, 1}];\)\), "\[IndentingNewLine]", 
    \(\(P4 = Random[Integer, {0, 1}];\)\), "\[IndentingNewLine]", 
    \(\(P5 = Random[Integer, {0, 1}];\)\), "\[IndentingNewLine]", 
    \(\(P6 = Random[Integer, {0, 1}];\)\), "\[IndentingNewLine]", 
    \({P1, P2, P3, P4, P5, P6}\)}], "Input",
  CellTags->"b:2.0.3"],

Cell["\<\
The projection operator on qubits 1,2,3,4,5 and 6 is written:\
\>", "Text",
  FontFamily->"Helvetica",
  CellTags->"b:2.0.3"],

Cell[BoxData[
    \(P\_\(a_, b_, c_, d_, e_, f_\)\ \  := \ \((\((\((\((\((\((\((\ \((\
\[ScriptCapitalP]\_a\ \ \[CircleTimes]\ \ \[ScriptCapitalP]\_b)\)\
\[CircleTimes]\ \ \[ScriptCapitalP]\_c)\)\[CircleTimes]\[ScriptCapitalP]\_d\ \
)\)\[CircleTimes]\ \ \
\[ScriptCapitalP]\_e)\)\[CircleTimes]\[ScriptCapitalP]\_f\ )\)\[CircleTimes]\ \
\[DoubleStruckCapitalI])\)\[CircleTimes]\ \[DoubleStruckCapitalI])\)\
\[CircleTimes]\ \[DoubleStruckCapitalI])\)\)], "Input",
  CellTags->"b:2.0.3"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  Cell[BoxData[
      FormBox[Cell[TextData[Cell[BoxData[
            FormBox[Cell[""], TraditionalForm]]]]], TraditionalForm]]],
  "Step 5: Bob state is computed "
}], "Subsection",
  CellFrame->True,
  FontFamily->"Times",
  CellTags->{"b:2.0.4", "c:22"}],

Cell["\<\
Bob's three qubit state, made of qubits 7, 8 and 9, is obtained by taking the \

partial trace of the full final state after Alice measurement (here is \
written in general depending on the 
six values of alice measurement)\
\>", "Text",
  FontFamily->"Helvetica",
  CellTags->"b:2.0.4"],

Cell[BoxData[
    \(\(time1 = SessionTime[];\)\)], "Input"],

Cell[BoxData[
    \(\(Bob\  = \ 
        Chop[CompPTr[{1, 2, 3, 4, 5, 6}\ \ , 
            2^6*P\_\(P1, P2, P3, P4, P5, P6\) . \[Rho]\_E . 
                P\_\(P1, P2, P3, P4, P5, P6\)\ ]];\)\)], "Input",
  CellTags->"b:2.0.4"],

Cell[BoxData[{
    \(\(time2 = SessionTime[];\)\), "\[IndentingNewLine]", 
    \(Print["\<The computation of Bob's density matrix took \>", 
      time2 - time1, "\< seconds\>"]\)}], "Input"],

Cell[TextData[{
  "Bob state, once Alice has ",
  StyleBox["clasically communicated",
    FontWeight->"Bold"],
  " P1,P2,P3,P4,P5 and P6 reads:"
}], "Text",
  FontFamily->"Helvetica",
  CellTags->"b:2.0.4"],

Cell[BoxData[
    \(\[Rho]\_Bob = Bob\)], "Input",
  CellTags->"b:2.0.4"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  Cell[BoxData[
      FormBox[Cell[TextData[Cell[BoxData[
            FormBox[Cell[""], TraditionalForm]]]]], TraditionalForm]]],
  "Step 6: Bob performs an arranged transformation on its state to recover \
the initial state"
}], "Subsection",
  CellFrame->True,
  FontFamily->"Times",
  CellTags->{"b:2.0.5", "c:23"}],

Cell["\<\
The coding of the operations is quite compact altough it could be improved \
slightly\
\>", "Text",
  FontFamily->"Helvetica",
  CellTags->"b:2.0.5"],

Cell[BoxData[{
    \(\(I1 = P1*2 + P4;\)\), "\[IndentingNewLine]", 
    \(\(I2 = P2*2 + P5;\)\), "\[IndentingNewLine]", 
    \(I3 = P3*2 + P6\), "\[IndentingNewLine]", 
    \(\(If\ [P1*2 + P4 \[Equal] 2, \ I1 = 3];\)\), "\[IndentingNewLine]", 
    \(\(If\ [P1*2 + P4 \[Equal] 3, \ I1 = 2];\)\), "\[IndentingNewLine]", 
    \(\(If\ [P2*2 + P5 \[Equal] 2, \ I2 = 3];\)\), "\[IndentingNewLine]", 
    \(\(If\ [P2*2 + P5 \[Equal] 3, \ I2 = 2];\)\), "\[IndentingNewLine]", 
    \(\(If\ [P3*2 + P6 \[Equal] 2, \ I3 = 3];\)\), "\[IndentingNewLine]", 
    \(\(If\ [P3*2 + P6 \[Equal] 3, \ I3 = 2];\)\), "\[IndentingNewLine]", 
    \(TrasF = \((\[Sigma]\_I1\ \[CircleTimes]\ \[Sigma]\_I2)\)\[CircleTimes]\ \
\[Sigma]\_I3\)}], "Input",
  CellTags->"b:2.0.5"],

Cell["\<\
The three qubit state in Bob's hands after the transformation is:\
\>", "Text",
  FontFamily->"Helvetica",
  CellTags->"b:2.0.5"],

Cell[BoxData[{
    \(BobT = \ 
      N[Chop[TrasF . \[Rho]\_Bob . Adj[TrasF]]]\), "\[IndentingNewLine]", 
    \(Chop[Eigenvalues[BobT]]\)}], "Input",
  CellTags->"b:2.0.5"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  Cell[BoxData[
      FormBox[Cell[TextData[Cell[BoxData[
            FormBox[Cell[""], TraditionalForm]]]]], TraditionalForm]]],
  "Step 7: Moment of truth, we compare both  intial Alice and final Bob \
state"
}], "Subsection",
  CellFrame->True,
  FontFamily->"Times",
  CellTags->{"b:2.0.6", "c:24"}],

Cell["\<\
...we can compare Bobs three qubit state to the original three qubit density \
matrix:\
\>", "Text",
  FontFamily->"Helvetica",
  CellTags->"b:2.0.6"],

Cell[BoxData[
    \(Chop[BobT\  - \[Rho]\_123]\)], "Input",
  CellTags->"b:2.0.6"],

Cell[BoxData[
    \(Quit\)], "Input",
  CellTags->"b:2.0.6"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["EPR telerpotation using an GHZ state", "Section",
  FontFamily->"Times",
  CellTags->"c:25"],

Cell["\<\
 Load the Qdensity Package, defines total number of qubits and plots the \
circuit:\
\>", "Text",
  FontFamily->"Helvetica"],

Cell[BoxData[
    \(Needs["\<QDENSITY`Qdensity`\>"]\)], "Input",
  FontFamily->"Courier New"],

Cell[BoxData[
    \(\(?QDENSITY`Qdensity`*\)\)], "Input",
  FontFamily->"Courier New"],

Cell[BoxData[
    \(\(nqx = 5;\)\)], "Input",
  FontFamily->"Courier New"],

Cell[BoxData[{
    \(\(figure1 = 
        Import["\<drawings/GHZ.png\>", "\<PNG\>"];\)\), \
"\[IndentingNewLine]", 
    \(\(Show[figure1];\)\)}], "Input"],

Cell[TextData[{
  StyleBox["Icalc=1 computes using symbols",
    FontSlant->"Italic"],
  ", anyother Icalc value performs the computation\nnumerically."
}], "Text",
  FontFamily->"Helvetica"],

Cell[BoxData[
    \(\(Icalc = 1;\)\)], "Input"],

Cell[CellGroupData[{

Cell[TextData[{
  Cell[BoxData[
      FormBox[Cell[TextData[Cell[BoxData[
            FormBox[Cell[""], TraditionalForm]]]]], TraditionalForm]]],
  "Step 1: Alice builds the EPR state to be teleported"
}], "Subsection",
  CellFrame->True,
  FontFamily->"Times",
  CellTags->{"b:6.0.0", "c:26"}],

Cell["\<\
 The EPR state is of the form A|00\[RightAngleBracket]+B|11\
\[RightAngleBracket]. It is built by first constructing (A|0\
\[RightAngleBracket]+B|1\[RightAngleBracket])|0\[RightAngleBracket] and then 
applying a CNOT(2,1,2). The first qubit is thus generated at random in the \
following way:\
\>", "Text",
  FontFamily->"Helvetica",
  CellTags->"b:6.0.0"],

Cell["\<\
 A general one qubit state is built by rotating the |0\[RightAngleBracket] \
state around the x axis an angle \[Theta]\
\>", "Text",
  FontFamily->"Helvetica",
  CellTags->"b:6.0.0"],

Cell[BoxData[
    \(\(\[Rho]\_1 = RandomQubit1;\)\)], "Input",
  CellTags->"b:6.0.0"],

Cell[BoxData[
    \(\(\(\ \)\(If[
        Icalc \[Equal] 1, \[Rho]\_1 = 
          1/\((A^2 + B^2)\)*\((A*Ket[0] + 
                  B*Ket[1])\)\[CircleTimes]\ \((A*Bra[0] + 
                  B*Bra[1])\)];\)\)\)], "Input",
  CellTags->"b:6.0.0"],

Cell["Then we construct the EPR state using a CNOT gate:", "Text",
  FontFamily->"Helvetica",
  CellTags->"b:6.0.0"],

Cell[BoxData[{
    \(\(OpEPR = CNOT[2, 1, 2];\)\), "\[IndentingNewLine]", 
    \(\(\[Rho]\_12 = \ \[Rho]\_1\[CircleTimes]\[ScriptCapitalP]\_0;\)\), "\
\[IndentingNewLine]", 
    \(\[Rho]\_EPR = 
      Chop[OpEPR . \[Rho]\_12 . Adj[OpEPR]]\), "\[IndentingNewLine]", 
    \(Tr[\[Rho]\_EPR]\), "\[IndentingNewLine]", 
    \(Tr[\[Rho]\_EPR . \[Rho]\_EPR]\)}], "Input",
  CellTags->"b:6.0.0"],

Cell["Check on Hermiticity of the EPR (only if Icalc=0)", "Text",
  FontFamily->"Helvetica",
  CellTags->"b:6.0.0"],

Cell[BoxData[
    RowBox[{" ", 
      RowBox[{"If", "[", 
        RowBox[{\(Icalc \[Equal] 0\), ",", 
          RowBox[{"If", "[", 
            RowBox[{
              RowBox[{
                RowBox[{"Chop", "[", 
                  RowBox[{
                    RowBox[{"Adj", "[", \(\[Rho]\_EPR\), 
                      StyleBox["  ",
                        FontSize->12], "]"}], " ", 
                    "-", \(\[Rho]\_\(\(EPR\)\(\ \)\)\)}], "]"}], 
                "\[Equal]", \(ZeroMatrix[Length[\[Rho]\_EPR]]\)}], 
              ",", \(Print["\<Hermitian\>"]\), 
              ",", \(Print["\<Not Hermitian\>"]\)}], "]"}], ",", "\"\<\>\""}],
         "]"}]}]], "Input",
  FontFamily->"Courier New",
  CellTags->"b:6.0.0"],

Cell["Check on Eigenvalues of the EPR", "Text",
  FontFamily->"Helvetica",
  CellTags->"b:6.0.0"],

Cell[BoxData[{
    \(evEPR := Chop[Eigenvalues[\[Rho]\_EPR]]\), "\[IndentingNewLine]", 
    \(evEPR\), "\[IndentingNewLine]", 
    \(Simplify[Chop[Tr[\[Rho]\_EPR]]]\), "\[IndentingNewLine]", 
    \(Simplify[Chop[Tr[\[Rho]\_EPR . \[Rho]\_EPR]]]\)}], "Input",
  CellTags->"b:6.0.0"],

Cell["Test Positivity:", "Text",
  FontFamily->"Helvetica",
  CellTags->"b:6.0.0"],

Cell[BoxData[
    \(\(\(\ \)\(If[Icalc \[Equal] 0, 
      Do[If[Re[evEPR[\([i]\)]] \[GreaterEqual] 0, 
          Print["\<Positive eigenvalue\>"], Print["\<Negative\>"]], {i, 1, 
          4}], "\<\>"]\)\)\)], "Input",
  FontFamily->"Courier New",
  CellTags->{"Do", "b:6.0.0"}]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  Cell[BoxData[
      FormBox[Cell[TextData[Cell[BoxData[
            FormBox[Cell[""], TraditionalForm]]]]], TraditionalForm]]],
  "Step 2: The GHZ state made of qubits 345 is built"
}], "Subsection",
  CellFrame->True,
  FontFamily->"Times",
  CellTags->{"b:6.0.1", "c:27"}],

Cell[BoxData[
    RowBox[{
      RowBox[{"  ", 
        RowBox[{
        "Build", " ", "the", " ", "Three", " ", "Qubit", " ", "entangled", 
          " ", "state", "   ", 
          StyleBox[\(\[Rho]\_GHZ\),
            FontSize->12], "  ", \((\ Entangled\ State\ Resource\ )\)}], 
        " "}], " "}]], "Text",
  FontFamily->"Helvetica",
  CellTags->"b:6.0.1"],

Cell[BoxData[
    RowBox[{
      StyleBox[\(\[Rho]\_00\),
        FontSize->12], 
      StyleBox["=",
        FontSize->
          12], \(\[ScriptCapitalP]\_0\ \ \[CircleTimes]\ \((\ \
\[ScriptCapitalP]\_0\ \[CircleTimes]\ \ \[ScriptCapitalP]\_0)\)\)}]], "Input",\

  CellTags->"b:6.0.1"],

Cell[" Generate GHZ state operator ", "Text",
  FontFamily->"Helvetica",
  CellTags->"b:6.0.1"],

Cell[BoxData[{
    \(\(figure2 = 
        Import["\<drawings/gGHZ.png\>", "\<PNG\>"];\)\), \
"\[IndentingNewLine]", 
    \(Show[figure2]\)}], "Input",
  CellTags->"b:6.0.1"],

Cell[BoxData[
    \(GHZop[qi_, qj_, qk_] := \(\(\(CNOT[3, qi, qk] . CNOT[3, qi, qj]\) . 
        had[3, qi]\)\(\ \)\)\)], "Input",
  FontFamily->"Courier New",
  CellTags->"b:6.0.1"],

Cell[BoxData[
    \(\(\(\ \ \)\(\[Rho]\_GHZ\ \ \ is\ the\ density\ matrix\ \ of\ the\ GHZ\ \
state\ produced\ by\ Bob\ \ \((or\ Eve)\)\ from\ qubits\ 3, \(4\  &\)\ 5\ \
\[IndentingNewLine]
    \ \ \(Bob\ sends\ one\ of\ these\ qubits\ to\ Alice\ who\ has\ qubits\ 1\ \
 &\)\ 2\ in\ state\ \[Rho]\_EPR\)\)\)], "Text",
  FontFamily->"Helvetica",
  CellTags->"b:6.0.1"],

Cell[BoxData[
    StyleBox[\(\(\ \)\(\[Rho]\_GHZ\ \  := 
          GHZop[1, 2, 3] . \[Rho]\_00 . Adj[GHZop[1, 2, 3]];\)\),
      FontSize->12]], "Input",
  FontFamily->"Courier New",
  FontSize->12,
  CellTags->"b:6.0.1"],

Cell[" Checks on GHZ states ", "Text",
  FontFamily->"Helvetica",
  CellTags->"b:6.0.1"],

Cell[BoxData[
    \(\[Rho]\_GHZ\)], "Input",
  CellTags->"b:6.0.1"],

Cell["\<\
 Vector and tensor polarizations of GHZ state 
 Vector polarizations are zero for GHZ states 
 Rank 2 Tensor polarizations for GHZ state 
 Rank 3 Tensor polarizations for GHZ state \
\>", "Text",
  FontFamily->"Helvetica",
  CellTags->"b:6.0.1"],

Cell[BoxData[{
    RowBox[{
      RowBox[{\(T[i_, j_, k_]\), ":=", 
        RowBox[{"Tr", "[", 
          
          RowBox[{\((\((\[Sigma]\_i\[CircleTimes]\[Sigma]\_j)\)\[CircleTimes]\
\[Sigma]\_k)\), ".", 
            StyleBox[\(\[Rho]\_GHZ\),
              FontSize->12]}], 
          StyleBox[" ",
            FontSize->12], 
          StyleBox["]",
            FontSize->12]}]}], 
      StyleBox[";",
        FontSize->12]}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        StyleBox[
          RowBox[{
            StyleBox["P",
              FontSize->12], "GHZ", 
            StyleBox["A",
              FontSize->12]}]], 
        StyleBox["=",
          FontSize->12], 
        RowBox[{
          StyleBox["{",
            FontSize->12], 
          RowBox[{
            StyleBox[\(T[1, 0, 0]\),
              FontSize->12], 
            StyleBox[",",
              FontSize->12], \(T[2, 0, 0]\), ",", \(T[3, 0, 0]\)}], "}"}]}], 
      ";"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        StyleBox[
          RowBox[{
            StyleBox["P",
              FontSize->12], "GHZ", 
            StyleBox["B",
              FontSize->12]}]], 
        StyleBox["=",
          FontSize->12], 
        RowBox[{
          StyleBox["{",
            FontSize->12], 
          RowBox[{
            StyleBox[\(T[0, 1, 0]\),
              FontSize->12], 
            StyleBox[",",
              FontSize->12], \(T[0, 2, 0]\), ",", \(T[0, 3, 0]\)}], "}"}]}], 
      ";"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{
          StyleBox[
            RowBox[{
              StyleBox["P",
                FontSize->12], "GHZ", 
              StyleBox["C",
                FontSize->12]}]], 
          StyleBox["=",
            FontSize->12], 
          RowBox[{
            StyleBox["{",
              FontSize->12], 
            RowBox[{
              StyleBox[\(T[0, 0, 1]\),
                FontSize->12], 
              StyleBox[",",
                FontSize->12], \(T[0, 0, 2]\), ",", \(T[0, 0, 3]\)}], "}"}]}],
         ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        StyleBox[
          RowBox[{"TGHZ", 
            StyleBox["AB",
              FontSize->12]}]], 
        StyleBox["=",
          FontSize->12], 
        RowBox[{
          StyleBox["{",
            FontSize->12], 
          RowBox[{
            StyleBox["Table",
              FontSize->12], 
            StyleBox["[",
              FontSize->12], 
            RowBox[{
              StyleBox[\(T[i, j, 0]\),
                FontSize->12], 
              StyleBox[",",
                FontSize->12], \({i, 1, 3}\), ",", \({j, 1, 3}\)}], "]"}], 
          "}"}]}], ";"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        StyleBox[
          RowBox[{"TGHZ", 
            StyleBox["AC",
              FontSize->12]}]], 
        StyleBox["=",
          FontSize->12], 
        RowBox[{
          StyleBox["{",
            FontSize->12], 
          RowBox[{
            StyleBox["Table",
              FontSize->12], 
            StyleBox["[",
              FontSize->12], 
            RowBox[{
              StyleBox[\(T[i, 0, j]\),
                FontSize->12], 
              StyleBox[",",
                FontSize->12], \({i, 1, 3}\), ",", \({j, 1, 3}\)}], "]"}], 
          "}"}]}], ";"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"TGHZBC", 
        StyleBox["=",
          FontSize->12], 
        RowBox[{
          StyleBox["{",
            FontSize->12], 
          RowBox[{
            StyleBox["Table",
              FontSize->12], 
            StyleBox["[",
              FontSize->12], 
            RowBox[{
              StyleBox[\(T[i, j, 0]\),
                FontSize->12], 
              StyleBox[",",
                FontSize->12], \({i, 1, 3}\), ",", \({j, 1, 3}\)}], "]"}], 
          "}"}]}], ";"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        StyleBox[
          RowBox[{"TGHZ", 
            StyleBox["ABC",
              FontSize->12]}]], 
        StyleBox["=",
          FontSize->12], 
        RowBox[{
          StyleBox["{",
            FontSize->12], 
          RowBox[{
            StyleBox["Table",
              FontSize->12], 
            StyleBox["[",
              FontSize->12], 
            RowBox[{
              StyleBox[\(T[i, j, k]\),
                FontSize->12], 
              StyleBox[",",
                FontSize->12], \({i, 1, 3}\), ",", \({j, 1, 3}\), 
              ",", \({k, 1, 3}\)}], "]"}], "}"}]}], 
      ";"}], "\[IndentingNewLine]", "PGHZA", "\[IndentingNewLine]", 
  "PGHZB", "\[IndentingNewLine]", 
  "PGHZC", "\[IndentingNewLine]", \(Flatten[TGHZAB, 
      1]\), "\[IndentingNewLine]", \(Flatten[TGHZAC, 
      1]\), "\[IndentingNewLine]", \(Flatten[TGHZBC, 
      1]\), "\[IndentingNewLine]", "TGHZABC"}], "Input",
  FontFamily->"Courier New",
  CellTags->"b:6.0.1"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  Cell[BoxData[
      FormBox[Cell[TextData[Cell[BoxData[
            FormBox[Cell[""], TraditionalForm]]]]], TraditionalForm]]],
  "Step 3: The initial 5 qubit state"
}], "Subsection",
  CellFrame->True,
  FontFamily->"Times",
  CellTags->{"b:6.0.2", "c:28"}],

Cell[BoxData[
    RowBox[{
      RowBox[{
      "The", " ", "initial", " ", "5", " ", "qubit", " ", "density", " ", 
        "matrix", " ", "is", " ", 
        RowBox[{"thus", ":", " ", 
          StyleBox[\(\[Rho]\_I\),
            FontSize->12]}]}], 
      StyleBox["=",
        FontSize->12], 
      StyleBox[
        RowBox[{
          StyleBox[" ",
            FontSize->12], " "}]], 
      RowBox[{
        StyleBox[\(\[Rho]\_EPR\),
          FontSize->12], " ", "\[CircleTimes]", " ", 
        StyleBox[\(\[Rho]\_GHZ\),
          FontSize->12]}]}]], "Text",
  FontFamily->"Helvetica",
  CellTags->"b:6.0.2"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        StyleBox[\(\[Rho]\_I\),
          FontSize->12], 
        StyleBox["=",
          FontSize->12], 
        StyleBox["  ",
          FontSize->12], 
        RowBox[{
          StyleBox[\(\[Rho]\_EPR\),
            FontSize->12], "\[CircleTimes]", 
          StyleBox[\(\[Rho]\_GHZ\),
            FontSize->12]}]}], 
      StyleBox[";",
        FontSize->12]}]], "Input",
  FontFamily->"Courier New",
  CellTags->"b:6.0.2"],

Cell[BoxData[
    RowBox[{"Checks", " ", "on", " ", "Full", " ", "Initial", "  ", 
      StyleBox[\(\[Rho]\_I\),
        FontSize->12], " ", "Density", " ", "Matrix"}]], "Text",
  FontFamily->"Helvetica",
  CellTags->"b:6.0.2"],

Cell[BoxData[
    RowBox[{"Length", "[", 
      StyleBox[\(\[Rho]\_I\),
        FontSize->12], 
      StyleBox["]",
        FontSize->12]}]], "Input",
  FontFamily->"Courier New",
  CellTags->"b:6.0.2"],

Cell[BoxData[
    RowBox[{"Trace", " ", "and", " ", "purity", " ", "of", "  ", 
      StyleBox[\(\[Rho]\_I\),
        FontSize->12], " ", "Density", " ", "Matrix"}]], "Text",
  FontFamily->"Helvetica",
  CellTags->"b:6.0.2"],

Cell[BoxData[{
    RowBox[{"Simplify", "[", 
      RowBox[{"Chop", "[", 
        RowBox[{"Tr", "[", 
          StyleBox[\(\[Rho]\_I\),
            FontSize->12], 
          StyleBox["]",
            FontSize->12]}], 
        StyleBox["]",
          FontSize->12]}], 
      StyleBox["]",
        FontSize->12]}], "\[IndentingNewLine]", 
    RowBox[{"Simplify", "[", 
      RowBox[{"Purity", "[", 
        StyleBox[\(\[Rho]\_I\),
          FontSize->12], 
        StyleBox["]",
          FontSize->12]}], 
      StyleBox["]",
        FontSize->12]}]}], "Input",
  FontFamily->"Courier New",
  CellTags->"b:6.0.2"],

Cell[BoxData[
    RowBox[{"If", "[", 
      RowBox[{\(Icalc \[Equal] 0\), ",", 
        RowBox[{
          RowBox[{"evI", ":=", 
            RowBox[{"Eigenvalues", "[", 
              StyleBox[\(\[Rho]\_I\),
                FontSize->12], 
              StyleBox["]",
                FontSize->12]}]}], 
          StyleBox[";",
            FontSize->12], "\[IndentingNewLine]", 
          RowBox[{"Do", "[", 
            
            RowBox[{\(If[Chop[evI[\([i]\)]] \[GreaterEqual] 0, 
                Print["\<Positive eigenvalue\>"], Print["\<Negative\>"]]\), 
              ",", 
              RowBox[{"{", 
                RowBox[{"i", ",", "1", ",", 
                  StyleBox[\(Length[evI]\),
                    FontSize->12]}], "}"}]}], "]"}]}], ",", "\"\<\>\""}], 
      "]"}]], "Input",
  FontFamily->"Courier New",
  CellTags->{"Do", "b:6.0.2"}]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  Cell[BoxData[
      FormBox[Cell[TextData[Cell[BoxData[
            FormBox[Cell[""], TraditionalForm]]]]], TraditionalForm]]],
  "Step 4: Alice receives qubit 3 and performs an operation on qubits 1,2,3 \
and then Measures them"
}], "Subsection",
  CellFrame->True,
  FontFamily->"Times",
  CellTags->{"b:6.0.3", "c:29"}],

Cell["\<\
Alice performs an operation defined by (see the figure above):\
\>", "Text",
  FontFamily->"Helvetica",
  CellTags->"b:6.0.3"],

Cell[BoxData[
    \(\(AliceOp = \ 
        had[5, 2] . CNOT[5, 3, 2] . had[5, 1] . CNOT[5, 1, 3];\)\)], "Input",
  CellTags->"b:6.0.3"],

Cell["\<\
 And therefore the density matrix of the 5 qubit system after Alice operation \
reads:\
\>", "Text",
  FontFamily->"Helvetica",
  CellTags->"b:6.0.3"],

Cell[BoxData[{
    \(\(\[Rho]\_T\  = AliceOp . \[Rho]\_I . Adj[AliceOp];\)\), "\n", 
    \(Simplify[Chop[Tr[\[Rho]\_T]]]\), "\n", 
    \(Simplify[Chop[Tr[\[Rho]\_T . \[Rho]\_T]]]\)}], "Input",
  FontFamily->"Courier New",
  CellTags->"b:6.0.3"],

Cell[BoxData[
    \(If[Icalc \[Equal] 0, evF := Eigenvalues[\[Rho]\_T]; 
      Do[If[Chop[evF[\([i]\)]] \[GreaterEqual] 0, 
          Print["\<Positive eigenvalue\>"], Print["\<Negative\>"]], {i, 1, 
          Length[evF]}], "\<\>"]\)], "Input",
  FontFamily->"Courier New",
  CellTags->"b:6.0.3"],

Cell[BoxData[
    \(Length[\[Rho]\_T]\)], "Input",
  FontFamily->"Courier New",
  CellTags->"b:6.0.3"],

Cell["\<\
 Eight  Projection Operators for Alice's Measurement on Qubits 1,2 and 3 \
\>", "Text",
  FontFamily->"Helvetica",
  CellTags->"b:6.0.3"],

Cell[BoxData[
    \(P\_\(a_, b_, c_\)\ \  := \ \((\((\ \((\[ScriptCapitalP]\_a\ \ \
\[CircleTimes]\ \ \[ScriptCapitalP]\_b)\)\[CircleTimes]\ \ \
\[ScriptCapitalP]\_c)\)\[CircleTimes]\ \[DoubleStruckCapitalI])\)\
\[CircleTimes]\ \[DoubleStruckCapitalI]\)], "Input",
  CellTags->"b:6.0.3"],

Cell["\<\
Bob's 2-Qubit Density Matrix--After measurement by Alice of abc \
\>", "Text",
  FontFamily->"Helvetica",
  CellTags->"b:6.0.3"],

Cell[BoxData[
    \(\(RhoBob[a_, b_, c_] := 
        Chop[\ PTr[{1, 2, 3}\ \ , 
            2^3.  P\_\(a, b, c\) . \[Rho]\_T . 
                P\_\(a, b, c\)\ ]];\)\)], "Input",
  FontFamily->"Courier New",
  CellTags->"b:6.0.3"],

Cell["\<\
   Alice measures 1,2,3 and gets values P1,P2,P3. 
Here we produce them at random.\
\>", "Text",
  FontFamily->"Helvetica",
  CellTags->"b:6.0.3"],

Cell[BoxData[{
    \(\(P1 = Random[Integer, {0, 1}];\)\), "\[IndentingNewLine]", 
    \(\(P2 = Random[Integer, {0, 1}];\)\), "\[IndentingNewLine]", 
    \(\(P3 = Random[Integer, {0, 1}];\)\), "\[IndentingNewLine]", 
    \(P1\), "\[IndentingNewLine]", 
    \(P2\), "\[IndentingNewLine]", 
    \(P3\)}], "Input",
  CellTags->"b:6.0.3"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  Cell[BoxData[
      FormBox[Cell[TextData[Cell[BoxData[
            FormBox[Cell[""], TraditionalForm]]]]], TraditionalForm]]],
  "Step 5: Alice sends the result of her measurement to Bob "
}], "Subsection",
  CellFrame->True,
  FontFamily->"Times",
  CellTags->{"b:6.0.4", "c:30"}],

Cell["\<\
 Alice classically transmits P1,P2 and P3 to Bob, which has then the \
following 
density matrix for qubits 4 and 5:\
\>", "Text",
  FontFamily->"Helvetica",
  CellTags->"b:6.0.4"],

Cell[BoxData[{
    \(\[Rho]\_45 = \ RhoBob[P1, P2, P3]\), "\[IndentingNewLine]", 
    \(Simplify[Tr[\[Rho]\_45]]\)}], "Input",
  CellTags->"b:6.0.4"],

Cell["\<\
 Bob, with the values of the measurements made by Alice, performs a set of 
operations on its two qubit system depending on P1,P2,P3\
\>", "Text",
  FontFamily->"Helvetica",
  CellTags->"b:6.0.4"],

Cell[BoxData[
    \(\(\(S\_\(\(i_\)\(\ \)\(,\)\(j_\)\(\ \ \)\)\)\(\ \ \)\(:=\)\(\ \ \)\((\ \
\[Sigma]\_i\ \[CircleTimes]\ \[Sigma]\_j\ )\)\(\ \)\)\)], "Input",
  CellTags->"b:6.0.4"],

Cell[BoxData[
    RowBox[{"BobOp", "=", 
      RowBox[{"Which", "[", " ", 
        RowBox[{\({P1, P2, P3} \[Equal] {0, 0, 0}\), ",", \(S\_\(0\ , 0\)\), 
          StyleBox[",",
            FontSize->12], 
          StyleBox["\[IndentingNewLine]",
            FontSize->12], 
          StyleBox["                      ",
            FontSize->12], 
          RowBox[{
            RowBox[{
              StyleBox["{",
                FontSize->12], \(P1, P2, P3\), "}"}], 
            "\[Equal]", \({1, 1, 0}\)}], ",", " ", 
          StyleBox[\(S\_\(0, 0\)\),
            FontSize->12], 
          StyleBox[",",
            FontSize->12], 
          StyleBox["\[IndentingNewLine]",
            FontSize->12], 
          StyleBox["                      ",
            FontSize->12], 
          StyleBox[\({P1, P2, P3} == {0, 0, 1}\),
            FontSize->12], ",", 
          StyleBox[\(S\_\(1, 1\)\),
            FontSize->12], 
          StyleBox[",",
            FontSize->12], 
          StyleBox["\[IndentingNewLine]",
            FontSize->12], 
          StyleBox["                      ",
            FontSize->12], 
          RowBox[{
            RowBox[{
              StyleBox["{",
                FontSize->12], \(P1, P2, P3\), "}"}], 
            "\[Equal]", \({1, 1, 1}\)}], ",", 
          StyleBox[\(S\_\(1, 1\)\),
            FontSize->12], 
          StyleBox[",",
            FontSize->12], 
          StyleBox["\[IndentingNewLine]",
            FontSize->12], 
          StyleBox[
            RowBox[{
              StyleBox["                     ",
                FontSize->12], " "}]], \({P1, P2, P3} \[Equal] {0, 1, 1}\), 
          ",", \(S\_\(1\ , 2\)\), 
          StyleBox[",",
            FontSize->12], 
          StyleBox["\[IndentingNewLine]",
            FontSize->12], 
          StyleBox["                      ",
            FontSize->12], 
          RowBox[{
            RowBox[{
              StyleBox["{",
                FontSize->12], \(P1, P2, P3\), "}"}], 
            "\[Equal]", \({1, 0, 1}\)}], ",", " ", 
          StyleBox[\(S\_\(1, 2\)\),
            FontSize->12], 
          StyleBox[",",
            FontSize->12], 
          StyleBox["\[IndentingNewLine]",
            FontSize->12], 
          StyleBox["                      ",
            FontSize->12], 
          StyleBox[\({P1, P2, P3} == {1, 0, 0}\),
            FontSize->12], ",", 
          StyleBox[\(S\_\(3, 0\)\),
            FontSize->12], 
          StyleBox[",",
            FontSize->12], 
          StyleBox["\[IndentingNewLine]",
            FontSize->12], 
          StyleBox["                      ",
            FontSize->12], 
          RowBox[{
            RowBox[{
              StyleBox["{",
                FontSize->12], \(P1, P2, P3\), "}"}], 
            "\[Equal]", \({0, 1, 0}\)}], ",", 
          StyleBox[\(S\_\(3, 0\)\),
            FontSize->12]}], 
        StyleBox["]",
          FontSize->12]}]}]], "Input",
  CellTags->"b:6.0.4"],

Cell[BoxData[
    \(\[Rho]\_BobF = Chop[BobOp . \[Rho]\_45 . Adj[BobOp]]\)], "Input",
  CellTags->"b:6.0.4"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  Cell[BoxData[
      FormBox[Cell[TextData[Cell[BoxData[
            FormBox[Cell[""], TraditionalForm]]]]], TraditionalForm]]],
  "Step 6: Final comparison, we compare the EPR state and the state in Bob \
hands:"
}], "Subsection",
  CellFrame->True,
  FontFamily->"Times",
  CellTags->{"b:6.0.5", "c:31"}],

Cell[BoxData[
    \(Chop[\[Rho]\_EPR\  - \[Rho]\_BobF]\)], "Input",
  CellTags->"b:6.0.5"],

Cell[BoxData[
    \(Quit\)], "Input",
  CellTags->"b:6.0.5"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
EPR teleportation Algorithm: (Gorbachev and Trubilko quant-ph/9906110)\
\>", "Section",
  FontFamily->"Times",
  CellTags->"c:32"],

Cell[TextData[StyleBox["Uses the Qdensity package:",
  FontFamily->"Helvetica"]], "Text",
  FontFamily->"Courier New"],

Cell[BoxData[
    \(Needs["\<QDENSITY`Qdensity`\>"]\)], "Input",
  FontFamily->"Courier New"],

Cell[BoxData[
    \(\(?QDENSITY`Qdensity`*\)\)], "Input",
  FontFamily->"Courier New"],

Cell[TextData[StyleBox["We set the number of Qubits to 5", "DisplayText",
  FontWeight->"Plain",
  Background->None,
  FontVariations->{"CompatibilityType"->0}]], "Text",
  FontFamily->"Helvetica"],

Cell[BoxData[
    \(\(nqx = 5;\)\)], "Input"],

Cell[CellGroupData[{

Cell["\<\
Step 1: Alice  prepares the EPR state to be teleported and the GHZ state is \
given\
\>", "Subsection",
  CellFrame->True,
  FontFamily->"Times",
  CellTags->{"b:7.0.0", "c:33"}],

Cell["\<\
A=Random[Real,{0,1}];
B=Sqrt[1-A^2];\
\>", "Input",
  CellTags->"b:7.0.0"],

Cell["\<\
This example permits both an algebraic computation or a numerical one. This \
is controlled
by the value of Icalc: 1 [Algebraic] / Else [Numerical]\
\>", "Text",
  FontFamily->"Helvetica",
  CellTags->"b:7.0.0"],

Cell[BoxData[
    \(\(Icalc = 1;\)\)], "Input",
  CellTags->"b:7.0.0"],

Cell[BoxData[{
    \(\(If[Icalc == 1, Clear[A, B], \ ];\)\ \), "\[IndentingNewLine]", 
    \({A, \ B}\)}], "Input",
  FontFamily->"Courier New",
  CellTags->"b:7.0.0"],

Cell["\<\
Alice builds the EPR density matrix to be teleported. Qubits 1 and 2
And we also need the GHZ state made of qubits 3, 4 and 5\
\>", "Text",
  FontFamily->"Helvetica",
  CellTags->"b:7.0.0"],

Cell[BoxData[{
    \(\[Rho]\_1 = {{A^2, A\ B}, {A\ B, B^2}}\), "\[IndentingNewLine]", 
    \(\(OpEPR = CNOT[2, 1, 2];\)\), "\[IndentingNewLine]", 
    \(\(\[Rho]\_12 = \ \[Rho]\_1\[CircleTimes]\[ScriptCapitalP]\_1;\)\), "\
\[IndentingNewLine]", 
    \(EPR = OpEPR . \[Rho]\_12 . Adj[OpEPR]\)}], "Input",
  CellTags->"b:7.0.0"],

Cell[BoxData[{
    \(\(\[Rho]\_345 = \ \
\((\[ScriptCapitalP]\_0\[CircleTimes]\[ScriptCapitalP]\_0)\)\[CircleTimes]\
\[ScriptCapitalP]\_0;\)\), "\[IndentingNewLine]", 
    \(\(OpGHZ = 
        CNOT[3, 1, 3] . CNOT[3, 1, 2] . 
          had[3, 1];\)\), "\[IndentingNewLine]", 
    \(GHZ = OpGHZ . \[Rho]\_345 . Adj[OpGHZ]\)}], "Input",
  CellTags->"b:7.0.0"],

Cell["Then the density matrix for the \"initial\" system is:", "Text",
  FontFamily->"Helvetica",
  CellTags->"b:7.0.0"],

Cell[BoxData[
    \(\(\[Rho]\_0 = EPR\[CircleTimes]GHZ;\)\)], "Input",
  CellTags->"b:7.0.0"]
}, Closed]],

Cell[CellGroupData[{

Cell["Step 2: The operator corresponding to the network is built", \
"Subsection",
  CellFrame->True,
  FontFamily->"Times",
  CellTags->{"b:7.0.1", "c:34"}],

Cell["\<\
The bulk of the network which is depicted in Fig. 3 of the abovementioned \
reference can be constructed easily: \
\>", "Text",
  FontFamily->"Helvetica",
  CellTags->"b:7.0.1"],

Cell[BoxData[
    \(\(\(\ \)\(Bop[qi_, qj_, qk_, ql_, qm_] := 
        CNOT[5, qm, qi] . had[5, qm] . CNOT[5, qi, ql] . CNOT[5, qm, ql] . 
          CNOT[5, qk, qm] . had[5, ql] . CNOT[5, qj, ql] . had[5, ql] . 
          CNOT[5, qk, ql] . had[5, qj] . CNOT[5, qj, qk] . 
          had[5, qj];\)\)\)], "Input",
  FontFamily->"Courier New",
  CellTags->"b:7.0.1"]
}, Closed]],

Cell[CellGroupData[{

Cell["Step 3: The final state density matrix is obtained", "Subsection",
  CellFrame->True,
  FontFamily->"Times",
  CellTags->{"b:7.0.2", "c:35"}],

Cell["\<\
The application of the network to the initial density matrix is readily \
evaluated:\
\>", "Text",
  FontFamily->"Helvetica",
  CellTags->"b:7.0.2"],

Cell[BoxData[
    StyleBox[\(\(\ \)\(\[Rho]\_E\ \  := \ 
          Bop[1, 2, 3, 4, 5] . \[Rho]\_0 . Adj[Bop[1, 2, 3, 4, 5]];\)\),
      FontSize->12]], "Input",
  FontFamily->"Courier New",
  FontSize->12,
  CellTags->"b:7.0.2"],

Cell["\<\
We can check that the density matrix is indeed so by computing its 
trace and the trace of it squared:\
\>", "Text",
  FontFamily->"Helvetica",
  CellTags->"b:7.0.2"],

Cell[BoxData[{
    \(Simplify[Chop[Tr[\[Rho]\_E]]]\), "\n", 
    \(Simplify[Chop[Tr[\[Rho]\_E . \[Rho]\_E]]]\)}], "Input",
  CellTags->"b:7.0.2"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  Cell[BoxData[
      FormBox[Cell[TextData[Cell[BoxData[
            FormBox[Cell[""], TraditionalForm]]]]], TraditionalForm]]],
  "Step 4: Bob state is computed and compared to the initial EPR"
}], "Subsection",
  CellFrame->True,
  FontFamily->"Times",
  CellTags->{"b:7.0.3", "c:36"}],

Cell["\<\
Bob's 2 qubit state, made of qubits 4 and 5, is obtained by taking the 
partial trace of the full final state:\
\>", "Text",
  FontFamily->"Helvetica",
  CellTags->"b:7.0.3"],

Cell[BoxData[
    \(\[Rho]\_Bob = PTr[{1, 2, 3}, \[Rho]\_E]\)], "Input",
  CellTags->"b:7.0.3"],

Cell["The 2qubit state density matrix is characterized by :", "Text",
  FontFamily->"Helvetica",
  CellTags->"b:7.0.3"],

Cell[BoxData[{
    RowBox[{
      RowBox[{\(T[i_, j_]\), ":=", 
        RowBox[{"Tr", "[", 
          RowBox[{\((\[Sigma]\_i\[CircleTimes]\[Sigma]\_j)\), ".", 
            StyleBox[\(\[Rho]\_Bob\),
              FontSize->12]}], 
          StyleBox[" ",
            FontSize->12], 
          StyleBox["]",
            FontSize->12]}]}], 
      StyleBox[";",
        FontSize->12]}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        StyleBox["PA",
          FontSize->12], 
        StyleBox["=",
          FontSize->12], 
        RowBox[{
          StyleBox["{",
            FontSize->12], 
          RowBox[{
            StyleBox[\(T[1, 0]\),
              FontSize->12], 
            StyleBox[",",
              FontSize->12], \(T[2, 0]\), ",", \(T[3, 0]\)}], "}"}]}], 
      ";"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        StyleBox["PB",
          FontSize->12], 
        StyleBox["=",
          FontSize->12], 
        RowBox[{
          StyleBox["{",
            FontSize->12], 
          RowBox[{
            StyleBox[\(T[0, 1]\),
              FontSize->12], 
            StyleBox[",",
              FontSize->12], \(T[0, 2]\), ",", \(T[0, 3]\)}], "}"}]}], 
      ";"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        StyleBox[
          RowBox[{"T", 
            StyleBox["AB",
              FontSize->12]}]], 
        StyleBox["=",
          FontSize->12], 
        RowBox[{
          StyleBox["{",
            FontSize->12], 
          RowBox[{
            StyleBox["Table",
              FontSize->12], 
            StyleBox["[",
              FontSize->12], 
            RowBox[{
              StyleBox[\(T[i, j]\),
                FontSize->12], 
              StyleBox[",",
                FontSize->12], \({i, 1, 3}\), ",", \({j, 1, 3}\)}], "]"}], 
          "}"}]}], ";"}], "\[IndentingNewLine]", "PA", "\[IndentingNewLine]", 
  "PB", "\[IndentingNewLine]", "TAB"}], "Input",
  CellTags->"b:7.0.3"],

Cell["...which we can compare to the original EPR state:", "Text",
  FontFamily->"Helvetica",
  CellTags->"b:7.0.3"],

Cell[BoxData[{
    RowBox[{
      RowBox[{\(TT[i_, j_]\), ":=", 
        RowBox[{
        "Tr", "[", \(\((\[Sigma]\_i\[CircleTimes]\[Sigma]\_j)\) . EPR\), 
          StyleBox[" ",
            FontSize->12], 
          StyleBox["]",
            FontSize->12]}]}], 
      StyleBox[";",
        FontSize->12]}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        StyleBox[
          RowBox[{"T", 
            StyleBox["PA",
              FontSize->12]}]], 
        StyleBox["=",
          FontSize->12], 
        RowBox[{
          StyleBox["{",
            FontSize->12], 
          RowBox[{
            StyleBox[\(TT[1, 0]\),
              FontSize->12], 
            StyleBox[",",
              FontSize->12], \(TT[2, 0]\), ",", \(TT[3, 0]\)}], "}"}]}], 
      ";"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        StyleBox[
          RowBox[{"T", 
            StyleBox["PB",
              FontSize->12]}]], 
        StyleBox["=",
          FontSize->12], 
        RowBox[{
          StyleBox["{",
            FontSize->12], 
          RowBox[{
            StyleBox[\(TT[0, 1]\),
              FontSize->12], 
            StyleBox[",",
              FontSize->12], \(TT[0, 2]\), ",", \(TT[0, 3]\)}], "}"}]}], 
      ";"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        StyleBox[
          RowBox[{"TT", 
            StyleBox["AB",
              FontSize->12]}]], 
        StyleBox["=",
          FontSize->12], 
        RowBox[{
          StyleBox["{",
            FontSize->12], 
          RowBox[{
            StyleBox["Table",
              FontSize->12], 
            StyleBox["[",
              FontSize->12], 
            RowBox[{
              StyleBox[\(TT[i, j]\),
                FontSize->12], 
              StyleBox[",",
                FontSize->12], \({i, 1, 3}\), ",", \({j, 1, 3}\)}], "]"}], 
          "}"}]}], ";"}], "\[IndentingNewLine]", "TPA", "\[IndentingNewLine]",
   "TPB", "\[IndentingNewLine]", "TTAB"}], "Input",
  CellTags->"b:7.0.3"]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Step 5: For completeness all one qubit partial traces are shown\
\>", "Subsection",
  CellFrame->True,
  FontFamily->"Times",
  CellTags->{"b:7.0.4", "c:37"}],

Cell[BoxData[{
    StyleBox[\(\[Rho]\_\(1  F\) = PTr[{2, 3, 4, 5}, \[Rho]\_E]\),
      FontSize->12], "\[IndentingNewLine]", 
    StyleBox[\(\[Rho]\_\(2  F\) = PTr[{1, 3, 4, 5}, \[Rho]\_E]\),
      FontSize->12], "\[IndentingNewLine]", 
    StyleBox[\(\[Rho]\_\(3  F\) = PTr[{1, 2, 4, 5}, \[Rho]\_E]\),
      FontSize->12], "\[IndentingNewLine]", 
    StyleBox[\(\[Rho]\_\(4  F\) = PTr[{1, 2, 3, 5}, \[Rho]\_E]\),
      FontSize->12], "\[IndentingNewLine]", 
    StyleBox[\(\[Rho]\_\(5  F\) = PTr[{1, 2, 3, 4}, \[Rho]\_E]\),
      FontSize->12]}], "Input",
  CellTags->"b:7.0.4"],

Cell[BoxData[
    \(Quit\)], "Input",
  CellTags->"b:7.0.4"]
}, Closed]]
}, Closed]]
},
FrontEndVersion->"5.2 for X",
ScreenRectangle->{{0, 1280}, {0, 800}},
ShowPageBreaks->False,
WindowToolbars->{},
WindowSize->{789, 746},
WindowMargins->{{35, Automatic}, {Automatic, 0}},
PrintingStartingPageNumber->15,
PrintingPageRange->{Automatic, Automatic},
PrintingOptions->{"PaperSize"->{612, 792},
"PaperOrientation"->"Portrait",
"PostScriptOutputFile":>FrontEnd`FileName[{"home", "bruno", "PITT", "QC"}, \
"Test1.1.nb.ps", CharacterEncoding -> "iso8859-1"],
"Magnification"->1},
ShowSelection->True,
TaggingRules:>{"PaginationCache" -> {{2005, 8, 9, 3, 36, \
19.580426`8.04439712024133}, {15, 15, 15, 15, 15, 15, 15, 15, 15, 15, 15, 15, \
15, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 17, 17, 17, 17, \
17, 17, 17, 17, 17, 17, 17, 17, 17, 17, 18, 18, 18, 18, 18, 18, 18, 18, 18, \
18, 18, 18, 18, 18, 18, 18, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, \
20, 20, 20, 20, 20, 20, 20, 20, 20, 20, 20, 20, 20, 20, 20, 21, 21, 22, 22, \
22, 22, 22, 22, 22, 22, 22, 22, 22, 22, 22, 23, 23, 23, 23, 23, 23, 23, 23, \
23, 23, 23, 23, 23, 24, 24, 24, 24, 24, 24, 24, 24, 24, 24, 24, 25, 25, 25, \
25, 25, 25, 25, 25, 25, 25, 25, 25, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, \
27, 27, 27, 27, 27, 27, 27, 27, 27, 27, 27, 27, 27, 27, 28, 28, 28, 28, 28, \
28, 28, 28, 28, 28, 28, 28, 28, 29, 29, 29, 29, 29, 29, 29, 29, 29, 29, 29, \
29, 30, 30, 30, 30, 30, 30, 30, 30, 30, 30, 30, 30, 31, 31, 31, 31, 31, 31, \
31, 31, 31, 31, 31, 31, 31, 31, 31, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, \
32, 32, 32, 32, 32, 32, 33, 33, 33, 33, 33, 33, 33, 33, 33, 33, 33, 34, 34, \
34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 35, 35, 35, 35, 35, 35, \
35, 35, 35, 35, 35, 35, 35, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, \
36, 37, 37, 37, 37, 37, 37, 37, 37, 37, 37, 37, 37, 38, 38, 38}, Automatic}},
CellLabelAutoDelete->True,
Magnification->1,
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions", "Title"],
  
  Cell["\<\
Modify the definitions below to change the default appearance of all cells in \
a given style.  Make modifications to any definition using commands in the \
Format menu.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Section"],
  
  Cell[StyleData[All, "Working"],
    PageWidth->WindowWidth,
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Presentation"],
    PageWidth->WindowWidth,
    ScriptMinSize->12,
    FontSize->16],
  
  Cell[StyleData[All, "SlideShow"],
    PageWidth->WindowWidth,
    ScrollingOptions->{"PagewiseDisplay"->True,
    "VerticalScrollRange"->Fit},
    ShowCellBracket->False,
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Condensed"],
    PageWidth->WindowWidth,
    CellBracketOptions->{"Margins"->{1, 1},
    "Widths"->{0, 5}},
    ScriptMinSize->8,
    FontSize->11],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    ScriptMinSize->7,
    FontSize->10,
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Section"],
  
  Cell["\<\
The options defined for the style below will be used at the Notebook level.\
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"]}, {Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    PageHeaderLines->{True, True},
    PrintingOptions->{"FirstPageHeader"->False,
    "FacingPages"->True},
    CellFrameLabelMargins->6,
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headings", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Title"],
    ShowCellBracket->False,
    CellMargins->{{0, 0}, {0, 0}},
    PageBreakBelow->False,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica", "gridMathematica"->FormBox[ 
            RowBox[ {"grid", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm], 
        "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm], Inherited},
    
    LineSpacing->{1, 11},
    CounterIncrements->"Title",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subtitle", 0}, {"Subsubtitle", 0}},
    FontSize->34,
    FontColor->GrayLevel[1],
    Background->RGBColor[0.571389, 0.19675, 0.570504]],
  
  Cell[StyleData["Title", "Presentation"],
    CellMargins->{{0, 0}, {0, 0}},
    CellFrameMargins->{{12, 10}, {24, 24}},
    LineSpacing->{1, 0},
    FontSize->46],
  
  Cell[StyleData["Title", "Condensed"],
    CellMargins->{{0, 0}, {0, 0}},
    FontSize->20],
  
  Cell[StyleData["Title", "Printout"],
    CellMargins->{{0, 0}, {0, 0}},
    FontSize->24,
    FontTracking->"Plain",
    Background->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subtitle"],
    ShowCellBracket->False,
    CellMargins->{{0, 0}, {0, 0}},
    PageBreakBelow->False,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica", "gridMathematica"->FormBox[ 
            RowBox[ {"grid", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm], 
        "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm], Inherited},
    
    LineSpacing->{1, 3},
    ParagraphIndent->-96,
    CounterIncrements->"Subtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->18,
    FontColor->GrayLevel[1],
    Background->RGBColor[0.2, 0.700008, 0.700008]],
  
  Cell[StyleData["Subtitle", "Presentation"],
    CellMargins->{{0, 0}, {4, 0}},
    CellFrameMargins->{{12, 10}, {12, 8}},
    LineSpacing->{1, 6},
    ParagraphIndent->-157,
    FontSize->28],
  
  Cell[StyleData["Subtitle", "Condensed"],
    CellMargins->{{0, 0}, {0, 0}},
    ParagraphIndent->-78,
    FontSize->14],
  
  Cell[StyleData["Subtitle", "Printout"],
    CellMargins->{{0, 0}, {0, 0}},
    ParagraphIndent->-85,
    FontSize->16,
    Background->GrayLevel[0.6]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubtitle"],
    ShowCellBracket->False,
    CellMargins->{{10, 4}, {30, 10}},
    PageBreakBelow->False,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica", "gridMathematica"->FormBox[ 
            RowBox[ {"grid", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm], 
        "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm], Inherited},
    
    CounterIncrements->"Subsubtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Helvetica",
    FontSize->14,
    FontSlant->"Italic"],
  
  Cell[StyleData["Subsubtitle", "Presentation"],
    CellMargins->{{15, 10}, {50, 10}},
    LineSpacing->{1, 0},
    FontSize->22],
  
  Cell[StyleData["Subsubtitle", "Condensed"],
    CellMargins->{{8, 10}, {12, 8}},
    FontSize->12],
  
  Cell[StyleData["Subsubtitle", "Printout"],
    CellMargins->{{9, 10}, {50, 10}},
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellFrame->{{6, 0}, {0, 1}},
    CellDingbat->None,
    CellMargins->{{12, Inherited}, {4, 24}},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    CellFrameMargins->6,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica", "gridMathematica"->FormBox[ 
            RowBox[ {"grid", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm], 
        "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm], Inherited},
    
    LineSpacing->{1, 7},
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold",
    FontColor->RGBColor[0.571389, 0.19675, 0.570504]],
  
  Cell[StyleData["Section", "Presentation"],
    CellFrame->{{8, 0}, {0, 2}},
    CellMargins->{{15, 10}, {14, 32}},
    CellFrameMargins->{{8, 10}, {10, 14}},
    LineSpacing->{1, 2},
    FontSize->24,
    FontTracking->"Condensed"],
  
  Cell[StyleData["Section", "Condensed"],
    CellMargins->{{8, Inherited}, {2, 12}},
    FontSize->12],
  
  Cell[StyleData["Section", "Printout"],
    CellMargins->{{9, 0}, {2, 50}},
    FontSize->14,
    FontTracking->"Plain",
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellMargins->{{12, Inherited}, {8, 20}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica", "gridMathematica"->FormBox[ 
            RowBox[ {"grid", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm], 
        "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm], Inherited},
    
    LineSpacing->{1, 7},
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->13,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "Presentation"],
    CellMargins->{{15, 10}, {12, 32}},
    LineSpacing->{1, 0},
    FontSize->22],
  
  Cell[StyleData["Subsection", "Condensed"],
    CellMargins->{{8, Inherited}, {2, 12}},
    FontSize->12],
  
  Cell[StyleData["Subsection", "Printout"],
    CellMargins->{{9, 0}, {4, 40}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{25, Inherited}, {8, 12}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica", "gridMathematica"->FormBox[ 
            RowBox[ {"grid", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm], 
        "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm], Inherited},
    
    LineSpacing->{1, 9},
    CounterIncrements->"Subsubsection",
    FontFamily->"Times",
    FontSize->13,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Presentation"],
    CellMargins->{{34, 10}, {18, 28}},
    LineSpacing->{1, 0},
    FontSize->18],
  
  Cell[StyleData["Subsubsection", "Condensed"],
    CellMargins->{{22, Inherited}, {2, 12}},
    FontSize->10],
  
  Cell[StyleData["Subsubsection", "Printout"],
    CellMargins->{{21, 0}, {4, 20}},
    FontSize->11]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Body Text", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{12, 10}, {5, 5}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica", "gridMathematica"->FormBox[ 
            RowBox[ {"grid", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm], 
        "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm], Inherited},
    
    LineSpacing->{1, 3},
    ParagraphSpacing->{0, 12},
    CounterIncrements->"Text",
    FontFamily->"Times"],
  
  Cell[StyleData["Text", "Presentation"],
    CellMargins->{{15, 10}, {8, 10}},
    LineSpacing->{1, 5},
    ParagraphSpacing->{0, 12},
    FontSize->18],
  
  Cell[StyleData["Text", "Condensed"],
    CellMargins->{{8, 10}, {4, 4}},
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, 4}],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{9, 0}, {4, 4}},
    Hyphenation->True,
    ParagraphSpacing->{0, 6}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SmallText"],
    CellMargins->{{12, 10}, {5, 5}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica", "gridMathematica"->FormBox[ 
            RowBox[ {"grid", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm], 
        "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm], Inherited},
    
    LineSpacing->{1, 3},
    ParagraphSpacing->{0, 6},
    CounterIncrements->"SmallText",
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["SmallText", "Presentation"],
    CellMargins->{{15, 10}, {8, 10}},
    LineSpacing->{1, 5},
    FontSize->14],
  
  Cell[StyleData["SmallText", "Condensed"],
    CellMargins->{{8, 10}, {2, 2}},
    LineSpacing->{1, 2},
    FontSize->9],
  
  Cell[StyleData["SmallText", "Printout"],
    CellMargins->{{9, 0}, {4, 4}},
    Hyphenation->True,
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Inline Formatting", "Section"],
  
  Cell["\<\
These styles are for modifying individual words or letters in a cell \
exclusive of the cell tag.\
\>", "Text"],
  
  Cell[StyleData["RM"],
    StyleMenuListing->None,
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["BF"],
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[StyleData["IT"],
    StyleMenuListing->None,
    FontSlant->"Italic"],
  
  Cell[StyleData["TR"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["TI"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["TB"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["TBI"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[StyleData["MR"],
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["MO"],
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["MB"],
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["MBO"],
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[StyleData["SR"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["SO"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["SB"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["SBO"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SO10"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["SO10", "Printout"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->7,
    FontWeight->"Plain",
    FontSlant->"Italic"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Inert"],
    StyleMenuListing->None,
    Background->RGBColor[0.870588, 0.905882, 0.972549]],
  
  Cell[StyleData["Inert", "Printout"],
    StyleMenuListing->None,
    Background->GrayLevel[1]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Input/Output", "Section"],
  
  Cell["\<\
The cells in this section define styles used for input and output to the \
kernel.  Be careful when modifying, renaming, or removing these styles, \
because the front end associates special meanings with these style names.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    CellFrame->{{3, 0}, {0, 0}},
    CellMargins->{{52, 10}, {8, 8}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{5, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    LinebreakAdjustments->{0.85, 2, 10, 0, 1},
    CounterIncrements->"Input",
    FontWeight->"Bold",
    Background->RGBColor[1, 0.700008, 0.4]],
  
  Cell[StyleData["Input", "Presentation"],
    CellFrame->{{5, 0}, {0, 0}},
    CellMargins->{{74, 10}, {8, 10}},
    CellFrameMargins->{{10, 10}, {14, 14}},
    LineSpacing->{1, 0},
    FontSize->18],
  
  Cell[StyleData["Input", "Condensed"],
    CellMargins->{{40, Inherited}, {1, 4}}],
  
  Cell[StyleData["Input", "Printout"],
    CellMargins->{{44, 0}, {2, 6}},
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineInput"],
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    DefaultFormatType->DefaultInputFormatType,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    FontWeight->"Bold"],
  
  Cell[StyleData["InlineInput", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["InlineInput", "Condensed"]],
  
  Cell[StyleData["InlineInput", "Printout"],
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    CellFrame->{{3, 0}, {0, 0}},
    CellMargins->{{52, 10}, {8, 8}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelMargins->{{3, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    FormatType->InputForm,
    CounterIncrements->"Output",
    Background->RGBColor[1, 0.900008, 0.900008]],
  
  Cell[StyleData["Output", "Presentation"],
    CellFrame->{{5, 0}, {0, 0}},
    CellMargins->{{74, 10}, {12, 5}},
    CellFrameMargins->{{10, 10}, {14, 14}},
    LineSpacing->{1, 0},
    FontSize->18],
  
  Cell[StyleData["Output", "Condensed"],
    CellMargins->{{40, Inherited}, {4, 1}}],
  
  Cell[StyleData["Output", "Printout"],
    CellMargins->{{44, 0}, {6, 2}},
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    CellMargins->{{62, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    FormatType->InputForm,
    CounterIncrements->"Message",
    StyleMenuListing->None,
    FontColor->RGBColor[1, 0, 0]],
  
  Cell[StyleData["Message", "Presentation"],
    CellMargins->{{86, 20}, {10, 10}},
    LineSpacing->{1, 0},
    FontSize->18],
  
  Cell[StyleData["Message", "Condensed"],
    CellMargins->{{50, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Message", "Printout"],
    CellMargins->{{54, Inherited}, {Inherited, Inherited}},
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    CellMargins->{{62, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    FormatType->InputForm,
    CounterIncrements->"Print",
    StyleMenuListing->None],
  
  Cell[StyleData["Print", "Presentation"],
    CellMargins->{{86, 20}, {4, 4}},
    LineSpacing->{1, 0},
    FontSize->18],
  
  Cell[StyleData["Print", "Condensed"],
    CellMargins->{{50, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Print", "Printout"],
    CellMargins->{{54, Inherited}, {Inherited, Inherited}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    CellMargins->{{62, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Graphics",
    StyleMenuListing->None],
  
  Cell[StyleData["Graphics", "Presentation"],
    CellMargins->{{86, 20}, {8, 8}},
    FontSize->18],
  
  Cell[StyleData["Graphics", "Condensed"],
    CellMargins->{{52, Inherited}, {Inherited, Inherited}},
    ImageSize->{175, 175}],
  
  Cell[StyleData["Graphics", "Printout"],
    CellMargins->{{54, Inherited}, {Inherited, Inherited}},
    ImageSize->{250, 250}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->11,
    FontWeight->"Bold",
    FontColor->RGBColor[0.571389, 0.19675, 0.570504]],
  
  Cell[StyleData["CellLabel", "Presentation"],
    FontSize->12],
  
  Cell[StyleData["CellLabel", "Condensed"],
    FontSize->8],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontSize->8,
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Unique Styles", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Author"],
    ShowCellBracket->False,
    CellMargins->{{10, 4}, {2, 10}},
    LineSpacing->{1, 5},
    FontSize->16,
    FontSlant->"Italic"],
  
  Cell[StyleData["Author", "Presentation"],
    CellMargins->{{15, 10}, {4, 16}},
    LineSpacing->{1, 5},
    ParagraphSpacing->{0, 12},
    FontSize->24],
  
  Cell[StyleData["Author", "Condensed"],
    CellMargins->{{8, 10}, {1, 4}},
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, 4},
    FontSize->12],
  
  Cell[StyleData["Author", "Printout"],
    CellMargins->{{9, 0}, {4, 12}},
    ParagraphSpacing->{0, 6},
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Copyright"],
    ShowCellBracket->False,
    CellMargins->{{10, 10}, {40, 2}},
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["Copyright", "Presentation"],
    CellMargins->{{15, 10}, {50, 4}},
    LineSpacing->{1, 5},
    FontSize->14],
  
  Cell[StyleData["Copyright", "Condensed"],
    CellMargins->{{8, 10}, {12, 1}},
    LineSpacing->{1, 2},
    FontSize->9],
  
  Cell[StyleData["Copyright", "Printout"],
    CellMargins->{{9, 0}, {72, 4}},
    FontSize->7]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Example"],
    CellMargins->{{12, 10}, {5, 12}},
    LineSpacing->{1, 3},
    ParagraphSpacing->{0, 12},
    CounterIncrements->"Example",
    FontFamily->"Times",
    FontWeight->"Bold"],
  
  Cell[StyleData["Example", "Presentation"],
    CellMargins->{{18, 10}, {8, 20}},
    LineSpacing->{1, 5},
    ParagraphSpacing->{0, 12},
    FontSize->18],
  
  Cell[StyleData["Example", "Condensed"],
    CellMargins->{{8, 10}, {4, 8}},
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, 4}],
  
  Cell[StyleData["Example", "Printout"],
    CellMargins->{{9, 0}, {4, 10}},
    ParagraphSpacing->{0, 6}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Definition"],
    CellFrame->{{3, 0}, {0, 0}},
    CellMargins->{{52, 10}, {8, 8}},
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    ShowStringCharacters->True,
    CounterIncrements->"Definition",
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontColor->GrayLevel[1],
    Background->RGBColor[0.2, 0.700008, 0.700008]],
  
  Cell[StyleData["Definition", "Presentation"],
    CellFrame->{{5, 0}, {0, 0}},
    CellMargins->{{74, 10}, {8, 12}},
    CellFrameMargins->{{10, 10}, {14, 14}},
    LineSpacing->{1, 0},
    FontSize->18],
  
  Cell[StyleData["Definition", "Condensed"],
    CellMargins->{{40, 10}, {1, 4}}],
  
  Cell[StyleData["Definition", "Printout"],
    CellMargins->{{44, 0}, {2, 6}},
    Hyphenation->True,
    Background->GrayLevel[0.6]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Theorem"],
    CellFrame->{{3, 0}, {0, 0}},
    CellMargins->{{52, 10}, {8, 8}},
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    ShowStringCharacters->True,
    CounterIncrements->"Theorem",
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontColor->GrayLevel[1],
    Background->RGBColor[0.571389, 0.19675, 0.570504]],
  
  Cell[StyleData["Theorem", "Presentation"],
    CellFrame->{{5, 0}, {0, 0}},
    CellMargins->{{74, 10}, {8, 12}},
    CellFrameMargins->{{10, 10}, {14, 14}},
    LineSpacing->{1, 0},
    FontSize->18],
  
  Cell[StyleData["Theorem", "Condensed"],
    CellMargins->{{40, 10}, {1, 4}}],
  
  Cell[StyleData["Theorem", "Printout"],
    CellMargins->{{44, 0}, {2, 6}},
    Hyphenation->True,
    Background->GrayLevel[0.4]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ExerciseMain"],
    CellFrame->{{6, 0}, {0, 1}},
    CellMargins->{{12, Inherited}, {4, 20}},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    CellFrameColor->RGBColor[0.571389, 0.19675, 0.570504],
    LineSpacing->{1, 7},
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold",
    FontColor->RGBColor[0.571389, 0.19675, 0.570504]],
  
  Cell[StyleData["ExerciseMain", "Presentation"],
    CellFrame->{{8, 0}, {0, 2}},
    CellMargins->{{18, 10}, {12, 32}},
    CellFrameMargins->{{10, 10}, {14, 14}},
    LineSpacing->{1, 2},
    FontSize->24,
    FontTracking->"Condensed"],
  
  Cell[StyleData["ExerciseMain", "Condensed"],
    CellMargins->{{8, Inherited}, {2, 12}},
    FontSize->12],
  
  Cell[StyleData["ExerciseMain", "Printout"],
    CellMargins->{{9, 0}, {2, 50}},
    CellFrameColor->GrayLevel[0.500008],
    FontSize->14,
    FontTracking->"Plain",
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Exercise"],
    CellDingbat->"\[FilledDownTriangle]",
    CellMargins->{{23, Inherited}, {4, 18}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    LineSpacing->{1, 7},
    CounterIncrements->"Subsubsection",
    FontFamily->"Times",
    FontSize->13,
    FontWeight->"Bold",
    FontColor->RGBColor[0.571389, 0.19675, 0.570504]],
  
  Cell[StyleData["Exercise", "Presentation"],
    CellMargins->{{28, 10}, {10, 34}},
    LineSpacing->{1, 0},
    FontSize->22],
  
  Cell[StyleData["Exercise", "Condensed"],
    CellMargins->{{17, Inherited}, {2, 12}},
    FontSize->10],
  
  Cell[StyleData["Exercise", "Printout"],
    CellFrame->{{0, 0}, {0.5, 0}},
    CellDingbat->None,
    CellMargins->{{9, 0}, {6, 20}},
    Hyphenation->True,
    FontSize->11,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ExerciseText"],
    CellMargins->{{62, 10}, {5, 5}},
    LineSpacing->{1, 3},
    ParagraphSpacing->{0, 8},
    CounterIncrements->"ExerciseText",
    FontFamily->"Times"],
  
  Cell[StyleData["ExerciseText", "Presentation"],
    CellMargins->{{100, 10}, {8, 8}},
    LineSpacing->{1, 5},
    ParagraphSpacing->{0, 12},
    FontSize->18],
  
  Cell[StyleData["ExerciseText", "Condensed"],
    CellMargins->{{52, 10}, {2, 2}},
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, 4}],
  
  Cell[StyleData["ExerciseText", "Printout"],
    CellMargins->{{54, 0}, {4, 4}},
    Hyphenation->True,
    ParagraphSpacing->{0, 6}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{62, 10}, {2, 10}},
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    ScriptLevel->0,
    SingleLetterItalics->True,
    UnderoverscriptBoxOptions->{LimitsPositioning->True}],
  
  Cell[StyleData["DisplayFormula", "Presentation"],
    CellMargins->{{100, 10}, {8, 16}},
    FontSize->18],
  
  Cell[StyleData["DisplayFormula", "Condensed"],
    CellMargins->{{52, 10}, {2, 10}},
    FontSize->10],
  
  Cell[StyleData["DisplayFormula", "Printout"],
    CellMargins->{{54, 10}, {2, 10}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ChemicalFormula"],
    CellMargins->{{62, 10}, {2, 10}},
    DefaultFormatType->DefaultInputFormatType,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    AutoSpacing->False,
    ScriptLevel->1,
    ScriptBaselineShifts->{0.6, Automatic},
    SingleLetterItalics->False,
    ZeroWidthTimes->True],
  
  Cell[StyleData["ChemicalFormula", "Presentation"],
    CellMargins->{{100, 10}, {8, 12}},
    FontSize->18],
  
  Cell[StyleData["ChemicalFormula", "Condensed"],
    CellMargins->{{52, 10}, {2, 10}},
    FontSize->10],
  
  Cell[StyleData["ChemicalFormula", "Printout"],
    CellMargins->{{54, 10}, {2, 10}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Program"],
    CellMargins->{{12, 10}, {Inherited, 6}},
    Hyphenation->False,
    LanguageCategory->"Formula",
    FontFamily->"Courier"],
  
  Cell[StyleData["Program", "Presentation"],
    CellMargins->{{20, 30}, {4, 4}},
    FontSize->18],
  
  Cell[StyleData["Program", "Condensed"],
    CellMargins->{{8, 10}, {Inherited, 4}},
    FontSize->9.5],
  
  Cell[StyleData["Program", "Printout"],
    CellMargins->{{9, 0}, {Inherited, 4}},
    FontSize->9.5]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Automatic Numbering", "Section"],
  
  Cell["\<\
The following styles are useful for numbered equations, figures, etc.  They \
automatically give the cell a FrameLabel containing a reference to a \
particular counter, and also increment that counter.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedEquation"],
    CellMargins->{{62, 10}, {Inherited, Inherited}},
    CellFrameLabels->{{None, Cell[ 
            TextData[ {"(", 
              CounterBox[ "NumberedEquation"], ")"}]]}, {None, None}},
    DefaultFormatType->DefaultInputFormatType,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    CounterIncrements->"NumberedEquation",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedEquation", "Presentation"],
    CellMargins->{{100, 10}, {6, 8}},
    FontSize->18],
  
  Cell[StyleData["NumberedEquation", "Condensed"],
    CellMargins->{{52, 10}, {Inherited, Inherited}}],
  
  Cell[StyleData["NumberedEquation", "Printout"],
    CellMargins->{{54, 0}, {Inherited, Inherited}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedFigure"],
    CellMargins->{{62, 145}, {Inherited, Inherited}},
    CellFrameLabels->{{None, None}, {Cell[ 
            TextData[ {"Figure ", 
              CounterBox[ "NumberedFigure"]}]], None}},
    CounterIncrements->"NumberedFigure",
    ImageMargins->{{43, Inherited}, {Inherited, 0}},
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedFigure", "Presentation"],
    CellMargins->{{100, 145}, {8, 6}},
    FontSize->18],
  
  Cell[StyleData["NumberedFigure", "Condensed"]],
  
  Cell[StyleData["NumberedFigure", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedTable"],
    CellMargins->{{62, 145}, {Inherited, Inherited}},
    CellFrameLabels->{{None, None}, {Cell[ 
            TextData[ {"Table ", 
              CounterBox[ "NumberedTable"]}]], None}},
    TextAlignment->Center,
    CounterIncrements->"NumberedTable",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedTable", "Presentation"],
    CellMargins->{{100, 145}, {8, 8}},
    FontSize->18],
  
  Cell[StyleData["NumberedTable", "Condensed"]],
  
  Cell[StyleData["NumberedTable", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headers and Footers", "Section"],
  
  Cell[StyleData["Header"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontSlant->"Italic"],
  
  Cell[StyleData["Footer"],
    CellMargins->{{0, 0}, {0, 4}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->6],
  
  Cell[StyleData["PageNumber"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontWeight->"Bold"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlink Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making hypertext ButtonBoxes.  The \
\"Hyperlink\" style is for links within the same Notebook, or between \
Notebooks.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0.269993, 0.308507, 0.6],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonFrame->"None",
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["Hyperlink", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["Hyperlink", "SlideShow"]],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell["\<\
The following styles are for linking automatically to the on-line help \
system.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0.269993, 0.308507, 0.6],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["MainBookLink", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["MainBookLink", "SlideShow"]],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0.269993, 0.308507, 0.6],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnsLink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["AddOnsLink", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["AddOnsLink", "SlideShow"]],
  
  Cell[StyleData["AddOnsLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0.269993, 0.308507, 0.6],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuide", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["RefGuideLink", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["RefGuideLink", "SlideShow"]],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLinkText"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0.269993, 0.308507, 0.6],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuide", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLinkText", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["RefGuideLinkText", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["RefGuideLinkText", "SlideShow"]],
  
  Cell[StyleData["RefGuideLinkText", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0.269993, 0.308507, 0.6],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["GettingStartedLink", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["GettingStartedLink", "SlideShow"]],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DemosLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0.269993, 0.308507, 0.6],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "Demos", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["DemosLink", "SlideShow"]],
  
  Cell[StyleData["DemosLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TourLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0.269993, 0.308507, 0.6],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "Tour", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["TourLink", "SlideShow"]],
  
  Cell[StyleData["TourLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0.269993, 0.308507, 0.6],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["OtherInformationLink", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["OtherInformationLink", "SlideShow"]],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MasterIndexLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0.269993, 0.308507, 0.6],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MasterIndex", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MasterIndexLink", "SlideShow"]],
  
  Cell[StyleData["MasterIndexLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Palette Styles", "Section"],
  
  Cell["\<\
The cells below define styles that define standard ButtonFunctions, for use \
in palette buttons.\
\>", "Text"],
  
  Cell[StyleData["Paste"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, After]}]&)}],
  
  Cell[StyleData["Evaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["EvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionMove[ 
          FrontEnd`InputNotebook[ ], All, Cell, 1], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Slide Show Styles", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SlideShowNavigationBar"],
    Editable->False,
    CellFrame->True,
    CellMargins->{{0, 0}, {3, 3}},
    CellElementSpacings->{"CellMinHeight"->0.8125},
    CellGroupingRules->{"SectionGrouping", 30},
    CellFrameMargins->False,
    CellFrameColor->GrayLevel[1],
    CellFrameLabelMargins->False,
    TextAlignment->Center,
    CounterIncrements->"SlideShowNavigationBar",
    StyleMenuListing->None,
    FontSize->10,
    Background->GrayLevel[0.8],
    Magnification->1,
    GridBoxOptions->{GridBaseline->Center,
    RowSpacings->0,
    ColumnSpacings->0,
    ColumnWidths->{3.5, 3.5, 3.5, 3.5, 13, 5, 4},
    RowAlignments->Baseline,
    ColumnAlignments->{
      Center, Center, Center, Center, Center, Center, Right, Center}}],
  
  Cell[StyleData["SlideShowNavigationBar", "Presentation"]],
  
  Cell[StyleData["SlideShowNavigationBar", "SlideShow"],
    Deletable->False,
    ShowCellBracket->False,
    CellMargins->{{-1, -1}, {-1, -1}},
    PageBreakAbove->True,
    CellFrameMargins->{{1, 1}, {0, 0}}],
  
  Cell[StyleData["SlideShowNavigationBar", "Printout"],
    CellMargins->{{18, 4}, {4, 4}},
    LineSpacing->{1, 3},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SlideShowSection"],
    CellFrame->{{0, 0}, {0, 0.5}},
    CellMargins->{{0, 0}, {10, 0}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CellFrameMargins->{{12, 4}, {6, 12}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica", "gridMathematica"->FormBox[ 
            RowBox[ {"grid", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm], 
        "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm], Inherited},
    
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->18,
    FontWeight->"Plain",
    FontColor->GrayLevel[1],
    Background->RGBColor[0.408011, 0.440726, 0.8]],
  
  Cell[StyleData["SlideShowSection", "Presentation"],
    CellFrameMargins->{{18, 10}, {10, 16}},
    FontSize->27],
  
  Cell[StyleData["SlideShowSection", "SlideShow"],
    ShowCellBracket->False,
    PageBreakAbove->True],
  
  Cell[StyleData["SlideShowSection", "Printout"],
    CellMargins->{{18, 30}, {0, 30}},
    CellFrameMargins->5,
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SlideHyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontSize->26,
    FontColor->GrayLevel[0.400015],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonMinHeight->0.85,
    ButtonMargins->0.5,
    ButtonNote->None}],
  
  Cell[StyleData["SlideHyperlink", "Presentation"],
    CellMargins->{{10, 10}, {8, 12}},
    FontSize->36],
  
  Cell[StyleData["SlideHyperlink", "SlideShow"]],
  
  Cell[StyleData["SlideHyperlink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SlideTOCLink"],
    CellMargins->{{24, Inherited}, {Inherited, Inherited}},
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Helvetica",
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonMargins->1.5,
    ButtonNote->ButtonData}],
  
  Cell[StyleData["SlideTOCLink", "Presentation"],
    CellMargins->{{35, 10}, {4, 6}},
    FontSize->18],
  
  Cell[StyleData["SlideTOCLink", "SlideShow"]],
  
  Cell[StyleData["SlideTOCLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SlideTOC"],
    CellDingbat->"\[Bullet]",
    CellMargins->{{18, Inherited}, {Inherited, Inherited}},
    StyleMenuListing->None,
    FontFamily->"Helvetica"],
  
  Cell[StyleData["SlideTOC", "Presentation"],
    CellMargins->{{25, 10}, {8, 6}},
    FontSize->18],
  
  Cell[StyleData["SlideTOC", "SlideShow"],
    FontSize->14],
  
  Cell[StyleData["SlideTOC", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]]
  }, Open  ]]
  }]
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "c:1"->{
    Cell[1754, 51, 116, 5, 122, "Title",
      CellTags->"c:1"]},
  "c:2"->{
    Cell[2607, 81, 95, 2, 62, "Section",
      CellTags->"c:2"]},
  "b:0.0.0"->{
    Cell[4347, 137, 145, 3, 69, "Subsection",
      CellTags->{"b:0.0.0", "c:3"}],
    Cell[4495, 142, 459, 9, 88, "Text",
      Evaluatable->False,
      CellTags->"b:0.0.0"],
    Cell[4957, 153, 136, 5, 77, "Input",
      CellTags->"b:0.0.0"],
    Cell[5096, 160, 105, 2, 28, "Text",
      CellTags->"b:0.0.0"],
    Cell[5204, 164, 144, 5, 77, "Input",
      CellTags->"b:0.0.0"],
    Cell[5351, 171, 220, 5, 58, "Text",
      CellTags->"b:0.0.0"],
    Cell[5574, 178, 70, 2, 47, "Input",
      CellTags->"b:0.0.0"],
    Cell[5647, 182, 181, 4, 63, "Input",
      CellTags->"b:0.0.0"],
    Cell[5831, 188, 181, 5, 58, "Text",
      CellTags->"b:0.0.0"],
    Cell[6015, 195, 597, 18, 47, "Input",
      CellTags->"b:0.0.0"],
    Cell[6615, 215, 136, 4, 28, "Text",
      CellTags->"b:0.0.0"],
    Cell[6754, 221, 300, 6, 63, "Input",
      CellTags->"b:0.0.0"],
    Cell[7057, 229, 124, 2, 28, "Text",
      CellTags->"b:0.0.0"],
    Cell[7184, 233, 736, 22, 95, "Input",
      CellTags->"b:0.0.0"],
    Cell[7923, 257, 96, 2, 28, "Text",
      CellTags->"b:0.0.0"],
    Cell[8022, 261, 225, 5, 63, "Input",
      CellTags->{"Do", "b:0.0.0"}],
    Cell[33913, 1125, 251, 6, 47, "Input",
      CellTags->"b:0.0.0"],
    Cell[50586, 1682, 251, 6, 47, "Input",
      CellTags->"b:0.0.0"]},
  "c:3"->{
    Cell[4347, 137, 145, 3, 69, "Subsection",
      CellTags->{"b:0.0.0", "c:3"}]},
  "Do"->{
    Cell[8022, 261, 225, 5, 63, "Input",
      CellTags->{"Do", "b:0.0.0"}],
    Cell[16809, 583, 502, 14, 79, "Input",
      CellTags->{"Do", "b:0.0.2"}],
    Cell[62150, 2071, 278, 6, 63, "Input",
      CellTags->{"Do", "b:6.0.0"}],
    Cell[72491, 2432, 857, 23, 79, "Input",
      CellTags->{"Do", "b:6.0.2"}]},
  "b:0.0.1"->{
    Cell[8284, 271, 131, 3, 53, "Subsection",
      CellTags->{"b:0.0.1", "c:4"}],
    Cell[8418, 276, 223, 6, 58, "Text",
      CellTags->"b:0.0.1"],
    Cell[8644, 284, 896, 29, 95, "Input",
      CellTags->"b:0.0.1"],
    Cell[9543, 315, 212, 6, 58, "Text",
      CellTags->"b:0.0.1"],
    Cell[9758, 323, 170, 4, 47, "Input",
      CellTags->"b:0.0.1"],
    Cell[9931, 329, 211, 6, 28, "Text",
      CellTags->"b:0.0.1"],
    Cell[10145, 337, 97, 3, 47, "Input",
      CellTags->"b:0.0.1"],
    Cell[10245, 342, 247, 7, 58, "Text",
      CellTags->"b:0.0.1"],
    Cell[10495, 351, 553, 12, 95, "Input",
      CellTags->"b:0.0.1"],
    Cell[11051, 365, 87, 2, 28, "Text",
      CellTags->"b:0.0.1"],
    Cell[11141, 369, 324, 9, 95, "Input",
      CellTags->"b:0.0.1"],
    Cell[11468, 380, 335, 8, 88, "Text",
      CellTags->"b:0.0.1"],
    Cell[11806, 390, 92, 2, 47, "Input",
      CellTags->"b:0.0.1"],
    Cell[11901, 394, 203, 4, 47, "Input",
      CellTags->"b:0.0.1"],
    Cell[12107, 400, 163, 5, 28, "Text",
      CellTags->"b:0.0.1"],
    Cell[12273, 407, 1892, 66, 95, "Input",
      CellTags->"b:0.0.1"],
    Cell[14168, 475, 111, 2, 28, "Text",
      CellTags->"b:0.0.1"],
    Cell[14282, 479, 96, 3, 63, "Input",
      CellTags->"b:0.0.1"],
    Cell[14381, 484, 101, 2, 28, "Text",
      CellTags->"b:0.0.1"],
    Cell[14485, 488, 71, 2, 47, "Input",
      CellTags->"b:0.0.1"],
    Cell[14716, 500, 220, 6, 58, "Text",
      CellTags->"b:0.0.1"]},
  "c:4"->{
    Cell[8284, 271, 131, 3, 53, "Subsection",
      CellTags->{"b:0.0.1", "c:4"}]},
  "b:0.0.2"->{
    Cell[14593, 495, 120, 3, 53, "Subsection",
      CellTags->{"b:0.0.2", "c:5"}],
    Cell[14939, 508, 354, 12, 47, "Input",
      CellTags->"b:0.0.2"],
    Cell[15296, 522, 96, 2, 28, "Text",
      CellTags->"b:0.0.2"],
    Cell[15395, 526, 202, 7, 47, "Input",
      CellTags->"b:0.0.2"],
    Cell[15600, 535, 372, 13, 47, "Input",
      CellTags->"b:0.0.2"],
    Cell[15975, 550, 270, 9, 28, "Text",
      CellTags->"b:0.0.2"],
    Cell[16248, 561, 417, 14, 47, "Input",
      CellTags->"b:0.0.2"],
    Cell[16668, 577, 138, 4, 28, "Text",
      CellTags->"b:0.0.2"],
    Cell[16809, 583, 502, 14, 79, "Input",
      CellTags->{"Do", "b:0.0.2"}]},
  "c:5"->{
    Cell[14593, 495, 120, 3, 53, "Subsection",
      CellTags->{"b:0.0.2", "c:5"}]},
  "b:0.0.3"->{
    Cell[17348, 602, 130, 3, 53, "Subsection",
      CellTags->{"b:0.0.3", "c:6"}],
    Cell[17481, 607, 399, 11, 178, "Text",
      CellTags->"b:0.0.3"],
    Cell[17883, 620, 306, 8, 118, "Text",
      CellTags->"b:0.0.3"],
    Cell[18192, 630, 138, 3, 26, "Text",
      CellTags->"b:0.0.3"],
    Cell[18333, 635, 307, 8, 47, "Input",
      CellTags->"b:0.0.3"],
    Cell[18643, 645, 174, 4, 26, "Text",
      CellTags->"b:0.0.3"],
    Cell[18820, 651, 174, 4, 63, "Input",
      CellTags->"b:0.0.3"],
    Cell[18997, 657, 261, 6, 79, "Input",
      CellTags->"b:0.0.3"],
    Cell[19261, 665, 102, 3, 47, "Input",
      CellTags->"b:0.0.3"],
    Cell[19366, 670, 280, 8, 28, "Text",
      CellTags->"b:0.0.3"],
    Cell[19649, 680, 190, 3, 47, "Input",
      CellTags->"b:0.0.3"],
    Cell[19842, 685, 213, 6, 95, "Input",
      CellTags->"b:0.0.3"]},
  "c:6"->{
    Cell[17348, 602, 130, 3, 53, "Subsection",
      CellTags->{"b:0.0.3", "c:6"}]},
  "b:0.0.4"->{
    Cell[20092, 696, 142, 3, 53, "Subsection",
      CellTags->{"b:0.0.4", "c:7"}],
    Cell[20237, 701, 405, 11, 88, "Text",
      CellTags->"b:0.0.4"],
    Cell[20645, 714, 162, 3, 63, "Input",
      CellTags->"b:0.0.4"],
    Cell[20810, 719, 166, 3, 47, "Input",
      CellTags->"b:0.0.4"],
    Cell[20979, 724, 163, 5, 28, "Text",
      CellTags->"b:0.0.4"],
    Cell[21145, 731, 102, 2, 47, "Input",
      CellTags->"b:0.0.4"],
    Cell[21250, 735, 158, 3, 47, "Input",
      CellTags->"b:0.0.4"],
    Cell[21411, 740, 61, 2, 47, "Input",
      CellTags->"b:0.0.4"],
    Cell[21475, 744, 228, 5, 95, "Input",
      CellTags->"b:0.0.4"]},
  "c:7"->{
    Cell[20092, 696, 142, 3, 53, "Subsection",
      CellTags->{"b:0.0.4", "c:7"}]},
  "b:0.0.5"->{
    Cell[21706, 751, 453, 13, 88, "Text",
      CellTags->"b:0.0.5"],
    Cell[22162, 766, 91, 2, 47, "Input",
      CellTags->"b:0.0.5"],
    Cell[22256, 770, 137, 4, 28, "Text",
      CellTags->"b:0.0.5"],
    Cell[22396, 776, 45, 1, 47, "Input",
      CellTags->"b:0.0.5"],
    Cell[22444, 779, 135, 4, 28, "Text",
      CellTags->"b:0.0.5"],
    Cell[22582, 785, 137, 3, 47, "Input",
      CellTags->"b:0.0.5"],
    Cell[22722, 790, 124, 5, 58, "Text",
      CellTags->"b:0.0.5"],
    Cell[22849, 797, 1475, 27, 808, "Text",
      CellTags->"b:0.0.5"],
    Cell[24327, 826, 5110, 143, 223, "Input",
      CellTags->"b:0.0.5"],
    Cell[29440, 971, 153, 5, 40, "DisplayText",
      CellTags->"b:0.0.5"],
    Cell[29596, 978, 184, 4, 47, "Input",
      CellTags->"b:0.0.5"],
    Cell[29783, 984, 155, 5, 40, "DisplayText",
      CellTags->"b:0.0.5"],
    Cell[29941, 991, 68, 2, 47, "Input",
      CellTags->"b:0.0.5"],
    Cell[30012, 995, 44, 1, 47, "Input",
      CellTags->"b:0.0.5"]},
  "c:8"->{
    Cell[30105, 1002, 109, 2, 42, "Section",
      CellTags->"c:8"]},
  "b:1.0.0"->{
    Cell[30954, 1035, 211, 6, 69, "Subsection",
      CellTags->{"b:1.0.0", "c:9"}],
    Cell[31168, 1043, 270, 6, 28, "Text",
      CellTags->"b:1.0.0"],
    Cell[31441, 1051, 72, 2, 47, "Input",
      CellTags->"b:1.0.0"],
    Cell[31516, 1055, 925, 21, 127, "Input",
      CellTags->"b:1.0.0"],
    Cell[32444, 1078, 250, 6, 28, "Text",
      CellTags->"b:1.0.0"],
    Cell[32697, 1086, 131, 3, 63, "Input",
      CellTags->"b:1.0.0"],
    Cell[32831, 1091, 215, 7, 28, "Text",
      CellTags->"b:1.0.0"],
    Cell[33049, 1100, 464, 9, 95, "Input",
      CellTags->"b:1.0.0"],
    Cell[33516, 1111, 125, 2, 28, "Text",
      CellTags->"b:1.0.0"],
    Cell[33644, 1115, 160, 4, 63, "Input",
      CellTags->"b:1.0.0"],
    Cell[33807, 1121, 103, 2, 28, "Text",
      CellTags->"b:1.0.0"],
    Cell[50480, 1678, 103, 2, 28, "Text",
      CellTags->"b:1.0.0"]},
  "c:9"->{
    Cell[30954, 1035, 211, 6, 69, "Subsection",
      CellTags->{"b:1.0.0", "c:9"}]},
  "b:1.0.1"->{
    Cell[34201, 1136, 138, 3, 53, "Subsection",
      CellTags->{"b:1.0.1", "c:10"}],
    Cell[34342, 1141, 311, 8, 88, "Text",
      CellTags->"b:1.0.1"],
    Cell[34656, 1151, 211, 5, 47, "Input",
      CellTags->"b:1.0.1"]},
  "c:10"->{
    Cell[34201, 1136, 138, 3, 53, "Subsection",
      CellTags->{"b:1.0.1", "c:10"}]},
  "b:1.0.2"->{
    Cell[34904, 1161, 147, 3, 53, "Subsection",
      CellTags->{"b:1.0.2", "c:11"}],
    Cell[35054, 1166, 163, 5, 28, "Text",
      CellTags->"b:1.0.2"],
    Cell[35220, 1173, 545, 18, 63, "Input",
      CellTags->"b:1.0.2"],
    Cell[35768, 1193, 187, 6, 58, "Text",
      CellTags->"b:1.0.2"],
    Cell[35958, 1201, 137, 3, 63, "Input",
      CellTags->"b:1.0.2"]},
  "c:11"->{
    Cell[34904, 1161, 147, 3, 53, "Subsection",
      CellTags->{"b:1.0.2", "c:11"}]},
  "b:1.0.3"->{
    Cell[36132, 1209, 144, 3, 53, "Subsection",
      CellTags->{"b:1.0.3", "c:12"}],
    Cell[36279, 1214, 190, 5, 28, "Text",
      CellTags->"b:1.0.3"]},
  "c:12"->{
    Cell[36132, 1209, 144, 3, 53, "Subsection",
      CellTags->{"b:1.0.3", "c:12"}]},
  "b:1.0.4"->{
    Cell[37767, 1255, 273, 8, 53, "Subsection",
      CellTags->{"b:1.0.4", "c:13"}],
    Cell[38043, 1265, 294, 7, 58, "Text",
      CellTags->"b:1.0.4"],
    Cell[38340, 1274, 209, 5, 47, "Input",
      CellTags->"b:1.0.4"],
    Cell[38552, 1281, 161, 5, 28, "Text",
      CellTags->"b:1.0.4"],
    Cell[38716, 1288, 342, 6, 111, "Input",
      CellTags->"b:1.0.4"],
    Cell[39061, 1296, 196, 7, 28, "Text",
      CellTags->"b:1.0.4"],
    Cell[39260, 1305, 89, 2, 47, "Input",
      CellTags->"b:1.0.4"]},
  "c:13"->{
    Cell[37767, 1255, 273, 8, 53, "Subsection",
      CellTags->{"b:1.0.4", "c:13"}]},
  "b:1.0.5"->{
    Cell[39386, 1312, 334, 9, 53, "Subsection",
      CellTags->{"b:1.0.5", "c:14"}],
    Cell[39723, 1323, 159, 5, 28, "Text",
      CellTags->"b:1.0.5"],
    Cell[39885, 1330, 514, 8, 143, "Input",
      CellTags->"b:1.0.5"],
    Cell[40402, 1340, 137, 4, 28, "Text",
      CellTags->"b:1.0.5"],
    Cell[40542, 1346, 169, 4, 63, "Input",
      CellTags->"b:1.0.5"]},
  "c:14"->{
    Cell[39386, 1312, 334, 9, 53, "Subsection",
      CellTags->{"b:1.0.5", "c:14"}]},
  "b:1.0.6"->{
    Cell[40748, 1355, 324, 9, 53, "Subsection",
      CellTags->{"b:1.0.6", "c:15"}],
    Cell[41075, 1366, 140, 4, 28, "Text",
      CellTags->"b:1.0.6"],
    Cell[41218, 1372, 1917, 65, 143, "Input",
      CellTags->"b:1.0.6"],
    Cell[43138, 1439, 139, 4, 28, "Text",
      CellTags->"b:1.0.6"],
    Cell[43280, 1445, 2043, 70, 143, "Input",
      CellTags->"b:1.0.6"],
    Cell[45326, 1517, 184, 6, 47, "Input",
      CellTags->"b:1.0.6"]},
  "c:15"->{
    Cell[40748, 1355, 324, 9, 53, "Subsection",
      CellTags->{"b:1.0.6", "c:15"}]},
  "b:1.0.7"->{
    Cell[45547, 1528, 168, 5, 53, "Subsection",
      CellTags->{"b:1.0.7", "c:16"}],
    Cell[45718, 1535, 744, 13, 127, "Input",
      CellTags->"b:1.0.7"]},
  "c:16"->{
    Cell[45547, 1528, 168, 5, 53, "Subsection",
      CellTags->{"b:1.0.7", "c:16"}]},
  "c:17"->{
    Cell[46511, 1554, 112, 2, 42, "Section",
      CellTags->"c:17"]},
  "b:2.0.0"->{
    Cell[47365, 1587, 167, 5, 69, "Subsection",
      CellTags->{"b:2.0.0", "c:18"}],
    Cell[47535, 1594, 217, 6, 58, "Text",
      CellTags->"b:2.0.0"],
    Cell[47755, 1602, 1005, 22, 111, "Input",
      CellTags->"b:2.0.0"],
    Cell[48763, 1626, 111, 2, 28, "Text",
      CellTags->"b:2.0.0"],
    Cell[48877, 1630, 132, 3, 63, "Input",
      CellTags->"b:2.0.0"],
    Cell[49012, 1635, 86, 2, 28, "Text",
      CellTags->"b:2.0.0"],
    Cell[49101, 1639, 86, 2, 47, "Input",
      CellTags->"b:2.0.0"],
    Cell[49190, 1643, 257, 7, 58, "Text",
      CellTags->"b:2.0.0"],
    Cell[49450, 1652, 656, 12, 111, "Input",
      CellTags->"b:2.0.0"],
    Cell[50109, 1666, 120, 2, 28, "Text",
      CellTags->"b:2.0.0"],
    Cell[50232, 1670, 245, 6, 79, "Input",
      CellTags->"b:2.0.0"]},
  "c:18"->{
    Cell[47365, 1587, 167, 5, 69, "Subsection",
      CellTags->{"b:2.0.0", "c:18"}]},
  "b:2.0.1"->{
    Cell[50874, 1693, 138, 3, 53, "Subsection",
      CellTags->{"b:2.0.1", "c:19"}],
    Cell[51015, 1698, 139, 4, 28, "Text",
      CellTags->"b:2.0.1"],
    Cell[51157, 1704, 262, 5, 63, "Input",
      CellTags->"b:2.0.1"],
    Cell[51422, 1711, 94, 2, 28, "Text",
      CellTags->"b:2.0.1"],
    Cell[51519, 1715, 471, 9, 95, "Input",
      CellTags->"b:2.0.1"],
    Cell[51993, 1726, 73, 2, 47, "Input",
      CellTags->"b:2.0.1"]},
  "c:19"->{
    Cell[50874, 1693, 138, 3, 53, "Subsection",
      CellTags->{"b:2.0.1", "c:19"}]},
  "b:2.0.2"->{
    Cell[52103, 1733, 147, 3, 53, "Subsection",
      CellTags->{"b:2.0.2", "c:20"}],
    Cell[52253, 1738, 163, 5, 28, "Text",
      CellTags->"b:2.0.2"],
    Cell[52419, 1745, 278, 7, 47, "Input",
      CellTags->"b:2.0.2"],
    Cell[52700, 1754, 176, 5, 58, "Text",
      CellTags->"b:2.0.2"],
    Cell[52879, 1761, 151, 3, 63, "Input",
      CellTags->"b:2.0.2"]},
  "c:20"->{
    Cell[52103, 1733, 147, 3, 53, "Subsection",
      CellTags->{"b:2.0.2", "c:20"}]},
  "b:2.0.3"->{
    Cell[53067, 1769, 148, 3, 53, "Subsection",
      CellTags->{"b:2.0.3", "c:21"}],
    Cell[53218, 1774, 173, 6, 58, "Text",
      CellTags->"b:2.0.3"],
    Cell[53394, 1782, 484, 8, 143, "Input",
      CellTags->"b:2.0.3"],
    Cell[53881, 1792, 135, 4, 28, "Text",
      CellTags->"b:2.0.3"],
    Cell[54019, 1798, 484, 8, 47, "Input",
      CellTags->"b:2.0.3"]},
  "c:21"->{
    Cell[53067, 1769, 148, 3, 53, "Subsection",
      CellTags->{"b:2.0.3", "c:21"}]},
  "b:2.0.4"->{
    Cell[54540, 1811, 273, 8, 53, "Subsection",
      CellTags->{"b:2.0.4", "c:22"}],
    Cell[54816, 1821, 297, 8, 88, "Text",
      CellTags->"b:2.0.4"],
    Cell[55178, 1834, 228, 5, 47, "Input",
      CellTags->"b:2.0.4"],
    Cell[55603, 1846, 206, 7, 28, "Text",
      CellTags->"b:2.0.4"],
    Cell[55812, 1855, 73, 2, 47, "Input",
      CellTags->"b:2.0.4"]},
  "c:22"->{
    Cell[54540, 1811, 273, 8, 53, "Subsection",
      CellTags->{"b:2.0.4", "c:22"}]},
  "b:2.0.5"->{
    Cell[55922, 1862, 334, 9, 53, "Subsection",
      CellTags->{"b:2.0.5", "c:23"}],
    Cell[56259, 1873, 159, 5, 28, "Text",
      CellTags->"b:2.0.5"],
    Cell[56421, 1880, 748, 12, 191, "Input",
      CellTags->"b:2.0.5"],
    Cell[57172, 1894, 139, 4, 28, "Text",
      CellTags->"b:2.0.5"],
    Cell[57314, 1900, 172, 4, 63, "Input",
      CellTags->"b:2.0.5"]},
  "c:23"->{
    Cell[55922, 1862, 334, 9, 53, "Subsection",
      CellTags->{"b:2.0.5", "c:23"}]},
  "b:2.0.6"->{
    Cell[57523, 1909, 319, 9, 53, "Subsection",
      CellTags->{"b:2.0.6", "c:24"}],
    Cell[57845, 1920, 160, 5, 28, "Text",
      CellTags->"b:2.0.6"],
    Cell[58008, 1927, 82, 2, 47, "Input",
      CellTags->"b:2.0.6"],
    Cell[58093, 1931, 60, 2, 47, "Input",
      CellTags->"b:2.0.6"]},
  "c:24"->{
    Cell[57523, 1909, 319, 9, 53, "Subsection",
      CellTags->{"b:2.0.6", "c:24"}]},
  "c:25"->{
    Cell[58202, 1939, 98, 2, 42, "Section",
      CellTags->"c:25"]},
  "b:6.0.0"->{
    Cell[59125, 1979, 294, 8, 69, "Subsection",
      CellTags->{"b:6.0.0", "c:26"}],
    Cell[59422, 1989, 366, 8, 58, "Text",
      CellTags->"b:6.0.0"],
    Cell[59791, 1999, 192, 5, 28, "Text",
      CellTags->"b:6.0.0"],
    Cell[59986, 2006, 85, 2, 47, "Input",
      CellTags->"b:6.0.0"],
    Cell[60074, 2010, 247, 6, 47, "Input",
      CellTags->"b:6.0.0"],
    Cell[60324, 2018, 116, 2, 28, "Text",
      CellTags->"b:6.0.0"],
    Cell[60443, 2022, 387, 8, 111, "Input",
      CellTags->"b:6.0.0"],
    Cell[60833, 2032, 115, 2, 28, "Text",
      CellTags->"b:6.0.0"],
    Cell[60951, 2036, 728, 18, 63, "Input",
      CellTags->"b:6.0.0"],
    Cell[61682, 2056, 97, 2, 28, "Text",
      CellTags->"b:6.0.0"],
    Cell[61782, 2060, 280, 5, 95, "Input",
      CellTags->"b:6.0.0"],
    Cell[62065, 2067, 82, 2, 28, "Text",
      CellTags->"b:6.0.0"],
    Cell[62150, 2071, 278, 6, 63, "Input",
      CellTags->{"Do", "b:6.0.0"}]},
  "c:26"->{
    Cell[59125, 1979, 294, 8, 69, "Subsection",
      CellTags->{"b:6.0.0", "c:26"}]},
  "b:6.0.1"->{
    Cell[62465, 2082, 292, 8, 53, "Subsection",
      CellTags->{"b:6.0.1", "c:27"}],
    Cell[62760, 2092, 363, 10, 26, "Text",
      CellTags->"b:6.0.1"],
    Cell[63126, 2104, 288, 9, 47, "Input",
      CellTags->"b:6.0.1"],
    Cell[63417, 2115, 95, 2, 28, "Text",
      CellTags->"b:6.0.1"],
    Cell[63515, 2119, 173, 5, 63, "Input",
      CellTags->"b:6.0.1"],
    Cell[63691, 2126, 182, 4, 47, "Input",
      CellTags->"b:6.0.1"],
    Cell[63876, 2132, 366, 7, 44, "Text",
      CellTags->"b:6.0.1"],
    Cell[64245, 2141, 221, 6, 47, "Input",
      CellTags->"b:6.0.1"],
    Cell[64469, 2149, 88, 2, 28, "Text",
      CellTags->"b:6.0.1"],
    Cell[64560, 2153, 67, 2, 47, "Input",
      CellTags->"b:6.0.1"],
    Cell[64630, 2157, 255, 7, 118, "Text",
      CellTags->"b:6.0.1"],
    Cell[64888, 2166, 4921, 164, 287, "Input",
      CellTags->"b:6.0.1"]},
  "c:27"->{
    Cell[62465, 2082, 292, 8, 53, "Subsection",
      CellTags->{"b:6.0.1", "c:27"}]},
  "b:6.0.2"->{
    Cell[69846, 2335, 276, 8, 53, "Subsection",
      CellTags->{"b:6.0.2", "c:28"}],
    Cell[70125, 2345, 614, 20, 26, "Text",
      CellTags->"b:6.0.2"],
    Cell[70742, 2367, 470, 17, 47, "Input",
      CellTags->"b:6.0.2"],
    Cell[71215, 2386, 227, 5, 26, "Text",
      CellTags->"b:6.0.2"],
    Cell[71445, 2393, 202, 7, 47, "Input",
      CellTags->"b:6.0.2"],
    Cell[71650, 2402, 224, 5, 26, "Text",
      CellTags->"b:6.0.2"],
    Cell[71877, 2409, 611, 21, 63, "Input",
      CellTags->"b:6.0.2"],
    Cell[72491, 2432, 857, 23, 79, "Input",
      CellTags->{"Do", "b:6.0.2"}]},
  "c:28"->{
    Cell[69846, 2335, 276, 8, 53, "Subsection",
      CellTags->{"b:6.0.2", "c:28"}]},
  "b:6.0.3"->{
    Cell[73385, 2460, 340, 9, 53, "Subsection",
      CellTags->{"b:6.0.3", "c:29"}],
    Cell[73728, 2471, 136, 4, 28, "Text",
      CellTags->"b:6.0.3"],
    Cell[73867, 2477, 135, 3, 47, "Input",
      CellTags->"b:6.0.3"],
    Cell[74005, 2482, 160, 5, 28, "Text",
      CellTags->"b:6.0.3"],
    Cell[74168, 2489, 244, 5, 79, "Input",
      CellTags->"b:6.0.3"],
    Cell[74415, 2496, 297, 6, 79, "Input",
      CellTags->"b:6.0.3"],
    Cell[74715, 2504, 102, 3, 47, "Input",
      CellTags->"b:6.0.3"],
    Cell[74820, 2509, 147, 4, 28, "Text",
      CellTags->"b:6.0.3"],
    Cell[74970, 2515, 287, 5, 47, "Input",
      CellTags->"b:6.0.3"],
    Cell[75260, 2522, 138, 4, 28, "Text",
      CellTags->"b:6.0.3"],
    Cell[75401, 2528, 230, 6, 47, "Input",
      CellTags->"b:6.0.3"],
    Cell[75634, 2536, 156, 5, 58, "Text",
      CellTags->"b:6.0.3"],
    Cell[75793, 2543, 333, 7, 127, "Input",
      CellTags->"b:6.0.3"]},
  "c:29"->{
    Cell[73385, 2460, 340, 9, 53, "Subsection",
      CellTags->{"b:6.0.3", "c:29"}]},
  "b:6.0.4"->{
    Cell[76163, 2555, 300, 8, 53, "Subsection",
      CellTags->{"b:6.0.4", "c:30"}],
    Cell[76466, 2565, 190, 6, 58, "Text",
      CellTags->"b:6.0.4"],
    Cell[76659, 2573, 149, 3, 63, "Input",
      CellTags->"b:6.0.4"],
    Cell[76811, 2578, 206, 5, 58, "Text",
      CellTags->"b:6.0.4"],
    Cell[77020, 2585, 182, 3, 47, "Input",
      CellTags->"b:6.0.4"],
    Cell[77205, 2590, 2971, 87, 159, "Input",
      CellTags->"b:6.0.4"],
    Cell[80179, 2679, 108, 2, 47, "Input",
      CellTags->"b:6.0.4"]},
  "c:30"->{
    Cell[76163, 2555, 300, 8, 53, "Subsection",
      CellTags->{"b:6.0.4", "c:30"}]},
  "b:6.0.5"->{
    Cell[80324, 2686, 323, 9, 53, "Subsection",
      CellTags->{"b:6.0.5", "c:31"}],
    Cell[80650, 2697, 90, 2, 47, "Input",
      CellTags->"b:6.0.5"],
    Cell[80743, 2701, 60, 2, 47, "Input",
      CellTags->"b:6.0.5"]},
  "c:31"->{
    Cell[80324, 2686, 323, 9, 53, "Subsection",
      CellTags->{"b:6.0.5", "c:31"}]},
  "c:32"->{
    Cell[80852, 2709, 140, 4, 42, "Section",
      CellTags->"c:32"]},
  "b:7.0.0"->{
    Cell[81571, 2738, 188, 6, 69, "Subsection",
      CellTags->{"b:7.0.0", "c:33"}],
    Cell[81762, 2746, 84, 4, 62, "Input",
      CellTags->"b:7.0.0"],
    Cell[81849, 2752, 221, 6, 58, "Text",
      CellTags->"b:7.0.0"],
    Cell[82073, 2760, 70, 2, 47, "Input",
      CellTags->"b:7.0.0"],
    Cell[82146, 2764, 167, 4, 63, "Input",
      CellTags->"b:7.0.0"],
    Cell[82316, 2770, 199, 5, 58, "Text",
      CellTags->"b:7.0.0"],
    Cell[82518, 2777, 326, 6, 95, "Input",
      CellTags->"b:7.0.0"],
    Cell[82847, 2785, 357, 8, 79, "Input",
      CellTags->"b:7.0.0"],
    Cell[83207, 2795, 120, 2, 28, "Text",
      CellTags->"b:7.0.0"],
    Cell[83330, 2799, 93, 2, 47, "Input",
      CellTags->"b:7.0.0"]},
  "c:33"->{
    Cell[81571, 2738, 188, 6, 69, "Subsection",
      CellTags->{"b:7.0.0", "c:33"}]},
  "b:7.0.1"->{
    Cell[83460, 2806, 157, 4, 53, "Subsection",
      CellTags->{"b:7.0.1", "c:34"}],
    Cell[83620, 2812, 187, 5, 28, "Text",
      CellTags->"b:7.0.1"],
    Cell[83810, 2819, 362, 7, 79, "Input",
      CellTags->"b:7.0.1"]},
  "c:34"->{
    Cell[83460, 2806, 157, 4, 53, "Subsection",
      CellTags->{"b:7.0.1", "c:34"}]},
  "b:7.0.2"->{
    Cell[84209, 2831, 147, 3, 53, "Subsection",
      CellTags->{"b:7.0.2", "c:35"}],
    Cell[84359, 2836, 158, 5, 28, "Text",
      CellTags->"b:7.0.2"],
    Cell[84520, 2843, 228, 6, 47, "Input",
      CellTags->"b:7.0.2"],
    Cell[84751, 2851, 176, 5, 58, "Text",
      CellTags->"b:7.0.2"],
    Cell[84930, 2858, 145, 3, 63, "Input",
      CellTags->"b:7.0.2"]},
  "c:35"->{
    Cell[84209, 2831, 147, 3, 53, "Subsection",
      CellTags->{"b:7.0.2", "c:35"}]},
  "b:7.0.3"->{
    Cell[85112, 2866, 304, 8, 53, "Subsection",
      CellTags->{"b:7.0.3", "c:36"}],
    Cell[85419, 2876, 184, 5, 58, "Text",
      CellTags->"b:7.0.3"],
    Cell[85606, 2883, 95, 2, 47, "Input",
      CellTags->"b:7.0.3"],
    Cell[85704, 2887, 119, 2, 28, "Text",
      CellTags->"b:7.0.3"],
    Cell[85826, 2891, 1956, 66, 143, "Input",
      CellTags->"b:7.0.3"],
    Cell[87785, 2959, 116, 2, 28, "Text",
      CellTags->"b:7.0.3"],
    Cell[87904, 2963, 1999, 68, 143, "Input",
      CellTags->"b:7.0.3"]},
  "c:36"->{
    Cell[85112, 2866, 304, 8, 53, "Subsection",
      CellTags->{"b:7.0.3", "c:36"}]},
  "b:7.0.4"->{
    Cell[89940, 3036, 168, 5, 53, "Subsection",
      CellTags->{"b:7.0.4", "c:37"}],
    Cell[90111, 3043, 579, 11, 111, "Input",
      CellTags->"b:7.0.4"],
    Cell[90693, 3056, 60, 2, 47, "Input",
      CellTags->"b:7.0.4"]},
  "c:37"->{
    Cell[89940, 3036, 168, 5, 53, "Subsection",
      CellTags->{"b:7.0.4", "c:37"}]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"c:1", 145978, 4858},
  {"c:2", 146055, 4861},
  {"b:0.0.0", 146136, 4864},
  {"c:3", 147435, 4902},
  {"Do", 147529, 4905},
  {"b:0.0.1", 147860, 4914},
  {"c:4", 149339, 4957},
  {"b:0.0.2", 149438, 4960},
  {"c:5", 150102, 4979},
  {"b:0.0.3", 150202, 4982},
  {"c:6", 151066, 5007},
  {"b:0.0.4", 151166, 5010},
  {"c:7", 151820, 5029},
  {"b:0.0.5", 151920, 5032},
  {"c:8", 152923, 5061},
  {"b:1.0.0", 153008, 5064},
  {"c:9", 153881, 5089},
  {"b:1.0.1", 153982, 5092},
  {"c:10", 154222, 5099},
  {"b:1.0.2", 154324, 5102},
  {"c:11", 154706, 5113},
  {"b:1.0.3", 154808, 5116},
  {"c:12", 154977, 5121},
  {"b:1.0.4", 155079, 5124},
  {"c:13", 155601, 5139},
  {"b:1.0.5", 155703, 5142},
  {"c:14", 156085, 5153},
  {"b:1.0.6", 156187, 5156},
  {"c:15", 156645, 5169},
  {"b:1.0.7", 156747, 5172},
  {"c:16", 156919, 5177},
  {"c:17", 157018, 5180},
  {"b:2.0.0", 157104, 5183},
  {"c:18", 157911, 5206},
  {"b:2.0.1", 158013, 5209},
  {"c:19", 158463, 5222},
  {"b:2.0.2", 158565, 5225},
  {"c:20", 158946, 5236},
  {"b:2.0.3", 159048, 5239},
  {"c:21", 159430, 5250},
  {"b:2.0.4", 159532, 5253},
  {"c:22", 159912, 5264},
  {"b:2.0.5", 160014, 5267},
  {"c:23", 160397, 5278},
  {"b:2.0.6", 160499, 5281},
  {"c:24", 160808, 5290},
  {"c:25", 160907, 5293},
  {"b:6.0.0", 160992, 5296},
  {"c:26", 161944, 5323},
  {"b:6.0.1", 162046, 5326},
  {"c:27", 162924, 5351},
  {"b:6.0.2", 163026, 5354},
  {"c:28", 163631, 5371},
  {"b:6.0.3", 163733, 5374},
  {"c:29", 164680, 5401},
  {"b:6.0.4", 164782, 5404},
  {"c:30", 165308, 5419},
  {"b:6.0.5", 165410, 5422},
  {"c:31", 165649, 5429},
  {"c:32", 165748, 5432},
  {"b:7.0.0", 165834, 5435},
  {"c:33", 166566, 5456},
  {"b:7.0.1", 166668, 5459},
  {"c:34", 166908, 5466},
  {"b:7.0.2", 167010, 5469},
  {"c:35", 167391, 5480},
  {"b:7.0.3", 167493, 5483},
  {"c:36", 168020, 5498},
  {"b:7.0.4", 168122, 5501},
  {"c:37", 168364, 5508}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 116, 5, 122, "Title",
  CellTags->"c:1"],
Cell[1873, 58, 62, 0, 41, "Subtitle"],
Cell[1938, 60, 489, 13, 83, "Abstract"],
Cell[2430, 75, 152, 2, 28, "Text"],

Cell[CellGroupData[{
Cell[2607, 81, 95, 2, 62, "Section",
  CellTags->"c:2"],
Cell[2705, 85, 161, 3, 28, "Text"],
Cell[2869, 90, 93, 2, 47, "Input"],
Cell[2965, 94, 86, 2, 47, "Input"],
Cell[3054, 98, 251, 5, 28, "Text"],
Cell[3308, 105, 154, 4, 63, "Input"],
Cell[3465, 111, 857, 22, 58, "Text"],

Cell[CellGroupData[{
Cell[4347, 137, 145, 3, 69, "Subsection",
  CellTags->{"b:0.0.0", "c:3"}],
Cell[4495, 142, 459, 9, 88, "Text",
  Evaluatable->False,
  CellTags->"b:0.0.0"],
Cell[4957, 153, 136, 5, 77, "Input",
  CellTags->"b:0.0.0"],
Cell[5096, 160, 105, 2, 28, "Text",
  CellTags->"b:0.0.0"],
Cell[5204, 164, 144, 5, 77, "Input",
  CellTags->"b:0.0.0"],
Cell[5351, 171, 220, 5, 58, "Text",
  CellTags->"b:0.0.0"],
Cell[5574, 178, 70, 2, 47, "Input",
  CellTags->"b:0.0.0"],
Cell[5647, 182, 181, 4, 63, "Input",
  CellTags->"b:0.0.0"],
Cell[5831, 188, 181, 5, 58, "Text",
  CellTags->"b:0.0.0"],
Cell[6015, 195, 597, 18, 47, "Input",
  CellTags->"b:0.0.0"],
Cell[6615, 215, 136, 4, 28, "Text",
  CellTags->"b:0.0.0"],
Cell[6754, 221, 300, 6, 63, "Input",
  CellTags->"b:0.0.0"],
Cell[7057, 229, 124, 2, 28, "Text",
  CellTags->"b:0.0.0"],
Cell[7184, 233, 736, 22, 95, "Input",
  CellTags->"b:0.0.0"],
Cell[7923, 257, 96, 2, 28, "Text",
  CellTags->"b:0.0.0"],
Cell[8022, 261, 225, 5, 63, "Input",
  CellTags->{"Do", "b:0.0.0"}]
}, Closed]],

Cell[CellGroupData[{
Cell[8284, 271, 131, 3, 53, "Subsection",
  CellTags->{"b:0.0.1", "c:4"}],
Cell[8418, 276, 223, 6, 58, "Text",
  CellTags->"b:0.0.1"],
Cell[8644, 284, 896, 29, 95, "Input",
  CellTags->"b:0.0.1"],
Cell[9543, 315, 212, 6, 58, "Text",
  CellTags->"b:0.0.1"],
Cell[9758, 323, 170, 4, 47, "Input",
  CellTags->"b:0.0.1"],
Cell[9931, 329, 211, 6, 28, "Text",
  CellTags->"b:0.0.1"],
Cell[10145, 337, 97, 3, 47, "Input",
  CellTags->"b:0.0.1"],
Cell[10245, 342, 247, 7, 58, "Text",
  CellTags->"b:0.0.1"],
Cell[10495, 351, 553, 12, 95, "Input",
  CellTags->"b:0.0.1"],
Cell[11051, 365, 87, 2, 28, "Text",
  CellTags->"b:0.0.1"],
Cell[11141, 369, 324, 9, 95, "Input",
  CellTags->"b:0.0.1"],
Cell[11468, 380, 335, 8, 88, "Text",
  CellTags->"b:0.0.1"],
Cell[11806, 390, 92, 2, 47, "Input",
  CellTags->"b:0.0.1"],
Cell[11901, 394, 203, 4, 47, "Input",
  CellTags->"b:0.0.1"],
Cell[12107, 400, 163, 5, 28, "Text",
  CellTags->"b:0.0.1"],
Cell[12273, 407, 1892, 66, 95, "Input",
  CellTags->"b:0.0.1"],
Cell[14168, 475, 111, 2, 28, "Text",
  CellTags->"b:0.0.1"],
Cell[14282, 479, 96, 3, 63, "Input",
  CellTags->"b:0.0.1"],
Cell[14381, 484, 101, 2, 28, "Text",
  CellTags->"b:0.0.1"],
Cell[14485, 488, 71, 2, 47, "Input",
  CellTags->"b:0.0.1"]
}, Closed]],

Cell[CellGroupData[{
Cell[14593, 495, 120, 3, 53, "Subsection",
  CellTags->{"b:0.0.2", "c:5"}],
Cell[14716, 500, 220, 6, 58, "Text",
  CellTags->"b:0.0.1"],
Cell[14939, 508, 354, 12, 47, "Input",
  CellTags->"b:0.0.2"],
Cell[15296, 522, 96, 2, 28, "Text",
  CellTags->"b:0.0.2"],
Cell[15395, 526, 202, 7, 47, "Input",
  CellTags->"b:0.0.2"],
Cell[15600, 535, 372, 13, 47, "Input",
  CellTags->"b:0.0.2"],
Cell[15975, 550, 270, 9, 28, "Text",
  CellTags->"b:0.0.2"],
Cell[16248, 561, 417, 14, 47, "Input",
  CellTags->"b:0.0.2"],
Cell[16668, 577, 138, 4, 28, "Text",
  CellTags->"b:0.0.2"],
Cell[16809, 583, 502, 14, 79, "Input",
  CellTags->{"Do", "b:0.0.2"}]
}, Closed]],

Cell[CellGroupData[{
Cell[17348, 602, 130, 3, 53, "Subsection",
  CellTags->{"b:0.0.3", "c:6"}],
Cell[17481, 607, 399, 11, 178, "Text",
  CellTags->"b:0.0.3"],
Cell[17883, 620, 306, 8, 118, "Text",
  CellTags->"b:0.0.3"],
Cell[18192, 630, 138, 3, 26, "Text",
  CellTags->"b:0.0.3"],
Cell[18333, 635, 307, 8, 47, "Input",
  CellTags->"b:0.0.3"],
Cell[18643, 645, 174, 4, 26, "Text",
  CellTags->"b:0.0.3"],
Cell[18820, 651, 174, 4, 63, "Input",
  CellTags->"b:0.0.3"],
Cell[18997, 657, 261, 6, 79, "Input",
  CellTags->"b:0.0.3"],
Cell[19261, 665, 102, 3, 47, "Input",
  CellTags->"b:0.0.3"],
Cell[19366, 670, 280, 8, 28, "Text",
  CellTags->"b:0.0.3"],
Cell[19649, 680, 190, 3, 47, "Input",
  CellTags->"b:0.0.3"],
Cell[19842, 685, 213, 6, 95, "Input",
  CellTags->"b:0.0.3"]
}, Closed]],

Cell[CellGroupData[{
Cell[20092, 696, 142, 3, 53, "Subsection",
  CellTags->{"b:0.0.4", "c:7"}],
Cell[20237, 701, 405, 11, 88, "Text",
  CellTags->"b:0.0.4"],
Cell[20645, 714, 162, 3, 63, "Input",
  CellTags->"b:0.0.4"],
Cell[20810, 719, 166, 3, 47, "Input",
  CellTags->"b:0.0.4"],
Cell[20979, 724, 163, 5, 28, "Text",
  CellTags->"b:0.0.4"],
Cell[21145, 731, 102, 2, 47, "Input",
  CellTags->"b:0.0.4"],
Cell[21250, 735, 158, 3, 47, "Input",
  CellTags->"b:0.0.4"],
Cell[21411, 740, 61, 2, 47, "Input",
  CellTags->"b:0.0.4"],
Cell[21475, 744, 228, 5, 95, "Input",
  CellTags->"b:0.0.4"],
Cell[21706, 751, 453, 13, 88, "Text",
  CellTags->"b:0.0.5"],
Cell[22162, 766, 91, 2, 47, "Input",
  CellTags->"b:0.0.5"],
Cell[22256, 770, 137, 4, 28, "Text",
  CellTags->"b:0.0.5"],
Cell[22396, 776, 45, 1, 47, "Input",
  CellTags->"b:0.0.5"],
Cell[22444, 779, 135, 4, 28, "Text",
  CellTags->"b:0.0.5"],
Cell[22582, 785, 137, 3, 47, "Input",
  CellTags->"b:0.0.5"],
Cell[22722, 790, 124, 5, 58, "Text",
  CellTags->"b:0.0.5"],
Cell[22849, 797, 1475, 27, 808, "Text",
  CellTags->"b:0.0.5"],
Cell[24327, 826, 5110, 143, 223, "Input",
  CellTags->"b:0.0.5"],
Cell[29440, 971, 153, 5, 40, "DisplayText",
  CellTags->"b:0.0.5"],
Cell[29596, 978, 184, 4, 47, "Input",
  CellTags->"b:0.0.5"],
Cell[29783, 984, 155, 5, 40, "DisplayText",
  CellTags->"b:0.0.5"],
Cell[29941, 991, 68, 2, 47, "Input",
  CellTags->"b:0.0.5"],
Cell[30012, 995, 44, 1, 47, "Input",
  CellTags->"b:0.0.5"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[30105, 1002, 109, 2, 42, "Section",
  CellTags->"c:8"],
Cell[30217, 1006, 118, 2, 28, "Text"],
Cell[30338, 1010, 93, 2, 47, "Input"],
Cell[30434, 1014, 86, 2, 47, "Input"],
Cell[30523, 1018, 197, 4, 28, "Text"],
Cell[30723, 1024, 45, 1, 47, "Input"],
Cell[30771, 1027, 158, 4, 63, "Input"],

Cell[CellGroupData[{
Cell[30954, 1035, 211, 6, 69, "Subsection",
  CellTags->{"b:1.0.0", "c:9"}],
Cell[31168, 1043, 270, 6, 28, "Text",
  CellTags->"b:1.0.0"],
Cell[31441, 1051, 72, 2, 47, "Input",
  CellTags->"b:1.0.0"],
Cell[31516, 1055, 925, 21, 127, "Input",
  CellTags->"b:1.0.0"],
Cell[32444, 1078, 250, 6, 28, "Text",
  CellTags->"b:1.0.0"],
Cell[32697, 1086, 131, 3, 63, "Input",
  CellTags->"b:1.0.0"],
Cell[32831, 1091, 215, 7, 28, "Text",
  CellTags->"b:1.0.0"],
Cell[33049, 1100, 464, 9, 95, "Input",
  CellTags->"b:1.0.0"],
Cell[33516, 1111, 125, 2, 28, "Text",
  CellTags->"b:1.0.0"],
Cell[33644, 1115, 160, 4, 63, "Input",
  CellTags->"b:1.0.0"],
Cell[33807, 1121, 103, 2, 28, "Text",
  CellTags->"b:1.0.0"],
Cell[33913, 1125, 251, 6, 47, "Input",
  CellTags->"b:0.0.0"]
}, Closed]],

Cell[CellGroupData[{
Cell[34201, 1136, 138, 3, 53, "Subsection",
  CellTags->{"b:1.0.1", "c:10"}],
Cell[34342, 1141, 311, 8, 88, "Text",
  CellTags->"b:1.0.1"],
Cell[34656, 1151, 211, 5, 47, "Input",
  CellTags->"b:1.0.1"]
}, Closed]],

Cell[CellGroupData[{
Cell[34904, 1161, 147, 3, 53, "Subsection",
  CellTags->{"b:1.0.2", "c:11"}],
Cell[35054, 1166, 163, 5, 28, "Text",
  CellTags->"b:1.0.2"],
Cell[35220, 1173, 545, 18, 63, "Input",
  CellTags->"b:1.0.2"],
Cell[35768, 1193, 187, 6, 58, "Text",
  CellTags->"b:1.0.2"],
Cell[35958, 1201, 137, 3, 63, "Input",
  CellTags->"b:1.0.2"]
}, Closed]],

Cell[CellGroupData[{
Cell[36132, 1209, 144, 3, 53, "Subsection",
  CellTags->{"b:1.0.3", "c:12"}],
Cell[36279, 1214, 190, 5, 28, "Text",
  CellTags->"b:1.0.3"],
Cell[36472, 1221, 1258, 29, 47, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[37767, 1255, 273, 8, 53, "Subsection",
  CellTags->{"b:1.0.4", "c:13"}],
Cell[38043, 1265, 294, 7, 58, "Text",
  CellTags->"b:1.0.4"],
Cell[38340, 1274, 209, 5, 47, "Input",
  CellTags->"b:1.0.4"],
Cell[38552, 1281, 161, 5, 28, "Text",
  CellTags->"b:1.0.4"],
Cell[38716, 1288, 342, 6, 111, "Input",
  CellTags->"b:1.0.4"],
Cell[39061, 1296, 196, 7, 28, "Text",
  CellTags->"b:1.0.4"],
Cell[39260, 1305, 89, 2, 47, "Input",
  CellTags->"b:1.0.4"]
}, Closed]],

Cell[CellGroupData[{
Cell[39386, 1312, 334, 9, 53, "Subsection",
  CellTags->{"b:1.0.5", "c:14"}],
Cell[39723, 1323, 159, 5, 28, "Text",
  CellTags->"b:1.0.5"],
Cell[39885, 1330, 514, 8, 143, "Input",
  CellTags->"b:1.0.5"],
Cell[40402, 1340, 137, 4, 28, "Text",
  CellTags->"b:1.0.5"],
Cell[40542, 1346, 169, 4, 63, "Input",
  CellTags->"b:1.0.5"]
}, Closed]],

Cell[CellGroupData[{
Cell[40748, 1355, 324, 9, 53, "Subsection",
  CellTags->{"b:1.0.6", "c:15"}],
Cell[41075, 1366, 140, 4, 28, "Text",
  CellTags->"b:1.0.6"],
Cell[41218, 1372, 1917, 65, 143, "Input",
  CellTags->"b:1.0.6"],
Cell[43138, 1439, 139, 4, 28, "Text",
  CellTags->"b:1.0.6"],
Cell[43280, 1445, 2043, 70, 143, "Input",
  CellTags->"b:1.0.6"],
Cell[45326, 1517, 184, 6, 47, "Input",
  CellTags->"b:1.0.6"]
}, Closed]],

Cell[CellGroupData[{
Cell[45547, 1528, 168, 5, 53, "Subsection",
  CellTags->{"b:1.0.7", "c:16"}],
Cell[45718, 1535, 744, 13, 127, "Input",
  CellTags->"b:1.0.7"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[46511, 1554, 112, 2, 42, "Section",
  CellTags->"c:17"],
Cell[46626, 1558, 118, 2, 28, "Text"],
Cell[46747, 1562, 93, 2, 47, "Input"],
Cell[46843, 1566, 86, 2, 47, "Input"],
Cell[46932, 1570, 197, 4, 28, "Text"],
Cell[47132, 1576, 47, 1, 47, "Input"],
Cell[47182, 1579, 158, 4, 63, "Input"],

Cell[CellGroupData[{
Cell[47365, 1587, 167, 5, 69, "Subsection",
  CellTags->{"b:2.0.0", "c:18"}],
Cell[47535, 1594, 217, 6, 58, "Text",
  CellTags->"b:2.0.0"],
Cell[47755, 1602, 1005, 22, 111, "Input",
  CellTags->"b:2.0.0"],
Cell[48763, 1626, 111, 2, 28, "Text",
  CellTags->"b:2.0.0"],
Cell[48877, 1630, 132, 3, 63, "Input",
  CellTags->"b:2.0.0"],
Cell[49012, 1635, 86, 2, 28, "Text",
  CellTags->"b:2.0.0"],
Cell[49101, 1639, 86, 2, 47, "Input",
  CellTags->"b:2.0.0"],
Cell[49190, 1643, 257, 7, 58, "Text",
  CellTags->"b:2.0.0"],
Cell[49450, 1652, 656, 12, 111, "Input",
  CellTags->"b:2.0.0"],
Cell[50109, 1666, 120, 2, 28, "Text",
  CellTags->"b:2.0.0"],
Cell[50232, 1670, 245, 6, 79, "Input",
  CellTags->"b:2.0.0"],
Cell[50480, 1678, 103, 2, 28, "Text",
  CellTags->"b:1.0.0"],
Cell[50586, 1682, 251, 6, 47, "Input",
  CellTags->"b:0.0.0"]
}, Closed]],

Cell[CellGroupData[{
Cell[50874, 1693, 138, 3, 53, "Subsection",
  CellTags->{"b:2.0.1", "c:19"}],
Cell[51015, 1698, 139, 4, 28, "Text",
  CellTags->"b:2.0.1"],
Cell[51157, 1704, 262, 5, 63, "Input",
  CellTags->"b:2.0.1"],
Cell[51422, 1711, 94, 2, 28, "Text",
  CellTags->"b:2.0.1"],
Cell[51519, 1715, 471, 9, 95, "Input",
  CellTags->"b:2.0.1"],
Cell[51993, 1726, 73, 2, 47, "Input",
  CellTags->"b:2.0.1"]
}, Closed]],

Cell[CellGroupData[{
Cell[52103, 1733, 147, 3, 53, "Subsection",
  CellTags->{"b:2.0.2", "c:20"}],
Cell[52253, 1738, 163, 5, 28, "Text",
  CellTags->"b:2.0.2"],
Cell[52419, 1745, 278, 7, 47, "Input",
  CellTags->"b:2.0.2"],
Cell[52700, 1754, 176, 5, 58, "Text",
  CellTags->"b:2.0.2"],
Cell[52879, 1761, 151, 3, 63, "Input",
  CellTags->"b:2.0.2"]
}, Closed]],

Cell[CellGroupData[{
Cell[53067, 1769, 148, 3, 53, "Subsection",
  CellTags->{"b:2.0.3", "c:21"}],
Cell[53218, 1774, 173, 6, 58, "Text",
  CellTags->"b:2.0.3"],
Cell[53394, 1782, 484, 8, 143, "Input",
  CellTags->"b:2.0.3"],
Cell[53881, 1792, 135, 4, 28, "Text",
  CellTags->"b:2.0.3"],
Cell[54019, 1798, 484, 8, 47, "Input",
  CellTags->"b:2.0.3"]
}, Closed]],

Cell[CellGroupData[{
Cell[54540, 1811, 273, 8, 53, "Subsection",
  CellTags->{"b:2.0.4", "c:22"}],
Cell[54816, 1821, 297, 8, 88, "Text",
  CellTags->"b:2.0.4"],
Cell[55116, 1831, 59, 1, 47, "Input"],
Cell[55178, 1834, 228, 5, 47, "Input",
  CellTags->"b:2.0.4"],
Cell[55409, 1841, 191, 3, 63, "Input"],
Cell[55603, 1846, 206, 7, 28, "Text",
  CellTags->"b:2.0.4"],
Cell[55812, 1855, 73, 2, 47, "Input",
  CellTags->"b:2.0.4"]
}, Closed]],

Cell[CellGroupData[{
Cell[55922, 1862, 334, 9, 53, "Subsection",
  CellTags->{"b:2.0.5", "c:23"}],
Cell[56259, 1873, 159, 5, 28, "Text",
  CellTags->"b:2.0.5"],
Cell[56421, 1880, 748, 12, 191, "Input",
  CellTags->"b:2.0.5"],
Cell[57172, 1894, 139, 4, 28, "Text",
  CellTags->"b:2.0.5"],
Cell[57314, 1900, 172, 4, 63, "Input",
  CellTags->"b:2.0.5"]
}, Closed]],

Cell[CellGroupData[{
Cell[57523, 1909, 319, 9, 53, "Subsection",
  CellTags->{"b:2.0.6", "c:24"}],
Cell[57845, 1920, 160, 5, 28, "Text",
  CellTags->"b:2.0.6"],
Cell[58008, 1927, 82, 2, 47, "Input",
  CellTags->"b:2.0.6"],
Cell[58093, 1931, 60, 2, 47, "Input",
  CellTags->"b:2.0.6"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[58202, 1939, 98, 2, 42, "Section",
  CellTags->"c:25"],
Cell[58303, 1943, 134, 4, 28, "Text"],
Cell[58440, 1949, 93, 2, 47, "Input"],
Cell[58536, 1953, 86, 2, 47, "Input"],
Cell[58625, 1957, 74, 2, 47, "Input"],
Cell[58702, 1961, 154, 4, 63, "Input"],
Cell[58859, 1967, 191, 5, 58, "Text"],
Cell[59053, 1974, 47, 1, 47, "Input"],

Cell[CellGroupData[{
Cell[59125, 1979, 294, 8, 69, "Subsection",
  CellTags->{"b:6.0.0", "c:26"}],
Cell[59422, 1989, 366, 8, 58, "Text",
  CellTags->"b:6.0.0"],
Cell[59791, 1999, 192, 5, 28, "Text",
  CellTags->"b:6.0.0"],
Cell[59986, 2006, 85, 2, 47, "Input",
  CellTags->"b:6.0.0"],
Cell[60074, 2010, 247, 6, 47, "Input",
  CellTags->"b:6.0.0"],
Cell[60324, 2018, 116, 2, 28, "Text",
  CellTags->"b:6.0.0"],
Cell[60443, 2022, 387, 8, 111, "Input",
  CellTags->"b:6.0.0"],
Cell[60833, 2032, 115, 2, 28, "Text",
  CellTags->"b:6.0.0"],
Cell[60951, 2036, 728, 18, 63, "Input",
  CellTags->"b:6.0.0"],
Cell[61682, 2056, 97, 2, 28, "Text",
  CellTags->"b:6.0.0"],
Cell[61782, 2060, 280, 5, 95, "Input",
  CellTags->"b:6.0.0"],
Cell[62065, 2067, 82, 2, 28, "Text",
  CellTags->"b:6.0.0"],
Cell[62150, 2071, 278, 6, 63, "Input",
  CellTags->{"Do", "b:6.0.0"}]
}, Closed]],

Cell[CellGroupData[{
Cell[62465, 2082, 292, 8, 53, "Subsection",
  CellTags->{"b:6.0.1", "c:27"}],
Cell[62760, 2092, 363, 10, 26, "Text",
  CellTags->"b:6.0.1"],
Cell[63126, 2104, 288, 9, 47, "Input",
  CellTags->"b:6.0.1"],
Cell[63417, 2115, 95, 2, 28, "Text",
  CellTags->"b:6.0.1"],
Cell[63515, 2119, 173, 5, 63, "Input",
  CellTags->"b:6.0.1"],
Cell[63691, 2126, 182, 4, 47, "Input",
  CellTags->"b:6.0.1"],
Cell[63876, 2132, 366, 7, 44, "Text",
  CellTags->"b:6.0.1"],
Cell[64245, 2141, 221, 6, 47, "Input",
  CellTags->"b:6.0.1"],
Cell[64469, 2149, 88, 2, 28, "Text",
  CellTags->"b:6.0.1"],
Cell[64560, 2153, 67, 2, 47, "Input",
  CellTags->"b:6.0.1"],
Cell[64630, 2157, 255, 7, 118, "Text",
  CellTags->"b:6.0.1"],
Cell[64888, 2166, 4921, 164, 287, "Input",
  CellTags->"b:6.0.1"]
}, Closed]],

Cell[CellGroupData[{
Cell[69846, 2335, 276, 8, 53, "Subsection",
  CellTags->{"b:6.0.2", "c:28"}],
Cell[70125, 2345, 614, 20, 26, "Text",
  CellTags->"b:6.0.2"],
Cell[70742, 2367, 470, 17, 47, "Input",
  CellTags->"b:6.0.2"],
Cell[71215, 2386, 227, 5, 26, "Text",
  CellTags->"b:6.0.2"],
Cell[71445, 2393, 202, 7, 47, "Input",
  CellTags->"b:6.0.2"],
Cell[71650, 2402, 224, 5, 26, "Text",
  CellTags->"b:6.0.2"],
Cell[71877, 2409, 611, 21, 63, "Input",
  CellTags->"b:6.0.2"],
Cell[72491, 2432, 857, 23, 79, "Input",
  CellTags->{"Do", "b:6.0.2"}]
}, Closed]],

Cell[CellGroupData[{
Cell[73385, 2460, 340, 9, 53, "Subsection",
  CellTags->{"b:6.0.3", "c:29"}],
Cell[73728, 2471, 136, 4, 28, "Text",
  CellTags->"b:6.0.3"],
Cell[73867, 2477, 135, 3, 47, "Input",
  CellTags->"b:6.0.3"],
Cell[74005, 2482, 160, 5, 28, "Text",
  CellTags->"b:6.0.3"],
Cell[74168, 2489, 244, 5, 79, "Input",
  CellTags->"b:6.0.3"],
Cell[74415, 2496, 297, 6, 79, "Input",
  CellTags->"b:6.0.3"],
Cell[74715, 2504, 102, 3, 47, "Input",
  CellTags->"b:6.0.3"],
Cell[74820, 2509, 147, 4, 28, "Text",
  CellTags->"b:6.0.3"],
Cell[74970, 2515, 287, 5, 47, "Input",
  CellTags->"b:6.0.3"],
Cell[75260, 2522, 138, 4, 28, "Text",
  CellTags->"b:6.0.3"],
Cell[75401, 2528, 230, 6, 47, "Input",
  CellTags->"b:6.0.3"],
Cell[75634, 2536, 156, 5, 58, "Text",
  CellTags->"b:6.0.3"],
Cell[75793, 2543, 333, 7, 127, "Input",
  CellTags->"b:6.0.3"]
}, Closed]],

Cell[CellGroupData[{
Cell[76163, 2555, 300, 8, 53, "Subsection",
  CellTags->{"b:6.0.4", "c:30"}],
Cell[76466, 2565, 190, 6, 58, "Text",
  CellTags->"b:6.0.4"],
Cell[76659, 2573, 149, 3, 63, "Input",
  CellTags->"b:6.0.4"],
Cell[76811, 2578, 206, 5, 58, "Text",
  CellTags->"b:6.0.4"],
Cell[77020, 2585, 182, 3, 47, "Input",
  CellTags->"b:6.0.4"],
Cell[77205, 2590, 2971, 87, 159, "Input",
  CellTags->"b:6.0.4"],
Cell[80179, 2679, 108, 2, 47, "Input",
  CellTags->"b:6.0.4"]
}, Closed]],

Cell[CellGroupData[{
Cell[80324, 2686, 323, 9, 53, "Subsection",
  CellTags->{"b:6.0.5", "c:31"}],
Cell[80650, 2697, 90, 2, 47, "Input",
  CellTags->"b:6.0.5"],
Cell[80743, 2701, 60, 2, 47, "Input",
  CellTags->"b:6.0.5"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[80852, 2709, 140, 4, 42, "Section",
  CellTags->"c:32"],
Cell[80995, 2715, 118, 2, 28, "Text"],
Cell[81116, 2719, 93, 2, 47, "Input"],
Cell[81212, 2723, 86, 2, 47, "Input"],
Cell[81301, 2727, 197, 4, 28, "Text"],
Cell[81501, 2733, 45, 1, 47, "Input"],

Cell[CellGroupData[{
Cell[81571, 2738, 188, 6, 69, "Subsection",
  CellTags->{"b:7.0.0", "c:33"}],
Cell[81762, 2746, 84, 4, 62, "Input",
  CellTags->"b:7.0.0"],
Cell[81849, 2752, 221, 6, 58, "Text",
  CellTags->"b:7.0.0"],
Cell[82073, 2760, 70, 2, 47, "Input",
  CellTags->"b:7.0.0"],
Cell[82146, 2764, 167, 4, 63, "Input",
  CellTags->"b:7.0.0"],
Cell[82316, 2770, 199, 5, 58, "Text",
  CellTags->"b:7.0.0"],
Cell[82518, 2777, 326, 6, 95, "Input",
  CellTags->"b:7.0.0"],
Cell[82847, 2785, 357, 8, 79, "Input",
  CellTags->"b:7.0.0"],
Cell[83207, 2795, 120, 2, 28, "Text",
  CellTags->"b:7.0.0"],
Cell[83330, 2799, 93, 2, 47, "Input",
  CellTags->"b:7.0.0"]
}, Closed]],

Cell[CellGroupData[{
Cell[83460, 2806, 157, 4, 53, "Subsection",
  CellTags->{"b:7.0.1", "c:34"}],
Cell[83620, 2812, 187, 5, 28, "Text",
  CellTags->"b:7.0.1"],
Cell[83810, 2819, 362, 7, 79, "Input",
  CellTags->"b:7.0.1"]
}, Closed]],

Cell[CellGroupData[{
Cell[84209, 2831, 147, 3, 53, "Subsection",
  CellTags->{"b:7.0.2", "c:35"}],
Cell[84359, 2836, 158, 5, 28, "Text",
  CellTags->"b:7.0.2"],
Cell[84520, 2843, 228, 6, 47, "Input",
  CellTags->"b:7.0.2"],
Cell[84751, 2851, 176, 5, 58, "Text",
  CellTags->"b:7.0.2"],
Cell[84930, 2858, 145, 3, 63, "Input",
  CellTags->"b:7.0.2"]
}, Closed]],

Cell[CellGroupData[{
Cell[85112, 2866, 304, 8, 53, "Subsection",
  CellTags->{"b:7.0.3", "c:36"}],
Cell[85419, 2876, 184, 5, 58, "Text",
  CellTags->"b:7.0.3"],
Cell[85606, 2883, 95, 2, 47, "Input",
  CellTags->"b:7.0.3"],
Cell[85704, 2887, 119, 2, 28, "Text",
  CellTags->"b:7.0.3"],
Cell[85826, 2891, 1956, 66, 143, "Input",
  CellTags->"b:7.0.3"],
Cell[87785, 2959, 116, 2, 28, "Text",
  CellTags->"b:7.0.3"],
Cell[87904, 2963, 1999, 68, 143, "Input",
  CellTags->"b:7.0.3"]
}, Closed]],

Cell[CellGroupData[{
Cell[89940, 3036, 168, 5, 53, "Subsection",
  CellTags->{"b:7.0.4", "c:37"}],
Cell[90111, 3043, 579, 11, 111, "Input",
  CellTags->"b:7.0.4"],
Cell[90693, 3056, 60, 2, 47, "Input",
  CellTags->"b:7.0.4"]
}, Closed]]
}, Closed]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

