(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     96815,       3178]*)
(*NotebookOutlinePosition[    121029,       3838]*)
(*  CellTagsIndexPosition[    120046,       3799]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[{
  StyleBox["QDENSITY",
    FontSlant->"Italic"],
  "\nIntroductory Tutorial"
}], "Title",
  CellTags->"c:1"],

Cell["Basic tools in QDENSITY", "Subtitle"],

Cell["Last Version: 18-Aug-2005", "Abstract"],

Cell[TextData[ButtonBox["Click here to get the palette: QDENSpalette.nb",
  ButtonData:>{"QDENSpalette.nb", None},
  ButtonStyle->"Hyperlink"]], "Text"],

Cell[CellGroupData[{

Cell["Getting started", "Section",
  FontFamily->"Times",
  CellTags->{"b:14.0", "c:2"}],

Cell[TextData[{
  StyleBox["All the codes simulating quantum circuits will start by loading \
the ",
    FontFamily->"Helvetica"],
  "QDENSITY",
  StyleBox[" package.\nTo make the package fully available copy the QDENSITY \
directory to this location on \nyour user account:",
    FontFamily->"Helvetica"]
}], "Text",
  TextJustification->0,
  FontFamily->"Courier New",
  CellTags->"b:14.0"],

Cell[BoxData[
    \(ToFileName[\ {$UserBaseDirectory, \ "\<Applications\>"}]\)], "Input"],

Cell[TextData[StyleBox["Then you can load the package by using:",
  FontFamily->"Helvetica"]], "Text",
  TextJustification->0,
  FontFamily->"Courier New",
  CellTags->"b:14.0"],

Cell[BoxData[
    \(Needs["\<QDENSITY`Qdensity`\>"]\)], "Input",
  FontFamily->"Courier New"],

Cell[TextData[StyleBox["To see all the commands contained in the package:  ",
  FontFamily->"Helvetica"]], "Text",
  FontFamily->"Courier New",
  CellTags->"b:14.0"],

Cell[BoxData[
    \(\(?QDENSITY`Qdensity`*\)\)], "Input",
  FontFamily->"Courier New"],

Cell[TextData[StyleBox["If you click on any entry in the display above, \
information about it will appear above this line.",
  FontFamily->"Helvetica"]], "Text",
  FontFamily->"Courier New",
  CellTags->"b:14.0"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(?intro\)\)], "Input"],

Cell[BoxData[
    \(\(?about\)\)], "Input"]
}, Open  ]],

Cell[TextData[{
  StyleBox["You can access the package Palette by clicking here: ",
    FontFamily->"Helvetica"],
  ButtonBox["QDENSpalette.nb",
    ButtonData:>{"QDENSpalette.nb", None},
    ButtonStyle->"Hyperlink"]
}], "Text",
  FontFamily->"Courier New",
  CellTags->"b:14.0"]
}, Closed]],

Cell[CellGroupData[{

Cell["Basic operations", "Section",
  FontFamily->"Times",
  CellTags->{"b:14.1", "c:3"}],

Cell[CellGroupData[{

Cell["a) Single qubit states", "Subsection",
  CellFrame->True,
  FontFamily->"Times",
  CellTags->{"b:11.0.0", "SingleQubitStates", "c:4"}],

Cell[TextData[{
  StyleBox["The initial state of the system is represented by a density \
matrix. A ",
    FontFamily->"Helvetica"],
  StyleBox["one qubit state ",
    FontFamily->"Helvetica",
    FontWeight->"Bold"],
  StyleBox["in the |0\[RightAngleBracket] state has the density matrix:",
    FontFamily->"Helvetica"]
}], "Text",
  FontFamily->"Courier New",
  CellTags->"b:14.1"],

Cell[BoxData[
    \(\[ScriptCapitalP]\_0\)], "Input"],

Cell[TextData[StyleBox["This is also the single qubit  projection operator  \
|0\[RightAngleBracket]\[LeftAngleBracket]0| .",
  FontFamily->"Helvetica"]], "Text",
  FontFamily->"Courier New",
  CellTags->"b:14.1"],

Cell[TextData[StyleBox[" ... in the |1\[RightAngleBracket] state...",
  FontFamily->"Helvetica"]], "Text",
  FontFamily->"Courier New",
  CellTags->"b:14.1"],

Cell[BoxData[
    \(\[ScriptCapitalP]\_1\)], "Input"],

Cell[TextData[StyleBox["This is also the single qubit  projection operator  \
|1\[RightAngleBracket]\[LeftAngleBracket]1| .",
  FontFamily->"Helvetica"]], "Text",
  FontFamily->"Courier New",
  CellTags->"b:14.1"],

Cell[TextData[StyleBox[" Alternatively we can define the states and \
associated density matrix making use of predefined Ket and Bra state vectors",
  
  FontFamily->"Helvetica"]], "Text",
  FontFamily->"Courier New",
  CellTags->"b:14.1"],

Cell[BoxData[
    \(Ket[0]\)], "Input"],

Cell[BoxData[
    \(Bra[1]\)], "Input"],

Cell[TextData[{
  StyleBox[" And so, one can build ",
    FontFamily->"Helvetica"],
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalP]\_0\)]],
  StyleBox["using the ",
    FontFamily->"Helvetica"],
  StyleBox["tensor product",
    FontFamily->"Helvetica",
    FontWeight->"Bold"],
  StyleBox[" \[CircleTimes]",
    FontFamily->"Helvetica"]
}], "Text",
  FontFamily->"Courier New",
  CellTags->"b:14.1"],

Cell[BoxData[
    \(Ket[0]\[CircleTimes]Bra[0]\)], "Input"],

Cell[TextData[StyleBox[" A more general 1 qubit state written using Ket, ",
  FontFamily->"Helvetica"]], "Text",
  FontFamily->"Courier New",
  CellTags->"b:14.1"],

Cell[BoxData[{
    \(GenQubit = a*Ket[0] + b*Ket[1]\), "\[IndentingNewLine]", 
    \(\[Rho]GenQubit = 
      GenQubit\[CircleTimes]Adj[
            GenQubit]\  /. {Conjugate[a] \[Rule] \(a\^*\), 
          Conjugate[b] \[Rule] \(b\^*\)}\)}], "Input"],

Cell[TextData[{
  StyleBox["And we can evaluate the ",
    FontFamily->"Helvetica"],
  StyleBox[" trace and purity  ",
    FontFamily->"Helvetica",
    FontWeight->"Bold"],
  StyleBox["of the above density matrix.",
    FontFamily->"Helvetica"]
}], "Text",
  FontFamily->"Courier New",
  CellTags->"b:14.1"],

Cell[BoxData[{
    \(Tr[\[Rho]GenQubit]\), "\[IndentingNewLine]", 
    \(Simplify[Purity[\[Rho]GenQubit]]\)}], "Input"],

Cell[TextData[{
  StyleBox["The package contains also definitions for ",
    FontFamily->"Helvetica"],
  StyleBox["|+\[RightAngleBracket] and |-\[RightAngleBracket] states, ",
    FontFamily->"Helvetica",
    FontWeight->"Bold"],
  StyleBox["i.e for states in the plus or minus x-direction",
    FontFamily->"Helvetica",
    FontVariations->{"CompatibilityType"->0}],
  StyleBox[" :",
    FontFamily->"Helvetica",
    FontWeight->"Bold"]
}], "Text",
  FontFamily->"Courier New",
  CellTags->"b:14.1"],

Cell[BoxData[{
    \(KetX[0]\), "\[IndentingNewLine]", 
    \(KetX[1]\)}], "Input"],

Cell[TextData[{
  StyleBox["One can readily check that the above states are eigenstates of ",
    FontFamily->"Helvetica"],
  Cell[BoxData[
      \(TraditionalForm\`\[Sigma]\_\(\(1\)\(\ \)\)\)]],
  "with eigenvalues 1 and -1 , respectively:"
}], "Text",
  FontFamily->"Courier New",
  CellTags->"b:14.1"],

Cell[BoxData[{
    \(\[Sigma]\_1 . KetX[0]\  == \ KetX[0]\), "\[IndentingNewLine]", 
    \(\[Sigma]\_1 . KetX[1]\  == \(-KetX[1]\)\)}], "Input"],

Cell[TextData[{
  StyleBox["Scalar products",
    FontFamily->"Helvetica",
    FontWeight->"Bold"],
  StyleBox[" are simple to compute; for instance, if we have a general state \
in the computational basis, we can compute its scalar product with the |+\
\[RightAngleBracket] or |-\[RightAngleBracket] operators (KetX[0] and \
KetX[1]):",
    FontFamily->"Helvetica"]
}], "Text",
  FontFamily->"Courier New",
  CellTags->"b:14.1"],

Cell[BoxData[
    \(State1 = a*Bra[0] + b*Bra[1]\)], "Input"],

Cell[BoxData[{
    \(State1 . KetX[0]\), "\[IndentingNewLine]", 
    \(State1 . KetX[1]\)}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["b) MultiQubit states", "Subsection",
  CellFrame->True,
  FontFamily->"Times",
  CellTags->{"b:11.0.0", "c:5"}],

Cell[TextData[{
  StyleBox[" Multiqubit states are built as tensor products of single qubit \
ones, for instance, a",
    FontFamily->"Helvetica"],
  StyleBox[" two qubit",
    FontFamily->"Helvetica",
    FontWeight->"Bold"],
  StyleBox[" state as |00\[RightAngleBracket] or |01\[RightAngleBracket] \
corresponds to:",
    FontFamily->"Helvetica"]
}], "Text",
  FontFamily->"Courier New",
  CellTags->"b:14.1"],

Cell[BoxData[{
    \(\((\[ScriptCapitalP]\_0\[CircleTimes]\[ScriptCapitalP]\_0)\)\), "\
\[IndentingNewLine]", 
    \(\((\[ScriptCapitalP]\_0\[CircleTimes]\[ScriptCapitalP]\_1)\)\)}], \
"Input"],

Cell[TextData[{
  StyleBox[" The use of the parentheses in the tensor product is essential \
when considering more than two qubits; for instance, the ",
    FontFamily->"Helvetica"],
  StyleBox["three qubit ",
    FontFamily->"Helvetica",
    FontWeight->"Bold"],
  StyleBox["state |011\[RightAngleBracket] corresponds to any of the two \
following forms,",
    FontFamily->"Helvetica"]
}], "Text",
  FontFamily->"Courier New",
  CellTags->"b:14.1"],

Cell[BoxData[{
    RowBox[{"(", 
      StyleBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              SubscriptBox["\[ScriptCapitalP]", 
                StyleBox["0",
                  ScriptLevel->0]], "\[CircleTimes]", 
              SubscriptBox["\[ScriptCapitalP]", 
                StyleBox["1",
                  ScriptLevel->0]]}], ")"}], "\[CircleTimes]", 
          SubscriptBox["\[ScriptCapitalP]", 
            StyleBox["1",
              ScriptLevel->0]]}],
        ScriptLevel->0], 
      StyleBox[")",
        ScriptLevel->0]}], "\[IndentingNewLine]", 
    StyleBox[
      RowBox[{"(", 
        RowBox[{
          SubscriptBox["\[ScriptCapitalP]", 
            StyleBox["0",
              ScriptLevel->0]], "\[CircleTimes]", 
          RowBox[{"(", 
            RowBox[{
              SubscriptBox["\[ScriptCapitalP]", 
                StyleBox["1",
                  ScriptLevel->0]], "\[CircleTimes]", 
              SubscriptBox["\[ScriptCapitalP]", 
                StyleBox["1",
                  ScriptLevel->0]]}], ")"}]}], ")"}],
      ScriptLevel->0]}], "Input"],

Cell[TextData[StyleBox["Using the BraKet notation we could build a three \
qubit state such as, [NOTE KetX[0] and KetX[1] are the eigenstates of SigmaX, \
the parentheses are again essential]",
  FontFamily->"Helvetica"]], "Text",
  FontFamily->"Courier New",
  CellTags->"b:14.1"],

Cell[BoxData[
    \(ket123\  = \ 
      Ket[0]\[CircleTimes]\((Ket[1]\[CircleTimes]KetX[1])\)\)], "Input"],

Cell[TextData[StyleBox["... and build its back to back density matrix out of \
it, ",
  FontFamily->"Helvetica"]], "Text",
  FontFamily->"Courier New",
  CellTags->"b:14.1"],

Cell[BoxData[
    \(\[Rho]123 = ket123\[CircleTimes]Adj[ket123]\)], "Input"],

Cell[TextData[{
  StyleBox["Then check its ",
    FontFamily->"Helvetica"],
  StyleBox["Trace and Purity",
    FontFamily->"Helvetica",
    FontWeight->"Bold"]
}], "Text",
  FontFamily->"Courier New",
  CellTags->"b:14.1"],

Cell[BoxData[{
    \(Tr[\[Rho]123]\), "\[IndentingNewLine]", 
    \(Purity[\[Rho]123]\)}], "Input"],

Cell[TextData[StyleBox["For states in the computational bases we can use \
alternatively the function KetV[List] and BraV[List]:",
  FontFamily->"Helvetica"]], "Text",
  FontFamily->"Courier New",
  CellTags->"b:14.1"],

Cell[BoxData[
    \(KetV[{0, 1, 1}]\)], "Input"],

Cell[BoxData[
    \(4*BraV[{0, 1, 1, 0, 1}]\  + \ BraV[{1, 1, 1, 0, 1}] + 
      A*BraV[{0, 0, 0, 1, 1}]\)], "Input"],

Cell[TextData[StyleBox["For example, the following expressions give the same \
output: ",
  FontFamily->"Helvetica"]], "Text",
  FontFamily->"Courier New",
  CellTags->"b:14.1"],

Cell[BoxData[{
    \(KetV[{0}] \[Equal] Ket[0]\), "\[IndentingNewLine]", 
    \(KetV[{0, 1}] \[Equal] 
      Ket[0]\[CircleTimes]Ket[1]\), "\[IndentingNewLine]", 
    \(KetV[{0, a, 
          b}] \[Equal] \((Ket[0]\[CircleTimes]Ket[a])\)\[CircleTimes]Ket[
          b]\)}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["c) Bell and GHZ states", "Subsection",
  CellFrame->True,
  FontFamily->"Times",
  CellTags->{"b:11.0.0", "c:6"}],

Cell[TextData[StyleBox[" Relevant two and three qubit states are the Bell \
states and the GHZ state. ",
  FontFamily->"Helvetica"]], "Text",
  FontFamily->"Courier New",
  CellTags->"b:14.1"],

Cell[TextData[{
  StyleBox["The ",
    FontFamily->"Helvetica"],
  StyleBox["Bell states",
    FontFamily->"Helvetica",
    FontWeight->"Bold"],
  StyleBox[" are the following:\n",
    FontFamily->"Helvetica"],
  Cell[BoxData[
      \(TraditionalForm\`B\_00 = \ 1/\@2\)]],
  "( |00\[RightAngleBracket] + |11\[RightAngleBracket] )\n",
  Cell[BoxData[
      \(TraditionalForm\`B\_01 = \ 1/\@2\)]],
  "( |01\[RightAngleBracket] + |10\[RightAngleBracket] )\n",
  Cell[BoxData[
      \(TraditionalForm\`B\_10 = \ 1/\@2\)]],
  "( |00\[RightAngleBracket] - |11\[RightAngleBracket] )\n",
  Cell[BoxData[
      \(TraditionalForm\`B\_11 = \ 1/\@2\)]],
  "( |01\[RightAngleBracket] - |10\[RightAngleBracket] )"
}], "Text",
  FontFamily->"Courier New",
  CellTags->"b:14.1"],

Cell[TextData[StyleBox["They can all be constructed in the following way, \
first we build a Bell operator of the form:",
  FontFamily->"Helvetica"]], "Text",
  FontFamily->"Courier New",
  CellTags->"b:14.1"],

Cell[BoxData[
    \(\(\(\ \)\(Bellop = \(\(CNOT[2, 1, 2] . 
        had[2, 1]\)\(\ \)\)\)\)\)], "Input"],

Cell[TextData[StyleBox["Then we build:",
  FontFamily->"Helvetica"]], "Text",
  FontFamily->"Courier New",
  CellTags->"b:14.1"],

Cell[BoxData[
    RowBox[{" ", 
      RowBox[{\(B\_\(a_, b_\)\), ":=", 
        RowBox[{"Bellop", ".", 
          RowBox[{"(", 
            StyleBox[
              RowBox[{
                SubscriptBox["\[ScriptCapitalP]", 
                  StyleBox["a",
                    ScriptLevel->0]], "\[CircleTimes]", 
                SubscriptBox["\[ScriptCapitalP]", 
                  StyleBox["b",
                    ScriptLevel->0]]}],
              ScriptLevel->0], 
            StyleBox[")",
              ScriptLevel->0]}], ".", 
          StyleBox[\(Adj[Bellop]\),
            ScriptLevel->0], " "}]}]}]], "Input"],

Cell[TextData[{
  StyleBox["These states are of capital importance in quantum circuits. Check \
for instance the Teleportation circuit; click here: ",
    FontFamily->"Helvetica"],
  ButtonBox["Teleportation.nb",
    ButtonData:>{"Teleportation.nb", None},
    ButtonStyle->"Hyperlink"]
}], "Text",
  FontFamily->"Courier New",
  CellTags->"b:14.1"],

Cell[TextData[{
  StyleBox["The ",
    FontFamily->"Helvetica"],
  StyleBox["GHZ state",
    FontFamily->"Helvetica",
    FontWeight->"Bold"],
  StyleBox[" may be prepared by acting on a state with three qubits all  \
initialized to 0 with the following operator:",
    FontFamily->"Helvetica"]
}], "Text",
  FontFamily->"Courier New",
  CellTags->"b:14.1"],

Cell[BoxData[
    \(\(GHZop = CNOT[3, 1, 3] . CNOT[3, 1, 2] . had[3, 1];\)\)], "Input",
  CellTags->"b:14.1"],

Cell[TextData[StyleBox["Then the density matrix for this GHZ state  is:",
  FontFamily->"Helvetica"]], "Text",
  FontFamily->"Courier New",
  CellTags->"b:14.1"],

Cell[BoxData[
    RowBox[{"\[Rho]GHZ", "=", 
      RowBox[{"GHZop", ".", 
        RowBox[{"(", 
          StyleBox[
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  SubscriptBox["\[ScriptCapitalP]", 
                    StyleBox["0",
                      ScriptLevel->0]], "\[CircleTimes]", 
                  SubscriptBox["\[ScriptCapitalP]", 
                    StyleBox["0",
                      ScriptLevel->0]]}], ")"}], "\[CircleTimes]", 
              SubscriptBox["\[ScriptCapitalP]", 
                StyleBox["0",
                  ScriptLevel->0]]}],
            ScriptLevel->0], 
          StyleBox[")",
            ScriptLevel->0]}], 
        StyleBox[".",
          ScriptLevel->0], 
        StyleBox[\(Adj[GHZop]\),
          ScriptLevel->0]}]}]], "Input"],

Cell[TextData[StyleBox["Which is mathematically equivalent to building the \
state and then its density matrix  as:",
  FontFamily->"Helvetica"]], "Text",
  FontFamily->"Courier New",
  CellTags->"b:14.1"],

Cell[BoxData[{
    RowBox[{
      RowBox[{"GHZvec", "=", 
        RowBox[{\(1/\@2\), 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"(", 
                
                StyleBox[\(\((Ket[0]\[CircleTimes]Ket[0])\)\[CircleTimes]Ket[
                      0]\),
                  ScriptLevel->0], 
                StyleBox[")",
                  ScriptLevel->0]}], 
              StyleBox[" ",
                ScriptLevel->0], 
              StyleBox["+",
                ScriptLevel->0], 
              StyleBox[" ",
                ScriptLevel->0], 
              RowBox[{"(", 
                
                StyleBox[\(\((Ket[1]\[CircleTimes]Ket[1])\)\[CircleTimes]Ket[
                      1]\),
                  ScriptLevel->0], 
                StyleBox[")",
                  ScriptLevel->0]}]}], 
            StyleBox[")",
              ScriptLevel->0]}]}]}], 
      StyleBox[";",
        ScriptLevel->0]}], "\[IndentingNewLine]", 
    StyleBox[\(\[Rho]GHZvec = GHZvec\[CircleTimes]Adj[GHZvec]\),
      ScriptLevel->0]}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["d) Subsystems, partial traces", "Subsection",
  CellFrame->True,
  FontFamily->"Times",
  CellTags->{"b:11.0.0", "c:7"}],

Cell[TextData[{
  StyleBox[" The density matrix of a specific subsystem can be computed \
easily by taking partial traces of the density matrix of the full system, \
e.g. we will build the ",
    FontFamily->"Helvetica"],
  StyleBox["4 qubit state ",
    FontFamily->"Helvetica",
    FontWeight->"Bold"],
  StyleBox["|0111\[RightAngleBracket] and then recover the state of either \
the subsystem (1) or the subsystems (24).  For example, starting with a four \
qubit state |0111\[RightAngleBracket], its density matrix is constructed and \
then partial traces taken:",
    FontFamily->"Helvetica"]
}], "Text",
  FontFamily->"Courier New",
  CellTags->"b:14.1"],

Cell[BoxData[{
    RowBox[{\(\[Rho]\_1234\), "=", 
      RowBox[{"(", 
        StyleBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"(", 
                  RowBox[{
                    SubscriptBox["\[ScriptCapitalP]", 
                      StyleBox["0",
                        ScriptLevel->0]], "\[CircleTimes]", 
                    SubscriptBox["\[ScriptCapitalP]", 
                      StyleBox["1",
                        ScriptLevel->0]]}], ")"}], "\[CircleTimes]", 
                SubscriptBox["\[ScriptCapitalP]", 
                  StyleBox["1",
                    ScriptLevel->0]]}], ")"}], "\[CircleTimes]", 
            SubscriptBox["\[ScriptCapitalP]", 
              StyleBox["1",
                ScriptLevel->0]]}],
          ScriptLevel->0], 
        StyleBox[")",
          ScriptLevel->0]}]}], "\[IndentingNewLine]", 
    RowBox[{
      SubscriptBox[
        StyleBox["\[Rho]",
          ScriptLevel->0], "1"], 
      "=", \(PTr[{2, 3, 
          4}, \[Rho]\_1234]\)}], "\[IndentingNewLine]", \(\[Rho]\_24 = 
      PTr[{1, 3}, \[Rho]\_1234]\)}], "Input"],

Cell[TextData[{
  StyleBox[" We can check basic properties of these density matrices, such as \
their ",
    FontFamily->"Helvetica"],
  StyleBox["length, trace ",
    FontFamily->"Helvetica",
    FontWeight->"Bold"],
  StyleBox["and ",
    FontFamily->"Helvetica"],
  StyleBox["Purity:",
    FontFamily->"Helvetica",
    FontWeight->"Bold"]
}], "Text",
  FontFamily->"Courier New",
  CellTags->"b:14.1"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(Length[\[Rho]\_1234]\), "\[IndentingNewLine]", 
    \(Tr[\[Rho]\_1234]\), "\[IndentingNewLine]", 
    \(Purity[\[Rho]\_1234]\), "\[IndentingNewLine]", 
    \(Length[\[Rho]\_24]\), "\[IndentingNewLine]", 
    \(Tr[\[Rho]\_24]\)}], "Input",
  CellTags->"b:14.1"],

Cell[TextData[StyleBox[" Similarly we can produce a more complicated density \
matrix that is not pure,",
  FontFamily->"Helvetica"]], "Text",
  FontFamily->"Courier New",
  CellTags->"b:14.1"],

Cell[BoxData[
    RowBox[{"a123", "=", 
      RowBox[{\(1/3\), "*", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"(", 
              StyleBox[
                RowBox[{
                  RowBox[{"(", 
                    RowBox[{
                      SubscriptBox["\[ScriptCapitalP]", 
                        StyleBox["0",
                          ScriptLevel->0]], "\[CircleTimes]", 
                      SubscriptBox["\[ScriptCapitalP]", 
                        StyleBox["1",
                          ScriptLevel->0]]}], ")"}], "\[CircleTimes]", 
                  SubscriptBox["\[ScriptCapitalP]", 
                    StyleBox["1",
                      ScriptLevel->0]]}],
                ScriptLevel->0], 
              StyleBox[")",
                ScriptLevel->0]}], 
            StyleBox["+",
              ScriptLevel->0], 
            RowBox[{"(", 
              StyleBox[
                RowBox[{
                  RowBox[{"(", 
                    RowBox[{\(\[ScriptCapitalP]\_1\), "\[CircleTimes]", 
                      SubscriptBox["\[ScriptCapitalP]", 
                        StyleBox["1",
                          ScriptLevel->0]]}], ")"}], "\[CircleTimes]", 
                  SubscriptBox["\[ScriptCapitalP]", 
                    StyleBox["1",
                      ScriptLevel->0]]}],
                ScriptLevel->0], 
              StyleBox[")",
                ScriptLevel->0]}], 
            StyleBox["+",
              ScriptLevel->0], 
            RowBox[{"(", 
              StyleBox[
                RowBox[{
                  RowBox[{"(", 
                    RowBox[{
                      SubscriptBox["\[ScriptCapitalP]", 
                        StyleBox["0",
                          ScriptLevel->0]], 
                      "\[CircleTimes]", \(\[ScriptCapitalP]\_0\)}], ")"}], 
                  "\[CircleTimes]", 
                  SubscriptBox["\[ScriptCapitalP]", 
                    StyleBox["1",
                      ScriptLevel->0]]}],
                ScriptLevel->0], 
              StyleBox[")",
                ScriptLevel->0]}]}], 
          StyleBox[")",
            ScriptLevel->0]}]}]}]], "Input"],

Cell[BoxData[{
    \(Tr[a123]\), "\[IndentingNewLine]", 
    \(Purity[a123]\)}], "Input"]
}, Closed]],

Cell[TextData[StyleBox["It is interesting to show the density matrix for each \
qubit taking partial traces. These subspace density matrices can be thought \
of  as the density matrices of qubit i in the environment of the remaining 2 \
qubits:",
  FontFamily->"Helvetica"]], "Text",
  FontFamily->"Courier New",
  CellTags->"b:14.1"],

Cell[BoxData[
    \(PTr[{2, 3}, a123]\)], "Input"],

Cell[BoxData[
    \(PTr[{1, 3}, a123]\)], "Input"],

Cell[BoxData[
    \(PTr[{1, 2}, a123]\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["e) Pauli Spin matrices", "Subsection",
  CellFrame->True,
  FontFamily->"Times",
  CellTags->{"b:11.0.0", "c:8"}],

Cell[TextData[{
  StyleBox[" The ",
    FontFamily->"Helvetica"],
  StyleBox["Pa",
    FontFamily->"Helvetica",
    FontWeight->"Bold"],
  StyleBox["uli spin matrices ",
    FontFamily->"Helvetica",
    FontWeight->"Bold"],
  StyleBox["are defined in the package and are easily used, ",
    FontFamily->"Helvetica"]
}], "Text",
  FontFamily->"Courier New",
  CellTags->"b:14.1"],

Cell[BoxData[{
    \(\[Sigma]\_0\), "\[IndentingNewLine]", 
    \(\[Sigma]\_1\), "\[IndentingNewLine]", 
    \(\[Sigma]\_2\), "\[IndentingNewLine]", 
    \(\[Sigma]\_3\)}], "Input",
  CellTags->"b:14.1"],

Cell[TextData[StyleBox["or alternatively with the notation:",
  FontFamily->"Helvetica"]], "Text",
  FontFamily->"Courier New",
  CellTags->"b:14.1"],

Cell[BoxData[{
    \(s[0]\), "\[IndentingNewLine]", 
    \(s[1]\), "\[IndentingNewLine]", 
    \(s[2]\), "\[IndentingNewLine]", 
    \(s[3]\)}], "Input",
  CellTags->"b:14.1"],

Cell[TextData[{
  StyleBox[" ",
    FontFamily->"Helvetica"],
  StyleBox["Pauli spin matrices ",
    FontFamily->"Helvetica",
    FontWeight->"Bold"],
  StyleBox["can be used to build the more general 2 and n qubit desnity \
matrices, e.g. for a ",
    FontFamily->"Helvetica"],
  StyleBox["general 2 qubit state",
    FontFamily->"Helvetica",
    FontWeight->"Bold"],
  StyleBox[" the density matrix",
    FontFamily->"Helvetica",
    FontVariations->{"CompatibilityType"->0}],
  StyleBox[" is:",
    FontFamily->"Helvetica"]
}], "Text",
  FontFamily->"Courier New",
  CellTags->"b:14.1"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(\ \)\(\(\[Rho]AB\  = \ 
        Sum[\((1/4)\)*
              P[i, j]\ *\((\ \[Sigma]\_i\[CircleTimes]\ \[Sigma]\_j)\), {i, 
              0, 3}, {j, 0, 3}]\  /. {P[0, 0] \[Rule] 1, 
            P[1, 0] \[Rule] P\_x\%A\ , P[2, 0] \[Rule] P\_y\%A, 
            P[3, 0] \[Rule] P\_z\%A, P[0, \ 1] \[Rule] P\_x\%B\ , 
            P[0, \ 2] \[Rule] P\_y\%B, 
            P[0, \ 3] \[Rule] P\_z\%B};\)\[IndentingNewLine]
    \((1/4)\)*Simplify[MatrixForm[\ 4*\[Rho]AB]]\[IndentingNewLine]
    Tr[\ \[Rho]AB]\)\)\)], "Input",
  CellTags->"b:14.1"],

Cell[TextData[{
  StyleBox[" ",
    FontFamily->"Helvetica"],
  StyleBox["The above",
    FontFamily->"Helvetica",
    FontWeight->"Bold"],
  StyleBox[" density matrix",
    FontFamily->"Helvetica",
    FontVariations->{"CompatibilityType"->0}],
  StyleBox[" is of the form ",
    FontFamily->"Helvetica"],
  " \[Rho]AB",
  StyleBox["= ",
    FontFamily->"Helvetica"],
  Cell[BoxData[
      \(TraditionalForm\`\(\(1\/4\)\(\ \ \)\([\)\(1\  + \ 
          P\&\[RightVector]\_\(\(A\)\(\ \)\)\)\)\)]],
  ".",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(\[Sigma]\&\[RightVector]\_\(\(A\)\(\ \)\)\ \
\  + \ P\&\[RightVector]\_\(\(B\)\(\ \)\)\)\)\)]],
  ".",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[Sigma]\&\[RightVector]\_B\)\(\ \)\)\)]],
  " + ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[Sigma]\&\[LongRightArrow]\_\(\(A\)\(\ \)\)\)\(\
\ \)\)\)]],
  ". ",
  Cell[BoxData[
      \(TraditionalForm\`T\&\[LongLeftRightArrow]\)]],
  " . ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[Sigma]\&\[LongLeftArrow]\_\(\(A\)\(\ \)\)\)\(\ \
\)\)\)]],
  "]",
  StyleBox[" as discussed in the text.",
    FontFamily->"Helvetica"]
}], "Text",
  FontFamily->"Courier New",
  CellTags->"b:14.1"]
}, Closed]],

Cell[TextData[{
  StyleBox["Sometimes we need a ",
    FontFamily->"Helvetica"],
  StyleBox["random one qubit density matrix",
    FontFamily->"Helvetica",
    FontWeight->"Bold"],
  StyleBox[" or a ",
    FontFamily->"Helvetica"],
  StyleBox["random 2 qubit density matrix",
    FontFamily->"Helvetica",
    FontWeight->"Bold"],
  StyleBox[". Now the states are not pure states and thus the Purity is lower \
than one. The procedure used to build the random 2 qubit state can be easily \
generalized to the nqubit case.",
    FontFamily->"Helvetica"]
}], "Text",
  FontFamily->"Courier New",
  CellTags->"b:14.1"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(\ \)\(\[Rho]\_one = RandomQubit1\[IndentingNewLine]
    Tr[\[Rho]\_one]\[IndentingNewLine]
    Chop[Purity[\[Rho]\_one]]\)\)\)], "Input",
  CellTags->"b:14.1"],

Cell[BoxData[{
    \(\[Rho]\_two = RandomQubit2\), "\[IndentingNewLine]", 
    \(Tr[\[Rho]\_two]\), "\[IndentingNewLine]", 
    \(Chop[Purity[\[Rho]\_two]]\)}], "Input",
  CellTags->"b:14.1"]
}, Closed]],

Cell[TextData[StyleBox["Now the subsystems are also not pure states, for \
instance, the subsystem corresponding to qubit number 2 of the two qubits \
density matrix is obtained by performing the partial trace of qubit 1,",
  FontFamily->"Helvetica"]], "Text",
  FontFamily->"Courier New",
  CellTags->"b:14.1"],

Cell[BoxData[
    \(\[Rho]\_\(2, two\) = Chop[PTr[{1}, \[Rho]\_two]]\)], "Input",
  CellTags->"b:14.1"],

Cell[TextData[StyleBox["Analogous functions for one qubit Ket and Bra exist:",
  
  FontFamily->"Helvetica"]], "Text",
  FontFamily->"Courier New",
  CellTags->"b:14.1"],

Cell[BoxData[{
    \(RandomKet1\), "\[IndentingNewLine]", 
    \(RandomBra1\)}], "Input"],

Cell[TextData[{
  StyleBox["Mathematica",
    FontFamily->"Helvetica",
    FontSlant->"Italic"],
  StyleBox[" contains convenient functions for dealing with matrices such as \
",
    FontFamily->"Helvetica"],
  StyleBox["MatrixExp",
    FontFamily->"Helvetica",
    FontWeight->"Bold"],
  StyleBox[" and ",
    FontFamily->"Helvetica"],
  StyleBox["MatrixPower",
    FontFamily->"Helvetica",
    FontWeight->"Bold"],
  StyleBox[". They allow one to easily construct ",
    FontFamily->"Helvetica"],
  StyleBox["Rotations ",
    FontFamily->"Helvetica",
    FontWeight->"Bold"],
  StyleBox["and other operations:  \nThe equality ",
    FontFamily->"Helvetica"],
  Cell[BoxData[
      \(TraditionalForm\`e\^\(i\ \[Alpha]\ \ \[Sigma]\_i\)\)]],
  "= Cos \[Alpha]  ",
  Cell[BoxData[
      \(TraditionalForm\`\[Sigma]\_0\)]],
  " + i Sin \[Alpha] ",
  Cell[BoxData[
      \(TraditionalForm\`\[Sigma]\_i\)]],
  "  ",
  StyleBox["can be demonstrated by comparing",
    FontFamily->"Helvetica"]
}], "Text",
  FontFamily->"Courier New",
  CellTags->"b:14.1"],

Cell[BoxData[
    \(\(\(\ \)\(ComplexExpand[
      MatrixExp[i\ \[Alpha]\ \[Sigma]\_1]]\)\)\)], "Input"],

Cell["to:", "Text",
  FontFamily->"Courier New",
  CellTags->"b:14.1"],

Cell[BoxData[
    \(TrigExpand[\((Cos[\[Alpha]]\ \[Sigma]\_0 + \ 
          i\ Sin[\[Alpha]]\ \[Sigma]\_1)\)]\)], "Input"],

Cell[BoxData[
    \(MatrixExp[\(-\[ImaginaryI]\)*\[Theta]*\[Sigma]\_3/2]\)], "Input"],

Cell[BoxData[
    \(MatrixPower[\[Sigma]\_3, 3]\)], "Input"],

Cell[TextData[{
  StyleBox["It allows us to check the formula ",
    FontFamily->"Helvetica"],
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox[\(\((\[Sigma] . P)\)\^2\),
            "TraditionalForm"], "=", \(P\^2\)}], TraditionalForm]]]
}], "Text",
  FontFamily->"Courier New",
  CellTags->"b:14.1"],

Cell[BoxData[
    \(Simplify[
      MatrixPower[a*\[Sigma]\_1 + b*\[Sigma]\_2 + c*\[Sigma]\_3, 
        2]]\)], "Input"],

Cell[BoxData[
    \(Simplify[
      MatrixPower[a*\[Sigma]\_1 + b*\[Sigma]\_2 + c*\[Sigma]\_3, 
        2]]\)], "Input"],

Cell[TextData[StyleBox["The rotation of a qubit state is given later",
  FontFamily->"Helvetica"]], "Text",
  FontFamily->"Courier New",
  CellTags->"b:14.1"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Quantum Gates", "Section",
  FontFamily->"Times",
  CellTags->{"Quantum Gates", "c:9"}],

Cell[TextData[StyleBox["In the density matrix language any operator [O] \
acting on the density matrix of the system \[Rho] acts producing:",
  FontFamily->"Helvetica"]], "Text",
  TextAlignment->Left,
  FontFamily->"Courier New"],

Cell[TextData[{
  StyleBox["\[Rho]' = ",
    FontFamily->"Helvetica",
    FontSize->14,
    FontWeight->"Bold"],
  Cell[BoxData[
      \(TraditionalForm\`O . \[Rho] . O\^\[Dagger]\)],
    FontWeight->"Bold"]
}], "Text",
  TextAlignment->-0.5,
  FontFamily->"Courier New"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["a) Single qubit operations: Hadmards and rotations",
  FontWeight->"Bold"]], "Subsection",
  CellFrame->True,
  FontFamily->"Times",
  CellTags->{"b:14.2.0", "c:10"}],

Cell[TextData[{
  StyleBox["The ",
    FontFamily->"Helvetica"],
  StyleBox["Hadamard operator",
    FontFamily->"Helvetica",
    FontWeight->"Bold"],
  StyleBox[" for one qubit is defined as \nHad |0\[RightAngleBracket] = (|0\
\[RightAngleBracket] + |1\[RightAngleBracket])/ ",
    FontFamily->"Helvetica"],
  Cell[BoxData[
      \(TraditionalForm\`\@2\)]],
  "  and Had |1\[RightAngleBracket] = ",
  StyleBox[" (|0\[RightAngleBracket] - |1\[RightAngleBracket])/ ",
    FontFamily->"Helvetica"],
  Cell[BoxData[
      \(TraditionalForm\`\@2\)]],
  StyleBox[", \nthis is equivalent to Had = (",
    FontFamily->"Helvetica"],
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          StyleBox["\[Sigma]",
            FontFamily->"Helvetica"], "1"], TraditionalForm]]],
  StyleBox[" + ",
    FontFamily->"Helvetica"],
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          StyleBox["\[Sigma]",
            FontFamily->"Helvetica"], "3"], TraditionalForm]]],
  StyleBox["\[RightAngleBracket]/ ",
    FontFamily->"Helvetica"],
  Cell[BoxData[
      \(TraditionalForm\`\@2\)]],
  StyleBox["\nTo Hadamard qubit one in a one qubit system use:",
    FontFamily->"Helvetica"]
}], "Text",
  FontFamily->"Courier New",
  CellTags->"b:14.2.0"],

Cell[CellGroupData[{

Cell[BoxData[
    \(HA\  = \ had[1, 1]\)], "Input",
  CellTags->"b:14.2.0"],

Cell[TextData[StyleBox["or the script form:",
  FontFamily->"Helvetica"]], "Text",
  FontFamily->"Courier New",
  CellTags->"b:14.1"],

Cell[BoxData[
    \(\[ScriptCapitalH]\)], "Input",
  CellTags->"b:14.2.0"],

Cell[TextData[StyleBox["If we have 3 qubits and want to Hadamard the second \
one,",
  FontFamily->"Helvetica"]], "Text",
  FontFamily->"Courier New",
  CellTags->"b:14.2.0"],

Cell[CellGroupData[{

Cell[BoxData[
    \(HAD32 = had[3, 2]\)], "Input",
  CellTags->"b:14.2.0"],

Cell[TextData[StyleBox["which  is equivalent to",
  FontFamily->"Helvetica"]], "Text",
  FontFamily->"Courier New",
  CellTags->"b:14.2.0"],

Cell[BoxData[
    \(\((\[DoubleStruckCapitalI]\ \[CircleTimes]\ \[ScriptCapitalH])\)\
\[CircleTimes]\[DoubleStruckCapitalI]\)], "Input"]
}, Closed]]
}, Closed]],

Cell[TextData[StyleBox["If we want to apply Hadamards as above to an initial \
system of |000\[RightAngleBracket],  we construct the initial density matrix \
and transform to the new desnity matrix, also we check the subsystems 2 and 1 \
to verify that it is only qubit 2 that has been subjected to a Hadamard:",
  FontFamily->"Helvetica"]], "Text",
  FontFamily->"Courier New",
  CellTags->"b:14.2.0"],

Cell[BoxData[{
    \(\(\[Rho]000 = \((\((\[ScriptCapitalP]\_0\[CircleTimes]\[ScriptCapitalP]\
\_0)\)\[CircleTimes]\[ScriptCapitalP]\_0)\);\)\ \), "\[IndentingNewLine]", 
    \(\[Rho]FINAL = \(\(\(HAD32\  . \ \[Rho]000\)\  . \ 
        Adj[HAD32]\)\(\ \)\)\), "\[IndentingNewLine]", 
    \(PTr[{1, 3}, \[Rho]FINAL]\), "\[IndentingNewLine]", 
    \(PTr[{2, 3}, \[Rho]FINAL]\)}], "Input",
  CellTags->"b:14.2.0"],

Cell[TextData[{
  StyleBox["Sometimes we need a ",
    FontFamily->"Helvetica"],
  StyleBox["Hadamard on every one of the qubits;",
    FontFamily->"Helvetica",
    FontWeight->"Bold"],
  StyleBox[" in that case you may use the command ",
    FontFamily->"Helvetica"],
  StyleBox["HALL",
    FontFamily->"Helvetica",
    FontWeight->"Bold"],
  StyleBox[":",
    FontFamily->"Helvetica"]
}], "Text",
  FontFamily->"Courier New",
  CellTags->"b:14.2.0"],

Cell[BoxData[
    \(HALL[3] . \[Rho]000\  . Adj[HALL[3]]\)], "Input",
  CellTags->{"i:2", "b:14.2.0"}],

Cell[TextData[StyleBox["The action of a Hadamard on state vectors is  also \
simple to evaluatel, ",
  FontFamily->"Helvetica"]], "Text",
  FontFamily->"Courier New",
  CellTags->"b:14.2.0"],

Cell[BoxData[{
    \(had[1, 1] . Ket[0]\), "\[IndentingNewLine]", 
    \(had[1, 1] . KetX[0]\), "\[IndentingNewLine]", 
    \(had[1, 1] . Ket[1]\)}], "Input"],

Cell[TextData[StyleBox["A rotation around the y axis of an angle \[Theta] \
applied to a state |0\[RightAngleBracket] can be generated by the user as:",
  FontFamily->"Helvetica"]], "Text",
  FontFamily->"Courier New",
  CellTags->"b:14.2.0"],

Cell[BoxData[{
    \(Roty\  = 
      MatrixExp[\(-\ \[ImaginaryI]\)*\ 
          s[2]*\[Theta]/2]\), "\[IndentingNewLine]", 
    \(TrigReduce[
      ComplexExpand[
        Roty\ \  . \ \[ScriptCapitalP]\_0 . \ Adj[Roty\ ]]]\)}], "Input",
  CellTags->"b:14.2.0"],

Cell[TextData[{
  StyleBox["and we see that Roty on state | 0 \[RightAngleBracket] gives us \
Cos ",
    FontFamily->"Helvetica"],
  Cell[BoxData[
      \(\[Theta]\/2\)]],
  StyleBox["  | 0\[RightAngleBracket] + Sin ",
    FontFamily->"Helvetica"],
  Cell[BoxData[
      \(\[Theta]\/2\)]],
  StyleBox["  | 1\[RightAngleBracket];   for ",
    FontFamily->"Helvetica"],
  Cell[BoxData[
      \(\[Theta]\  = \ Pi/2\)]],
  StyleBox["  gives ",
    FontFamily->"Helvetica"],
  Cell[BoxData[
      \(TraditionalForm\`\((1/\@2\)\)]],
  StyleBox[") ( | 0\[VeryThinSpace]\[RightAngleBracket] + | 1 \
\[RightAngleBracket])= |+\[RightAngleBracket].",
    FontFamily->"Helvetica"]
}], "Text",
  FontFamily->"Courier New",
  CellTags->"b:14.2.0"],

Cell[BoxData[
    \(Roty . \ Ket[0]\)], "Input"],

Cell[TextData[{
  StyleBox["or the user can use the ",
    FontFamily->"Helvetica"],
  "QDENSITY",
  StyleBox[" command RotY[ ",
    FontFamily->"Helvetica"],
  "\[Theta]",
  StyleBox[" ]",
    FontFamily->"Helvetica"]
}], "Text",
  FontFamily->"Courier New",
  CellTags->"b:14.2.0"],

Cell[BoxData[{
    \(RotY[\[Theta]]\), "\[IndentingNewLine]", 
    \(RotY[Pi/2] . \ Ket[0]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["b) Two Qubit operations: CNOT gate",
  FontWeight->"Bold"]], "Subsection",
  CellFrame->True,
  FontFamily->"Times",
  CellTags->{"i:1", "b:14.2.1", "c:11"}],

Cell[TextData[{
  StyleBox["Two and in general n-qubit gates can be constructed. Among them \
the CNOT gate plays a very important role. A ",
    FontFamily->"Helvetica"],
  StyleBox["CNOT gate ( |a\[RightAngleBracket]|b\[RightAngleBracket]  -> |a\
\[RightAngleBracket]|(a ",
    FontFamily->"Helvetica",
    FontWeight->"Bold"],
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[CirclePlus]\)\(\ \)\)\)]],
  StyleBox["b) mod 2\[RightAngleBracket]) operating with qubit 1 as control \
and qubit 2 as target in a circuit with only two qubits",
    FontFamily->"Helvetica",
    FontWeight->"Bold"],
  StyleBox[" can be constructed as: ",
    FontFamily->"Helvetica"]
}], "Text",
  FontFamily->"Courier New",
  CellTags->"b:14.2.1"],

Cell[BoxData[
    \(CNOT[2, 1, 2]\)], "Input",
  CellTags->"b:14.2.1"],

Cell[TextData[{
  StyleBox["If we apply the ",
    FontFamily->"Helvetica"],
  StyleBox["CNOT",
    FontFamily->"Helvetica",
    FontWeight->"Bold"],
  StyleBox[" to an initial density matrix  |10\[RightAngleBracket]\
\[LeftAngleBracket]10|, we write, ",
    FontFamily->"Helvetica"]
}], "Text",
  FontFamily->"Courier New",
  CellTags->"b:14.2.1"],

Cell[BoxData[
    \(CNOT[2, 1, 
        2]\  . \ \((\[ScriptCapitalP]\_1\[CircleTimes]\[ScriptCapitalP]\_0)\) \
. Adj[CNOT[2, 1, 2]]\)], "Input",
  CellTags->"b:14.2.1"],

Cell[TextData[StyleBox["which trivially  is seen to be equal to the density \
matrix for |11\[RightAngleBracket]\[LeftAngleBracket]11|",
  FontFamily->"Helvetica"]], "Text",
  FontFamily->"Courier New",
  CellTags->"b:14.2.1"],

Cell[BoxData[
    \(\((\[ScriptCapitalP]\_1\[CircleTimes]\[ScriptCapitalP]\_1)\)\)], "Input",\

  CellTags->"b:14.2.1"],

Cell[TextData[{
  StyleBox["A ",
    FontFamily->"Helvetica"],
  StyleBox["more general case",
    FontFamily->"Helvetica",
    FontWeight->"Bold"],
  StyleBox[" would be to have a CNOT gate with control in qubit 3 and target \
in qubit 5 in a circuit with 6 qubits:",
    FontFamily->"Helvetica"]
}], "Text",
  FontFamily->"Courier New",
  CellTags->"b:14.2.1"],

Cell[BoxData[
    \(\(CNOT[6, 3, 5];\)\)], "Input",
  CellTags->"b:14.2.1"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["c) Two Qubit operations (CPHASE)",
  FontWeight->"Bold"]], "Subsection",
  CellFrame->True,
  FontFamily->"Times",
  CellTags->{"i:1", "b:14.2.1", "c:12"}],

Cell[TextData[StyleBox["The Cphase operation, used mainly in the cluster \
model approach, is defined by:",
  FontFamily->"Helvetica"]], "Text",
  FontFamily->"Courier New",
  CellTags->"b:14.2.1"],

Cell[TextData[StyleBox["CPHASE | a b \[RightAngleBracket] = (-1)^(ab)  | a b \
\[RightAngleBracket]",
  FontFamily->"Helvetica",
  FontWeight->"Bold"]], "Text",
  TextAlignment->-0.5,
  FontFamily->"Courier New",
  CellTags->"b:14.2.1"],

Cell[TextData[StyleBox[" Its syntax is is similar to a CNOT gate, but in this \
case the order of the control and target qubits is not relevant. \nTherefore, \
CPHASE[L,q1,q2], performs a CPHASE gate on qubits q1 and q2 on a system of L \
qubits.",
  FontFamily->"Helvetica"]], "Text",
  FontFamily->"Courier New",
  CellTags->"b:14.2.1"],

Cell[BoxData[{
    \(CPHASE[2, 1, 2]\), "\[IndentingNewLine]", 
    \(CPHASE[2, 2, 1]\)}], "Input"],

Cell[TextData[{
  StyleBox["In a multiquibit environment: of say three qubits, a ",
    FontFamily->"Helvetica"],
  StyleBox["CPHASE",
    FontFamily->"Helvetica",
    FontWeight->"Bold"],
  StyleBox[" between qubits 1 and 2 is:",
    FontFamily->"Helvetica"]
}], "Text",
  FontFamily->"Courier New",
  CellTags->"b:14.2.1"],

Cell[BoxData[
    \(CPHASE[3, 2, 1]\)], "Input"],

Cell[TextData[StyleBox["A different version of the same gate  is defined by \
CPHASEV[ i,  j,  a ]  and is used to get the CPHASE action on qubits i and j \
of a  state vector a.",
  FontFamily->"Helvetica"]], "Text",
  FontFamily->"Courier New",
  CellTags->"b:14.2.1"],

Cell[TextData[StyleBox["For instance, if we apply CPHASE to the two qubit \
vector:",
  FontFamily->"Helvetica"]], "Text",
  FontFamily->"Courier New",
  CellTags->"b:14.2.1"],

Cell[TextData[StyleBox["CPHASE[ 2, 1, 2]   [  a | 0 0 \[RightAngleBracket]+  \
b | 0 1 \[RightAngleBracket] +  c | 1 0 \[RightAngleBracket] + d | 1 1 \
\[RightAngleBracket] ]  =   a | 0 0\[RightAngleBracket]+ b | 0 1\
\[RightAngleBracket]+ c | 1 0\[RightAngleBracket]  -  d | 1 1\
\[RightAngleBracket]",
  FontFamily->"Helvetica",
  FontWeight->"Bold"]], "Text",
  TextAlignment->-0.5,
  FontFamily->"Courier New",
  CellTags->"b:14.2.1"],

Cell[TextData[StyleBox["Which corresponds to the followng command:",
  FontFamily->"Helvetica"]], "Text",
  FontFamily->"Courier New",
  CellTags->"b:14.2.1"],

Cell[BoxData[
    \(CPHASEV[1, 2, {a, b, c, d}]\)], "Input"],

Cell[TextData[StyleBox["Thus CPHASEV[  i  , j , a]  gives the result of  a \
CPHASE acting on qubits i and j for a state vector with expansion \
coefficients a:{a,b,c.....}.  The length of the array gives the total number \
of qubits.",
  FontFamily->"Helvetica"]], "Text",
  FontFamily->"Courier New",
  CellTags->"b:14.2.1"],

Cell[BoxData[
    \(CPHASEV[1, 3, {a, b, c, d, e, f, g, h}]\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["d) Two Qubit operations, TwoOp",
  FontWeight->"Bold"]], "Subsection",
  CellFrame->True,
  FontFamily->"Times",
  CellTags->{"i:1", "b:14.2.1", "c:13"}],

Cell[TextData[StyleBox["General Two Qubit operations are build using TwoOp. \
Its syntax is is very simple and allows one to build any two qubit operation \
embedded in an L qubit system. ",
  FontFamily->"Helvetica"]], "Text",
  FontFamily->"Courier New",
  CellTags->"b:14.2.1"],

Cell[TextData[{
  StyleBox["The TwoOp function should be called with the following arguments: \
\nL: total number of qubits, ",
    FontFamily->"Helvetica"],
  Cell[BoxData[
      \(TraditionalForm\`q\_1\)]],
  "and ",
  Cell[BoxData[
      \(TraditionalForm\`q\_2\)]],
  ", ",
  StyleBox["qubits involved in the operation, ",
    FontFamily->"Helvetica"],
  Cell[BoxData[
      \(TraditionalForm\`\(op\_1\) and\ op\_2\)]],
  " ",
  StyleBox["are the Pauli \noperators ",
    FontFamily->"Helvetica"],
  Cell[BoxData[
      \(TraditionalForm\`\((\[Sigma]\_\(op\_1\), \[Sigma]\_\(op\_2\))\)\)]],
  " ",
  StyleBox["performed on",
    FontFamily->"Helvetica"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`q\_1\)]],
  "and ",
  Cell[BoxData[
      \(TraditionalForm\`q\_2\)]],
  ".\n",
  StyleBox["Thus for a three qubit system with  ",
    FontFamily->"Helvetica"],
  Cell[BoxData[
      \(\[Sigma]\_0\ \ acting\ on\ qubit\ 1\ \ and\)],
    FontFamily->"Helvetica"],
  StyleBox[" ",
    FontFamily->"Helvetica"],
  Cell[BoxData[
      \(\[Sigma]\_1\ \ acting\ on\ qubit\ 2, \ the\ operator\ is\)],
    FontFamily->"Helvetica"],
  StyleBox[" ",
    FontFamily->"Helvetica"]
}], "Text",
  FontFamily->"Courier New",
  CellTags->"b:14.2.1"],

Cell[BoxData[
    \(TwoOp[3, 1, 2, 0, 1]\)], "Input"],

Cell[TextData[{
  StyleBox["For example, the CNOT and CPHASE gates between any two qubits in \
a total of L qubits have been coded using this function.\nA ThreeOp[ L,  i,  \
j, k, ",
    FontFamily->"Helvetica"],
  Cell[BoxData[
      \(TraditionalForm\`op\_1\)],
    FontFamily->"Helvetica"],
  StyleBox[" ",
    FontFamily->"Helvetica"],
  Cell[BoxData[
      \(TraditionalForm\`op\_2\)],
    FontFamily->"Helvetica"],
  StyleBox[" ",
    FontFamily->"Helvetica"],
  Cell[BoxData[
      \(TraditionalForm\`op\_3\)],
    FontFamily->"Helvetica"],
  StyleBox["] is also provided by ",
    FontFamily->"Helvetica"],
  "QDENSITY",
  StyleBox[", which also serves as a building block for higher order \
operators.",
    FontFamily->"Helvetica"]
}], "Text",
  FontFamily->"Courier New",
  CellTags->"b:14.2.1"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Measurements", "Section",
  FontFamily->"Times",
  CellTags->{"b:14.3", "Measurement", "c:14"}],

Cell[TextData[StyleBox["A projective measurement on our system corresponds to \
a projection of the density matrix of the full system into the unmeasured \
subsytem.",
  FontFamily->"Helvetica"]], "Text",
  FontFamily->"Courier New",
  CellTags->"b:14.3"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["a) Measuring  in the computational bases with density \
matrix",
  FontWeight->"Bold"]], "Subsection",
  CellFrame->True,
  FontFamily->"Times",
  CellTags->{"b:14.2.0", "Measurements", "c:15"}],

Cell[TextData[{
  StyleBox["Let us assume we have a four qubit system initially in the | 0 0 \
0 0 \[RightAngleBracket] state, we build  its density matrix ",
    FontFamily->"Helvetica"],
  "\[Rho]4",
  StyleBox["  after a chain of Hadamard and CNOT gates act as,",
    FontFamily->"Helvetica"]
}], "Text",
  FontFamily->"Courier New",
  CellTags->"b:14.3"],

Cell[BoxData[{
    \(\(Ope = 
        CNOT[4, 1, 2] . had[4, 2] . CNOT[4, 3, 4] . had[4, 1] . 
          CNOT[4, 1, 4] . had[4, 3];\)\), "\[IndentingNewLine]", 
    \(\[Rho]4 = 
      Ope . \((\((\((\[ScriptCapitalP]\_0\ \ \[CircleTimes]\ \ \
\[ScriptCapitalP]\_0)\)\ \[CircleTimes]\[ScriptCapitalP]\_0)\)\ \
\[CircleTimes]\ \ \[ScriptCapitalP]\_0)\) . Adj[Ope]\)}], "Input",
  CellTags->"b:14.3"],

Cell[TextData[StyleBox["We can then measure for instance qubits 1 and 3 \
simultaneously, the projection operator would be:",
  FontFamily->"Helvetica"]], "Text",
  FontFamily->"Courier New",
  CellTags->"b:14.3"],

Cell[BoxData[
    \(P\_\(a_, b_\)\ \  := \ \((\((\ \((\[ScriptCapitalP]\_a\ \ \
\[CircleTimes]\ \ \
\[DoubleStruckCapitalI])\)\[CircleTimes]\[ScriptCapitalP]\_b)\)\[CircleTimes]\
\ \[DoubleStruckCapitalI])\)\)], "Input",
  CellTags->"b:14.3"],

Cell[TextData[StyleBox["And therefore the state of the remaining subsystem, \
which depends on the values measured, after the measurement reads, ",
  FontFamily->"Helvetica"]], "Text",
  FontFamily->"Courier New",
  CellTags->"b:14.3"],

Cell[BoxData[
    \(\(\[Rho]24[a_, b_] := 
        Chop[\ PTr[{1, 3}\ \ , 
            2^2*P\_\(a, b\) . \[Rho]4 . P\_\(a, b\)\ ]];\)\)], "Input",
  CellTags->"b:14.3"],

Cell[TextData[StyleBox["If the result of the measurement was (01) then we \
would have the following density matrix for the remaining subsystem:",
  FontFamily->"Helvetica"]], "Text",
  FontFamily->"Courier New",
  CellTags->"b:14.3"],

Cell[BoxData[{
    \(\[Rho]24[0, 1]\), "\[IndentingNewLine]", 
    \(Tr[\[Rho]24[0, 1]]\)}], "Input",
  CellTags->"b:14.3"],

Cell[TextData[StyleBox["The computation could be left depending on the values \
of the measurement:",
  FontFamily->"Helvetica"]], "Text",
  FontFamily->"Courier New",
  CellTags->"b:14.3"],

Cell[BoxData[{
    \(\[Rho]24[a, b]\), "\[IndentingNewLine]", 
    \(Tr[\[Rho]24[a, b]]\)}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["b) Measuring  in the computational bases using \
MeasureKet",
  FontWeight->"Bold"]], "Subsection",
  CellFrame->True,
  FontFamily->"Times",
  CellTags->{"b:14.2.0", "Measurements", "MeasureKet", "c:16"}],

Cell[TextData[StyleBox["Consider a similar example to the previous one, using \
kets:",
  FontFamily->"Helvetica"]], "Text",
  FontFamily->"Courier New",
  CellTags->"b:14.3"],

Cell[BoxData[{
    \(\(Ope = 
        CNOT[4, 1, 2] . had[4, 2] . CNOT[4, 3, 4] . had[4, 1] . 
          CNOT[4, 1, 4] . had[4, 3];\)\), "\[IndentingNewLine]", 
    \(ket1234 = 
      Ope . \((\((\((Ket[0]\ \ \[CircleTimes]\ \ Ket[0])\)\ \[CircleTimes]Ket[
                  0])\)\ \[CircleTimes]\ \ Ket[0])\)\)}], "Input",
  CellTags->"b:14.3"],

Cell[TextData[StyleBox["We can then measure for instance qubits 1 and 3 \
simultaneously, using MeasureKet.",
  FontFamily->"Helvetica"]], "Text",
  FontFamily->"Courier New",
  CellTags->"b:14.3"],

Cell[TextData[StyleBox["The state of the remaining twoqubit subsystem, which \
depends on the values measured, after the measurement reads, ",
  FontFamily->"Helvetica"]], "Text",
  FontFamily->"Courier New",
  CellTags->"b:14.3"],

Cell[BoxData[
    \(ket24[a_, b_] := MeasureKet[ket1234, {1, 3}, {a, b}]\)], "Input",
  CellTags->"b:14.3"],

Cell[TextData[StyleBox["If the result of the measurement was (01) then we \
would have the following ket for the remaining  qubit 2 and 4 subsystem:",
  FontFamily->"Helvetica"]], "Text",
  FontFamily->"Courier New",
  CellTags->"b:14.3"],

Cell[BoxData[
    \(ket24[0, 1]\)], "Input",
  CellTags->"b:14.3"],

Cell[TextData[StyleBox["Construct the back to back density matrix for that \
state:",
  FontFamily->"Helvetica"]], "Text",
  FontFamily->"Courier New",
  CellTags->"b:14.3"],

Cell[BoxData[
    \(\[Rho]24k = ket24[0, 1]\[CircleTimes]Adj[ket24[0, 1]]\)], "Input"],

Cell[BoxData[
    \(Purity[\[Rho]24k]\)], "Input"],

Cell[TextData[StyleBox["Which is identical to the density matrix obtained \
earlier",
  FontFamily->"Helvetica"]], "Text",
  FontFamily->"Courier New",
  CellTags->"b:14.3"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["c) Example with measurements in the X and Y bases \
using the density matrix",
  FontWeight->"Bold"]], "Subsection",
  CellFrame->True,
  FontFamily->"Times",
  CellTags->{"b:14.2.0", "c:17"}],

Cell[BoxData[{
    \(\(figure = 
        Import["\<drawings/Had5q.png\>", "\<PNG\>"];\)\), \
"\[IndentingNewLine]", 
    \(\(Show[figure];\)\)}], "Input"],

Cell[TextData[StyleBox["Let us  assume we have a five qubit system built as \
in the figure, which corresponds to:",
  FontFamily->"Helvetica"]], "Text",
  FontFamily->"Courier New",
  CellTags->"b:14.3"],

Cell[BoxData[{
    \(\(Ope2 = 
        CPHASE[5, 1, 2] . CPHASE[5, 2, 3] . CPHASE[5, 3, 4] . 
          CPHASE[5, 4, 5];\)\), "\[IndentingNewLine]", 
    \(\(\[Rho]1 = RandomQubit1;\)\), "\[IndentingNewLine]", 
    \(\(\[Rho]Initial = \((\((\((\((\[Rho]1\[CircleTimes]PX[
                          0])\)\[CircleTimes]\ \ PX[0])\)\ \[CircleTimes]PX[
                  0])\)\[CircleTimes]PX[0])\);\)\), "\[IndentingNewLine]", 
    \(\(\[Rho]12345 = Chop[\ Ope2 . \[Rho]Initial . Adj[Ope2]];\)\)}], "Input",\

  CellTags->"b:14.3"],

Cell[TextData[StyleBox["We now measure qubit 1 in the X basis, qubits 2, 3 \
and 4 in the Y basis and check what  \nwe have in qubit 5 ",
  FontFamily->"Helvetica"]], "Text",
  FontFamily->"Courier New",
  CellTags->"b:14.3"],

Cell[BoxData[
    \(PP\_\(a_, b_, c_, d_\)\ \  := \ \((\((\((\ \((PX[
                        a]\ \[CircleTimes]\ \ PY[b])\)\[CircleTimes]PY[
                    c])\)\[CircleTimes]\ 
              PY[d])\)\[CircleTimes]\[DoubleStruckCapitalI])\)\)], "Input",
  CellTags->"b:14.3"],

Cell[TextData[{
  StyleBox["(this proyector could have been written using ",
    FontFamily->"Helvetica"],
  StyleBox["MultiQProj[{1,2,2,2,0},{a,b,c,d,0}] )",
    FontFamily->"Helvetica",
    FontWeight->"Bold"]
}], "Text",
  FontFamily->"Courier New",
  CellTags->"b:14.3"],

Cell[TextData[StyleBox["And therefore the state of the remaining subsystem, \
which depends on the values measured, after the measurement reads, ",
  FontFamily->"Helvetica"]], "Text",
  FontFamily->"Courier New",
  CellTags->"b:14.3"],

Cell[BoxData[
    \(\(\[Rho]5[a_, b_, c_, d_] := 
        Chop[\ PTr[{1, 2, 3, 4}\ \ , 
            2^4*PP\_\(a, b, c, d\) . \[Rho]12345 . 
                Adj[PP\_\(a, b, c, d\)\ ]]];\)\)], "Input",
  CellTags->"b:14.3"],

Cell[TextData[StyleBox["If the result of the measurement was 1 for qubit 2 in \
the Z bases and 0 for qubit 3 in the X bases then the \nstate of qubits 1 and \
4 would be given by the following:",
  FontFamily->"Helvetica"]], "Text",
  FontFamily->"Courier New",
  CellTags->"b:14.3"],

Cell[BoxData[
    \(\[Rho]5[0, 1, 1, 1]\)], "Input",
  CellTags->"b:14.3"],

Cell[TextData[StyleBox["Now we can relate this problem to the realization of \
a Hadamard in the Cluster Model, in fact, our \nexample corresponds exactly \
to Fig 2(d) of Raussendorf et al., Phys. Rev. A 022312 (2003). \nTherefore \
according to those authors the output should be, up to a prefactor depending \
on the\nprevious measurements, a Hadamard of the first qubit:",
  FontFamily->"Helvetica"]], "Text",
  FontFamily->"Courier New",
  CellTags->"b:14.3"],

Cell[TextData[StyleBox["The prefactor is the following:",
  FontFamily->"Helvetica"]], "Text",
  FontFamily->"Courier New",
  CellTags->"b:14.3"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(\(U\_\(\[CapitalSigma], H\)\)\(=\)\)\)],
    FontSize->14],
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox[\(\[Sigma]\_x\^\(a + c + d\)\),
            "TraditionalForm"], \(\[Sigma]\_z\^\(b + c\)\)}], 
        TraditionalForm]],
    FontSize->14]
}], "Text",
  TextAlignment->-0.5,
  FontFamily->"Courier New",
  CellTags->"b:14.3"],

Cell[BoxData[
    \(Prefactor[a_, b_, c_, d_] := 
      MatrixPower[\[Sigma]\_1, a + c + d] . 
        MatrixPower[\[Sigma]\_3, b + c]\)], "Input"],

Cell[BoxData[
    \(\[Rho]5Final[a_, b_, c_, d_] := 
      Prefactor[a, b, c, d] . \[Rho]5[a, b, c, d] . 
        Adj[Prefactor[a, b, c, d]]\)], "Input"],

Cell[BoxData[
    \(Chop[\[Rho]5Final[1, 1, 0, 1]]\)], "Input"],

Cell[BoxData[
    \(Chop[had[1, 1] . \[Rho]1 . Adj[had[1, 1]]]\)], "Input"],

Cell[TextData[StyleBox["The equivalence of the above two results confirms \
that the cluster diagram and the prefactor step does indeed represent a \
Hadamard.",
  FontFamily->"Helvetica"]], "Text",
  FontFamily->"Courier New",
  CellTags->"b:14.3"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Miscellaneous", "Section",
  FontFamily->"Times",
  CellTags->{"b:14.3", "Measurement", "c:18"}],

Cell[CellGroupData[{

Cell["a) Von Neumann Entropy", "Subsection",
  CellFrame->True,
  FontFamily->"Times",
  CellTags->{"b:11.0.0", "c:19"}],

Cell[TextData[StyleBox["The Von Neumann entropy is defined as:  S[\[Rho]] = - \
Tr [\[Rho] Log[2,\[Rho] ] ]",
  FontFamily->"Helvetica"]], "Text",
  FontFamily->"Courier New",
  CellTags->"b:14.1"],

Cell[TextData[{
  StyleBox["Which can be rewritten as  S[\[Rho]] = -\[Sum] ",
    FontFamily->"Helvetica"],
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox[\(\[Rho]\_\[Lambda]\),
            "TraditionalForm"], \(Log[2, \[Rho]\_\[Lambda]]\)}], 
        TraditionalForm]]],
  StyleBox[" \n",
    FontFamily->"Helvetica"],
  StyleBox["where ",
    FontFamily->"Helvetica"],
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[Rho]\_\[Lambda]\)\(\ \)\)\)],
    FontFamily->"Helvetica"],
  StyleBox["are the eigenvalues of \[Rho], and we keep the convenction",
    FontFamily->"Helvetica"],
  " 0*Log[2,0]:=0"
}], "Text",
  FontFamily->"Courier New",
  CellTags->"b:14.1"],

Cell[TextData[{
  StyleBox["The Function Entropy[ ] is already defined in ",
    FontFamily->"Helvetica"],
  "QDENSITY",
  StyleBox[", let's check some examples, Ex 11.11 and 11.12 of Nielsen and \
Chuang:",
    FontFamily->"Helvetica"]
}], "Text",
  FontFamily->"Courier New",
  CellTags->"b:14.1"],

Cell[BoxData[{
    RowBox[{"\[Rho]1", "=", 
      SubscriptBox["\[ScriptCapitalP]", 
        StyleBox["0",
          ScriptLevel->0]]}], "\[IndentingNewLine]", \(\[Rho]2 = 
      1/2*\((s[0] + s[1])\)\), "\[IndentingNewLine]", 
    RowBox[{"\[Rho]3", "=", 
      RowBox[{\(1/3\), "*", 
        RowBox[{"(", 
          RowBox[{\(s[0]\), "+", \(s[1]\), "+", 
            SubscriptBox["\[ScriptCapitalP]", 
              StyleBox["0",
                ScriptLevel->0]]}], ")"}]}]}]}], "Input",
  CellTags->"b:14.1"],

Cell[TextData[StyleBox["..and their entropies are:",
  FontFamily->"Helvetica"]], "Text",
  FontFamily->"Courier New",
  CellTags->"b:14.1"],

Cell[BoxData[{
    \(Entropy[\[Rho]1]\), "\[IndentingNewLine]", 
    \(Entropy[\[Rho]2]\), "\[IndentingNewLine]", 
    \(Entropy[\[Rho]3]\), "\[IndentingNewLine]", 
    \(N[%]\)}], "Input",
  CellTags->"b:14.1"],

Cell[TextData[StyleBox[" Now lets check 11.12",
  FontFamily->"Helvetica"]], "Text",
  FontFamily->"Courier New",
  CellTags->"b:14.1"],

Cell[BoxData[{
    RowBox[{
      RowBox[{\(\[Rho]Entropy[p_]\), ":=", 
        RowBox[{
          RowBox[{"p", "*", 
            SubscriptBox["\[ScriptCapitalP]", 
              StyleBox["0",
                ScriptLevel->0]]}], "+", \(\((1 - p)\)*PX[0]\)}]}], 
      ";"}], "\[IndentingNewLine]", \(M[p_] := 
        Eigenvalues[\[Rho]Entropy[p]];\), "\[IndentingNewLine]", \(MP[p_] = 
        Select[M[p], Positive];\), "\[IndentingNewLine]", \(Plot[
        Entropy[\[Rho]Entropy[p]], {p, 0, 1}, 
        AxesLabel \[Rule] {"\<p\>", "\<Entropy\>"}];\)}], "Input"],

Cell[TextData[{
  StyleBox["Examples using GHZ and other Multi-qubit states are easily \
generated in ",
    FontFamily->"Helvetica"],
  "QDENSITY",
  StyleBox[".",
    FontFamily->"Helvetica"]
}], "Text",
  FontFamily->"Courier New",
  CellTags->"b:14.3"]
}, Open  ]],

Cell[CellGroupData[{

Cell["b) Fidelity", "Subsection",
  CellFrame->True,
  FontFamily->"Times",
  CellTags->{"b:11.0.0", "c:20"}],

Cell[TextData[{
  StyleBox["The fidelity of two states is defined:  Fidelity",
    FontFamily->"Helvetica"],
  Cell[BoxData[
      \(TraditionalForm\`\([\[Rho]\_1, \[Rho]\_2\)\)]],
  StyleBox["] = Tr [ ",
    FontFamily->"Helvetica"],
  Cell[BoxData[
      \(TraditionalForm\`\@\(\@\[Rho]\_2 . \[Rho]\_1 . \@\[Rho]\_2\)\)]]
}], "Text",
  FontFamily->"Courier New",
  CellTags->"b:14.1"],

Cell[BoxData[{
    \(State1 = RandomQubit2\), "\[IndentingNewLine]", 
    \(State2 = RandomQubit2\)}], "Input",
  CellTags->"b:14.1"],

Cell[TextData[StyleBox["their fidelity is:",
  FontFamily->"Helvetica"]], "Text",
  FontFamily->"Courier New",
  CellTags->"b:14.1"],

Cell[BoxData[{
    \(Fidelity[State1, State2]\), "\[IndentingNewLine]", 
    \(Fidelity[State2, State1]\)}], "Input",
  CellTags->"b:14.1"],

Cell[TextData[StyleBox[" The fidelity is one if both states are the same:",
  FontFamily->"Helvetica"]], "Text",
  FontFamily->"Courier New",
  CellTags->"b:14.1"],

Cell[BoxData[
    \(Fidelity[State1, State1]\)], "Input"],

Cell[TextData[StyleBox[" Let's see the behavior of the Fidelity for a couple \
of interesting examples:",
  FontFamily->"Helvetica"]], "Text",
  FontFamily->"Courier New",
  CellTags->"b:14.1"],

Cell[BoxData[{
    \(\(\[Rho]Fid[p_] := 
        p*\[ScriptCapitalP]\_1 + \((1 - p)\)*
            PX[1];\)\), "\[IndentingNewLine]", 
    \(Fide[p_] := 
      Fidelity[\[ScriptCapitalP]\_0, \[Rho]Fid[p]]\), "\[IndentingNewLine]", 
    \(\(Plot[Abs[Fide[p]], {p, \(-5\), 7}, 
        AxesLabel \[Rule] {"\<p\>", "\<Fidelity\>"}];\)\)}], "Input"],

Cell[BoxData[{
    \(\(\[Rho]Fid2[p_] := 
        Sin[p]^2*\[ScriptCapitalP]\_1 + 
          Cos[p]^2*PX[0];\)\), "\[IndentingNewLine]", 
    \(Fide[p_] := 
      Fidelity[\[ScriptCapitalP]\_0, \[Rho]Fid2[
          p]]\), "\[IndentingNewLine]", 
    \(\(Plot[Abs[Fide[p]], {p, 0, 4*Pi}, 
        AxesLabel \[Rule] {"\<p\>", "\<Fidelity\>"}];\)\)}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["c) GHZ study", "Subsection",
  CellFrame->True,
  FontFamily->"Times",
  CellTags->{"c:4", "b:6.0.1"}],

Cell["\<\
Start with a pure three qubit state in the computational basis |abc\
\[RightAngleBracket]\[LeftAngleBracket]abc| :\
\>", "Text",
  FontFamily->"Helvetica"],

Cell[BoxData[
    RowBox[{\(\[Rho]\_\(a_, b_, c_\)\), ":=", " ", 
      RowBox[{
        StyleBox[\(\[ScriptCapitalP]\_a\),
          ScriptLevel->0], "\[CircleTimes]", " ", 
        RowBox[{"(", 
          
          StyleBox[\(\[ScriptCapitalP]\_b\[CircleTimes]\[ScriptCapitalP]\_c\),
            
            ScriptLevel->0], 
          StyleBox[")",
            ScriptLevel->0]}]}]}]], "Input",
  CellTags->"b:6.0.1"],

Cell[" Generate GHZ state operator as seen in the figure:", "Text",
  FontFamily->"Helvetica",
  CellTags->"b:6.0.1"],

Cell[BoxData[{
    \(\(figure2 = 
        Import["\<drawings/gGHZ.png\>", "\<PNG\>"];\)\), \
"\[IndentingNewLine]", 
    \(\(Show[figure2];\)\)}], "Input",
  CellTags->"b:6.0.1"],

Cell[BoxData[
    \(Clear[GHZop]\)], "Input"],

Cell[BoxData[
    \(GHZop[qi_, qj_, qk_] := \(\(\(CNOT[3, qi, qk] . CNOT[3, qi, qj]\) . 
        had[3, qi]\)\(\ \)\)\)], "Input",
  FontFamily->"Courier New",
  CellTags->"b:6.0.1"],

Cell[BoxData[
    \(\(\(\ \ \)\(GHZ\[Rho]\ \ \ is\ the\ density\ matrix\ \ of\ any\ of\ the\
\ GHZ\ states, \ 
    depending\ on\ the\ initial\ \(\(state\)\(:\)\(\ \)\)\)\)\)], "Text",
  FontFamily->"Helvetica",
  CellTags->"b:6.0.1"],

Cell[BoxData[
    StyleBox[
      RowBox[{" ", 
        RowBox[{
          RowBox[{
            SubscriptBox[
              StyleBox[
                RowBox[{"G", 
                  StyleBox["HZ",
                    FontSize->12], "\[Rho]"}]], \(a_, b_, c_\)], "  ", 
            ":=", \(GHZop[1, 2, 3] . \[Rho]\_\(a, b, c\) . 
              Adj[GHZop[1, 2, 3]]\)}], ";"}]}],
      FontSize->12]], "Input",
  FontFamily->"Courier New",
  FontSize->12,
  CellTags->"b:6.0.1"],

Cell[" Checks on some of the GHZ states: ", "Text",
  FontFamily->"Helvetica",
  CellTags->"b:6.0.1"],

Cell[BoxData[
    SubscriptBox[
      StyleBox[
        RowBox[{"G", 
          StyleBox["HZ",
            FontSize->12], "\[Rho]"}]], \(0, 0, 0\)]], "Input",
  CellTags->"b:6.0.1"],

Cell[BoxData[{
    SubscriptBox[
      StyleBox[
        RowBox[{"G", 
          StyleBox["HZ",
            FontSize->12], "\[Rho]"}]], \(0, 0, 1\)], "\[IndentingNewLine]", 
    SubscriptBox[
      StyleBox[
        RowBox[{"G", 
          StyleBox["HZ",
            FontSize->12], "\[Rho]"}]], \(1, 0, 1\)]}], "Input"],

Cell[BoxData[{
    SubscriptBox[
      StyleBox[
        RowBox[{"G", 
          StyleBox["HZ",
            FontSize->12], "\[Rho]"}]], \(0, 1, 0\)], "\[IndentingNewLine]", 
    SubscriptBox[
      StyleBox[
        RowBox[{"G", 
          StyleBox["HZ",
            FontSize->12], "\[Rho]"}]], \(1, 1, 0\)]}], "Input"],

Cell[BoxData[{
    SubscriptBox[
      StyleBox[
        RowBox[{"G", 
          StyleBox["HZ",
            FontSize->12], "\[Rho]"}]], \(0, 1, 1\)], "\[IndentingNewLine]", 
    SubscriptBox[
      StyleBox[
        RowBox[{"G", 
          StyleBox["HZ",
            FontSize->12], "\[Rho]"}]], \(1, 1, 1\)]}], "Input"],

Cell["\<\
Now we will focus on one of the states, the usual GHZ, and study its 
properties:
 Vector and tensor polarizations of GHZ state 
 Vector polarizations are zero for GHZ states 
 Rank 2 Tensor polarizations for GHZ state 
 Rank 3 Tensor polarizations for GHZ state \
\>", "Text",
  FontFamily->"Helvetica",
  CellTags->"b:6.0.1"],

Cell[BoxData[
    RowBox[{
      StyleBox[\(\[Rho]\_GHZ\),
        FontSize->12], "=", 
      SubscriptBox[
        StyleBox[
          RowBox[{"G", 
            StyleBox["HZ",
              FontSize->12], "\[Rho]"}]], \(0, 0, 0\)]}]], "Input"],

Cell[BoxData[{
    RowBox[{
      RowBox[{\(T[i_, j_, k_]\), ":=", 
        RowBox[{"Tr", "[", 
          
          RowBox[{\((\((\[Sigma]\_i\[CircleTimes]\[Sigma]\_j)\)\[CircleTimes]\
\[Sigma]\_k)\), ".", 
            StyleBox[\(\[Rho]\_GHZ\),
              FontSize->12]}], 
          StyleBox[" ",
            FontSize->12], 
          StyleBox["]",
            FontSize->12]}]}], 
      StyleBox[";",
        FontSize->12]}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        StyleBox[
          RowBox[{
            StyleBox["P",
              FontSize->12], "GHZ", 
            StyleBox["A",
              FontSize->12]}]], 
        StyleBox["=",
          FontSize->12], 
        RowBox[{
          StyleBox["{",
            FontSize->12], 
          RowBox[{
            StyleBox[\(T[1, 0, 0]\),
              FontSize->12], 
            StyleBox[",",
              FontSize->12], \(T[2, 0, 0]\), ",", \(T[3, 0, 0]\)}], "}"}]}], 
      ";"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        StyleBox[
          RowBox[{
            StyleBox["P",
              FontSize->12], "GHZ", 
            StyleBox["B",
              FontSize->12]}]], 
        StyleBox["=",
          FontSize->12], 
        RowBox[{
          StyleBox["{",
            FontSize->12], 
          RowBox[{
            StyleBox[\(T[0, 1, 0]\),
              FontSize->12], 
            StyleBox[",",
              FontSize->12], \(T[0, 2, 0]\), ",", \(T[0, 3, 0]\)}], "}"}]}], 
      ";"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        StyleBox[
          RowBox[{
            StyleBox["P",
              FontSize->12], "GHZ", 
            StyleBox["C",
              FontSize->12]}]], 
        StyleBox["=",
          FontSize->12], 
        RowBox[{
          StyleBox["{",
            FontSize->12], 
          RowBox[{
            StyleBox[\(T[0, 0, 1]\),
              FontSize->12], 
            StyleBox[",",
              FontSize->12], \(T[0, 0, 2]\), ",", \(T[0, 0, 3]\)}], "}"}]}], 
      ";"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        StyleBox[
          RowBox[{"TGHZ", 
            StyleBox["AB",
              FontSize->12]}]], 
        StyleBox["=",
          FontSize->12], 
        RowBox[{
          StyleBox["{",
            FontSize->12], 
          RowBox[{
            StyleBox["Table",
              FontSize->12], 
            StyleBox["[",
              FontSize->12], 
            RowBox[{
              StyleBox[\(T[i, j, 0]\),
                FontSize->12], 
              StyleBox[",",
                FontSize->12], \({i, 1, 3}\), ",", \({j, 1, 3}\)}], "]"}], 
          "}"}]}], ";"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        StyleBox[
          RowBox[{"TGHZ", 
            StyleBox["AC",
              FontSize->12]}]], 
        StyleBox["=",
          FontSize->12], 
        RowBox[{
          StyleBox["{",
            FontSize->12], 
          RowBox[{
            StyleBox["Table",
              FontSize->12], 
            StyleBox["[",
              FontSize->12], 
            RowBox[{
              StyleBox[\(T[i, 0, j]\),
                FontSize->12], 
              StyleBox[",",
                FontSize->12], \({i, 1, 3}\), ",", \({j, 1, 3}\)}], "]"}], 
          "}"}]}], ";"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"TGHZBC", 
        StyleBox["=",
          FontSize->12], 
        RowBox[{
          StyleBox["{",
            FontSize->12], 
          RowBox[{
            StyleBox["Table",
              FontSize->12], 
            StyleBox["[",
              FontSize->12], 
            RowBox[{
              StyleBox[\(T[i, j, 0]\),
                FontSize->12], 
              StyleBox[",",
                FontSize->12], \({i, 1, 3}\), ",", \({j, 1, 3}\)}], "]"}], 
          "}"}]}], ";"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        StyleBox[
          RowBox[{"TGHZ", 
            StyleBox["ABC",
              FontSize->12]}]], 
        StyleBox["=",
          FontSize->12], 
        RowBox[{
          StyleBox["{",
            FontSize->12], 
          RowBox[{
            StyleBox["Table",
              FontSize->12], 
            StyleBox["[",
              FontSize->12], 
            RowBox[{
              StyleBox[\(T[i, j, k]\),
                FontSize->12], 
              StyleBox[",",
                FontSize->12], \({i, 1, 3}\), ",", \({j, 1, 3}\), 
              ",", \({k, 1, 3}\)}], "]"}], "}"}]}], 
      ";"}], "\[IndentingNewLine]", "PGHZA", "\[IndentingNewLine]", 
  "PGHZB", "\[IndentingNewLine]", 
  "PGHZC", "\[IndentingNewLine]", \(Flatten[TGHZAB, 
      1]\), "\[IndentingNewLine]", \(Flatten[TGHZAC, 
      1]\), "\[IndentingNewLine]", \(Flatten[TGHZBC, 
      1]\), "\[IndentingNewLine]", "TGHZABC"}], "Input",
  FontFamily->"Courier New",
  CellTags->"b:6.0.1"],

Cell[BoxData[{
    \(T[1, 1, 1]\), "\[IndentingNewLine]", 
    \(T[1, 2, 2]\), "\[IndentingNewLine]", 
    \(T[2, 1, 2]\), "\[IndentingNewLine]", 
    \(T[2, 2, 1]\)}], "Input"],

Cell["We can reconstruct the Density Matrix ", "Text",
  FontFamily->"Helvetica",
  CellTags->"b:6.0.1"],

Cell[BoxData[
    \(\((1/
          8)\)\ \ \(\[Sum]\+\(i = 0\)\%3\ \ \ \(\[Sum]\+\(j = 0\)\%3\ \ \(\
\[Sum]\+\(k = 0\)\%3\ \ T[i, j, 
                k]*\((\((\[Sigma]\_i\[CircleTimes]\[Sigma]\_j)\)\[CircleTimes]\
\[Sigma]\_k)\)\)\)\)\)], "Input"],

Cell["or, identically making use of the general SP function: ", "Text",
  FontFamily->"Helvetica",
  CellTags->"b:6.0.1"],

Cell[BoxData[
    \(\((1/8)\)\ \ \ \((\ \ SP[3, {0, 0, 0}]\ \  + \ SP[3, {3, 3, 0}] + \ 
          SP[3, {3, 0, 3}] + \ SP[3, {0, 3, 3}] + \ SP[3, {1, 1, 1}] - 
          SP[3, {1, 2, 2}] - SP[3, {2, 1, 2}] - 
          SP[3, {2, 2, 1}])\)\)], "Input"],

Cell["Check on the Entropy of the full system and Sub Entropies", "Text",
  FontFamily->"Helvetica",
  CellTags->"b:6.0.1"],

Cell[BoxData[
    RowBox[{"Entropy", "[", 
      StyleBox[\(\[Rho]\_GHZ\),
        FontSize->12], "]"}]], "Input"],

Cell["\<\
The density matrix of the subsystem [a,b] can be obtained readily, and its 
decomposition into products of Pauli matrices is explictly given\
\>", "Text",
  FontFamily->"Helvetica",
  CellTags->"b:6.0.1"],

Cell[BoxData[
    RowBox[{\(Subsys[a_, b_]\), ":=", 
      RowBox[{"PTr", "[", 
        RowBox[{\(Complement[{1, 2, 3}, {a, b}]\), ",", 
          StyleBox[\(\[Rho]\_GHZ\),
            FontSize->12]}], 
        StyleBox["]",
          FontSize->12]}]}]], "Input"],

Cell[BoxData[
    \(Subsys23 = Subsys[2, 3]\)], "Input"],

Cell[BoxData[{
    StyleBox[\(Subsys23 = Subsys[2, 3]\),
      FontSize->12], "\[IndentingNewLine]", 
    StyleBox[\(Tr[Subsys23 . SP[2, {1, 0}]]\),
      FontSize->12], "\[IndentingNewLine]", 
    StyleBox[\(Tr[Subsys23 . SP[2, {2, 0}]]\),
      FontSize->12], "\[IndentingNewLine]", 
    StyleBox[\(Tr[Subsys23 . SP[2, {3, 0}]]\),
      FontSize->12], "\[IndentingNewLine]", 
    StyleBox[\(Tr[Subsys23 . SP[2, {0, 1}]]\),
      FontSize->12], "\[IndentingNewLine]", 
    StyleBox[\(Tr[Subsys23 . SP[2, {0, 2}]]\),
      FontSize->12], "\[IndentingNewLine]", 
    StyleBox[\(Tr[Subsys23 . SP[2, {0, 3}]]\),
      FontSize->12], "\[IndentingNewLine]", 
    StyleBox[\(Tr[Subsys23 . SP[2, {1, 1}]]\),
      FontSize->12], "\[IndentingNewLine]", 
    StyleBox[\(Tr[Subsys23 . SP[2, {1, 2}]]\),
      FontSize->12], "\[IndentingNewLine]", 
    StyleBox[\(Tr[Subsys23 . SP[2, {1, 3}]]\),
      FontSize->12], "\[IndentingNewLine]", 
    StyleBox[\(Tr[Subsys23 . SP[2, {2, 1}]]\),
      FontSize->12], "\[IndentingNewLine]", 
    StyleBox[\(Tr[Subsys23 . SP[2, {2, 2}]]\),
      FontSize->12], "\[IndentingNewLine]", 
    StyleBox[\(Tr[Subsys23 . SP[2, {2, 3}]]\),
      FontSize->12], "\[IndentingNewLine]", 
    StyleBox[\(Tr[Subsys23 . SP[2, {3, 1}]]\),
      FontSize->12], "\[IndentingNewLine]", 
    StyleBox[\(Tr[Subsys23 . SP[2, {3, 2}]]\),
      FontSize->12], "\[IndentingNewLine]", 
    StyleBox[\(Tr[Subsys23 . SP[2, {3, 3}]]\),
      FontSize->12]}], "Input"],

Cell["The Entropy of the subsystem 23 is however:", "Text",
  FontFamily->"Helvetica",
  CellTags->"b:6.0.1"],

Cell[BoxData[
    \(Entropy[Subsys23]\)], "Input"],

Cell["\<\
It is simple to do the same game for the other subsystems, which can be \
checked to give the same 
result as this one.\
\>", "Text",
  FontFamily->"Helvetica",
  CellTags->"b:6.0.1"],

Cell["\<\
Finally we show the Sub Entropy for the single qubit density matrices: \
\>", "Text",
  FontFamily->"Helvetica",
  CellTags->"b:6.0.1"],

Cell[BoxData[{
    RowBox[{"Subsys3", "=", 
      RowBox[{"PTr", "[", 
        RowBox[{\({1, 2}\), ",", 
          StyleBox[\(\[Rho]\_GHZ\),
            FontSize->12]}], 
        StyleBox["]",
          FontSize->12]}]}], "\[IndentingNewLine]", \(Entropy[
      Subsys3]\)}], "Input"],

Cell[BoxData[{
    RowBox[{"Subsys2", "=", 
      RowBox[{"PTr", "[", 
        RowBox[{\({1, 3}\), ",", 
          StyleBox[\(\[Rho]\_GHZ\),
            FontSize->12]}], 
        StyleBox["]",
          FontSize->12]}]}], "\[IndentingNewLine]", \(Entropy[
      Subsys2]\)}], "Input"],

Cell[BoxData[{
    RowBox[{"Subsys1", "=", 
      RowBox[{"PTr", "[", 
        RowBox[{\({2, 3}\), ",", 
          StyleBox[\(\[Rho]\_GHZ\),
            FontSize->12]}], 
        StyleBox["]",
          FontSize->12]}]}], "\[IndentingNewLine]", \(Entropy[
      Subsys1]\)}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["d) Werner State Study", "Subsection",
  CellFrame->True,
  FontFamily->"Times",
  CellTags->{"c:4", "b:6.0.1"}],

Cell["\<\
Werner state is used to study how a noisy entangled resource alters the \
efficacy of a quantum channel\
\>", "Text",
  FontFamily->"Helvetica"],

Cell[CellGroupData[{

Cell[TextData[{
  Cell[BoxData[
      FormBox[Cell[TextData[Cell[BoxData[
            FormBox[Cell[""], TraditionalForm]]]]], TraditionalForm]]],
  "Step 1: The Werner state made of qubits 12  is built"
}], "Subsubsection",
  CellFrame->True,
  FontFamily->"Times",
  CellTags->{"c:4", "b:6.0.1"}],

Cell[BoxData[{
    RowBox[{
      RowBox[{
      "Build", " ", "the", " ", "Two", " ", "Qubit", " ", "Werner", "  ", 
        "density", " ", "matrix", "   ", 
        StyleBox["W",
          FontSize->12], "  ", \((\ Noisy\ Entangled\ State\ Resource\ )\)}], 
      " "}], "\[IndentingNewLine]", \(\(First\)\(\ \)\(get\)\(\ \)\(the\)\(\ \
\)\(Bell\)\(\ \)\(density\)\(\ \)\(matrix\)\(\ \)\)}], "Text",
  FontFamily->"Helvetica",
  CellTags->"b:6.0.1"],

Cell[TextData[{
  StyleBox["The ",
    FontFamily->"Helvetica"],
  StyleBox["Bell states",
    FontFamily->"Helvetica",
    FontWeight->"Bold"],
  StyleBox[" are the following:\n",
    FontFamily->"Helvetica"],
  Cell[BoxData[
      \(TraditionalForm\`B\_00 = \ 1/\@2\)]],
  "( |00\[RightAngleBracket] + |11\[RightAngleBracket] )\n",
  Cell[BoxData[
      \(TraditionalForm\`B\_01 = \ 1/\@2\)]],
  "( |01\[RightAngleBracket] + |10\[RightAngleBracket] )\n",
  Cell[BoxData[
      \(TraditionalForm\`B\_10 = \ 1/\@2\)]],
  "( |00\[RightAngleBracket] - |11\[RightAngleBracket] )\n",
  Cell[BoxData[
      \(TraditionalForm\`B\_11 = \ 1/\@2\)]],
  "( |01\[RightAngleBracket] - |10\[RightAngleBracket] )"
}], "Text",
  FontFamily->"Courier New",
  CellTags->"b:14.1"],

Cell[TextData[StyleBox["They can all be constructed in the following way, \
first we build a Bell operator of the form:",
  FontFamily->"Helvetica"]], "Text",
  FontFamily->"Courier New",
  CellTags->"b:14.1"],

Cell[BoxData[
    \(\(\(\ \)\(Bellop = \(\(CNOT[2, 1, 2] . 
        had[2, 1]\)\(\ \)\)\)\)\)], "Input"],

Cell[TextData[StyleBox["Then we build the Bell density matrix",
  FontFamily->"Helvetica"]], "Text",
  FontFamily->"Courier New",
  CellTags->"b:14.1"],

Cell[BoxData[
    RowBox[{" ", 
      RowBox[{\(B\_\(a_, b_\)\), ":=", 
        RowBox[{"Bellop", ".", 
          RowBox[{"(", 
            StyleBox[
              RowBox[{
                SubscriptBox["\[ScriptCapitalP]", 
                  StyleBox["a",
                    ScriptLevel->0]], "\[CircleTimes]", 
                SubscriptBox["\[ScriptCapitalP]", 
                  StyleBox["b",
                    ScriptLevel->0]]}],
              ScriptLevel->0], 
            StyleBox[")",
              ScriptLevel->0]}], ".", 
          StyleBox[\(Adj[Bellop]\),
            ScriptLevel->0], " "}]}]}]], "Input"],

Cell[BoxData[
    \(\(\(\ \)\(B\_\(0, 0\)\[IndentingNewLine]
    B\_\(0, 1\)\[IndentingNewLine]
    B\_\(1, 0\)\[IndentingNewLine]
    B\_\(1, 1\)\)\)\)], "Input"],

Cell[TextData[StyleBox["Then we build the Werner density matrix which adds a \
noisy density matrix to the Bell State density matrix with a parameter \
\[Lambda] that varies between 0 and 1;  1 being pure Bell entangled state, 0 \
being completely random or noisy.",
  FontFamily->"Helvetica"]], "Text",
  FontFamily->"Courier New",
  CellTags->"b:14.1"],

Cell[BoxData[
    RowBox[{" ", 
      RowBox[{
        SubscriptBox["W", 
          RowBox[{"a_", ",", "b_", ",", 
            StyleBox["\[Lambda]_",
              FontFamily->"Helvetica"]}]], ":=", 
        RowBox[{
          RowBox[{
            StyleBox["\[Lambda]",
              FontFamily->"Helvetica"], 
            StyleBox["   ",
              FontFamily->"Helvetica"], 
            RowBox[{"Bellop", ".", 
              RowBox[{"(", 
                StyleBox[
                  RowBox[{
                    SubscriptBox["\[ScriptCapitalP]", 
                      StyleBox["a",
                        ScriptLevel->0]], "\[CircleTimes]", 
                    SubscriptBox["\[ScriptCapitalP]", 
                      StyleBox["b",
                        ScriptLevel->0]]}],
                  ScriptLevel->0], 
                StyleBox[")",
                  ScriptLevel->0]}], ".", 
              StyleBox[\(Adj[Bellop]\),
                ScriptLevel->0]}]}], " ", "+", " ", 
          RowBox[{
            RowBox[{"(", " ", 
              RowBox[{"1", "-", " ", 
                StyleBox["\[Lambda]",
                  FontFamily->"Helvetica"]}], 
              StyleBox[")",
                FontFamily->"Helvetica"]}], 
            StyleBox["  ",
              
              FontFamily->
                "Helvetica"], \(\((\ \[Sigma]\_0\[CircleTimes]\ \
\[Sigma]\_0)\)/4\)}]}]}]}]], "Input"],

Cell[TextData[StyleBox["General Form of Werner density Matrix for 2 qubits;  \
and check Trace",
  FontFamily->"Helvetica"]], "Text",
  FontFamily->"Courier New",
  CellTags->"b:14.1"],

Cell[BoxData[{
    RowBox[{"Simplify", "[", 
      SubscriptBox["W", 
        RowBox[{"a", ",", "b", ",", 
          StyleBox["\[Lambda]",
            FontFamily->"Helvetica"]}]], "]"}], "\[IndentingNewLine]", 
    RowBox[{" ", 
      RowBox[{"Simplify", "[", 
        RowBox[{"Tr", "[", 
          SubscriptBox["W", 
            RowBox[{"a", ",", "b", ",", 
              StyleBox["\[Lambda]",
                FontFamily->"Helvetica"]}]], 
          StyleBox["]",
            FontSize->12]}], 
        StyleBox["]",
          FontSize->12]}]}]}], "Input"],

Cell[TextData[StyleBox["Particular cases of Werner density Matrix for 2 \
qubits with different starting Bell state ",
  FontFamily->"Helvetica"]], "Text",
  FontFamily->"Courier New",
  CellTags->"b:14.1"],

Cell[BoxData[{
    RowBox[{"Simplify", "[", " ", 
      SubscriptBox["W", 
        RowBox[{"0", ",", "0", ",", 
          StyleBox["\[Lambda]",
            FontFamily->"Helvetica"]}]], "]"}], "\[IndentingNewLine]", 
    RowBox[{"Simplify", "[", " ", 
      SubscriptBox["W", 
        RowBox[{"0", ",", "1", ",", 
          StyleBox["\[Lambda]",
            FontFamily->"Helvetica"]}]], "]"}], "\[IndentingNewLine]", 
    RowBox[{"Simplify", "[", " ", 
      SubscriptBox["W", 
        RowBox[{"1", ",", "0", ",", 
          StyleBox["\[Lambda]",
            FontFamily->"Helvetica"]}]], "]"}], "\[IndentingNewLine]", 
    RowBox[{"Simplify", "[", " ", 
      SubscriptBox["W", 
        RowBox[{"1", ",", "1", ",", 
          StyleBox["\[Lambda]",
            FontFamily->"Helvetica"]}]], "]"}]}], "Input"],

Cell[TextData[StyleBox["Check eigenvalues of Werner density Matrix for 2 \
qubits with different starting Bell state ",
  FontFamily->"Helvetica"]], "Text",
  FontFamily->"Courier New",
  CellTags->"b:14.1"],

Cell[BoxData[{
    RowBox[{
      RowBox[{"FullSimplify", "[", 
        RowBox[{"Eigenvalues", "[", 
          SubscriptBox["W", 
            RowBox[{"a", ",", "b", ",", 
              StyleBox["\[Lambda]",
                FontFamily->"Helvetica"]}]], "]"}], "]"}], " ", "/.", 
      " ", \({a \[Rule] 0, \ b -> 0}\)}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"FullSimplify", "[", 
        RowBox[{"Eigenvalues", "[", 
          SubscriptBox["W", 
            RowBox[{"a", ",", "b", ",", 
              StyleBox["\[Lambda]",
                FontFamily->"Helvetica"]}]], "]"}], "]"}], " ", "/.", 
      " ", \({a \[Rule] 0, \ b \[Rule] 1}\)}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"FullSimplify", "[", 
        RowBox[{"Eigenvalues", "[", 
          SubscriptBox["W", 
            RowBox[{"a", ",", "b", ",", 
              StyleBox["\[Lambda]",
                FontFamily->"Helvetica"]}]], "]"}], "]"}], " ", "/.", 
      " ", \({a \[Rule] 1, \ b -> 0}\)}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"FullSimplify", "[", 
        RowBox[{"Eigenvalues", "[", 
          SubscriptBox["W", 
            RowBox[{"a", ",", "b", ",", 
              StyleBox["\[Lambda]",
                FontFamily->"Helvetica"]}]], "]"}], "]"}], " ", "/.", 
      " ", \({a \[Rule] 1, \ b \[Rule] 1}\)}]}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  Cell[BoxData[
      FormBox[Cell[TextData[Cell[BoxData[
            FormBox[Cell[""], TraditionalForm]]]]], TraditionalForm]]],
  "Step 2: Look at the Polarization and Tensor Polarization of the Werner \
state  "
}], "Subsubsection",
  CellFrame->True,
  FontFamily->"Times",
  CellTags->{"c:4", "b:6.0.1"}],

Cell["\<\
Vector and tensor polarizations of Werner state  
Rank 2 Tensor polarizations for Werner state \
\>", "Text",
  FontFamily->"Helvetica",
  CellTags->"b:6.0.1"],

Cell[BoxData[{
    RowBox[{
      RowBox[{\(T[i_, j_]\), ":=", 
        RowBox[{"Tr", "[", 
          RowBox[{\((\[Sigma]\_i\[CircleTimes]\[Sigma]\_j)\), ".", 
            StyleBox[
              SubscriptBox["W", 
                RowBox[{"a", ",", "b", ",", 
                  StyleBox["\[Lambda]",
                    FontFamily->"Helvetica"]}]],
              FontSize->12]}], 
          StyleBox[" ",
            FontSize->12], 
          StyleBox["]",
            FontSize->12]}]}], 
      StyleBox[";",
        FontSize->12]}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        StyleBox[
          RowBox[{
            StyleBox["P",
              FontSize->12], "W", 
            StyleBox["A",
              FontSize->12]}]], 
        StyleBox["=",
          FontSize->12], 
        RowBox[{
          StyleBox["{",
            FontSize->12], 
          RowBox[{
            StyleBox[\(T[1, 0]\),
              FontSize->12], 
            StyleBox[",",
              FontSize->12], \(T[2, 0]\), ",", \(T[3, 0]\)}], "}"}]}], 
      ";"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        StyleBox[
          RowBox[{
            StyleBox["P",
              FontSize->12], "W", 
            StyleBox["B",
              FontSize->12]}]], 
        StyleBox["=",
          FontSize->12], 
        RowBox[{
          StyleBox["{",
            FontSize->12], 
          RowBox[{
            StyleBox[\(T[0, 1]\),
              FontSize->12], 
            StyleBox[",",
              FontSize->12], \(T[0, 2]\), ",", \(T[0, 3]\)}], "}"}]}], 
      ";"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{
          StyleBox[
            RowBox[{"TW", 
              StyleBox["AB",
                FontSize->12]}]], 
          StyleBox["=",
            FontSize->12], 
          RowBox[{
            StyleBox["{",
              FontSize->12], 
            RowBox[{
              StyleBox["Table",
                FontSize->12], 
              StyleBox["[",
                FontSize->12], 
              RowBox[{
                StyleBox[\(T[i, j]\),
                  FontSize->12], 
                StyleBox[",",
                  FontSize->12], \({i, 1, 3}\), ",", \({j, 1, 3}\)}], "]"}], 
            "}"}]}], ";"}], 
      "\[IndentingNewLine]"}], "\[IndentingNewLine]", \(Simplify[
      PWA]\), "\[IndentingNewLine]", \(Simplify[
      PWB]\), "\[IndentingNewLine]", \(Simplify[Flatten[TWAB, 1]]\)}], "Input",\

  FontFamily->"Courier New",
  CellTags->"b:6.0.1"],

Cell["\<\
Vector polarizations of Werner state are zero 
Rank 2 Tensor polarizations for Werner state are diagonal\
\>", "Text",
  FontFamily->"Helvetica",
  CellTags->"b:6.0.1"],

Cell["Vector polarizations of Werner state are zero ", "Text",
  FontFamily->"Helvetica",
  CellTags->"b:6.0.1"],

Cell["Look at Purity and Entropy", "Text",
  FontFamily->"Helvetica",
  CellTags->"b:6.0.1"],

Cell[BoxData[{
    RowBox[{
      StyleBox[
        RowBox[{
          StyleBox["Full",
            FontSize->12], "Simplify"}]], "[", 
      RowBox[{"Purity", "[", 
        SubscriptBox["W", 
          RowBox[{"a", ",", "b", ",", 
            StyleBox["\[Lambda]",
              FontFamily->"Helvetica"]}]], 
        StyleBox["]",
          FontSize->12]}], 
      StyleBox["]",
        FontSize->12]}], "\[IndentingNewLine]", 
    RowBox[{
      StyleBox[
        RowBox[{
          StyleBox["Full",
            FontSize->12], "Simplify"}]], "[", 
      RowBox[{"Entropy", "[", 
        SubscriptBox["W", 
          RowBox[{"a", ",", "b", ",", 
            StyleBox["\[Lambda]",
              FontFamily->"Helvetica"]}]], 
        StyleBox["]",
          FontSize->12]}], 
      StyleBox["]",
        FontSize->12]}]}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  Cell[BoxData[
      FormBox[Cell[TextData[Cell[BoxData[
            FormBox[Cell[""], TraditionalForm]]]]], TraditionalForm]]],
  "Step 3:  Structure of the Werner Density Matrix"
}], "Subsubsection",
  CellFrame->True,
  FontFamily->"Times",
  CellTags->{"c:4", "b:6.0.1"}],

Cell["\<\
Reconstruct Density Matrix 
Note the Werner state has zero polarization for each qubit and a simple \
tensor polarization structure\
\>", "Text",
  FontFamily->"Helvetica",
  CellTags->"b:6.0.1"],

Cell[BoxData[{\(FullSimplify[\((1/
            4)\)\ \ \(\[Sum]\+\(i = 0\)\%3\ \ \ \(\[Sum]\+\(j = 0\)\%3\ \ \ \ \
T[i, j]*\((\[Sigma]\_i\[CircleTimes]\[Sigma]\_j)\)\)\)]\), "\
\[IndentingNewLine]", 
    RowBox[{"Simplify", "[", 
      RowBox[{"%", "-", 
        SubscriptBox["W", 
          RowBox[{"a", ",", "b", ",", 
            StyleBox["\[Lambda]",
              FontFamily->"Helvetica"]}]]}], "]"}]}], "Input"],

Cell[TextData[{
  " Werner Density Matrix  has Form\n",
  "= (1/4)  [ 1 + \[Lambda] ( ",
  Cell[BoxData[
      \(TraditionalForm\`\((\(-1\))\)\^a\ \ \((\[Sigma]\_1\[CircleTimes]\
\[Sigma]\_1)\)\)]],
  "   - ",
  Cell[BoxData[
      \(TraditionalForm\`\((\(-1\))\)\^\(\(a\)\(+\)\(b\)\(\ \)\)\)]],
  " ",
  Cell[BoxData[
      \(\(\(\ \ \)\((\[Sigma]\_2\[CircleTimes]\[Sigma]\_2)\)\)\)],
    FontFamily->"Helvetica"],
  "  + ",
  Cell[BoxData[
      \(TraditionalForm\`\((\(-1\))\)\^b\)]],
  Cell[BoxData[
      \(\(\(\ \ \)\((\[Sigma]\_3\[CircleTimes]\[Sigma]\_3)\)\)\)],
    FontFamily->"Helvetica"],
  " ]"
}], "Text",
  FontFamily->"Helvetica",
  CellTags->"b:6.0.1"],

Cell[BoxData[{
    \(reconstruct = \ \((1/
            4)\)\ \ \ \ \((\ \ SP[
              2, {0, 0}]\ \  + \[Lambda] \((\ \((\(-1\))\)^a\ \ SP[
                      2, {1, 1}] - \((\(-1\))\)^a\ \ \((\(-1\))\)^b\ \ \ SP[
                      2, {2, 2}] + \((\(-1\))\)^b\ SP[
                      2, {3\ , \ 3}])\)\ )\)\), "\[IndentingNewLine]", 
    \(Simplify[reconstruct - W\_\(a, b, \[Lambda]\)]\)}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  Cell[BoxData[
      FormBox[Cell[TextData[Cell[BoxData[
            FormBox[Cell[""], TraditionalForm]]]]], TraditionalForm]]],
  "Step 3: Look at the Entropy, Purity and Sub-entropy of the Werner state  "
}], "Subsubsection",
  CellFrame->True,
  FontFamily->"Times",
  CellTags->{"c:4", "b:6.0.1"}],

Cell["Check on Purity", "Text",
  FontFamily->"Helvetica",
  CellTags->"b:6.0.1"],

Cell[BoxData[{
    RowBox[{"FullSimplify", "[", 
      RowBox[{"Purity", "[", 
        StyleBox[
          SubscriptBox["W", 
            RowBox[{"a", ",", "b", ",", 
              StyleBox["\[Lambda]",
                FontFamily->"Helvetica"]}]],
          FontSize->12], "]"}], "]"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"FullSimplify", "[", 
        RowBox[{"Purity", "[", 
          StyleBox[
            SubscriptBox["W", 
              RowBox[{"a", ",", "b", ",", 
                StyleBox["\[Lambda]",
                  FontFamily->"Helvetica"]}]],
            FontSize->12], "]"}], "]"}], " ", "/.", 
      "  ", \({a \[Rule] 0, \ b -> 0}\)}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"FullSimplify", "[", 
        RowBox[{"Purity", "[", 
          StyleBox[
            SubscriptBox["W", 
              RowBox[{"a", ",", "b", ",", 
                StyleBox["\[Lambda]",
                  FontFamily->"Helvetica"]}]],
            FontSize->12], "]"}], "]"}], "/.", 
      "  ", \({a \[Rule] 0, \ b \[Rule] 1}\)}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"FullSimplify", "[", 
        RowBox[{"Purity", "[", 
          StyleBox[
            SubscriptBox["W", 
              RowBox[{"a", ",", "b", ",", 
                StyleBox["\[Lambda]",
                  FontFamily->"Helvetica"]}]],
            FontSize->12], "]"}], "]"}], " ", "/.", 
      " ", \({a \[Rule] 1, \ b -> 0}\)}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"FullSimplify", "[", 
        RowBox[{"Purity", "[", 
          StyleBox[
            SubscriptBox["W", 
              RowBox[{"a", ",", "b", ",", 
                StyleBox["\[Lambda]",
                  FontFamily->"Helvetica"]}]],
            FontSize->12], "]"}], "]"}], " ", "/.", 
      " ", \({a \[Rule] 1, \ b \[Rule] 1}\)}]}], "Input"],

Cell["Check on Entropy", "Text",
  FontFamily->"Helvetica",
  CellTags->"b:6.0.1"],

Cell[BoxData[{
    RowBox[{
      RowBox[{"FullSimplify", "[", 
        RowBox[{"Entropy", "[", 
          StyleBox[
            SubscriptBox["W", 
              RowBox[{"a", ",", "b", ",", 
                StyleBox["\[Lambda]",
                  FontFamily->"Helvetica"]}]],
            FontSize->12], "]"}], "]"}], " ", "/.", 
      "  ", \({a \[Rule] 0, \ b -> 0}\)}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"FullSimplify", "[", 
        RowBox[{"Entropy", "[", 
          StyleBox[
            SubscriptBox["W", 
              RowBox[{"a", ",", "b", ",", 
                StyleBox["\[Lambda]",
                  FontFamily->"Helvetica"]}]],
            FontSize->12], "]"}], "]"}], "/.", 
      "  ", \({a \[Rule] 0, \ b \[Rule] 1}\)}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"FullSimplify", "[", 
        RowBox[{"Entropy", "[", 
          StyleBox[
            SubscriptBox["W", 
              RowBox[{"a", ",", "b", ",", 
                StyleBox["\[Lambda]",
                  FontFamily->"Helvetica"]}]],
            FontSize->12], "]"}], "]"}], " ", "/.", 
      " ", \({a \[Rule] 1, \ b -> 0}\)}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"FullSimplify", "[", 
        RowBox[{"Entropy", "[", 
          StyleBox[
            SubscriptBox["W", 
              RowBox[{"a", ",", "b", ",", 
                StyleBox["\[Lambda]",
                  FontFamily->"Helvetica"]}]],
            FontSize->12], "]"}], "]"}], " ", "/.", 
      " ", \({a \[Rule] 1, \ b \[Rule] 1}\)}]}], "Input"],

Cell["\<\
Prepare for Entropy versus \[Lambda] plot\
\>", "Text",
  FontFamily->"Helvetica",
  CellTags->"b:6.0.1"],

Cell[BoxData[
    RowBox[{\(Ent[x_, y_, z_]\), ":=", 
      RowBox[{
        RowBox[{"Simplify", "[", 
          RowBox[{"Entropy", "[", 
            StyleBox[
              SubscriptBox["W", 
                RowBox[{"a", ",", "b", ",", 
                  StyleBox["\[Lambda]",
                    FontFamily->"Helvetica"]}]],
              FontSize->12], "]"}], "]"}], " ", "/.", 
        " ", \({a \[Rule] x, 
          b \[Rule] y, \[Lambda]\  \[Rule] z}\)}]}]], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{"Plot", "[", 
        RowBox[{
          RowBox[{"Evaluate", "[", 
            StyleBox[\(Ent[0, 0, s]\),
              FontSize->12], "]"}], ",", \({s,  .0001,  .99999}\)}], "]"}], 
      ";"}]], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{"Plot", "[", 
        RowBox[{
          RowBox[{"Evaluate", "[", 
            StyleBox[\(Ent[0, 1, s]\),
              FontSize->12], "]"}], ",", \({s,  .0001,  .99999}\)}], "]"}], 
      ";"}]], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{"Plot", "[", 
        RowBox[{
          RowBox[{"Evaluate", "[", 
            StyleBox[\(Ent[1, 0, s]\),
              FontSize->12], "]"}], ",", \({s,  .0001,  .99999}\)}], "]"}], 
      ";"}]], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{"Plot", "[", 
        RowBox[{
          RowBox[{"Evaluate", "[", 
            StyleBox[\(Ent[1, 1, s]\),
              FontSize->12], "]"}], ",", \({s,  .0001,  .99999}\)}], "]"}], 
      ";"}]], "Input"],

Cell["Same plot for all Bell states cases.", "Text",
  FontFamily->"Helvetica",
  CellTags->"b:6.0.1"],

Cell["Look at Sub-system 2", "Text",
  FontFamily->"Helvetica",
  CellTags->"b:6.0.1"],

Cell[BoxData[{
    RowBox[{"r2", "=", 
      RowBox[{"PTr", "[", 
        RowBox[{\({1}\), ",", 
          StyleBox[
            SubscriptBox["W", 
              RowBox[{"a", ",", "b", ",", 
                StyleBox["\[Lambda]",
                  FontFamily->"Helvetica"]}]],
            FontSize->12]}], 
        StyleBox["]",
          FontSize->12]}]}], "\[IndentingNewLine]", 
    RowBox[{"{", 
      StyleBox[\(Tr[r2 . \[Sigma]\_1], Tr[r2 . \[Sigma]\_2], 
        Tr[r2 . \[Sigma]\_3]\),
        FontSize->12], 
      StyleBox["}",
        FontSize->12]}]}], "Input"],

Cell["Entropy and Purity of system 2", "Text",
  FontFamily->"Helvetica",
  CellTags->"b:6.0.1"],

Cell[BoxData[{
    \(Entropy[r2]\), "\[IndentingNewLine]", 
    \(Purity[r2]\)}], "Input"],

Cell["Look at Sub-system 1", "Text",
  FontFamily->"Helvetica",
  CellTags->"b:6.0.1"],

Cell[BoxData[{
    RowBox[{"r1", "=", 
      RowBox[{"PTr", "[", 
        RowBox[{\({2}\), ",", 
          StyleBox[
            SubscriptBox["W", 
              RowBox[{"a", ",", "b", ",", 
                StyleBox["\[Lambda]",
                  FontFamily->"Helvetica"]}]],
            FontSize->12]}], 
        StyleBox["]",
          FontSize->12]}]}], "\[IndentingNewLine]", 
    RowBox[{"{", 
      StyleBox[\(Tr[r1 . \[Sigma]\_1], Tr[r1 . \[Sigma]\_2], 
        Tr[r1 . \[Sigma]\_3]\),
        FontSize->12], 
      StyleBox["}",
        FontSize->12]}]}], "Input"],

Cell["Entropy and Purity of system 1", "Text",
  FontFamily->"Helvetica",
  CellTags->"b:6.0.1"],

Cell[BoxData[{
    \(Entropy[r1]\), "\[IndentingNewLine]", 
    \(Purity[r1]\)}], "Input"],

Cell["Eigenvalues of sub-systems", "Text",
  FontFamily->"Helvetica",
  CellTags->"b:6.0.1"],

Cell[BoxData[
    \(\(\(FullSimplify[Eigenvalues[r1]]\ \ \[IndentingNewLine]
    FullSimplify[Eigenvalues[r2]]\)\(\ \)\)\)], "Input"],

Cell["Double Check on Entropy of the Full Werner case", "Text",
  FontFamily->"Helvetica",
  CellTags->"b:6.0.1"],

Cell[BoxData[
    RowBox[{"val", "=", 
      RowBox[{
        RowBox[{"FullSimplify", "[", 
          RowBox[{"Eigenvalues", "[", 
            StyleBox[
              SubscriptBox["W", 
                RowBox[{"a", ",", "b", ",", 
                  StyleBox["\[Lambda]",
                    FontFamily->"Helvetica"]}]],
              FontSize->12], "]"}], "]"}], " ", "/.", 
        " ", \({a \[Rule] 0, \ b -> 0}\)}]}]], "Input"],

Cell[BoxData[{
    \(val[\([1]\)]\), "\[IndentingNewLine]", 
    \(val[\([2]\)]\), "\[IndentingNewLine]", 
    \(val[\([3]\)]\), "\[IndentingNewLine]", 
    \(val[\([4]\)]\)}], "Input"],

Cell[BoxData[
    \(entcheck = 
      FullSimplify[\(-\((val[\([1]\)]\ Log[2, val[\([1]\)]] + 
              val[\([2]\)]\ Log[2, val[\([2]\)]] + 
              val[\([3]\)]\ Log[2, val[\([3]\)]] + 
              val[\([4]\)]\ Log[2, val[\([4]\)]])\)\)]\)], "Input"],

Cell[BoxData[
    \(\(Plot[entcheck, {\[Lambda],  .00001, 1}];\)\)], "Input"],

Cell[BoxData[
    \(N[Simplify[Ent[1, 1, \[Lambda]] - entcheck]]\)], "Input"]
}, Closed]]
}, Closed]]
}, Closed]]
},
FrontEndVersion->"5.2 for X",
ScreenRectangle->{{0, 1280}, {0, 800}},
ShowPageBreaks->False,
WindowToolbars->{},
CellGrouping->Manual,
WindowSize->{892, 746},
WindowMargins->{{3, Automatic}, {Automatic, 0}},
Visible->True,
PrintingCopies->1,
PrintingStartingPageNumber->1,
PrintingPageRange->{1, 32000},
PrintingOptions->{"PaperSize"->{612, 792},
"PaperOrientation"->"Portrait",
"PostScriptOutputFile":>FrontEnd`FileName[{$RootDirectory, "export", "home", \
"brunojd"}, "t.ps", CharacterEncoding -> "iso8859-1"],
"Magnification"->1},
ShowSelection->True,
TaggingRules:>{"NextIndexingNumber" -> 3, "IndexEntries" -> {{"i:1", "CNOT\t\
"}, {"i:2", "HALL"}}, "PaginationCache" -> {{2005, 8, 9, 3, 36, \
18.585304`8.02174465349935}, {1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, \
2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 3, 3, 3, 3, 3, 3, 3, 3, \
3, 3, 3, 3, 3, 3, 3, 3, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 5, \
5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, \
6, 6, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 8, 8, 8, 8, 8, 8, 8, 8, \
8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, \
9, 9, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 11, 11, 11, 11, 11, \
11, 11, 11, 11, 11, 11, 11, 11, 11, 11, 11, 12, 12, 12, 12, 12, 12, 12, 12, \
12, 12, 12, 12, 12, 12, 12, 12, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, \
13, 13, 13, 13, 14, 14, 14, 14, 14, 14, 14, 14, 14, 14, 14, 14, 14, 14, 14}, \
Automatic}},
CellLabelAutoDelete->True,
InputAliases->{"intt"->RowBox[ {"\[Integral]", 
        RowBox[ {"\[SelectionPlaceholder]", 
          RowBox[ {"\[DifferentialD]", "\[Placeholder]"}]}]}], 
    "dintt"->RowBox[ {
        SubsuperscriptBox[ 
        "\[Integral]", "\[SelectionPlaceholder]", "\[Placeholder]"], 
        RowBox[ {"\[Placeholder]", 
          RowBox[ {"\[DifferentialD]", "\[Placeholder]"}]}]}], 
    "sumt"->RowBox[ {
        UnderoverscriptBox[ "\[Sum]", 
          RowBox[ {"\[SelectionPlaceholder]", "=", "\[Placeholder]"}], 
          "\[Placeholder]"], "\[Placeholder]"}], "prodt"->RowBox[ {
        UnderoverscriptBox[ "\[Product]", 
          RowBox[ {"\[SelectionPlaceholder]", "=", "\[Placeholder]"}], 
          "\[Placeholder]"], "\[Placeholder]"}], "dt"->RowBox[ {
        SubscriptBox[ "\[PartialD]", "\[Placeholder]"], " ", 
        "\[SelectionPlaceholder]"}], "notation"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongLeftRightArrow]", " ",
           
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "notation>"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongRightArrow]", " ", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "notation<"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongLeftArrow]", " ", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "symb"->RowBox[ {"Symbolize", "[", 
        TagBox[ 
        "\[Placeholder]", NotationBoxTag, TagStyle -> 
          "NotationTemplateStyle"], "]"}], 
    "infixnotation"->RowBox[ {"InfixNotation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], ",", "\[Placeholder]"}], "]"}], 
    "addia"->RowBox[ {"AddInputAlias", "[", 
        RowBox[ {"\"\[Placeholder]\"", "\[Rule]", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "pattwraper"->TagBox[ 
      "\[Placeholder]", NotationPatternTag, TagStyle -> 
        "NotationPatternWrapperStyle"], 
    "madeboxeswraper"->TagBox[ 
      "\[Placeholder]", NotationMadeBoxesTag, TagStyle -> 
        "NotationMadeBoxesWrapperStyle"]},
Magnification->1,
StyleDefinitions -> "Classroom.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "c:1"->{
    Cell[1754, 51, 124, 5, 122, "Title",
      CellTags->"c:1"]},
  "b:14.0"->{
    Cell[2152, 68, 88, 2, 62, "Section",
      CellTags->{"b:14.0", "c:2"}],
    Cell[2243, 72, 392, 11, 88, "Text",
      CellTags->"b:14.0"],
    Cell[2730, 88, 177, 4, 28, "Text",
      CellTags->"b:14.0"],
    Cell[3006, 98, 165, 3, 28, "Text",
      CellTags->"b:14.0"],
    Cell[3263, 107, 213, 4, 28, "Text",
      CellTags->"b:14.0"],
    Cell[3605, 122, 280, 8, 28, "Text",
      CellTags->"b:14.0"]},
  "c:2"->{
    Cell[2152, 68, 88, 2, 62, "Section",
      CellTags->{"b:14.0", "c:2"}]},
  "b:14.1"->{
    Cell[3922, 135, 89, 2, 42, "Section",
      CellTags->{"b:14.1", "c:3"}],
    Cell[4179, 146, 383, 11, 28, "Text",
      CellTags->"b:14.1"],
    Cell[4621, 162, 213, 4, 28, "Text",
      CellTags->"b:14.1"],
    Cell[4837, 168, 157, 3, 28, "Text",
      CellTags->"b:14.1"],
    Cell[5053, 176, 213, 4, 28, "Text",
      CellTags->"b:14.1"],
    Cell[5269, 182, 239, 5, 28, "Text",
      CellTags->"b:14.1"],
    Cell[5595, 195, 410, 14, 28, "Text",
      CellTags->"b:14.1"],
    Cell[6070, 214, 163, 3, 28, "Text",
      CellTags->"b:14.1"],
    Cell[6489, 226, 307, 10, 28, "Text",
      CellTags->"b:14.1"],
    Cell[6921, 242, 500, 14, 28, "Text",
      CellTags->"b:14.1"],
    Cell[7510, 262, 304, 8, 28, "Text",
      CellTags->"b:14.1"],
    Cell[7964, 276, 429, 11, 46, "Text",
      CellTags->"b:14.1"],
    Cell[8718, 304, 411, 12, 28, "Text",
      CellTags->"b:14.1"],
    Cell[9328, 324, 449, 12, 46, "Text",
      CellTags->"b:14.1"],
    Cell[10891, 372, 281, 5, 46, "Text",
      CellTags->"b:14.1"],
    Cell[11284, 383, 173, 4, 28, "Text",
      CellTags->"b:14.1"],
    Cell[11539, 392, 222, 8, 28, "Text",
      CellTags->"b:14.1"],
    Cell[11866, 406, 218, 4, 28, "Text",
      CellTags->"b:14.1"],
    Cell[12258, 419, 177, 4, 28, "Text",
      CellTags->"b:14.1"],
    Cell[12879, 441, 192, 4, 28, "Text",
      CellTags->"b:14.1"],
    Cell[13074, 447, 762, 22, 148, "Text",
      CellTags->"b:14.1"],
    Cell[13839, 471, 209, 4, 28, "Text",
      CellTags->"b:14.1"],
    Cell[14158, 481, 128, 3, 28, "Text",
      CellTags->"b:14.1"],
    Cell[14910, 505, 349, 9, 28, "Text",
      CellTags->"b:14.1"],
    Cell[15262, 516, 357, 11, 28, "Text",
      CellTags->"b:14.1"],
    Cell[15622, 529, 109, 2, 47, "Input",
      CellTags->"b:14.1"],
    Cell[15734, 533, 161, 3, 28, "Text",
      CellTags->"b:14.1"],
    Cell[16718, 563, 205, 4, 28, "Text",
      CellTags->"b:14.1"],
    Cell[18154, 610, 660, 15, 64, "Text",
      CellTags->"b:14.1"],
    Cell[19948, 659, 404, 14, 28, "Text",
      CellTags->"b:14.1"],
    Cell[20377, 677, 281, 6, 111, "Input",
      CellTags->"b:14.1"],
    Cell[20661, 685, 193, 4, 28, "Text",
      CellTags->"b:14.1"],
    Cell[23138, 755, 334, 6, 46, "Text",
      CellTags->"b:14.1"],
    Cell[23790, 780, 378, 13, 28, "Text",
      CellTags->"b:14.1"],
    Cell[24171, 795, 203, 5, 95, "Input",
      CellTags->"b:14.1"],
    Cell[24377, 802, 149, 3, 28, "Text",
      CellTags->"b:14.1"],
    Cell[24529, 807, 175, 5, 95, "Input",
      CellTags->"b:14.1"],
    Cell[24707, 814, 589, 19, 28, "Text",
      CellTags->"b:14.1"],
    Cell[25321, 837, 564, 11, 97, "Input",
      CellTags->"b:14.1"],
    Cell[25888, 850, 1196, 40, 36, "Text",
      CellTags->"b:14.1"],
    Cell[27099, 893, 614, 17, 46, "Text",
      CellTags->"b:14.1"],
    Cell[27738, 914, 183, 4, 79, "Input",
      CellTags->"b:14.1"],
    Cell[27924, 920, 191, 4, 79, "Input",
      CellTags->"b:14.1"],
    Cell[28130, 927, 311, 5, 46, "Text",
      CellTags->"b:14.1"],
    Cell[28444, 934, 103, 2, 47, "Input",
      CellTags->"b:14.1"],
    Cell[28550, 938, 169, 4, 28, "Text",
      CellTags->"b:14.1"],
    Cell[28814, 948, 1049, 35, 76, "Text",
      CellTags->"b:14.1"],
    Cell[29973, 989, 70, 2, 27, "Text",
      CellTags->"b:14.1"],
    Cell[30322, 1003, 318, 10, 28, "Text",
      CellTags->"b:14.1"],
    Cell[30889, 1025, 158, 3, 28, "Text",
      CellTags->"b:14.1"],
    Cell[33261, 1110, 133, 3, 28, "Text",
      CellTags->"b:14.1"],
    Cell[55280, 1825, 197, 4, 28, "Text",
      CellTags->"b:14.1"],
    Cell[55480, 1831, 681, 21, 58, "Text",
      CellTags->"b:14.1"],
    Cell[56164, 1854, 299, 9, 28, "Text",
      CellTags->"b:14.1"],
    Cell[56466, 1865, 511, 13, 79, "Input",
      CellTags->"b:14.1"],
    Cell[56980, 1880, 140, 3, 28, "Text",
      CellTags->"b:14.1"],
    Cell[57123, 1885, 211, 5, 95, "Input",
      CellTags->"b:14.1"],
    Cell[57337, 1892, 135, 3, 28, "Text",
      CellTags->"b:14.1"],
    Cell[58449, 1930, 386, 11, 33, "Text",
      CellTags->"b:14.1"],
    Cell[58838, 1943, 133, 3, 63, "Input",
      CellTags->"b:14.1"],
    Cell[58974, 1948, 132, 3, 28, "Text",
      CellTags->"b:14.1"],
    Cell[59109, 1953, 139, 3, 63, "Input",
      CellTags->"b:14.1"],
    Cell[59251, 1958, 163, 3, 28, "Text",
      CellTags->"b:14.1"],
    Cell[59477, 1966, 193, 4, 28, "Text",
      CellTags->"b:14.1"],
    Cell[74688, 2475, 762, 22, 148, "Text",
      CellTags->"b:14.1"],
    Cell[75453, 2499, 209, 4, 28, "Text",
      CellTags->"b:14.1"],
    Cell[75772, 2509, 151, 3, 28, "Text",
      CellTags->"b:14.1"],
    Cell[76713, 2539, 354, 6, 46, "Text",
      CellTags->"b:14.1"],
    Cell[78477, 2588, 184, 4, 28, "Text",
      CellTags->"b:14.1"],
    Cell[79223, 2612, 206, 4, 28, "Text",
      CellTags->"b:14.1"],
    Cell[80240, 2640, 207, 4, 28, "Text",
      CellTags->"b:14.1"]},
  "c:3"->{
    Cell[3922, 135, 89, 2, 42, "Section",
      CellTags->{"b:14.1", "c:3"}]},
  "b:11.0.0"->{
    Cell[4036, 141, 140, 3, 69, "Subsection",
      CellTags->{"b:11.0.0", "SingleQubitStates", "c:4"}],
    Cell[8598, 299, 117, 3, 53, "Subsection",
      CellTags->{"b:11.0.0", "c:5"}],
    Cell[12757, 436, 119, 3, 53, "Subsection",
      CellTags->{"b:11.0.0", "c:6"}],
    Cell[18025, 605, 126, 3, 53, "Subsection",
      CellTags->{"b:11.0.0", "c:7"}],
    Cell[23668, 775, 119, 3, 53, "Subsection",
      CellTags->{"b:11.0.0", "c:8"}],
    Cell[55157, 1820, 120, 3, 69, "Subsection",
      CellTags->{"b:11.0.0", "c:19"}],
    Cell[58337, 1925, 109, 3, 69, "Subsection",
      CellTags->{"b:11.0.0", "c:20"}]},
  "SingleQubitStates"->{
    Cell[4036, 141, 140, 3, 69, "Subsection",
      CellTags->{"b:11.0.0", "SingleQubitStates", "c:4"}]},
  "c:4"->{
    Cell[4036, 141, 140, 3, 69, "Subsection",
      CellTags->{"b:11.0.0", "SingleQubitStates", "c:4"}],
    Cell[60416, 1994, 108, 3, 53, "Subsection",
      CellTags->{"c:4", "b:6.0.1"}],
    Cell[73634, 2440, 117, 3, 53, "Subsection",
      CellTags->{"c:4", "b:6.0.1"}],
    Cell[73933, 2453, 297, 8, 63, "Subsubsection",
      CellTags->{"c:4", "b:6.0.1"}],
    Cell[81814, 2683, 325, 9, 63, "Subsubsection",
      CellTags->{"c:4", "b:6.0.1"}],
    Cell[86081, 2834, 292, 8, 63, "Subsubsection",
      CellTags->{"c:4", "b:6.0.1"}],
    Cell[88129, 2899, 318, 8, 63, "Subsubsection",
      CellTags->{"c:4", "b:6.0.1"}]},
  "c:5"->{
    Cell[8598, 299, 117, 3, 53, "Subsection",
      CellTags->{"b:11.0.0", "c:5"}]},
  "c:6"->{
    Cell[12757, 436, 119, 3, 53, "Subsection",
      CellTags->{"b:11.0.0", "c:6"}]},
  "c:7"->{
    Cell[18025, 605, 126, 3, 53, "Subsection",
      CellTags->{"b:11.0.0", "c:7"}]},
  "c:8"->{
    Cell[23668, 775, 119, 3, 53, "Subsection",
      CellTags->{"b:11.0.0", "c:8"}]},
  "Quantum Gates"->{
    Cell[31096, 1034, 93, 2, 42, "Section",
      CellTags->{"Quantum Gates", "c:9"}]},
  "c:9"->{
    Cell[31096, 1034, 93, 2, 42, "Section",
      CellTags->{"Quantum Gates", "c:9"}]},
  "b:14.2.0"->{
    Cell[31721, 1058, 190, 4, 69, "Subsection",
      CellTags->{"b:14.2.0", "c:10"}],
    Cell[31914, 1064, 1244, 38, 118, "Text",
      CellTags->"b:14.2.0"],
    Cell[33183, 1106, 75, 2, 47, "Input",
      CellTags->"b:14.2.0"],
    Cell[33397, 1115, 74, 2, 47, "Input",
      CellTags->"b:14.2.0"],
    Cell[33474, 1119, 174, 4, 28, "Text",
      CellTags->"b:14.2.0"],
    Cell[33673, 1127, 74, 2, 47, "Input",
      CellTags->"b:14.2.0"],
    Cell[33750, 1131, 139, 3, 28, "Text",
      CellTags->"b:14.2.0"],
    Cell[34055, 1142, 402, 6, 45, "Text",
      CellTags->"b:14.2.0"],
    Cell[34460, 1150, 409, 7, 95, "Input",
      CellTags->"b:14.2.0"],
    Cell[34872, 1159, 451, 15, 28, "Text",
      CellTags->"b:14.2.0"],
    Cell[35326, 1176, 102, 2, 47, "Input",
      CellTags->{"i:2", "b:14.2.0"}],
    Cell[35431, 1180, 190, 4, 28, "Text",
      CellTags->"b:14.2.0"],
    Cell[35785, 1191, 242, 4, 28, "Text",
      CellTags->"b:14.2.0"],
    Cell[36030, 1197, 261, 7, 63, "Input",
      CellTags->"b:14.2.0"],
    Cell[36294, 1206, 733, 23, 31, "Text",
      CellTags->"b:14.2.0"],
    Cell[37081, 1234, 283, 11, 28, "Text",
      CellTags->"b:14.2.0"],
    Cell[45841, 1533, 218, 5, 69, "Subsection",
      CellTags->{"b:14.2.0", "Measurements", "c:15"}],
    Cell[48386, 1610, 229, 5, 69, "Subsection",
      CellTags->{"b:14.2.0", "Measurements", "MeasureKet", "c:16"}],
    Cell[50525, 1679, 216, 5, 69, "Subsection",
      CellTags->{"b:14.2.0", "c:17"}]},
  "c:10"->{
    Cell[31721, 1058, 190, 4, 69, "Subsection",
      CellTags->{"b:14.2.0", "c:10"}]},
  "i:2"->{
    Cell[35326, 1176, 102, 2, 47, "Input",
      CellTags->{"i:2", "b:14.2.0"}]},
  "i:1"->{
    Cell[37508, 1254, 181, 4, 69, "Subsection",
      CellTags->{"i:1", "b:14.2.1", "c:11"}],
    Cell[39845, 1334, 179, 4, 53, "Subsection",
      CellTags->{"i:1", "b:14.2.1", "c:12"}],
    Cell[42841, 1427, 177, 4, 53, "Subsection",
      CellTags->{"i:1", "b:14.2.1", "c:13"}]},
  "b:14.2.1"->{
    Cell[37508, 1254, 181, 4, 69, "Subsection",
      CellTags->{"i:1", "b:14.2.1", "c:11"}],
    Cell[37692, 1260, 726, 18, 46, "Text",
      CellTags->"b:14.2.1"],
    Cell[38421, 1280, 70, 2, 47, "Input",
      CellTags->"b:14.2.1"],
    Cell[38494, 1284, 348, 11, 28, "Text",
      CellTags->"b:14.2.1"],
    Cell[38845, 1297, 169, 4, 47, "Input",
      CellTags->"b:14.2.1"],
    Cell[39017, 1303, 226, 4, 28, "Text",
      CellTags->"b:14.2.1"],
    Cell[39246, 1309, 119, 3, 47, "Input",
      CellTags->"b:14.2.1"],
    Cell[39368, 1314, 362, 11, 28, "Text",
      CellTags->"b:14.2.1"],
    Cell[39733, 1327, 75, 2, 47, "Input",
      CellTags->"b:14.2.1"],
    Cell[39845, 1334, 179, 4, 53, "Subsection",
      CellTags->{"i:1", "b:14.2.1", "c:12"}],
    Cell[40027, 1340, 197, 4, 28, "Text",
      CellTags->"b:14.2.1"],
    Cell[40227, 1346, 236, 6, 28, "Text",
      CellTags->"b:14.2.1"],
    Cell[40466, 1354, 338, 6, 58, "Text",
      CellTags->"b:14.2.1"],
    Cell[40909, 1366, 324, 10, 28, "Text",
      CellTags->"b:14.2.1"],
    Cell[41287, 1381, 270, 5, 28, "Text",
      CellTags->"b:14.2.1"],
    Cell[41560, 1388, 175, 4, 28, "Text",
      CellTags->"b:14.2.1"],
    Cell[41738, 1394, 438, 9, 28, "Text",
      CellTags->"b:14.2.1"],
    Cell[42179, 1405, 158, 3, 28, "Text",
      CellTags->"b:14.2.1"],
    Cell[42403, 1413, 326, 6, 46, "Text",
      CellTags->"b:14.2.1"],
    Cell[42841, 1427, 177, 4, 53, "Subsection",
      CellTags->{"i:1", "b:14.2.1", "c:13"}],
    Cell[43021, 1433, 280, 5, 46, "Text",
      CellTags->"b:14.2.1"],
    Cell[43304, 1440, 1239, 43, 119, "Text",
      CellTags->"b:14.2.1"],
    Cell[44602, 1488, 806, 26, 58, "Text",
      CellTags->"b:14.2.1"]},
  "c:11"->{
    Cell[37508, 1254, 181, 4, 69, "Subsection",
      CellTags->{"i:1", "b:14.2.1", "c:11"}]},
  "c:12"->{
    Cell[39845, 1334, 179, 4, 53, "Subsection",
      CellTags->{"i:1", "b:14.2.1", "c:12"}]},
  "c:13"->{
    Cell[42841, 1427, 177, 4, 53, "Subsection",
      CellTags->{"i:1", "b:14.2.1", "c:13"}]},
  "b:14.3"->{
    Cell[45457, 1520, 101, 2, 42, "Section",
      CellTags->{"b:14.3", "Measurement", "c:14"}],
    Cell[45561, 1524, 255, 5, 28, "Text",
      CellTags->"b:14.3"],
    Cell[46062, 1540, 358, 9, 46, "Text",
      CellTags->"b:14.3"],
    Cell[46423, 1551, 397, 8, 63, "Input",
      CellTags->"b:14.3"],
    Cell[46823, 1561, 213, 4, 28, "Text",
      CellTags->"b:14.3"],
    Cell[47039, 1567, 242, 5, 47, "Input",
      CellTags->"b:14.3"],
    Cell[47284, 1574, 235, 4, 28, "Text",
      CellTags->"b:14.3"],
    Cell[47522, 1580, 168, 4, 47, "Input",
      CellTags->"b:14.3"],
    Cell[47693, 1586, 234, 4, 28, "Text",
      CellTags->"b:14.3"],
    Cell[47930, 1592, 123, 3, 63, "Input",
      CellTags->"b:14.3"],
    Cell[48056, 1597, 189, 4, 28, "Text",
      CellTags->"b:14.3"],
    Cell[48618, 1617, 175, 4, 28, "Text",
      CellTags->"b:14.3"],
    Cell[48796, 1623, 345, 7, 63, "Input",
      CellTags->"b:14.3"],
    Cell[49144, 1632, 197, 4, 28, "Text",
      CellTags->"b:14.3"],
    Cell[49344, 1638, 230, 4, 28, "Text",
      CellTags->"b:14.3"],
    Cell[49577, 1644, 107, 2, 47, "Input",
      CellTags->"b:14.3"],
    Cell[49687, 1648, 238, 4, 28, "Text",
      CellTags->"b:14.3"],
    Cell[49928, 1654, 66, 2, 47, "Input",
      CellTags->"b:14.3"],
    Cell[49997, 1658, 173, 4, 28, "Text",
      CellTags->"b:14.3"],
    Cell[50315, 1670, 173, 4, 28, "Text",
      CellTags->"b:14.3"],
    Cell[50901, 1692, 204, 4, 28, "Text",
      CellTags->"b:14.3"],
    Cell[51108, 1698, 528, 10, 95, "Input",
      CellTags->"b:14.3"],
    Cell[51639, 1710, 225, 4, 58, "Text",
      CellTags->"b:14.3"],
    Cell[51867, 1716, 281, 5, 47, "Input",
      CellTags->"b:14.3"],
    Cell[52151, 1723, 274, 8, 28, "Text",
      CellTags->"b:14.3"],
    Cell[52428, 1733, 235, 4, 28, "Text",
      CellTags->"b:14.3"],
    Cell[52666, 1739, 221, 5, 47, "Input",
      CellTags->"b:14.3"],
    Cell[52890, 1746, 284, 5, 58, "Text",
      CellTags->"b:14.3"],
    Cell[53177, 1753, 74, 2, 47, "Input",
      CellTags->"b:14.3"],
    Cell[53254, 1757, 464, 7, 118, "Text",
      CellTags->"b:14.3"],
    Cell[53721, 1766, 145, 3, 28, "Text",
      CellTags->"b:14.3"],
    Cell[53869, 1771, 410, 14, 27, "Text",
      CellTags->"b:14.3"],
    Cell[54732, 1803, 249, 5, 28, "Text",
      CellTags->"b:14.3"],
    Cell[55030, 1814, 102, 2, 42, "Section",
      CellTags->{"b:14.3", "Measurement", "c:18"}],
    Cell[58044, 1911, 256, 9, 28, "Text",
      CellTags->"b:14.3"]},
  "Measurement"->{
    Cell[45457, 1520, 101, 2, 42, "Section",
      CellTags->{"b:14.3", "Measurement", "c:14"}],
    Cell[55030, 1814, 102, 2, 42, "Section",
      CellTags->{"b:14.3", "Measurement", "c:18"}]},
  "c:14"->{
    Cell[45457, 1520, 101, 2, 42, "Section",
      CellTags->{"b:14.3", "Measurement", "c:14"}]},
  "Measurements"->{
    Cell[45841, 1533, 218, 5, 69, "Subsection",
      CellTags->{"b:14.2.0", "Measurements", "c:15"}],
    Cell[48386, 1610, 229, 5, 69, "Subsection",
      CellTags->{"b:14.2.0", "Measurements", "MeasureKet", "c:16"}]},
  "c:15"->{
    Cell[45841, 1533, 218, 5, 69, "Subsection",
      CellTags->{"b:14.2.0", "Measurements", "c:15"}]},
  "MeasureKet"->{
    Cell[48386, 1610, 229, 5, 69, "Subsection",
      CellTags->{"b:14.2.0", "Measurements", "MeasureKet", "c:16"}]},
  "c:16"->{
    Cell[48386, 1610, 229, 5, 69, "Subsection",
      CellTags->{"b:14.2.0", "Measurements", "MeasureKet", "c:16"}]},
  "c:17"->{
    Cell[50525, 1679, 216, 5, 69, "Subsection",
      CellTags->{"b:14.2.0", "c:17"}]},
  "c:18"->{
    Cell[55030, 1814, 102, 2, 42, "Section",
      CellTags->{"b:14.3", "Measurement", "c:18"}]},
  "c:19"->{
    Cell[55157, 1820, 120, 3, 69, "Subsection",
      CellTags->{"b:11.0.0", "c:19"}]},
  "c:20"->{
    Cell[58337, 1925, 109, 3, 69, "Subsection",
      CellTags->{"b:11.0.0", "c:20"}]},
  "b:6.0.1"->{
    Cell[60416, 1994, 108, 3, 53, "Subsection",
      CellTags->{"c:4", "b:6.0.1"}],
    Cell[60695, 2005, 421, 12, 47, "Input",
      CellTags->"b:6.0.1"],
    Cell[61119, 2019, 117, 2, 28, "Text",
      CellTags->"b:6.0.1"],
    Cell[61239, 2023, 178, 5, 63, "Input",
      CellTags->"b:6.0.1"],
    Cell[61468, 2033, 182, 4, 47, "Input",
      CellTags->"b:6.0.1"],
    Cell[61653, 2039, 234, 5, 26, "Text",
      CellTags->"b:6.0.1"],
    Cell[61890, 2046, 475, 15, 49, "Input",
      CellTags->"b:6.0.1"],
    Cell[62368, 2063, 101, 2, 28, "Text",
      CellTags->"b:6.0.1"],
    Cell[62472, 2067, 181, 6, 49, "Input",
      CellTags->"b:6.0.1"],
    Cell[63622, 2111, 337, 9, 178, "Text",
      CellTags->"b:6.0.1"],
    Cell[64209, 2132, 4845, 163, 271, "Input",
      CellTags->"b:6.0.1"],
    Cell[69237, 2303, 104, 2, 28, "Text",
      CellTags->"b:6.0.1"],
    Cell[69595, 2314, 121, 2, 28, "Text",
      CellTags->"b:6.0.1"],
    Cell[69974, 2324, 123, 2, 27, "Text",
      CellTags->"b:6.0.1"],
    Cell[70217, 2333, 214, 5, 58, "Text",
      CellTags->"b:6.0.1"],
    Cell[72230, 2386, 109, 2, 28, "Text",
      CellTags->"b:6.0.1"],
    Cell[72395, 2393, 193, 6, 58, "Text",
      CellTags->"b:6.0.1"],
    Cell[72591, 2401, 145, 4, 28, "Text",
      CellTags->"b:6.0.1"],
    Cell[73634, 2440, 117, 3, 53, "Subsection",
      CellTags->{"c:4", "b:6.0.1"}],
    Cell[73933, 2453, 297, 8, 63, "Subsubsection",
      CellTags->{"c:4", "b:6.0.1"}],
    Cell[74233, 2463, 452, 10, 44, "Text",
      CellTags->"b:6.0.1"],
    Cell[81814, 2683, 325, 9, 63, "Subsubsection",
      CellTags->{"c:4", "b:6.0.1"}],
    Cell[82142, 2694, 169, 5, 58, "Text",
      CellTags->"b:6.0.1"],
    Cell[82314, 2701, 2506, 83, 159, "Input",
      CellTags->"b:6.0.1"],
    Cell[84823, 2786, 178, 5, 58, "Text",
      CellTags->"b:6.0.1"],
    Cell[85004, 2793, 112, 2, 28, "Text",
      CellTags->"b:6.0.1"],
    Cell[85119, 2797, 92, 2, 28, "Text",
      CellTags->"b:6.0.1"],
    Cell[86081, 2834, 292, 8, 63, "Subsubsection",
      CellTags->{"c:4", "b:6.0.1"}],
    Cell[86376, 2844, 205, 6, 58, "Text",
      CellTags->"b:6.0.1"],
    Cell[87004, 2863, 669, 22, 58, "Text",
      CellTags->"b:6.0.1"],
    Cell[88129, 2899, 318, 8, 63, "Subsubsection",
      CellTags->{"c:4", "b:6.0.1"}],
    Cell[88450, 2909, 81, 2, 28, "Text",
      CellTags->"b:6.0.1"],
    Cell[90357, 2963, 82, 2, 28, "Text",
      CellTags->"b:6.0.1"],
    Cell[91973, 3009, 115, 4, 28, "Text",
      CellTags->"b:6.0.1"],
    Cell[93564, 3065, 102, 2, 28, "Text",
      CellTags->"b:6.0.1"],
    Cell[93669, 3069, 86, 2, 28, "Text",
      CellTags->"b:6.0.1"],
    Cell[94333, 3092, 96, 2, 28, "Text",
      CellTags->"b:6.0.1"],
    Cell[94525, 3100, 86, 2, 28, "Text",
      CellTags->"b:6.0.1"],
    Cell[95189, 3123, 96, 2, 28, "Text",
      CellTags->"b:6.0.1"],
    Cell[95381, 3131, 92, 2, 28, "Text",
      CellTags->"b:6.0.1"],
    Cell[95612, 3139, 113, 2, 28, "Text",
      CellTags->"b:6.0.1"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"c:1", 101565, 3283},
  {"b:14.0", 101645, 3286},
  {"c:2", 102067, 3299},
  {"b:14.1", 102159, 3302},
  {"c:3", 107057, 3445},
  {"b:11.0.0", 107152, 3448},
  {"SingleQubitStates", 107796, 3463},
  {"c:4", 107913, 3466},
  {"c:5", 108552, 3481},
  {"c:6", 108648, 3484},
  {"c:7", 108745, 3487},
  {"c:8", 108842, 3490},
  {"Quantum Gates", 108949, 3493},
  {"c:9", 109048, 3496},
  {"b:14.2.0", 109152, 3499},
  {"c:10", 110642, 3538},
  {"i:2", 110741, 3541},
  {"i:1", 110834, 3544},
  {"b:14.2.1", 111133, 3551},
  {"c:11", 112858, 3598},
  {"c:12", 112965, 3601},
  {"c:13", 113072, 3604},
  {"b:14.3", 113181, 3607},
  {"Measurement", 115684, 3678},
  {"c:14", 115891, 3683},
  {"Measurements", 116009, 3686},
  {"c:15", 116242, 3691},
  {"MeasureKet", 116364, 3694},
  {"c:16", 116494, 3697},
  {"c:17", 116624, 3700},
  {"c:18", 116724, 3703},
  {"c:19", 116834, 3706},
  {"c:20", 116934, 3709},
  {"b:6.0.1", 117037, 3712}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 124, 5, 122, "Title",
  CellTags->"c:1"],
Cell[1881, 58, 43, 0, 41, "Subtitle"],
Cell[1927, 60, 45, 0, 26, "Abstract"],
Cell[1975, 62, 152, 2, 28, "Text"],

Cell[CellGroupData[{
Cell[2152, 68, 88, 2, 62, "Section",
  CellTags->{"b:14.0", "c:2"}],
Cell[2243, 72, 392, 11, 88, "Text",
  CellTags->"b:14.0"],
Cell[2638, 85, 89, 1, 47, "Input"],
Cell[2730, 88, 177, 4, 28, "Text",
  CellTags->"b:14.0"],
Cell[2910, 94, 93, 2, 47, "Input"],
Cell[3006, 98, 165, 3, 28, "Text",
  CellTags->"b:14.0"],
Cell[3174, 103, 86, 2, 47, "Input"],
Cell[3263, 107, 213, 4, 28, "Text",
  CellTags->"b:14.0"],

Cell[CellGroupData[{
Cell[3501, 115, 43, 1, 47, "Input"],
Cell[3547, 118, 43, 1, 47, "Input"]
}, Open  ]],
Cell[3605, 122, 280, 8, 28, "Text",
  CellTags->"b:14.0"]
}, Closed]],

Cell[CellGroupData[{
Cell[3922, 135, 89, 2, 42, "Section",
  CellTags->{"b:14.1", "c:3"}],

Cell[CellGroupData[{
Cell[4036, 141, 140, 3, 69, "Subsection",
  CellTags->{"b:11.0.0", "SingleQubitStates", "c:4"}],
Cell[4179, 146, 383, 11, 28, "Text",
  CellTags->"b:14.1"],
Cell[4565, 159, 53, 1, 47, "Input"],
Cell[4621, 162, 213, 4, 28, "Text",
  CellTags->"b:14.1"],
Cell[4837, 168, 157, 3, 28, "Text",
  CellTags->"b:14.1"],
Cell[4997, 173, 53, 1, 47, "Input"],
Cell[5053, 176, 213, 4, 28, "Text",
  CellTags->"b:14.1"],
Cell[5269, 182, 239, 5, 28, "Text",
  CellTags->"b:14.1"],
Cell[5511, 189, 39, 1, 47, "Input"],
Cell[5553, 192, 39, 1, 47, "Input"],
Cell[5595, 195, 410, 14, 28, "Text",
  CellTags->"b:14.1"],
Cell[6008, 211, 59, 1, 47, "Input"],
Cell[6070, 214, 163, 3, 28, "Text",
  CellTags->"b:14.1"],
Cell[6236, 219, 250, 5, 63, "Input"],
Cell[6489, 226, 307, 10, 28, "Text",
  CellTags->"b:14.1"],
Cell[6799, 238, 119, 2, 63, "Input"],
Cell[6921, 242, 500, 14, 28, "Text",
  CellTags->"b:14.1"],
Cell[7424, 258, 83, 2, 63, "Input"],
Cell[7510, 262, 304, 8, 28, "Text",
  CellTags->"b:14.1"],
Cell[7817, 272, 144, 2, 63, "Input"],
Cell[7964, 276, 429, 11, 46, "Text",
  CellTags->"b:14.1"],
Cell[8396, 289, 61, 1, 47, "Input"],
Cell[8460, 292, 101, 2, 63, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[8598, 299, 117, 3, 53, "Subsection",
  CellTags->{"b:11.0.0", "c:5"}],
Cell[8718, 304, 411, 12, 28, "Text",
  CellTags->"b:14.1"],
Cell[9132, 318, 193, 4, 63, "Input"],
Cell[9328, 324, 449, 12, 46, "Text",
  CellTags->"b:14.1"],
Cell[9780, 338, 1108, 32, 63, "Input"],
Cell[10891, 372, 281, 5, 46, "Text",
  CellTags->"b:14.1"],
Cell[11175, 379, 106, 2, 47, "Input"],
Cell[11284, 383, 173, 4, 28, "Text",
  CellTags->"b:14.1"],
Cell[11460, 389, 76, 1, 47, "Input"],
Cell[11539, 392, 222, 8, 28, "Text",
  CellTags->"b:14.1"],
Cell[11764, 402, 99, 2, 63, "Input"],
Cell[11866, 406, 218, 4, 28, "Text",
  CellTags->"b:14.1"],
Cell[12087, 412, 48, 1, 47, "Input"],
Cell[12138, 415, 117, 2, 47, "Input"],
Cell[12258, 419, 177, 4, 28, "Text",
  CellTags->"b:14.1"],
Cell[12438, 425, 282, 6, 79, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[12757, 436, 119, 3, 53, "Subsection",
  CellTags->{"b:11.0.0", "c:6"}],
Cell[12879, 441, 192, 4, 28, "Text",
  CellTags->"b:14.1"],
Cell[13074, 447, 762, 22, 148, "Text",
  CellTags->"b:14.1"],
Cell[13839, 471, 209, 4, 28, "Text",
  CellTags->"b:14.1"],
Cell[14051, 477, 104, 2, 47, "Input"],
Cell[14158, 481, 128, 3, 28, "Text",
  CellTags->"b:14.1"],
Cell[14289, 486, 618, 17, 47, "Input"],
Cell[14910, 505, 349, 9, 28, "Text",
  CellTags->"b:14.1"],
Cell[15262, 516, 357, 11, 28, "Text",
  CellTags->"b:14.1"],
Cell[15622, 529, 109, 2, 47, "Input",
  CellTags->"b:14.1"],
Cell[15734, 533, 161, 3, 28, "Text",
  CellTags->"b:14.1"],
Cell[15898, 538, 817, 23, 47, "Input"],
Cell[16718, 563, 205, 4, 28, "Text",
  CellTags->"b:14.1"],
Cell[16926, 569, 1062, 31, 70, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[18025, 605, 126, 3, 53, "Subsection",
  CellTags->{"b:11.0.0", "c:7"}],
Cell[18154, 610, 660, 15, 64, "Text",
  CellTags->"b:14.1"],
Cell[18817, 627, 1128, 30, 79, "Input"],
Cell[19948, 659, 404, 14, 28, "Text",
  CellTags->"b:14.1"],

Cell[CellGroupData[{
Cell[20377, 677, 281, 6, 111, "Input",
  CellTags->"b:14.1"],
Cell[20661, 685, 193, 4, 28, "Text",
  CellTags->"b:14.1"],
Cell[20857, 691, 2174, 57, 47, "Input"],
Cell[23034, 750, 89, 2, 63, "Input"]
}, Closed]],
Cell[23138, 755, 334, 6, 46, "Text",
  CellTags->"b:14.1"],
Cell[23475, 763, 50, 1, 47, "Input"],
Cell[23528, 766, 50, 1, 47, "Input"],
Cell[23581, 769, 50, 1, 47, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[23668, 775, 119, 3, 53, "Subsection",
  CellTags->{"b:11.0.0", "c:8"}],
Cell[23790, 780, 378, 13, 28, "Text",
  CellTags->"b:14.1"],
Cell[24171, 795, 203, 5, 95, "Input",
  CellTags->"b:14.1"],
Cell[24377, 802, 149, 3, 28, "Text",
  CellTags->"b:14.1"],
Cell[24529, 807, 175, 5, 95, "Input",
  CellTags->"b:14.1"],
Cell[24707, 814, 589, 19, 28, "Text",
  CellTags->"b:14.1"],

Cell[CellGroupData[{
Cell[25321, 837, 564, 11, 97, "Input",
  CellTags->"b:14.1"],
Cell[25888, 850, 1196, 40, 36, "Text",
  CellTags->"b:14.1"]
}, Closed]],
Cell[27099, 893, 614, 17, 46, "Text",
  CellTags->"b:14.1"],

Cell[CellGroupData[{
Cell[27738, 914, 183, 4, 79, "Input",
  CellTags->"b:14.1"],
Cell[27924, 920, 191, 4, 79, "Input",
  CellTags->"b:14.1"]
}, Closed]],
Cell[28130, 927, 311, 5, 46, "Text",
  CellTags->"b:14.1"],
Cell[28444, 934, 103, 2, 47, "Input",
  CellTags->"b:14.1"],
Cell[28550, 938, 169, 4, 28, "Text",
  CellTags->"b:14.1"],
Cell[28722, 944, 89, 2, 63, "Input"],
Cell[28814, 948, 1049, 35, 76, "Text",
  CellTags->"b:14.1"],
Cell[29866, 985, 104, 2, 47, "Input"],
Cell[29973, 989, 70, 2, 27, "Text",
  CellTags->"b:14.1"],
Cell[30046, 993, 122, 2, 47, "Input"],
Cell[30171, 997, 85, 1, 47, "Input"],
Cell[30259, 1000, 60, 1, 47, "Input"],
Cell[30322, 1003, 318, 10, 28, "Text",
  CellTags->"b:14.1"],
Cell[30643, 1015, 120, 3, 47, "Input"],
Cell[30766, 1020, 120, 3, 47, "Input"],
Cell[30889, 1025, 158, 3, 28, "Text",
  CellTags->"b:14.1"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[31096, 1034, 93, 2, 42, "Section",
  CellTags->{"Quantum Gates", "c:9"}],
Cell[31192, 1038, 230, 4, 28, "Text"],
Cell[31425, 1044, 271, 10, 30, "Text"],

Cell[CellGroupData[{
Cell[31721, 1058, 190, 4, 69, "Subsection",
  CellTags->{"b:14.2.0", "c:10"}],
Cell[31914, 1064, 1244, 38, 118, "Text",
  CellTags->"b:14.2.0"],

Cell[CellGroupData[{
Cell[33183, 1106, 75, 2, 47, "Input",
  CellTags->"b:14.2.0"],
Cell[33261, 1110, 133, 3, 28, "Text",
  CellTags->"b:14.1"],
Cell[33397, 1115, 74, 2, 47, "Input",
  CellTags->"b:14.2.0"],
Cell[33474, 1119, 174, 4, 28, "Text",
  CellTags->"b:14.2.0"],

Cell[CellGroupData[{
Cell[33673, 1127, 74, 2, 47, "Input",
  CellTags->"b:14.2.0"],
Cell[33750, 1131, 139, 3, 28, "Text",
  CellTags->"b:14.2.0"],
Cell[33892, 1136, 136, 2, 47, "Input"]
}, Closed]]
}, Closed]],
Cell[34055, 1142, 402, 6, 45, "Text",
  CellTags->"b:14.2.0"],
Cell[34460, 1150, 409, 7, 95, "Input",
  CellTags->"b:14.2.0"],
Cell[34872, 1159, 451, 15, 28, "Text",
  CellTags->"b:14.2.0"],
Cell[35326, 1176, 102, 2, 47, "Input",
  CellTags->{"i:2", "b:14.2.0"}],
Cell[35431, 1180, 190, 4, 28, "Text",
  CellTags->"b:14.2.0"],
Cell[35624, 1186, 158, 3, 79, "Input"],
Cell[35785, 1191, 242, 4, 28, "Text",
  CellTags->"b:14.2.0"],
Cell[36030, 1197, 261, 7, 63, "Input",
  CellTags->"b:14.2.0"],
Cell[36294, 1206, 733, 23, 31, "Text",
  CellTags->"b:14.2.0"],
Cell[37030, 1231, 48, 1, 47, "Input"],
Cell[37081, 1234, 283, 11, 28, "Text",
  CellTags->"b:14.2.0"],
Cell[37367, 1247, 104, 2, 63, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[37508, 1254, 181, 4, 69, "Subsection",
  CellTags->{"i:1", "b:14.2.1", "c:11"}],
Cell[37692, 1260, 726, 18, 46, "Text",
  CellTags->"b:14.2.1"],
Cell[38421, 1280, 70, 2, 47, "Input",
  CellTags->"b:14.2.1"],
Cell[38494, 1284, 348, 11, 28, "Text",
  CellTags->"b:14.2.1"],
Cell[38845, 1297, 169, 4, 47, "Input",
  CellTags->"b:14.2.1"],
Cell[39017, 1303, 226, 4, 28, "Text",
  CellTags->"b:14.2.1"],
Cell[39246, 1309, 119, 3, 47, "Input",
  CellTags->"b:14.2.1"],
Cell[39368, 1314, 362, 11, 28, "Text",
  CellTags->"b:14.2.1"],
Cell[39733, 1327, 75, 2, 47, "Input",
  CellTags->"b:14.2.1"]
}, Closed]],

Cell[CellGroupData[{
Cell[39845, 1334, 179, 4, 53, "Subsection",
  CellTags->{"i:1", "b:14.2.1", "c:12"}],
Cell[40027, 1340, 197, 4, 28, "Text",
  CellTags->"b:14.2.1"],
Cell[40227, 1346, 236, 6, 28, "Text",
  CellTags->"b:14.2.1"],
Cell[40466, 1354, 338, 6, 58, "Text",
  CellTags->"b:14.2.1"],
Cell[40807, 1362, 99, 2, 63, "Input"],
Cell[40909, 1366, 324, 10, 28, "Text",
  CellTags->"b:14.2.1"],
Cell[41236, 1378, 48, 1, 47, "Input"],
Cell[41287, 1381, 270, 5, 28, "Text",
  CellTags->"b:14.2.1"],
Cell[41560, 1388, 175, 4, 28, "Text",
  CellTags->"b:14.2.1"],
Cell[41738, 1394, 438, 9, 28, "Text",
  CellTags->"b:14.2.1"],
Cell[42179, 1405, 158, 3, 28, "Text",
  CellTags->"b:14.2.1"],
Cell[42340, 1410, 60, 1, 47, "Input"],
Cell[42403, 1413, 326, 6, 46, "Text",
  CellTags->"b:14.2.1"],
Cell[42732, 1421, 72, 1, 47, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[42841, 1427, 177, 4, 53, "Subsection",
  CellTags->{"i:1", "b:14.2.1", "c:13"}],
Cell[43021, 1433, 280, 5, 46, "Text",
  CellTags->"b:14.2.1"],
Cell[43304, 1440, 1239, 43, 119, "Text",
  CellTags->"b:14.2.1"],
Cell[44546, 1485, 53, 1, 47, "Input"],
Cell[44602, 1488, 806, 26, 58, "Text",
  CellTags->"b:14.2.1"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[45457, 1520, 101, 2, 42, "Section",
  CellTags->{"b:14.3", "Measurement", "c:14"}],
Cell[45561, 1524, 255, 5, 28, "Text",
  CellTags->"b:14.3"],

Cell[CellGroupData[{
Cell[45841, 1533, 218, 5, 69, "Subsection",
  CellTags->{"b:14.2.0", "Measurements", "c:15"}],
Cell[46062, 1540, 358, 9, 46, "Text",
  CellTags->"b:14.3"],
Cell[46423, 1551, 397, 8, 63, "Input",
  CellTags->"b:14.3"],
Cell[46823, 1561, 213, 4, 28, "Text",
  CellTags->"b:14.3"],
Cell[47039, 1567, 242, 5, 47, "Input",
  CellTags->"b:14.3"],
Cell[47284, 1574, 235, 4, 28, "Text",
  CellTags->"b:14.3"],
Cell[47522, 1580, 168, 4, 47, "Input",
  CellTags->"b:14.3"],
Cell[47693, 1586, 234, 4, 28, "Text",
  CellTags->"b:14.3"],
Cell[47930, 1592, 123, 3, 63, "Input",
  CellTags->"b:14.3"],
Cell[48056, 1597, 189, 4, 28, "Text",
  CellTags->"b:14.3"],
Cell[48248, 1603, 101, 2, 63, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[48386, 1610, 229, 5, 69, "Subsection",
  CellTags->{"b:14.2.0", "Measurements", "MeasureKet", "c:16"}],
Cell[48618, 1617, 175, 4, 28, "Text",
  CellTags->"b:14.3"],
Cell[48796, 1623, 345, 7, 63, "Input",
  CellTags->"b:14.3"],
Cell[49144, 1632, 197, 4, 28, "Text",
  CellTags->"b:14.3"],
Cell[49344, 1638, 230, 4, 28, "Text",
  CellTags->"b:14.3"],
Cell[49577, 1644, 107, 2, 47, "Input",
  CellTags->"b:14.3"],
Cell[49687, 1648, 238, 4, 28, "Text",
  CellTags->"b:14.3"],
Cell[49928, 1654, 66, 2, 47, "Input",
  CellTags->"b:14.3"],
Cell[49997, 1658, 173, 4, 28, "Text",
  CellTags->"b:14.3"],
Cell[50173, 1664, 86, 1, 47, "Input"],
Cell[50262, 1667, 50, 1, 47, "Input"],
Cell[50315, 1670, 173, 4, 28, "Text",
  CellTags->"b:14.3"]
}, Closed]],

Cell[CellGroupData[{
Cell[50525, 1679, 216, 5, 69, "Subsection",
  CellTags->{"b:14.2.0", "c:17"}],
Cell[50744, 1686, 154, 4, 63, "Input"],
Cell[50901, 1692, 204, 4, 28, "Text",
  CellTags->"b:14.3"],
Cell[51108, 1698, 528, 10, 95, "Input",
  CellTags->"b:14.3"],
Cell[51639, 1710, 225, 4, 58, "Text",
  CellTags->"b:14.3"],
Cell[51867, 1716, 281, 5, 47, "Input",
  CellTags->"b:14.3"],
Cell[52151, 1723, 274, 8, 28, "Text",
  CellTags->"b:14.3"],
Cell[52428, 1733, 235, 4, 28, "Text",
  CellTags->"b:14.3"],
Cell[52666, 1739, 221, 5, 47, "Input",
  CellTags->"b:14.3"],
Cell[52890, 1746, 284, 5, 58, "Text",
  CellTags->"b:14.3"],
Cell[53177, 1753, 74, 2, 47, "Input",
  CellTags->"b:14.3"],
Cell[53254, 1757, 464, 7, 118, "Text",
  CellTags->"b:14.3"],
Cell[53721, 1766, 145, 3, 28, "Text",
  CellTags->"b:14.3"],
Cell[53869, 1771, 410, 14, 27, "Text",
  CellTags->"b:14.3"],
Cell[54282, 1787, 147, 3, 47, "Input"],
Cell[54432, 1792, 153, 3, 47, "Input"],
Cell[54588, 1797, 63, 1, 47, "Input"],
Cell[54654, 1800, 75, 1, 47, "Input"],
Cell[54732, 1803, 249, 5, 28, "Text",
  CellTags->"b:14.3"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[55030, 1814, 102, 2, 42, "Section",
  CellTags->{"b:14.3", "Measurement", "c:18"}],

Cell[CellGroupData[{
Cell[55157, 1820, 120, 3, 69, "Subsection",
  CellTags->{"b:11.0.0", "c:19"}],
Cell[55280, 1825, 197, 4, 28, "Text",
  CellTags->"b:14.1"],
Cell[55480, 1831, 681, 21, 58, "Text",
  CellTags->"b:14.1"],
Cell[56164, 1854, 299, 9, 28, "Text",
  CellTags->"b:14.1"],
Cell[56466, 1865, 511, 13, 79, "Input",
  CellTags->"b:14.1"],
Cell[56980, 1880, 140, 3, 28, "Text",
  CellTags->"b:14.1"],
Cell[57123, 1885, 211, 5, 95, "Input",
  CellTags->"b:14.1"],
Cell[57337, 1892, 135, 3, 28, "Text",
  CellTags->"b:14.1"],
Cell[57475, 1897, 566, 12, 95, "Input"],
Cell[58044, 1911, 256, 9, 28, "Text",
  CellTags->"b:14.3"]
}, Open  ]],

Cell[CellGroupData[{
Cell[58337, 1925, 109, 3, 69, "Subsection",
  CellTags->{"b:11.0.0", "c:20"}],
Cell[58449, 1930, 386, 11, 33, "Text",
  CellTags->"b:14.1"],
Cell[58838, 1943, 133, 3, 63, "Input",
  CellTags->"b:14.1"],
Cell[58974, 1948, 132, 3, 28, "Text",
  CellTags->"b:14.1"],
Cell[59109, 1953, 139, 3, 63, "Input",
  CellTags->"b:14.1"],
Cell[59251, 1958, 163, 3, 28, "Text",
  CellTags->"b:14.1"],
Cell[59417, 1963, 57, 1, 47, "Input"],
Cell[59477, 1966, 193, 4, 28, "Text",
  CellTags->"b:14.1"],
Cell[59673, 1972, 345, 7, 79, "Input"],
Cell[60021, 1981, 358, 8, 79, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[60416, 1994, 108, 3, 53, "Subsection",
  CellTags->{"c:4", "b:6.0.1"}],
Cell[60527, 1999, 165, 4, 28, "Text"],
Cell[60695, 2005, 421, 12, 47, "Input",
  CellTags->"b:6.0.1"],
Cell[61119, 2019, 117, 2, 28, "Text",
  CellTags->"b:6.0.1"],
Cell[61239, 2023, 178, 5, 63, "Input",
  CellTags->"b:6.0.1"],
Cell[61420, 2030, 45, 1, 43, "Input"],
Cell[61468, 2033, 182, 4, 47, "Input",
  CellTags->"b:6.0.1"],
Cell[61653, 2039, 234, 5, 26, "Text",
  CellTags->"b:6.0.1"],
Cell[61890, 2046, 475, 15, 49, "Input",
  CellTags->"b:6.0.1"],
Cell[62368, 2063, 101, 2, 28, "Text",
  CellTags->"b:6.0.1"],
Cell[62472, 2067, 181, 6, 49, "Input",
  CellTags->"b:6.0.1"],
Cell[62656, 2075, 319, 10, 67, "Input"],
Cell[62978, 2087, 319, 10, 67, "Input"],
Cell[63300, 2099, 319, 10, 67, "Input"],
Cell[63622, 2111, 337, 9, 178, "Text",
  CellTags->"b:6.0.1"],
Cell[63962, 2122, 244, 8, 49, "Input"],
Cell[64209, 2132, 4845, 163, 271, "Input",
  CellTags->"b:6.0.1"],
Cell[69057, 2297, 177, 4, 95, "Input"],
Cell[69237, 2303, 104, 2, 28, "Text",
  CellTags->"b:6.0.1"],
Cell[69344, 2307, 248, 5, 73, "Input"],
Cell[69595, 2314, 121, 2, 28, "Text",
  CellTags->"b:6.0.1"],
Cell[69719, 2318, 252, 4, 63, "Input"],
Cell[69974, 2324, 123, 2, 27, "Text",
  CellTags->"b:6.0.1"],
Cell[70100, 2328, 114, 3, 47, "Input"],
Cell[70217, 2333, 214, 5, 58, "Text",
  CellTags->"b:6.0.1"],
Cell[70434, 2340, 263, 7, 47, "Input"],
Cell[70700, 2349, 56, 1, 47, "Input"],
Cell[70759, 2352, 1468, 32, 287, "Input"],
Cell[72230, 2386, 109, 2, 28, "Text",
  CellTags->"b:6.0.1"],
Cell[72342, 2390, 50, 1, 47, "Input"],
Cell[72395, 2393, 193, 6, 58, "Text",
  CellTags->"b:6.0.1"],
Cell[72591, 2401, 145, 4, 28, "Text",
  CellTags->"b:6.0.1"],
Cell[72739, 2407, 284, 8, 63, "Input"],
Cell[73026, 2417, 284, 8, 63, "Input"],
Cell[73313, 2427, 284, 8, 63, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[73634, 2440, 117, 3, 53, "Subsection",
  CellTags->{"c:4", "b:6.0.1"}],
Cell[73754, 2445, 154, 4, 28, "Text"],

Cell[CellGroupData[{
Cell[73933, 2453, 297, 8, 63, "Subsubsection",
  CellTags->{"c:4", "b:6.0.1"}],
Cell[74233, 2463, 452, 10, 44, "Text",
  CellTags->"b:6.0.1"],
Cell[74688, 2475, 762, 22, 148, "Text",
  CellTags->"b:14.1"],
Cell[75453, 2499, 209, 4, 28, "Text",
  CellTags->"b:14.1"],
Cell[75665, 2505, 104, 2, 47, "Input"],
Cell[75772, 2509, 151, 3, 28, "Text",
  CellTags->"b:14.1"],
Cell[75926, 2514, 618, 17, 47, "Input"],
Cell[76547, 2533, 163, 4, 95, "Input"],
Cell[76713, 2539, 354, 6, 46, "Text",
  CellTags->"b:14.1"],
Cell[77070, 2547, 1404, 39, 48, "Input"],
Cell[78477, 2588, 184, 4, 28, "Text",
  CellTags->"b:14.1"],
Cell[78664, 2594, 556, 16, 63, "Input"],
Cell[79223, 2612, 206, 4, 28, "Text",
  CellTags->"b:14.1"],
Cell[79432, 2618, 805, 20, 95, "Input"],
Cell[80240, 2640, 207, 4, 28, "Text",
  CellTags->"b:14.1"],
Cell[80450, 2646, 1327, 32, 95, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[81814, 2683, 325, 9, 63, "Subsubsection",
  CellTags->{"c:4", "b:6.0.1"}],
Cell[82142, 2694, 169, 5, 58, "Text",
  CellTags->"b:6.0.1"],
Cell[82314, 2701, 2506, 83, 159, "Input",
  CellTags->"b:6.0.1"],
Cell[84823, 2786, 178, 5, 58, "Text",
  CellTags->"b:6.0.1"],
Cell[85004, 2793, 112, 2, 28, "Text",
  CellTags->"b:6.0.1"],
Cell[85119, 2797, 92, 2, 28, "Text",
  CellTags->"b:6.0.1"],
Cell[85214, 2801, 830, 28, 63, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[86081, 2834, 292, 8, 63, "Subsubsection",
  CellTags->{"c:4", "b:6.0.1"}],
Cell[86376, 2844, 205, 6, 58, "Text",
  CellTags->"b:6.0.1"],
Cell[86584, 2852, 417, 9, 92, "Input"],
Cell[87004, 2863, 669, 22, 58, "Text",
  CellTags->"b:6.0.1"],
Cell[87676, 2887, 416, 7, 79, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[88129, 2899, 318, 8, 63, "Subsubsection",
  CellTags->{"c:4", "b:6.0.1"}],
Cell[88450, 2909, 81, 2, 28, "Text",
  CellTags->"b:6.0.1"],
Cell[88534, 2913, 1820, 48, 111, "Input"],
Cell[90357, 2963, 82, 2, 28, "Text",
  CellTags->"b:6.0.1"],
Cell[90442, 2967, 1528, 40, 95, "Input"],
Cell[91973, 3009, 115, 4, 28, "Text",
  CellTags->"b:6.0.1"],
Cell[92091, 3015, 474, 12, 47, "Input"],
Cell[92568, 3029, 246, 7, 47, "Input"],
Cell[92817, 3038, 246, 7, 47, "Input"],
Cell[93066, 3047, 246, 7, 47, "Input"],
Cell[93315, 3056, 246, 7, 47, "Input"],
Cell[93564, 3065, 102, 2, 28, "Text",
  CellTags->"b:6.0.1"],
Cell[93669, 3069, 86, 2, 28, "Text",
  CellTags->"b:6.0.1"],
Cell[93758, 3073, 572, 17, 63, "Input"],
Cell[94333, 3092, 96, 2, 28, "Text",
  CellTags->"b:6.0.1"],
Cell[94432, 3096, 90, 2, 63, "Input"],
Cell[94525, 3100, 86, 2, 28, "Text",
  CellTags->"b:6.0.1"],
Cell[94614, 3104, 572, 17, 63, "Input"],
Cell[95189, 3123, 96, 2, 28, "Text",
  CellTags->"b:6.0.1"],
Cell[95288, 3127, 90, 2, 63, "Input"],
Cell[95381, 3131, 92, 2, 28, "Text",
  CellTags->"b:6.0.1"],
Cell[95476, 3135, 133, 2, 63, "Input"],
Cell[95612, 3139, 113, 2, 28, "Text",
  CellTags->"b:6.0.1"],
Cell[95728, 3143, 430, 11, 47, "Input"],
Cell[96161, 3156, 185, 4, 95, "Input"],
Cell[96349, 3162, 266, 5, 95, "Input"],
Cell[96618, 3169, 77, 1, 47, "Input"],
Cell[96698, 3172, 77, 1, 47, "Input"]
}, Closed]]
}, Closed]]
}, Closed]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

